Case study: Lorenz attractor
============================

This notebook contains a full TDA pipeline to analyse the transitions of
the Lorenz system to a chaotic regime from the stable one and viceversa.

If you are looking at a static version of this notebook and would like
to run its contents, head over to
`github <https://github.com/giotto-ai/giotto-tda/blob/master/examples/lorenz_attractor.ipynb>`__.

**License: AGPLv3**

Import libraries
----------------

The first step consists in importing relevant *gtda* components and
other useful libraries or modules.

.. code:: ipython3

    # Import the gtda modules
    from gtda.time_series import Resampler, TakensEmbedding, SlidingWindow, PermutationEntropy
    from gtda.homology import VietorisRipsPersistence
    from gtda.diagrams import Scaler, Filtering, PersistenceEntropy, BettiCurve, PairwiseDistance
    from gtda.graphs import KNeighborsGraph, GraphGeodesicDistance
    
    from gtda.pipeline import Pipeline
    
    import numpy as np
    from sklearn.metrics import pairwise_distances
    
    import plotly.express as px
    from plotly.offline import init_notebook_mode, iplot
    init_notebook_mode(connected=True)
    
    # gtda plotting functions
    from gtda.plotting import plot_heatmap
    
    # Import data from openml
    import openml



.. raw:: html

    <script type="text/javascript">
    window.PlotlyConfig = {MathJaxConfig: 'local'};
    if (window.MathJax) {MathJax.Hub.Config({SVG: {font: "STIX-Web"}});}
    if (typeof require !== 'undefined') {
    require.undef("plotly");
    requirejs.config({
        paths: {
            'plotly': ['https://cdn.plot.ly/plotly-latest.min']
        }
    });
    require(['plotly'], function(Plotly) {
        window._Plotly = Plotly;
    });
    }
    </script>



.. code:: ipython3

    # Plotting functions
    from gtda.plotting import plot_diagram, plot_betti_surfaces
    from gtda.plotting import plot_point_cloud

Setting up the Lorenz attractor simulation
------------------------------------------

In the next block we set up all the parameters of the Lorenz system and
we define also the instants at which the regime (stable VS chaotic)
changes.

.. code:: ipython3

    # Plotting the trajectories of the Lorenz system
    from openml.datasets.functions import get_dataset
    
    point_cloud = get_dataset(42182).get_data(dataset_format='array')[0]
    plot_point_cloud(point_cloud)



.. raw:: html

    <div>
    
    
                <div id="90eb7b0c-ff92-438a-8f70-6c4c069612d7" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("90eb7b0c-ff92-438a-8f70-6c4c069612d7")) {
                        Plotly.newPlot(
                            '90eb7b0c-ff92-438a-8f70-6c4c069612d7',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 474, 475, 476, 477, 478, 479, 480, 481, 482, 483, 484, 485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 664, 665, 666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676, 677, 678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 755, 756, 757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820, 821, 822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832, 833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844, 845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856, 857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868, 869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898, 899, 900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 912, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924, 925, 926, 927, 928, 929, 930, 931, 932, 933, 934, 935, 936, 937, 938, 939, 940, 941, 942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988, 989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000, 1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320, 1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341, 1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451, 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541, 1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571, 1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591, 1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650, 1651, 1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660, 1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670, 1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680, 1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720, 1721, 1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731, 1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761, 1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781, 1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 1855, 1856, 1857, 1858, 1859, 1860, 1861, 1862, 1863, 1864, 1865, 1866, 1867, 1868, 1869, 1870, 1871, 1872, 1873, 1874, 1875, 1876, 1877, 1878, 1879, 1880, 1881, 1882, 1883, 1884, 1885, 1886, 1887, 1888, 1889, 1890, 1891, 1892, 1893, 1894, 1895, 1896, 1897, 1898, 1899, 1900, 1901, 1902, 1903, 1904, 1905, 1906, 1907, 1908, 1909, 1910, 1911, 1912, 1913, 1914, 1915, 1916, 1917, 1918, 1919, 1920, 1921, 1922, 1923, 1924, 1925, 1926, 1927, 1928, 1929, 1930, 1931, 1932, 1933, 1934, 1935, 1936, 1937, 1938, 1939, 1940, 1941, 1942, 1943, 1944, 1945, 1946, 1947, 1948, 1949, 1950, 1951, 1952, 1953, 1954, 1955, 1956, 1957, 1958, 1959, 1960, 1961, 1962, 1963, 1964, 1965, 1966, 1967, 1968, 1969, 1970, 1971, 1972, 1973, 1974, 1975, 1976, 1977, 1978, 1979, 1980, 1981, 1982, 1983, 1984, 1985, 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024, 2025, 2026, 2027, 2028, 2029, 2030, 2031, 2032, 2033, 2034, 2035, 2036, 2037, 2038, 2039, 2040, 2041, 2042, 2043, 2044, 2045, 2046, 2047, 2048, 2049, 2050, 2051, 2052, 2053, 2054, 2055, 2056, 2057, 2058, 2059, 2060, 2061, 2062, 2063, 2064, 2065, 2066, 2067, 2068, 2069, 2070, 2071, 2072, 2073, 2074, 2075, 2076, 2077, 2078, 2079, 2080, 2081, 2082, 2083, 2084, 2085, 2086, 2087, 2088, 2089, 2090, 2091, 2092, 2093, 2094, 2095, 2096, 2097, 2098, 2099, 2100, 2101, 2102, 2103, 2104, 2105, 2106, 2107, 2108, 2109, 2110, 2111, 2112, 2113, 2114, 2115, 2116, 2117, 2118, 2119, 2120, 2121, 2122, 2123, 2124, 2125, 2126, 2127, 2128, 2129, 2130, 2131, 2132, 2133, 2134, 2135, 2136, 2137, 2138, 2139, 2140, 2141, 2142, 2143, 2144, 2145, 2146, 2147, 2148, 2149, 2150, 2151, 2152, 2153, 2154, 2155, 2156, 2157, 2158, 2159, 2160, 2161, 2162, 2163, 2164, 2165, 2166, 2167, 2168, 2169, 2170, 2171, 2172, 2173, 2174, 2175, 2176, 2177, 2178, 2179, 2180, 2181, 2182, 2183, 2184, 2185, 2186, 2187, 2188, 2189, 2190, 2191, 2192, 2193, 2194, 2195, 2196, 2197, 2198, 2199, 2200, 2201, 2202, 2203, 2204, 2205, 2206, 2207, 2208, 2209, 2210, 2211, 2212, 2213, 2214, 2215, 2216, 2217, 2218, 2219, 2220, 2221, 2222, 2223, 2224, 2225, 2226, 2227, 2228, 2229, 2230, 2231, 2232, 2233, 2234, 2235, 2236, 2237, 2238, 2239, 2240, 2241, 2242, 2243, 2244, 2245, 2246, 2247, 2248, 2249, 2250, 2251, 2252, 2253, 2254, 2255, 2256, 2257, 2258, 2259, 2260, 2261, 2262, 2263, 2264, 2265, 2266, 2267, 2268, 2269, 2270, 2271, 2272, 2273, 2274, 2275, 2276, 2277, 2278, 2279, 2280, 2281, 2282, 2283, 2284, 2285, 2286, 2287, 2288, 2289, 2290, 2291, 2292, 2293, 2294, 2295, 2296, 2297, 2298, 2299, 2300, 2301, 2302, 2303, 2304, 2305, 2306, 2307, 2308, 2309, 2310, 2311, 2312, 2313, 2314, 2315, 2316, 2317, 2318, 2319, 2320, 2321, 2322, 2323, 2324, 2325, 2326, 2327, 2328, 2329, 2330, 2331, 2332, 2333, 2334, 2335, 2336, 2337, 2338, 2339, 2340, 2341, 2342, 2343, 2344, 2345, 2346, 2347, 2348, 2349, 2350, 2351, 2352, 2353, 2354, 2355, 2356, 2357, 2358, 2359, 2360, 2361, 2362, 2363, 2364, 2365, 2366, 2367, 2368, 2369, 2370, 2371, 2372, 2373, 2374, 2375, 2376, 2377, 2378, 2379, 2380, 2381, 2382, 2383, 2384, 2385, 2386, 2387, 2388, 2389, 2390, 2391, 2392, 2393, 2394, 2395, 2396, 2397, 2398, 2399, 2400, 2401, 2402, 2403, 2404, 2405, 2406, 2407, 2408, 2409, 2410, 2411, 2412, 2413, 2414, 2415, 2416, 2417, 2418, 2419, 2420, 2421, 2422, 2423, 2424, 2425, 2426, 2427, 2428, 2429, 2430, 2431, 2432, 2433, 2434, 2435, 2436, 2437, 2438, 2439, 2440, 2441, 2442, 2443, 2444, 2445, 2446, 2447, 2448, 2449, 2450, 2451, 2452, 2453, 2454, 2455, 2456, 2457, 2458, 2459, 2460, 2461, 2462, 2463, 2464, 2465, 2466, 2467, 2468, 2469, 2470, 2471, 2472, 2473, 2474, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486, 2487, 2488, 2489, 2490, 2491, 2492, 2493, 2494, 2495, 2496, 2497, 2498, 2499, 2500, 2501, 2502, 2503, 2504, 2505, 2506, 2507, 2508, 2509, 2510, 2511, 2512, 2513, 2514, 2515, 2516, 2517, 2518, 2519, 2520, 2521, 2522, 2523, 2524, 2525, 2526, 2527, 2528, 2529, 2530, 2531, 2532, 2533, 2534, 2535, 2536, 2537, 2538, 2539, 2540, 2541, 2542, 2543, 2544, 2545, 2546, 2547, 2548, 2549, 2550, 2551, 2552, 2553, 2554, 2555, 2556, 2557, 2558, 2559, 2560, 2561, 2562, 2563, 2564, 2565, 2566, 2567, 2568, 2569, 2570, 2571, 2572, 2573, 2574, 2575, 2576, 2577, 2578, 2579, 2580, 2581, 2582, 2583, 2584, 2585, 2586, 2587, 2588, 2589, 2590, 2591, 2592, 2593, 2594, 2595, 2596, 2597, 2598, 2599, 2600, 2601, 2602, 2603, 2604, 2605, 2606, 2607, 2608, 2609, 2610, 2611, 2612, 2613, 2614, 2615, 2616, 2617, 2618, 2619, 2620, 2621, 2622, 2623, 2624, 2625, 2626, 2627, 2628, 2629, 2630, 2631, 2632, 2633, 2634, 2635, 2636, 2637, 2638, 2639, 2640, 2641, 2642, 2643, 2644, 2645, 2646, 2647, 2648, 2649, 2650, 2651, 2652, 2653, 2654, 2655, 2656, 2657, 2658, 2659, 2660, 2661, 2662, 2663, 2664, 2665, 2666, 2667, 2668, 2669, 2670, 2671, 2672, 2673, 2674, 2675, 2676, 2677, 2678, 2679, 2680, 2681, 2682, 2683, 2684, 2685, 2686, 2687, 2688, 2689, 2690, 2691, 2692, 2693, 2694, 2695, 2696, 2697, 2698, 2699, 2700, 2701, 2702, 2703, 2704, 2705, 2706, 2707, 2708, 2709, 2710, 2711, 2712, 2713, 2714, 2715, 2716, 2717, 2718, 2719, 2720, 2721, 2722, 2723, 2724, 2725, 2726, 2727, 2728, 2729, 2730, 2731, 2732, 2733, 2734, 2735, 2736, 2737, 2738, 2739, 2740, 2741, 2742, 2743, 2744, 2745, 2746, 2747, 2748, 2749, 2750, 2751, 2752, 2753, 2754, 2755, 2756, 2757, 2758, 2759, 2760, 2761, 2762, 2763, 2764, 2765, 2766, 2767, 2768, 2769, 2770, 2771, 2772, 2773, 2774, 2775, 2776, 2777, 2778, 2779, 2780, 2781, 2782, 2783, 2784, 2785, 2786, 2787, 2788, 2789, 2790, 2791, 2792, 2793, 2794, 2795, 2796, 2797, 2798, 2799, 2800, 2801, 2802, 2803, 2804, 2805, 2806, 2807, 2808, 2809, 2810, 2811, 2812, 2813, 2814, 2815, 2816, 2817, 2818, 2819, 2820, 2821, 2822, 2823, 2824, 2825, 2826, 2827, 2828, 2829, 2830, 2831, 2832, 2833, 2834, 2835, 2836, 2837, 2838, 2839, 2840, 2841, 2842, 2843, 2844, 2845, 2846, 2847, 2848, 2849, 2850, 2851, 2852, 2853, 2854, 2855, 2856, 2857, 2858, 2859, 2860, 2861, 2862, 2863, 2864, 2865, 2866, 2867, 2868, 2869, 2870, 2871, 2872, 2873, 2874, 2875, 2876, 2877, 2878, 2879, 2880, 2881, 2882, 2883, 2884, 2885, 2886, 2887, 2888, 2889, 2890, 2891, 2892, 2893, 2894, 2895, 2896, 2897, 2898, 2899, 2900, 2901, 2902, 2903, 2904, 2905, 2906, 2907, 2908, 2909, 2910, 2911, 2912, 2913, 2914, 2915, 2916, 2917, 2918, 2919, 2920, 2921, 2922, 2923, 2924, 2925, 2926, 2927, 2928, 2929, 2930, 2931, 2932, 2933, 2934, 2935, 2936, 2937, 2938, 2939, 2940, 2941, 2942, 2943, 2944, 2945, 2946, 2947, 2948, 2949, 2950, 2951, 2952, 2953, 2954, 2955, 2956, 2957, 2958, 2959, 2960, 2961, 2962, 2963, 2964, 2965, 2966, 2967, 2968, 2969, 2970, 2971, 2972, 2973, 2974, 2975, 2976, 2977, 2978, 2979, 2980, 2981, 2982, 2983, 2984, 2985, 2986, 2987, 2988, 2989, 2990, 2991, 2992, 2993, 2994, 2995, 2996, 2997, 2998, 2999, 3000, 3001, 3002, 3003, 3004, 3005, 3006, 3007, 3008, 3009, 3010, 3011, 3012, 3013, 3014, 3015, 3016, 3017, 3018, 3019, 3020, 3021, 3022, 3023, 3024, 3025, 3026, 3027, 3028, 3029, 3030, 3031, 3032, 3033, 3034, 3035, 3036, 3037, 3038, 3039, 3040, 3041, 3042, 3043, 3044, 3045, 3046, 3047, 3048, 3049, 3050, 3051, 3052, 3053, 3054, 3055, 3056, 3057, 3058, 3059, 3060, 3061, 3062, 3063, 3064, 3065, 3066, 3067, 3068, 3069, 3070, 3071, 3072, 3073, 3074, 3075, 3076, 3077, 3078, 3079, 3080, 3081, 3082, 3083, 3084, 3085, 3086, 3087, 3088, 3089, 3090, 3091, 3092, 3093, 3094, 3095, 3096, 3097, 3098, 3099, 3100, 3101, 3102, 3103, 3104, 3105, 3106, 3107, 3108, 3109, 3110, 3111, 3112, 3113, 3114, 3115, 3116, 3117, 3118, 3119, 3120, 3121, 3122, 3123, 3124, 3125, 3126, 3127, 3128, 3129, 3130, 3131, 3132, 3133, 3134, 3135, 3136, 3137, 3138, 3139, 3140, 3141, 3142, 3143, 3144, 3145, 3146, 3147, 3148, 3149, 3150, 3151, 3152, 3153, 3154, 3155, 3156, 3157, 3158, 3159, 3160, 3161, 3162, 3163, 3164, 3165, 3166, 3167, 3168, 3169, 3170, 3171, 3172, 3173, 3174, 3175, 3176, 3177, 3178, 3179, 3180, 3181, 3182, 3183, 3184, 3185, 3186, 3187, 3188, 3189, 3190, 3191, 3192, 3193, 3194, 3195, 3196, 3197, 3198, 3199, 3200, 3201, 3202, 3203, 3204, 3205, 3206, 3207, 3208, 3209, 3210, 3211, 3212, 3213, 3214, 3215, 3216, 3217, 3218, 3219, 3220, 3221, 3222, 3223, 3224, 3225, 3226, 3227, 3228, 3229, 3230, 3231, 3232, 3233, 3234, 3235, 3236, 3237, 3238, 3239, 3240, 3241, 3242, 3243, 3244, 3245, 3246, 3247, 3248, 3249, 3250, 3251, 3252, 3253, 3254, 3255, 3256, 3257, 3258, 3259, 3260, 3261, 3262, 3263, 3264, 3265, 3266, 3267, 3268, 3269, 3270, 3271, 3272, 3273, 3274, 3275, 3276, 3277, 3278, 3279, 3280, 3281, 3282, 3283, 3284, 3285, 3286, 3287, 3288, 3289, 3290, 3291, 3292, 3293, 3294, 3295, 3296, 3297, 3298, 3299, 3300, 3301, 3302, 3303, 3304, 3305, 3306, 3307, 3308, 3309, 3310, 3311, 3312, 3313, 3314, 3315, 3316, 3317, 3318, 3319, 3320, 3321, 3322, 3323, 3324, 3325, 3326, 3327, 3328, 3329, 3330, 3331, 3332, 3333, 3334, 3335, 3336, 3337, 3338, 3339, 3340, 3341, 3342, 3343, 3344, 3345, 3346, 3347, 3348, 3349, 3350, 3351, 3352, 3353, 3354, 3355, 3356, 3357, 3358, 3359, 3360, 3361, 3362, 3363, 3364, 3365, 3366, 3367, 3368, 3369, 3370, 3371, 3372, 3373, 3374, 3375, 3376, 3377, 3378, 3379, 3380, 3381, 3382, 3383, 3384, 3385, 3386, 3387, 3388, 3389, 3390, 3391, 3392, 3393, 3394, 3395, 3396, 3397, 3398, 3399, 3400, 3401, 3402, 3403, 3404, 3405, 3406, 3407, 3408, 3409, 3410, 3411, 3412, 3413, 3414, 3415, 3416, 3417, 3418, 3419, 3420, 3421, 3422, 3423, 3424, 3425, 3426, 3427, 3428, 3429, 3430, 3431, 3432, 3433, 3434, 3435, 3436, 3437, 3438, 3439, 3440, 3441, 3442, 3443, 3444, 3445, 3446, 3447, 3448, 3449, 3450, 3451, 3452, 3453, 3454, 3455, 3456, 3457, 3458, 3459, 3460, 3461, 3462, 3463, 3464, 3465, 3466, 3467, 3468, 3469, 3470, 3471, 3472, 3473, 3474, 3475, 3476, 3477, 3478, 3479, 3480, 3481, 3482, 3483, 3484, 3485, 3486, 3487, 3488, 3489, 3490, 3491, 3492, 3493, 3494, 3495, 3496, 3497, 3498, 3499, 3500, 3501, 3502, 3503, 3504, 3505, 3506, 3507, 3508, 3509, 3510, 3511, 3512, 3513, 3514, 3515, 3516, 3517, 3518, 3519, 3520, 3521, 3522, 3523, 3524, 3525, 3526, 3527, 3528, 3529, 3530, 3531, 3532, 3533, 3534, 3535, 3536, 3537, 3538, 3539, 3540, 3541, 3542, 3543, 3544, 3545, 3546, 3547, 3548, 3549, 3550, 3551, 3552, 3553, 3554, 3555, 3556, 3557, 3558, 3559, 3560, 3561, 3562, 3563, 3564, 3565, 3566, 3567, 3568, 3569, 3570, 3571, 3572, 3573, 3574, 3575, 3576, 3577, 3578, 3579, 3580, 3581, 3582, 3583, 3584, 3585, 3586, 3587, 3588, 3589, 3590, 3591, 3592, 3593, 3594, 3595, 3596, 3597, 3598, 3599, 3600, 3601, 3602, 3603, 3604, 3605, 3606, 3607, 3608, 3609, 3610, 3611, 3612, 3613, 3614, 3615, 3616, 3617, 3618, 3619, 3620, 3621, 3622, 3623, 3624, 3625, 3626, 3627, 3628, 3629, 3630, 3631, 3632, 3633, 3634, 3635, 3636, 3637, 3638, 3639, 3640, 3641, 3642, 3643, 3644, 3645, 3646, 3647, 3648, 3649, 3650, 3651, 3652, 3653, 3654, 3655, 3656, 3657, 3658, 3659, 3660, 3661, 3662, 3663, 3664, 3665, 3666, 3667, 3668, 3669, 3670, 3671, 3672, 3673, 3674, 3675, 3676, 3677, 3678, 3679, 3680, 3681, 3682, 3683, 3684, 3685, 3686, 3687, 3688, 3689, 3690, 3691, 3692, 3693, 3694, 3695, 3696, 3697, 3698, 3699, 3700, 3701, 3702, 3703, 3704, 3705, 3706, 3707, 3708, 3709, 3710, 3711, 3712, 3713, 3714, 3715, 3716, 3717, 3718, 3719, 3720, 3721, 3722, 3723, 3724, 3725, 3726, 3727, 3728, 3729, 3730, 3731, 3732, 3733, 3734, 3735, 3736, 3737, 3738, 3739, 3740, 3741, 3742, 3743, 3744, 3745, 3746, 3747, 3748, 3749, 3750, 3751, 3752, 3753, 3754, 3755, 3756, 3757, 3758, 3759, 3760, 3761, 3762, 3763, 3764, 3765, 3766, 3767, 3768, 3769, 3770, 3771, 3772, 3773, 3774, 3775, 3776, 3777, 3778, 3779, 3780, 3781, 3782, 3783, 3784, 3785, 3786, 3787, 3788, 3789, 3790, 3791, 3792, 3793, 3794, 3795, 3796, 3797, 3798, 3799, 3800, 3801, 3802, 3803, 3804, 3805, 3806, 3807, 3808, 3809, 3810, 3811, 3812, 3813, 3814, 3815, 3816, 3817, 3818, 3819, 3820, 3821, 3822, 3823, 3824, 3825, 3826, 3827, 3828, 3829, 3830, 3831, 3832, 3833, 3834, 3835, 3836, 3837, 3838, 3839, 3840, 3841, 3842, 3843, 3844, 3845, 3846, 3847, 3848, 3849, 3850, 3851, 3852, 3853, 3854, 3855, 3856, 3857, 3858, 3859, 3860, 3861, 3862, 3863, 3864, 3865, 3866, 3867, 3868, 3869, 3870, 3871, 3872, 3873, 3874, 3875, 3876, 3877, 3878, 3879, 3880, 3881, 3882, 3883, 3884, 3885, 3886, 3887, 3888, 3889, 3890, 3891, 3892, 3893, 3894, 3895, 3896, 3897, 3898, 3899, 3900, 3901, 3902, 3903, 3904, 3905, 3906, 3907, 3908, 3909, 3910, 3911, 3912, 3913, 3914, 3915, 3916, 3917, 3918, 3919, 3920, 3921, 3922, 3923, 3924, 3925, 3926, 3927, 3928, 3929, 3930, 3931, 3932, 3933, 3934, 3935, 3936, 3937, 3938, 3939, 3940, 3941, 3942, 3943, 3944, 3945, 3946, 3947, 3948, 3949, 3950, 3951, 3952, 3953, 3954, 3955, 3956, 3957, 3958, 3959, 3960, 3961, 3962, 3963, 3964, 3965, 3966, 3967, 3968, 3969, 3970, 3971, 3972, 3973, 3974, 3975, 3976, 3977, 3978, 3979, 3980, 3981, 3982, 3983, 3984, 3985, 3986, 3987, 3988, 3989, 3990, 3991, 3992, 3993, 3994, 3995, 3996, 3997, 3998, 3999, 4000, 4001, 4002, 4003, 4004, 4005, 4006, 4007, 4008, 4009, 4010, 4011, 4012, 4013, 4014, 4015, 4016, 4017, 4018, 4019, 4020, 4021, 4022, 4023, 4024, 4025, 4026, 4027, 4028, 4029, 4030, 4031, 4032, 4033, 4034, 4035, 4036, 4037, 4038, 4039, 4040, 4041, 4042, 4043, 4044, 4045, 4046, 4047, 4048, 4049, 4050, 4051, 4052, 4053, 4054, 4055, 4056, 4057, 4058, 4059, 4060, 4061, 4062, 4063, 4064, 4065, 4066, 4067, 4068, 4069, 4070, 4071, 4072, 4073, 4074, 4075, 4076, 4077, 4078, 4079, 4080, 4081, 4082, 4083, 4084, 4085, 4086, 4087, 4088, 4089, 4090, 4091, 4092, 4093, 4094, 4095, 4096, 4097, 4098, 4099, 4100, 4101, 4102, 4103, 4104, 4105, 4106, 4107, 4108, 4109, 4110, 4111, 4112, 4113, 4114, 4115, 4116, 4117, 4118, 4119, 4120, 4121, 4122, 4123, 4124, 4125, 4126, 4127, 4128, 4129, 4130, 4131, 4132, 4133, 4134, 4135, 4136, 4137, 4138, 4139, 4140, 4141, 4142, 4143, 4144, 4145, 4146, 4147, 4148, 4149, 4150, 4151, 4152, 4153, 4154, 4155, 4156, 4157, 4158, 4159, 4160, 4161, 4162, 4163, 4164, 4165, 4166, 4167, 4168, 4169, 4170, 4171, 4172, 4173, 4174, 4175, 4176, 4177, 4178, 4179, 4180, 4181, 4182, 4183, 4184, 4185, 4186, 4187, 4188, 4189, 4190, 4191, 4192, 4193, 4194, 4195, 4196, 4197, 4198, 4199, 4200, 4201, 4202, 4203, 4204, 4205, 4206, 4207, 4208, 4209, 4210, 4211, 4212, 4213, 4214, 4215, 4216, 4217, 4218, 4219, 4220, 4221, 4222, 4223, 4224, 4225, 4226, 4227, 4228, 4229, 4230, 4231, 4232, 4233, 4234, 4235, 4236, 4237, 4238, 4239, 4240, 4241, 4242, 4243, 4244, 4245, 4246, 4247, 4248, 4249, 4250, 4251, 4252, 4253, 4254, 4255, 4256, 4257, 4258, 4259, 4260, 4261, 4262, 4263, 4264, 4265, 4266, 4267, 4268, 4269, 4270, 4271, 4272, 4273, 4274, 4275, 4276, 4277, 4278, 4279, 4280, 4281, 4282, 4283, 4284, 4285, 4286, 4287, 4288, 4289, 4290, 4291, 4292, 4293, 4294, 4295, 4296, 4297, 4298, 4299, 4300, 4301, 4302, 4303, 4304, 4305, 4306, 4307, 4308, 4309, 4310, 4311, 4312, 4313, 4314, 4315, 4316, 4317, 4318, 4319, 4320, 4321, 4322, 4323, 4324, 4325, 4326, 4327, 4328, 4329, 4330, 4331, 4332, 4333, 4334, 4335, 4336, 4337, 4338, 4339, 4340, 4341, 4342, 4343, 4344, 4345, 4346, 4347, 4348, 4349, 4350, 4351, 4352, 4353, 4354, 4355, 4356, 4357, 4358, 4359, 4360, 4361, 4362, 4363, 4364, 4365, 4366, 4367, 4368, 4369, 4370, 4371, 4372, 4373, 4374, 4375, 4376, 4377, 4378, 4379, 4380, 4381, 4382, 4383, 4384, 4385, 4386, 4387, 4388, 4389, 4390, 4391, 4392, 4393, 4394, 4395, 4396, 4397, 4398, 4399, 4400, 4401, 4402, 4403, 4404, 4405, 4406, 4407, 4408, 4409, 4410, 4411, 4412, 4413, 4414, 4415, 4416, 4417, 4418, 4419, 4420, 4421, 4422, 4423, 4424, 4425, 4426, 4427, 4428, 4429, 4430, 4431, 4432, 4433, 4434, 4435, 4436, 4437, 4438, 4439, 4440, 4441, 4442, 4443, 4444, 4445, 4446, 4447, 4448, 4449, 4450, 4451, 4452, 4453, 4454, 4455, 4456, 4457, 4458, 4459, 4460, 4461, 4462, 4463, 4464, 4465, 4466, 4467, 4468, 4469, 4470, 4471, 4472, 4473, 4474, 4475, 4476, 4477, 4478, 4479, 4480, 4481, 4482, 4483, 4484, 4485, 4486, 4487, 4488, 4489, 4490, 4491, 4492, 4493, 4494, 4495, 4496, 4497, 4498, 4499, 4500, 4501, 4502, 4503, 4504, 4505, 4506, 4507, 4508, 4509, 4510, 4511, 4512, 4513, 4514, 4515, 4516, 4517, 4518, 4519, 4520, 4521, 4522, 4523, 4524, 4525, 4526, 4527, 4528, 4529, 4530, 4531, 4532, 4533, 4534, 4535, 4536, 4537, 4538, 4539, 4540, 4541, 4542, 4543, 4544, 4545, 4546, 4547, 4548, 4549, 4550, 4551, 4552, 4553, 4554, 4555, 4556, 4557, 4558, 4559, 4560, 4561, 4562, 4563, 4564, 4565, 4566, 4567, 4568, 4569, 4570, 4571, 4572, 4573, 4574, 4575, 4576, 4577, 4578, 4579, 4580, 4581, 4582, 4583, 4584, 4585, 4586, 4587, 4588, 4589, 4590, 4591, 4592, 4593, 4594, 4595, 4596, 4597, 4598, 4599, 4600, 4601, 4602, 4603, 4604, 4605, 4606, 4607, 4608, 4609, 4610, 4611, 4612, 4613, 4614, 4615, 4616, 4617, 4618, 4619, 4620, 4621, 4622, 4623, 4624, 4625, 4626, 4627, 4628, 4629, 4630, 4631, 4632, 4633, 4634, 4635, 4636, 4637, 4638, 4639, 4640, 4641, 4642, 4643, 4644, 4645, 4646, 4647, 4648, 4649, 4650, 4651, 4652, 4653, 4654, 4655, 4656, 4657, 4658, 4659, 4660, 4661, 4662, 4663, 4664, 4665, 4666, 4667, 4668, 4669, 4670, 4671, 4672, 4673, 4674, 4675, 4676, 4677, 4678, 4679, 4680, 4681, 4682, 4683, 4684, 4685, 4686, 4687, 4688, 4689, 4690, 4691, 4692, 4693, 4694, 4695, 4696, 4697, 4698, 4699, 4700, 4701, 4702, 4703, 4704, 4705, 4706, 4707, 4708, 4709, 4710, 4711, 4712, 4713, 4714, 4715, 4716, 4717, 4718, 4719, 4720, 4721, 4722, 4723, 4724, 4725, 4726, 4727, 4728, 4729, 4730, 4731, 4732, 4733, 4734, 4735, 4736, 4737, 4738, 4739, 4740, 4741, 4742, 4743, 4744, 4745, 4746, 4747, 4748, 4749, 4750, 4751, 4752, 4753, 4754, 4755, 4756, 4757, 4758, 4759, 4760, 4761, 4762, 4763, 4764, 4765, 4766, 4767, 4768, 4769, 4770, 4771, 4772, 4773, 4774, 4775, 4776, 4777, 4778, 4779, 4780, 4781, 4782, 4783, 4784, 4785, 4786, 4787, 4788, 4789, 4790, 4791, 4792, 4793, 4794, 4795, 4796, 4797, 4798, 4799, 4800, 4801, 4802, 4803, 4804, 4805, 4806, 4807, 4808, 4809, 4810, 4811, 4812, 4813, 4814, 4815, 4816, 4817, 4818, 4819, 4820, 4821, 4822, 4823, 4824, 4825, 4826, 4827, 4828, 4829, 4830, 4831, 4832, 4833, 4834, 4835, 4836, 4837, 4838, 4839, 4840, 4841, 4842, 4843, 4844, 4845, 4846, 4847, 4848, 4849, 4850, 4851, 4852, 4853, 4854, 4855, 4856, 4857, 4858, 4859, 4860, 4861, 4862, 4863, 4864, 4865, 4866, 4867, 4868, 4869, 4870, 4871, 4872, 4873, 4874, 4875, 4876, 4877, 4878, 4879, 4880, 4881, 4882, 4883, 4884, 4885, 4886, 4887, 4888, 4889, 4890, 4891, 4892, 4893, 4894, 4895, 4896, 4897, 4898, 4899, 4900, 4901, 4902, 4903, 4904, 4905, 4906, 4907, 4908, 4909, 4910, 4911, 4912, 4913, 4914, 4915, 4916, 4917, 4918, 4919, 4920, 4921, 4922, 4923, 4924, 4925, 4926, 4927, 4928, 4929, 4930, 4931, 4932, 4933, 4934, 4935, 4936, 4937, 4938, 4939, 4940, 4941], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [1.0, -0.10000000149011612, -1.0850000381469727, -1.961086630821228, -2.734959602355957, -3.4134247303009033, -4.003073215484619, -4.510103702545166, -4.940247058868408, -5.298763275146484, -5.590487003326416, -5.819896221160889, -5.991193771362305, -6.108391761779785, -6.1753830909729, -6.196005344390869, -6.1740851402282715, -6.113463878631592, -6.018008232116699, -5.891604900360107, -5.7381367683410645, -5.561453819274902, -5.365334510803223, -5.153444766998291, -4.929294586181641, -4.696200370788574, -4.457251071929932, -4.215278625488281, -3.972842216491699, -3.7322123050689697, -3.4953689575195312, -3.264003276824951, -3.039527416229248, -2.823087453842163, -2.615581750869751, -2.4176812171936035, -2.229851245880127, -2.052375078201294, -1.885377287864685, -1.7288448810577393, -1.5826497077941895, -1.446568489074707, -1.3203002214431763, -1.2034839391708374, -1.095712423324585, -0.9965459108352661, -0.9055230021476746, -0.8221703767776489, -0.7460107207298279, -0.6765697002410889, -0.6133813261985779, -0.5559921860694885, -0.5039650201797485, -0.4568811058998108, -0.41434216499328613, -0.3759714961051941, -0.3414146602153778, -0.31033968925476074, -0.28243711590766907, -0.2574193477630615, -0.23502019047737122, -0.2149941325187683, -0.19711527228355408, -0.18117642402648926, -0.1669880896806717, -0.1543772965669632, -0.14318659901618958, -0.1332729309797287, -0.12450660765171051, -0.11677029728889465, -0.1099579930305481, -0.10397415608167648, -0.09873276948928833, -0.09415653347969055, -0.09017610549926758, -0.08672935515642166, -0.08376068621873856, -0.08122044056653976, -0.07906430214643478, -0.0772528126835823, -0.07575084269046783, -0.07452717423439026, -0.07355412095785141, -0.07280714809894562, -0.07226452976465225, -0.07190709561109543, -0.07171791791915894, -0.07168209552764893, -0.0717865377664566, -0.07201974093914032, -0.07237885147333145, -0.07286151498556137, -0.07346592843532562, -0.07419081777334213, -0.07503540068864822, -0.0759994387626648, -0.07708317786455154, -0.07828737795352936, -0.07961329072713852, -0.0810626670718193, -0.08263776451349258, -0.08434130996465683, -0.0861765667796135, -0.08814728260040283, -0.09025771915912628, -0.09251268208026886, -0.09491749107837677, -0.09747803956270218, -0.10020077973604202, -0.10309276729822159, -0.10616166144609451, -0.10941577702760696, -0.11286410689353943, -0.11651633679866791, -0.12038290500640869, -0.12447503954172134, -0.12880480289459229, -0.13338513672351837, -0.13822990655899048, -0.14335396885871887, -0.14877328276634216, -0.15450486540794373, -0.16056697070598602, -0.16697914898395538, -0.1737622767686844, -0.1809387356042862, -0.18853244185447693, -0.19656899571418762, -0.20507580041885376, -0.21408215165138245, -0.22361944615840912, -0.23372125625610352, -0.24442355334758759, -0.25576481223106384, -0.26778626441955566, -0.2805320918560028, -0.29404959082603455, -0.30838942527770996, -0.3236059844493866, -0.33975744247436523, -0.35690629482269287, -0.37511950731277466, -0.39446887373924255, -0.4150314927101135, -0.4368900656700134, -0.46013328433036804, -0.4848564565181732, -0.5111618638038635, -0.5391592979431152, -0.568966805934906, -0.600710928440094, -0.6345279216766357, -0.6705639958381653, -0.708976149559021, -0.7499332427978516, -0.7936167120933533, -0.8402214646339417, -0.8899568915367126, -0.9430480003356934, -0.9997365474700928, -1.0602821111679077, -1.124963402748108, -1.1940797567367554, -1.2679523229599, -1.346925139427185, -1.4313675165176392, -1.5216747522354126, -1.6182695627212524, -1.7216041088104248, -1.8321610689163208, -1.950454831123352, -2.0770325660705566, -2.212475299835205, -2.357398271560669, -2.512451410293579, -2.6783175468444824, -2.8557121753692627, -3.0453810691833496, -3.2480947971343994, -3.4646456241607666, -3.6958377361297607, -3.942478656768799, -4.20536470413208, -4.485264301300049, -4.782896041870117, -5.09890079498291, -5.433807849884033, -5.787993907928467, -6.1616315841674805, -6.554630279541016, -6.965951442718506, -7.394130229949951, -7.837179183959961, -8.292485237121582, -8.75670337677002, -9.22566032409668, -9.694263458251953, -10.156438827514648, -10.605095863342285, -11.032155990600586, -11.428635597229004, -11.784817695617676, -12.090520858764648, -12.335466384887695, -12.509742736816406, -12.604347229003906, -12.611770629882812, -12.526573181152344, -12.345894813537598, -12.069820404052734, -11.701566696166992, -11.247432708740234, -10.716509819030762, -10.120189666748047, -9.36433219909668, -8.481619834899902, -7.506406307220459, -6.472689151763916, -5.412297248840332, -4.353507995605469, -3.3201944828033447, -2.3314952850341797, -1.4019087553024292, -0.5416853427886963, 0.24261239171028137, 0.9474887251853943, 1.571908712387085, 2.1167526245117188, 2.584351062774658, 2.978104591369629, 3.3021817207336426, 3.5612807273864746, 3.7604453563690186, 3.9049198627471924, 4.000033855438232, 4.0511088371276855, 4.063381195068359, 4.041934490203857, 3.9916489124298096, 3.917149782180786, 3.8227744102478027, 3.712541103363037, 3.5901291370391846, 3.458867311477661, 3.321727752685547, 3.181330680847168, 3.0399529933929443, 2.8995418548583984, 2.7617361545562744, 2.6278867721557617, 2.49908185005188, 2.376173734664917, 2.259803533554077, 2.1504292488098145, 2.048349618911743, 1.9537289142608643, 1.8666188716888428, 1.7869793176651, 1.7146967649459839, 1.6496009826660156, 1.5914793014526367, 1.540089726448059, 1.4951714277267456, 1.4564539194107056, 1.4236650466918945, 1.3965370655059814, 1.374812126159668, 1.358245611190796, 1.3466103076934814, 1.339698076248169, 1.3373219966888428, 1.3393173217773438, 1.3455426692962646, 1.3558801412582397, 1.3702356815338135, 1.38853919506073, 1.410744071006775, 1.436827301979065, 1.4667892456054688, 1.5006530284881592, 1.5384641885757446, 1.5802909135818481, 1.6262235641479492, 1.676374077796936, 1.7308766841888428, 1.7898868322372437, 1.8535821437835693, 1.92216157913208, 1.995846152305603, 2.074878692626953, 2.1595234870910645, 2.2500672340393066, 2.346818208694458, 2.450106143951416, 2.5602827072143555, 2.677719831466675, 2.802809476852417, 2.9359629154205322, 3.077608108520508, 3.2281877994537354, 3.388157367706299, 3.5579798221588135, 3.738121509552002, 3.9290459156036377, 4.1312055587768555, 4.345033168792725, 4.570930004119873, 4.809250354766846, 5.060286521911621, 5.32424783706665, 5.601238250732422, 5.891226768493652, 6.1940178871154785, 6.509216785430908, 6.836185932159424, 7.173355579376221, 7.518829345703125, 7.870335578918457, 8.225174903869629, 8.580181121826172, 8.931689262390137, 9.275522232055664, 9.607000350952148, 9.920970916748047, 10.211881637573242, 10.473883628845215, 10.70097541809082, 10.88719367980957, 11.026833534240723, 11.114700317382812, 11.14637565612793, 11.118478775024414, 11.028901100158691, 10.876995086669922, 10.663689613342285, 10.391521453857422, 10.064571380615234, 9.688308715820312, 9.2693510055542, 8.815169334411621, 8.33375072479248, 7.8332600593566895, 7.321717262268066, 6.806715488433838, 6.295199871063232, 5.793302536010742, 5.306247711181641, 4.838308334350586, 4.392818450927734, 3.972219228744507, 3.578134775161743, 3.2114663124084473, 2.872493267059326, 2.5609755516052246, 2.276254177093506, 2.017343282699585, 1.7830134630203247, 1.5718637704849243, 1.3823845386505127, 1.2130088806152344, 1.06215500831604, 0.928259551525116, 0.8098036050796509, 0.7053318619728088, 0.6134664416313171, 0.5329155921936035, 0.4624791443347931, 0.4010503888130188, 0.34761592745780945, 0.30125346779823303, 0.26112833619117737, 0.22648902237415314, 0.1966620832681656, 0.1710466593503952, 0.14910884201526642, 0.13037604093551636, 0.11443138867616653, 0.10090851783752441, 0.08948644250631332, 0.07988486438989639, 0.07185973972082138, 0.06519927829504013, 0.059720225632190704, 0.055264513939619064, 0.05169624462723732, 0.04889898747205734, 0.04677334427833557, 0.04523482918739319, 0.044207263737916946, 0.04362663999199867, 0.0434393510222435, 0.04360070824623108, 0.04407365247607231, 0.044827651232481, 0.04583776369690895, 0.047083839774131775, 0.048549823462963104, 0.05022319406270981, 0.05209445580840111, 0.054156720638275146, 0.056405358016490936, 0.05883768945932388, 0.06145274639129639, 0.06425105035305023, 0.06723442673683167, 0.07040586322546005, 0.07376938313245773, 0.07732994854450226, 0.08109334111213684, 0.08506613969802856, 0.08925560861825943, 0.09366967529058456, 0.09831689298152924, 0.10320639610290527, 0.10834785550832748, 0.11375150084495544, 0.11942806094884872, 0.1253887563943863, 0.1316453218460083, 0.13735726475715637, 0.14261485636234283, 0.1474994719028473, 0.15208451449871063, 0.15643616020679474, 0.1606140434741974, 0.16467203199863434, 0.1686587780714035, 0.17261841893196106, 0.17659102380275726, 0.18061323463916779, 0.18471866846084595, 0.18893833458423615, 0.19330111145973206, 0.19783411920070648, 0.20256294310092926, 0.20751211047172546, 0.21270526945590973, 0.21816547214984894, 0.22391550242900848, 0.22997796535491943, 0.236375629901886, 0.2431315779685974, 0.2502693831920624, 0.25781330466270447, 0.26578855514526367, 0.2742212414741516, 0.28313881158828735, 0.292570024728775, 0.3025452196598053, 0.31309643387794495, 0.32425758242607117, 0.3360646665096283, 0.34855592250823975, 0.3617720603942871, 0.3757564127445221, 0.39055511355400085, 0.40621742606163025, 0.4227959215641022, 0.4403466582298279, 0.4589296281337738, 0.47860878705978394, 0.4994525909423828, 0.5215341448783875, 0.5449317097663879, 0.5697288513183594, 0.5960150957107544, 0.6238861083984375, 0.653444230556488, 0.6847990155220032, 0.7180677056312561, 0.753375768661499, 0.7908573746681213, 0.8306561708450317, 0.8729259371757507, 0.9178311824798584, 0.9655478596687317, 1.0162643194198608, 1.070181965827942, 1.1275161504745483, 1.1884970664978027, 1.2533708810806274, 1.3224003314971924, 1.3958660364151, 1.474067211151123, 1.5573230981826782, 1.645973563194275, 1.7403799295425415, 1.8409265279769897, 1.9480208158493042, 2.062094211578369, 2.183603048324585, 2.313027858734131, 2.450873851776123, 2.597670555114746, 2.753969669342041, 2.920344352722168, 3.097385883331299, 3.2856993675231934, 3.4858994483947754, 3.6986029148101807, 3.924419641494751, 4.163941383361816, 4.417728424072266, 4.6862897872924805, 4.970065116882324, 5.269395351409912, 5.584493160247803, 5.915406703948975, 6.261973857879639, 6.623776435852051, 7.00007963180542, 7.389772891998291, 7.791298866271973, 8.202585220336914, 8.620967864990234, 9.043126106262207, 9.465018272399902, 9.88183879852295, 10.28799819946289, 10.677139282226562, 11.041168212890625, 11.371438026428223, 11.65894603729248, 11.89461612701416, 12.069657325744629, 12.175985336303711, 12.206686019897461, 12.156479835510254, 12.022148132324219, 11.802864074707031, 11.50039005279541, 11.119101524353027, 10.66583251953125, 10.149535179138184, 9.580803871154785, 8.971295356750488, 8.33312702178955, 7.678281784057617, 7.018101215362549, 6.36287784576416, 5.7215728759765625, 5.101658821105957, 4.509069442749023, 3.948241949081421, 3.4222261905670166, 2.932833194732666, 2.4808099269866943, 2.06601881980896, 1.6876130104064941, 1.344197154045105, 1.033972144126892, 0.754858672618866, 0.5046022534370422, 0.28085818886756897, 0.0812600702047348, -0.09652736037969589, -0.2547683119773865, -0.3956272006034851, -0.5211491584777832, -0.6332477927207947, -0.7336992621421814, -0.8241405487060547, -0.9060719609260559, -0.9808616042137146, -1.049752116203308, -1.1138688325881958, -1.1742286682128906, -1.2317488193511963, -1.2872567176818848, -1.341498851776123, -1.3951501846313477, -1.448821783065796, -1.5030697584152222, -1.55840265750885, -1.6152875423431396, -1.6741575002670288, -1.7354167699813843, -1.7994459867477417, -1.8666068315505981, -1.9372466802597046, -2.0117015838623047, -2.0902998447418213, -2.1733651161193848, -2.2612171173095703, -2.354175567626953, -2.4525604248046875, -2.556692361831665, -2.6668941974639893, -2.7834908962249756, -2.9068081378936768, -3.0371718406677246, -3.1749062538146973, -3.320331573486328, -3.4737603664398193, -3.6354939937591553, -3.805816888809204, -3.9849905967712402, -4.173245906829834, -4.370774745941162, -4.577717304229736, -4.794153213500977, -5.020084857940674, -5.255422592163086, -5.499966144561768, -5.753384590148926, -6.015196323394775, -6.28474235534668, -6.561164379119873, -6.843379020690918, -7.1300506591796875, -7.419571399688721, -7.710035800933838, -7.9992289543151855, -8.284613609313965, -8.563331604003906, -8.8322172164917, -9.08781909942627, -9.32645034790039, -9.544246673583984, -9.737249374389648, -9.901512145996094, -10.033220291137695, -10.128829002380371, -10.185205459594727, -10.19977855682373, -10.170675277709961, -10.096837043762207, -9.978116035461426, -9.815320014953613, -9.610222816467285, -9.365527153015137, -9.084773063659668, -8.772216796875, -8.432669639587402, -8.071317672729492, -7.693536281585693, -7.304707050323486, -6.910050868988037, -6.51448392868042, -6.122504234313965, -5.737456321716309, -5.362284183502197, -4.9994964599609375, -4.651150226593018, -4.318861484527588, -4.003823757171631, -3.706841468811035, -3.4283666610717773, -3.168544292449951, -2.927255630493164, -2.704162359237671, -2.498748302459717, -2.3103585243225098, -2.138232707977295, -1.98153817653656, -1.839394450187683, -1.7108969688415527, -1.5951356887817383, -1.4912099838256836, -1.3982412815093994, -1.3153817653656006, -1.2418218851089478, -1.1767951250076294, -1.119580626487732, -1.0695055723190308, -1.0259455442428589, -0.9883239269256592, -0.9561111330986023, -0.9288225769996643, -0.9060172438621521, -0.8872946500778198, -0.8722930550575256, -0.8606864809989929, -0.8521820902824402, -0.8465179204940796, -0.8434601426124573, -0.8428006768226624, -0.844355046749115, -0.8479599356651306, -0.8534714579582214, -0.8607629537582397, -0.8697236776351929, -0.8802566528320312, -0.8922774791717529, -0.9057130217552185, -0.9204999804496765, -0.936583936214447, -0.9539181590080261, -0.9724626541137695, -0.9921836256980896, -1.013052225112915, -1.0350443124771118, -1.0581393241882324, -1.0823203325271606, -1.1028110980987549, -1.120231032371521, -1.135140061378479, -1.148042917251587, -1.1593927145004272, -1.16959547996521, -1.1790138483047485, -1.1879714727401733, -1.196756362915039, -1.2056249380111694, -1.2148053646087646, -1.2245012521743774, -1.2348941564559937, -1.24614679813385, -1.2584055662155151, -1.271803379058838, -1.2864612340927124, -1.3024907112121582, -1.3199959993362427, -1.3390750885009766, -1.3598214387893677, -1.3823257684707642, -1.406677007675171, -1.4329631328582764, -1.461272954940796, -1.4916962385177612, -1.5243251323699951, -1.5592548847198486, -1.5965839624404907, -1.6364153623580933, -1.6788570880889893, -1.7240221500396729, -1.7720296382904053, -1.8230048418045044, -1.8770798444747925, -1.9343935251235962, -1.9950920343399048, -2.0593292713165283, -2.1272666454315186, -2.199073314666748, -2.2749264240264893, -2.355010509490967, -2.4395179748535156, -2.5286483764648438, -2.6226086616516113, -2.7216110229492188, -2.825873851776123, -2.935619831085205, -3.051074266433716, -3.172464370727539, -3.2847611904144287, -3.389258861541748, -3.487091064453125, -3.5792481899261475, -3.6665940284729004, -3.74988055229187, -3.8297603130340576, -3.9067983627319336, -3.9814813137054443, -4.054227828979492, -4.125394344329834, -4.195284366607666, -4.264150619506836, -4.332205772399902, -4.39962100982666, -4.46653413772583, -4.533052444458008, -4.599254131317139, -4.665191650390625, -4.730895519256592, -4.7963738441467285, -4.861616134643555, -4.9265947341918945, -4.991264820098877, -5.055566787719727, -5.119429111480713, -5.182765483856201, -5.245479583740234, -5.307465553283691, -5.368607997894287, -5.4287824630737305, -5.487859725952148, -5.545704364776611, -5.602175712585449, -5.657131195068359, -5.710426330566406, -5.761916160583496, -5.811456680297852, -5.858907222747803, -5.904130458831787, -5.946995735168457, -5.9873785972595215, -6.025164604187012, -6.060248374938965, -6.092537879943848, -6.121953010559082, -6.148428916931152, -6.171916961669922, -6.192383766174316, -6.209815979003906, -6.224216938018799, -6.235610008239746, -6.244037628173828, -6.2495622634887695, -6.252265930175781, -6.252248764038086, -6.249630451202393, -6.244548797607422, -6.237157344818115, -6.227626800537109, -6.216141223907471, -6.202898025512695, -6.188105583190918, -6.171983242034912, -6.154757022857666, -6.136659145355225, -6.117926597595215, -6.098798751831055, -6.079516410827637, -6.060317516326904, -6.041439056396484, -6.023114204406738, -6.0055694580078125, -5.989025592803955, -5.97369384765625, -5.959779262542725, -5.947474002838135, -5.936961650848389, -5.9284138679504395, -5.921990394592285, -5.917839050292969, -5.916094779968262, -5.916880130767822, -5.920304298400879, -5.9264631271362305, -5.9354400634765625, -5.947304725646973, -5.962113380432129, -5.979908466339111, -6.000720024108887, -6.024563789367676, -6.051442623138428, -6.081344127655029, -6.11424446105957, -6.150103569030762, -6.188867568969727, -6.230469226837158, -6.274825096130371, -6.321837425231934, -6.371392250061035, -6.423360347747803, -6.476959705352783, -6.5314507484436035, -6.586132526397705, -6.640336990356445, -6.693428993225098, -6.744801044464111, -6.793877124786377, -6.840108394622803, -6.882979869842529, -6.9220075607299805, -6.9567437171936035, -6.98677921295166, -7.011747360229492, -7.0313262939453125, -7.0452423095703125, -7.053273677825928, -7.0552544593811035, -7.051074504852295, -7.040681838989258, -7.024085521697998, -7.001354217529297, -6.9726152420043945, -6.938055038452148, -6.897914886474609, -6.852487564086914, -6.8021159172058105, -6.7471842765808105, -6.688116550445557, -6.625368595123291, -6.559421062469482, -6.490776538848877, -6.419949531555176, -6.347460746765137, -6.273833274841309, -6.199584484100342, -6.125221252441406, -6.051235675811768, -5.978100299835205, -5.906264305114746, -5.836151123046875, -5.768157005310059, -5.7026472091674805, -5.639955043792725, -5.580384254455566, -5.524205207824707, -5.4716572761535645, -5.422949314117432, -5.378260135650635, -5.337741374969482, -5.301516056060791, -5.26968240737915, -5.242315292358398, -5.219467639923096, -5.201170921325684, -5.187438011169434, -5.17826509475708, -5.17363166809082, -5.1735029220581055, -5.177829265594482, -5.186549663543701, -5.19959020614624, -5.216866493225098, -5.238281726837158, -5.263730049133301, -5.293093681335449, -5.32624626159668, -5.363049507141113, -5.403353691101074, -5.446999549865723, -5.493814945220947, -5.54361629486084, -5.596207618713379, -5.651378631591797, -5.7089056968688965, -5.768552303314209, -5.830065727233887, -5.893178462982178, -5.957608222961426, -6.023056983947754, -6.089211940765381, -6.155745029449463, -6.222313404083252, -6.288562297821045, -6.354124069213867, -6.4186201095581055, -6.481663227081299, -6.542860984802246, -6.601816177368164, -6.658131122589111, -6.711411952972412, -6.761270046234131, -6.807328224182129, -6.84922456741333, -6.886615753173828, -6.919183731079102, -6.9466376304626465, -6.968719959259033, -6.9852118492126465, -6.995934009552002, -7.000753402709961, -6.999583721160889, -6.99238920211792, -6.979186058044434, -6.960043907165527, -6.935083389282227, -6.904478549957275, -6.8684539794921875, -6.827280044555664, -6.781274795532227, -6.730793476104736, -6.676230430603027, -6.618008613586426, -6.556577205657959, -6.492406368255615, -6.425978660583496, -6.357785224914551, -6.288320541381836, -6.218075275421143, -6.147533893585205, -6.077166557312012, -6.0074286460876465, -5.938754081726074, -5.871555328369141, -5.806218147277832, -5.743102073669434, -5.682537078857422, -5.6248250007629395, -5.57023811340332, -5.519017219543457, -5.471376895904541, -5.4275007247924805, -5.387547492980957, -5.351647853851318, -5.319908618927002, -5.292413711547852, -5.269224166870117, -5.2503814697265625, -5.235908031463623, -5.2258076667785645, -5.220069885253906, -5.218667984008789, -5.221560478210449, -5.22869348526001, -5.240001678466797, -5.255406856536865, -5.274819374084473, -5.298140048980713, -5.325257301330566, -5.356050491333008, -5.390387535095215, -5.428125381469727, -5.469110488891602, -5.513177871704102, -5.560150146484375, -5.609838008880615, -5.6620402336120605, -5.716541767120361, -5.77311372756958, -5.831514835357666, -5.891488075256348, -5.952763080596924, -6.015055179595947, -6.078064918518066, -6.141480445861816, -6.204975605010986, -6.268212795257568, -6.330842018127441, -6.392505645751953, -6.452836513519287, -6.511462211608887, -6.568007946014404, -6.622097969055176, -6.673358917236328, -6.721424102783203, -6.765937328338623, -6.806554794311523, -6.842952251434326, -6.874826908111572, -6.901901721954346, -6.92393159866333, -6.940703868865967, -6.952045917510986, -6.95782470703125, -6.957952499389648, -6.95238733291626, -6.941135406494141, -6.924251556396484, -6.901839733123779, -6.874053478240967, -6.841091156005859, -6.80319881439209, -6.76066255569458, -6.713808059692383, -6.6629958152771, -6.608615398406982, -6.551083564758301, -6.490835189819336, -6.428320407867432, -6.363999843597412, -6.298336505889893, -6.231794357299805, -6.164831638336182, -6.09789514541626, -6.0314202308654785, -5.965822696685791, -5.901500225067139, -5.838826656341553, -5.719136714935303, -5.550455570220947, -5.340717792510986, -5.097636699676514, -4.828582763671875, -4.540469169616699, -4.239659309387207, -3.9318957328796387, -3.62225341796875, -3.3151192665100098, -3.0141942501068115, -2.7225136756896973, -2.4424853324890137, -2.1759390830993652, -1.9241819381713867, -1.6880613565444946, -1.4680252075195312, -1.2641842365264893, -1.0763691663742065, -0.9041849374771118, -0.747058629989624, -0.6042833924293518, -0.4750554859638214, -0.3585071563720703, -0.25373348593711853, -0.15981505811214447, -0.075836181640625, -0.0008993695955723524, 0.06586352735757828, 0.12528304755687714, 0.17814631760120392, 0.22519324719905853, 0.2671145498752594, 0.3045508861541748, 0.33809351921081543, 0.36828532814979553, 0.3956230580806732, 0.4205593764781952, 0.4435059726238251, 0.4648362696170807, 0.48488864302635193, 0.5039694905281067, 0.5223562717437744, 0.540300726890564, 0.558031439781189, 0.5757569074630737, 0.5936681628227234, 0.6119410395622253, 0.6307387351989746, 0.6502138376235962, 0.6705103516578674, 0.6917657256126404, 0.7141122817993164, 0.7376792430877686, 0.7625938653945923, 0.7889830470085144, 0.8169747591018677, 0.8466988801956177, 0.878288984298706, 0.9118828177452087, 0.9476239681243896, 0.985662579536438, 1.0261564254760742, 1.0692720413208008, 1.1151857376098633, 1.164084553718567, 1.2161672115325928, 1.2716450691223145, 1.330743670463562, 1.3937029838562012, 1.4607793092727661, 1.5322455167770386, 1.608392596244812, 1.689530611038208, 1.7759896516799927, 1.8681209087371826, 1.9662972688674927, 2.0709147453308105, 2.182391881942749, 2.3011720180511475, 2.4277219772338867, 2.5625321865081787, 2.7061166763305664, 2.8590121269226074, 3.0217745304107666, 3.1949779987335205, 3.379210948944092, 3.5750701427459717, 3.7831544876098633, 4.004056930541992, 4.2383527755737305, 4.486587047576904, 4.749256134033203, 5.026788711547852, 5.319519996643066, 5.627662181854248, 5.951269626617432, 6.290195465087891, 6.644048690795898, 7.012135982513428, 7.39340353012085, 7.785672187805176, 8.186270713806152, 8.591960906982422, 8.998873710632324, 9.402461051940918, 9.797464370727539, 10.083890914916992, 10.262483596801758, 10.334569931030273, 10.30257511138916, 10.170425415039062, 9.943790435791016, 9.630159378051758, 9.23873519897461, 8.780166625976562, 8.266160011291504, 7.709003448486328, 7.121068477630615, 6.51433801651001, 5.899996757507324, 5.288113594055176, 4.687429428100586, 4.1052446365356445, 3.5474002361297607, 3.018329381942749, 2.521164655685425, 2.0578770637512207, 1.6294361352920532, 1.2359706163406372, 0.8769270777702332, 0.5512152910232544, 0.2573385238647461, -0.0064927563071250916, -0.24226465821266174, -0.4520798623561859, -0.6380926370620728, -0.8024570345878601, -0.9472869038581848, -1.0746257305145264, -1.1864246129989624, -1.28452730178833, -1.3706609010696411, -1.4464309215545654, -1.5133200883865356, -1.5726900100708008, -1.6257846355438232, -1.673735499382019, -1.7175685167312622, -1.75821053981781, -1.7964972257614136, -1.8331809043884277, -1.8689379692077637, -1.9043769836425781, -1.9400454759597778, -1.9764374494552612, -2.0139999389648438, -2.0531389713287354, -2.0942256450653076, -2.137601375579834, -2.1835825443267822, -2.2324655055999756, -2.284529685974121, -2.3400421142578125, -2.3992598056793213, -2.462433338165283, -2.529808282852173, -2.601628541946411, -2.6781363487243652, -2.759575843811035, -2.8461921215057373, -2.9382331371307373, -3.035949230194092, -3.1395938396453857, -3.249422311782837, -3.3656914234161377, -3.4886579513549805, -3.6185765266418457, -3.755697011947632, -3.9002621173858643, -4.052501678466797, -4.212629795074463, -4.380837917327881, -4.55728816986084, -4.742105484008789, -4.935368061065674, -5.1370978355407715, -5.34724760055542, -5.565687656402588, -5.792190074920654, -6.026414394378662, -6.26788854598999, -6.515989780426025, -6.769926071166992, -7.028716564178467, -7.291171550750732, -7.555875778198242, -7.821173191070557, -8.085156440734863, -8.345660209655762, -8.600264549255371, -8.846306800842285, -9.080903053283691, -9.300986289978027, -9.503352165222168, -9.684728622436523, -9.841856956481934, -9.971580505371094, -10.069969177246094, -10.13349723815918, -10.159168243408203, -10.144639015197754, -10.088332176208496, -9.989527702331543, -9.848422050476074, -9.666152000427246, -9.444771766662598, -9.1871976852417, -8.897096633911133, -8.578754425048828, -8.236913681030273, -7.8765997886657715, -7.50294303894043, -7.121014595031738, -6.7356743812561035, -6.3514509201049805, -5.972442150115967, -5.602252960205078, -5.24395751953125, -4.900086879730225, -4.572640895843506, -4.2631144523620605, -3.9725399017333984, -3.7015326023101807, -3.4503467082977295, -3.2189278602600098, -3.0069665908813477, -2.8139500617980957, -2.639207124710083, -2.481950521469116, -2.3413145542144775, -2.2163846492767334, -2.1062254905700684, -2.009902238845825, -1.9264984130859375, -1.8551292419433594, -1.7949529886245728, -1.7451778650283813, -1.7050679922103882, -1.6739462614059448, -1.6511961221694946, -1.6362619400024414, -1.6286485195159912, -1.6279194355010986, -1.6336952447891235, -1.64565110206604, -1.6635140180587769, -1.6870602369308472, -1.7161126136779785, -1.7505377531051636, -1.790243148803711, -1.835174798965454, -1.8853148221969604, -1.9406791925430298, -2.0013155937194824, -2.067300796508789, -2.138740062713623, -2.215763807296753, -2.2985270023345947, -2.38720703125, -2.482001304626465, -2.5831267833709717, -2.690816879272461, -2.805319309234619, -2.9268949031829834, -3.0558130741119385, -3.1923506259918213, -3.3367860317230225, -3.489396572113037, -3.6504530906677246, -3.8202130794525146, -3.998915195465088, -4.186769485473633, -4.383948802947998, -4.590578079223633, -4.8067216873168945, -5.03236722946167, -5.2674126625061035, -5.51164436340332, -5.764720916748047, -6.026147365570068, -6.295254707336426, -6.571173667907715, -6.852809906005859, -7.138819217681885, -7.427583694458008, -7.717190742492676, -8.00541877746582, -8.289728164672852, -8.567256927490234, -8.834842681884766, -9.089038848876953, -9.326168060302734, -9.542379379272461, -9.733734130859375, -9.896310806274414, -10.026321411132812, -10.120255470275879, -10.174013137817383, -10.184151649475098, -10.148030281066895, -10.063955307006836, -9.931278228759766, -9.750465393066406, -9.523113250732422, -9.251906394958496, -8.94052505493164, -8.593502044677734, -8.216039657592773, -7.813800811767578, -7.39269495010376, -6.958660125732422, -6.517469882965088, -6.07456636428833, -5.634926795959473, -5.202969074249268, -4.782493591308594, -4.376659393310547, -3.987989902496338, -3.6183981895446777, -3.2692344188690186, -2.941340446472168, -2.6351125240325928, -2.3505661487579346, -2.087399959564209, -1.8450555801391602, -1.622773289680481, -1.4196419715881348, -1.2346431016921997, -1.0666874647140503, -0.9146477580070496, -0.7773838043212891, -0.653764009475708, -0.5426821112632751, -0.4430695176124573, -0.35390505194664, -0.2742212414741516, -0.2031087428331375, -0.13971850275993347, -0.08326255530118942, -0.03221717104315758, 0.013659760355949402, 0.0546516478061676, 0.09107071161270142, 0.12324727326631546, 0.1515207588672638, 0.1762322187423706, 0.19771826267242432, 0.21630631387233734, 0.2323109358549118, 0.24603107571601868, 0.2577483057975769, 0.26772555708885193, 0.2762066423892975, 0.28341612219810486, 0.28955960273742676, 0.2948243021965027, 0.29937994480133057, 0.30337971448898315, 0.3069612979888916, 0.31024816632270813, 0.31335076689720154, 0.31636759638786316, 0.31938663125038147, 0.3224862515926361, 0.32573652267456055, 0.32920023798942566, 0.33293378353118896, 0.3369882106781006, 0.3414100706577301, 0.34624215960502625, 0.35152435302734375, 0.3572941720485687, 0.36358752846717834, 0.37043923139572144, 0.3778834939002991, 0.38595446944236755, 0.3946867287158966, 0.40411558747291565, 0.4142775535583496, 0.42521071434020996, 0.4369550347328186, 0.4495528042316437, 0.4630488157272339, 0.4774908125400543, 0.49292975664138794, 0.5094201564788818, 0.5270203948020935, 0.5457931160926819, 0.5658055543899536, 0.5871297717094421, 0.6098433136940002, 0.6340293288230896, 0.6597772240638733, 0.6871828436851501, 0.7163492441177368, 0.7473871111869812, 0.7804150581359863, 0.8155605792999268, 0.8529605269432068, 0.8927615284919739, 0.9351210594177246, 0.9802079796791077, 1.0282032489776611, 1.0793009996414185, 1.1337090730667114, 1.191650390625, 1.2533632516860962, 1.3191031217575073, 1.3891429901123047, 1.4637749195098877, 1.543310523033142, 1.6280828714370728, 1.7184468507766724, 1.814780354499817, 1.9174853563308716, 2.0269887447357178, 2.1437430381774902, 2.2682266235351562, 2.400944232940674, 2.542426586151123, 2.6932294368743896, 2.853933095932007, 3.025139570236206, 3.2074697017669678, 3.4015586376190186, 3.60805082321167, 3.8275904655456543, 4.060814380645752, 4.30833625793457, 4.570733070373535, 4.848524570465088, 5.142149925231934, 5.451936721801758, 5.778069019317627, 6.12054443359375, 6.479125499725342, 6.8532867431640625, 7.24215030670166, 7.644418239593506, 8.058298110961914, 8.480659484863281, 8.907726287841797, 9.334999084472656, 9.7572021484375, 10.168257713317871, 10.561299324035645, 10.928735733032227, 11.26237964630127, 11.553644180297852, 11.79382038116455, 11.974424362182617, 12.087611198425293, 12.126619338989258, 12.086228370666504, 11.963177680969238, 11.756494522094727, 11.467702865600586, 11.10086441040039, 10.662442207336426, 10.16099739074707, 9.606735229492188, 9.01096248626709, 8.385497093200684, 7.742097854614258, 7.091958999633789, 6.445300579071045, 5.811081886291504, 5.196828365325928, 4.608572483062744, 4.050880432128906, 3.526947259902954, 3.0387375354766846, 2.5871505737304688, 2.172194242477417, 1.7931561470031738, 1.4487615823745728, 1.1373177766799927, 0.8566927909851074, 0.6046433448791504, 0.37888380885124207, 0.1771407425403595, -0.0028056311421096325, -0.1630905121564865, -0.3057427406311035, -0.43267038464546204, -0.5456523299217224, -0.6463345289230347, -0.7362301349639893, -0.8167219161987305, -0.8890672922134399, -0.9544045329093933, -1.013759732246399, -1.0680545568466187, -1.1181142330169678, -1.1646755933761597, -1.2083946466445923, -1.2498544454574585, -1.2895718812942505, -1.3280048370361328, -1.3655579090118408, -1.4025886058807373, -1.4394124746322632, -1.4763078689575195, -1.5135201215744019, -1.551265835762024, -1.589735746383667, -1.6290980577468872, -1.6695014238357544, -1.7110767364501953, -1.7539395093917847, -1.7981914281845093, -1.8439217805862427, -1.8912091255187988, -1.9401216506958008, -1.9907186031341553, -2.0430502891540527, -2.0971596240997314, -2.153080701828003, -2.2108407020568848, -2.270458936691284, -2.3319475650787354, -2.395310401916504, -2.460543632507324, -2.527634382247925, -2.5965616703033447, -2.667295217514038, -2.7397937774658203, -2.814007043838501, -2.8898723125457764, -2.967315435409546, -3.0462498664855957, -3.1132218837738037, -3.169840097427368, -3.2175586223602295, -3.2576892375946045, -3.2914130687713623, -3.3197929859161377, -3.3437821865081787, -3.3642356395721436, -3.38191819190979, -3.3975131511688232, -3.411630630493164, -3.424813985824585, -3.437546968460083, -3.4502596855163574, -3.46333384513855, -3.4771082401275635, -3.491882801055908, -3.5079240798950195, -3.5254669189453125, -3.544719696044922, -3.565866708755493, -3.589071035385132, -3.6144766807556152, -3.6422111988067627, -3.67238712310791, -3.705103874206543, -3.7404491901397705, -3.778500556945801, -3.8193252086639404, -3.8629822731018066, -3.90952205657959, -3.9589879512786865, -4.011415004730225, -4.066831588745117, -4.125257968902588, -4.186707019805908, -4.25118350982666, -4.3186845779418945, -4.38919734954834, -4.462698459625244, -4.53915548324585, -4.618523120880127, -4.700743675231934, -4.785745620727539, -4.873441219329834, -4.963726997375488, -5.056481838226318, -5.15156364440918, -5.248810768127441, -5.348038673400879, -5.449038982391357, -5.551578521728516, -5.655396938323975, -5.760207653045654, -5.865695476531982, -5.971517086029053, -6.07729959487915, -6.182642459869385, -6.2871174812316895, -6.390269756317139, -6.49161958694458, -6.5906662940979, -6.686890125274658, -6.779757022857666, -6.868721961975098, -6.953238010406494, -7.0327582359313965, -7.106746196746826, -7.174680709838867, -7.2360663414001465, -7.290441036224365, -7.3373823165893555, -7.376519203186035, -7.407538414001465, -7.430191993713379, -7.444304466247559, -7.4497785568237305, -7.44659948348999, -7.434838771820068, -7.414654731750488, -7.386292934417725, -7.350085258483887, -7.306443691253662, -7.255858421325684, -7.198887825012207, -7.136153697967529, -7.068329334259033, -6.996131896972656, -6.9203104972839355, -6.841636657714844, -6.76089334487915, -6.678864002227783, -6.596325397491455, -6.514036655426025, -6.432732105255127, -6.353114604949951, -6.275851249694824, -6.201565742492676, -6.1308393478393555, -6.064205169677734, -6.0021491050720215, -5.944502353668213, -5.891127586364746, -5.841913223266602, -5.796766757965088, -5.755609512329102, -5.718376159667969, -5.685006141662598, -5.6554460525512695, -5.62964391708374, -5.607548713684082, -5.589108943939209, -5.5742716789245605, -5.5629801750183105, -5.555174350738525, -5.550790309906006, -5.549757957458496, -5.552003383636475, -5.557446002960205, -5.5659990310668945, -5.577570915222168, -5.5920610427856445, -5.6093645095825195, -5.629368305206299, -5.651951789855957, -5.676987648010254, -5.704340934753418, -5.7338690757751465, -5.765420913696289, -5.798839092254639, -5.833956718444824, -5.870599269866943, -5.908585071563721, -5.947723388671875, -5.98781681060791, -6.028660774230957, -6.070043563842773, -6.111745834350586, -6.153544902801514, -6.195210933685303, -6.236510753631592, -6.27720832824707, -6.317065715789795, -6.355844020843506, -6.39330530166626, -6.429214000701904, -6.463339328765869, -6.495456695556641, -6.52534818649292, -6.552807807922363, -6.577639102935791, -6.5996623039245605, -6.618711471557617, -6.634640216827393, -6.647320747375488, -6.656647205352783, -6.662537097930908, -6.6649322509765625, -6.663798809051514, -6.659130573272705, -6.650946617126465, -6.639294147491455, -6.624246120452881, -6.605902194976807, -6.584387302398682, -6.559849739074707, -6.532461643218994, -6.502415657043457, -6.469923496246338, -6.435214042663574, -6.398529529571533, -6.360126495361328, -6.320268154144287, -6.279226779937744, -6.237277984619141, -6.194699287414551, -6.151767253875732, -6.108755588531494, -6.065934181213379, -6.023563385009766, -5.98189640045166, -5.9411749839782715, -5.901630401611328, -5.8634796142578125, -5.826925754547119, -5.792158126831055, -5.759350299835205, -5.7286601066589355, -5.700230121612549, -5.674187183380127, -5.650641918182373, -5.629690170288086, -5.611412525177002, -5.595873832702637, -5.583126068115234, -5.573205947875977, -5.566136837005615, -5.561930179595947, -5.560583591461182, -5.5620832443237305, -5.566402912139893, -5.5735063552856445, -5.583345413208008, -5.595860958099365, -5.610984802246094, -5.62863826751709, -5.648731708526611, -5.671167850494385, -5.69583797454834, -5.722625255584717, -5.751403331756592, -5.782036304473877, -5.814380645751953, -5.848282337188721, -5.883579730987549, -5.920103073120117, -5.9576735496521, -5.996105670928955, -6.035205364227295, -6.074772834777832, -6.1146016120910645, -6.154479026794434, -6.194189071655273, -6.2335100173950195, -6.272219181060791, -6.310091018676758, -6.346273422241211, -6.37997579574585, -6.410468578338623, -6.437081336975098, -6.459201335906982, -6.476277828216553, -6.487819194793701, -6.493399143218994, -6.492655277252197, -6.485292911529541, -6.4710869789123535, -6.4498820304870605, -6.421594142913818, -6.386210918426514, -6.343789577484131, -6.2944560050964355, -6.238402366638184, -6.175882339477539, -6.107208251953125, -6.03274393081665, -5.952899932861328, -5.868125915527344, -5.733067989349365, -5.555102348327637, -5.341463088989258, -5.099135875701904, -4.83475399017334, -4.554506778717041, -4.264064311981201, -3.9685235023498535, -3.672372579574585, -3.3794796466827393, -3.0930981636047363, -2.8158891201019287, -2.549956798553467, -2.296893835067749, -2.057831287384033, -1.8334940671920776, -1.6242552995681763, -1.430190086364746, -1.2511266469955444, -1.0866934061050415, -0.9363621473312378, -0.7994855642318726, -0.6753311157226562, -0.5631089806556702, -0.4619967043399811, -0.3711589276790619, -0.2897636890411377, -0.21699535846710205, -0.15206460654735565, -0.09421587735414505, -0.04273267090320587, 0.003059007693082094, 0.043788693845272064, 0.08004074543714523, 0.11235460638999939, 0.14122585952281952, 0.16710785031318665, 0.19041375815868378, 0.2115190029144287, 0.230763778090477, 0.2484557181596756, 0.26487264037132263, 0.28026530146598816, 0.294859915971756, 0.30886074900627136, 0.3224526345729828, 0.3358031213283539, 0.3490648567676544, 0.3623773455619812, 0.3758690655231476, 0.3896591067314148, 0.40385884046554565, 0.41857340931892395, 0.4339030683040619, 0.44994455575942993, 0.46679219603538513, 0.48453912138938904, 0.5032781958580017, 0.5231030583381653, 0.5441089868545532, 0.5663939118385315, 0.5900591611862183, 0.615210235118866, 0.6419578194618225, 0.6704183220863342, 0.7007150650024414, 0.7329785823822021, 0.7673479318618774, 0.8039713501930237, 0.8430069088935852, 0.8846239447593689, 0.9290035367012024, 0.9763396382331848, 1.0268402099609375, 1.08072829246521, 1.1382429599761963, 1.1996406316757202, 1.265196442604065, 1.3352049589157104, 1.4099825620651245, 1.4898674488067627, 1.5752222537994385, 1.666434645652771, 1.7639187574386597, 1.868116855621338, 1.9795002937316895, 2.0985705852508545, 2.225860357284546, 2.361934185028076, 2.507388114929199, 2.6628501415252686, 2.8289783000946045, 3.006460428237915, 3.1960091590881348, 3.3983590602874756, 3.614260673522949, 3.8444714546203613, 4.08974552154541, 4.350819110870361, 4.628394603729248, 4.923116207122803, 5.235079288482666, 5.564253330230713, 5.910429954528809, 6.2731709480285645, 6.6517438888549805, 7.045055389404297, 7.451579570770264, 7.869276523590088, 8.295515060424805, 8.726995468139648, 9.159675598144531, 9.58871841430664, 10.008459091186523, 10.41240406036377, 10.793280601501465, 11.143143653869629, 11.453550338745117, 11.715806007385254, 11.921293258666992, 12.061864852905273, 12.130285263061523, 12.120692253112793, 12.029036521911621, 11.853456497192383, 11.594537734985352, 11.25542163848877, 10.8417329788208, 10.361340522766113, 9.823949813842773, 9.240581512451172, 8.622992515563965, 7.983084201812744, 7.332367897033691, 6.681511402130127, 6.0400071144104, 5.415954113006592, 4.815959453582764, 4.245138168334961, 3.707184076309204, 3.2044990062713623, 2.738352060317993, 2.3090529441833496, 1.9161262512207031, 1.558476448059082, 1.2345378398895264, 0.9424065947532654, 0.6799533367156982, 0.44491609930992126, 0.2349766492843628, 0.04782000184059143, -0.11881958693265915, -0.2671246826648712, -0.3991706669330597, -0.5169099569320679, -0.622162938117981, -0.71661376953125, -0.7955895066261292, -0.860317587852478, -0.9120750427246094, -0.9521539211273193, -0.9818329215049744, -1.0023550987243652, -1.0149104595184326, -1.0206228494644165, -1.0205413103103638, -1.015634298324585, -1.006786584854126, -0.994799017906189, -0.9803897142410278, -0.9641967415809631, -0.9467818140983582, -0.92863529920578, -0.9101811051368713, -0.8917823433876038, -0.8737468123435974, -0.8563327193260193, -0.8397542238235474, -0.8241864442825317, -0.809770941734314, -0.7966198325157166, -0.7848206758499146, -0.7744399309158325, -0.7655269503593445, -0.7581169605255127, -0.752234160900116, -0.7478940486907959, -0.745106041431427, -0.7438750267028809, -0.7442034482955933, -0.746092677116394, -0.7495443224906921, -0.754561185836792, -0.7611485123634338, -0.769314706325531, -0.7790719270706177, -0.7904366850852966, -0.8034306764602661, -0.8180809617042542, -0.8344204425811768, -0.8524883389472961, -0.8723304271697998, -0.8939995765686035, -0.9175558686256409, -0.9430669546127319, -0.9706085920333862, -1.0002647638320923, -1.0321282148361206, -1.066300630569458, -1.1028934717178345, -1.1420278549194336, -1.183835506439209, -1.2284587621688843, -1.276051640510559, -1.3267802000045776, -1.380822777748108, -1.4383710622787476, -1.4996304512023926, -1.5648208856582642, -1.634177327156067, -1.707950472831726, -1.786407470703125, -1.8698325157165527, -1.9585272073745728, -2.05281138420105, -2.1530230045318604, -2.259519100189209, -2.3726754188537598, -2.4928860664367676, -2.620563268661499, -2.756136894226074, -2.900052309036255, -3.052769184112549, -3.2147583961486816, -3.38649845123291, -3.568471908569336, -3.761157751083374, -3.9650256633758545, -4.180525779724121, -4.408078670501709, -4.648059368133545, -4.900784492492676, -5.166488170623779, -5.445303916931152, -5.737232685089111, -6.042115211486816, -6.359595775604248, -6.689080715179443, -7.029697895050049, -7.380247116088867, -7.739151477813721, -8.10440731048584, -8.47353744506836, -8.843547821044922, -9.210894584655762, -9.571465492248535, -9.920583724975586, -10.253036499023438, -10.562150001525879, -10.840926170349121, -11.082202911376953, -11.278874397277832, -11.424150466918945, -11.51186466217041, -11.536797523498535, -11.494993209838867, -11.384053230285645, -11.203353881835938, -10.954183578491211, -10.639763832092285, -10.265146255493164, -9.83699893951416, -9.363286018371582, -8.851899147033691, -8.311421394348145, -7.750715732574463, -7.178536891937256, -6.603194713592529, -6.032287120819092, -5.472510814666748, -4.92954683303833, -4.408019065856934, -3.9115047454833984, -3.442596912384033, -3.00299072265625, -2.5935921669006348, -2.2146334648132324, -1.8657886981964111, -1.5462853908538818, -1.2550042867660522, -0.9905704259872437, -0.7514307498931885, -0.5359198451042175, -0.3423146605491638, -0.16887825727462769, -0.013894779607653618, 0.12430406361818314, 0.24731920659542084, 0.35667023062705994, 0.45378613471984863, 0.5400001406669617, 0.6165471076965332, 0.6845640540122986, 0.7450919151306152, 0.7990788817405701, 0.8473849892616272, 0.89078688621521, 0.9299832582473755, 0.9656006097793579, 0.9981987476348877, 1.0282764434814453, 1.056276798248291, 1.082592248916626, 1.107569932937622, 1.131515622138977, 1.154698371887207, 1.177354097366333, 1.1933387517929077, 1.2036423683166504, 1.209173560142517, 1.2107603549957275, 1.2091518640518188, 1.2050215005874634, 1.1989706754684448, 1.1915332078933716, 1.1831798553466797, 1.1743237972259521, 1.1653252840042114, 1.1564966440200806, 1.1481072902679443, 1.1403884887695312, 1.133538007736206, 1.1277236938476562, 1.1230883598327637, 1.1197525262832642, 1.1178183555603027, 1.1173726320266724, 1.1184892654418945, 1.121232032775879, 1.1256568431854248, 1.131813645362854, 1.1397483348846436, 1.1495040655136108, 1.1611229181289673, 1.1746472120285034, 1.1901205778121948, 1.20758855342865, 1.2271000146865845, 1.2487075328826904, 1.2724686861038208, 1.2984455823898315, 1.3267067670822144, 1.357326626777649, 1.3903864622116089, 1.4259750843048096, 1.464188575744629, 1.5051313638687134, 1.548916220664978, 1.5956650972366333, 1.6455087661743164, 1.6985877752304077, 1.7550526857376099, 1.8150640726089478, 1.8787932395935059, 1.9464223384857178, 2.018144130706787, 2.094163417816162, 2.1746950149536133, 2.2599666118621826, 2.3502156734466553, 2.4456918239593506, 2.5466549396514893, 2.653374671936035, 2.7661304473876953, 2.885209798812866, 3.01090669631958, 3.1435205936431885, 3.283353090286255, 3.4307055473327637, 3.5858755111694336, 3.749152421951294, 3.920811653137207, 4.101109981536865, 4.2902750968933105, 4.488501071929932, 4.6959333419799805, 4.912661552429199, 5.138701438903809, 5.373983860015869, 5.61833381652832, 5.871453285217285, 6.132898330688477, 6.402059555053711, 6.678133964538574, 6.960103511810303, 7.246708393096924, 7.53642463684082, 7.8274431228637695, 8.11765193939209, 8.404626846313477, 8.685628890991211, 8.957613945007324, 9.217256546020508, 9.460988998413086, 9.68506145477295, 9.885615348815918, 10.058786392211914, 10.200817108154297, 10.30819034576416, 10.37777042388916, 10.406944274902344, 10.39376163482666, 10.337054252624512, 10.236533164978027, 10.092841148376465, 9.907576560974121, 9.683258056640625, 9.42325210571289, 9.130684852600098, 8.80942440032959, 8.463906288146973, 8.098958015441895, 7.71960973739624, 7.330912113189697, 6.937774181365967, 6.544824123382568, 6.15629768371582, 5.7759599685668945, 5.407054424285889, 5.052282333374023, 4.713805198669434, 4.393266201019287, 4.091828346252441, 3.8102176189422607, 3.548779249191284, 3.3075294494628906, 3.086211919784546, 2.884348154067993, 2.7012882232666016, 2.536252498626709, 2.388371467590332, 2.2567191123962402, 2.14034104347229, 2.038278102874756, 1.9495859146118164, 1.8733487129211426, 1.808692455291748, 1.7547924518585205, 1.7108795642852783, 1.6762442588806152, 1.650238037109375, 1.632275104522705, 1.6218311786651611, 1.6184422969818115, 1.6217031478881836, 1.6312646865844727, 1.6468313932418823, 1.6681585311889648, 1.695049524307251, 1.7273527383804321, 1.7649590969085693, 1.807798981666565, 1.8558403253555298, 1.9090856313705444, 1.967570185661316, 2.031359910964966, 2.10054874420166, 2.175257921218872, 2.255633592605591, 2.3418445587158203, 2.4340813159942627, 2.5325541496276855, 2.637490749359131, 2.7491350173950195, 2.867743492126465, 2.993584156036377, 3.1269326210021973, 3.268068790435791, 3.41727352142334, 3.5748229026794434, 3.7409827709198, 3.916003465652466, 4.100110054016113, 4.293496131896973, 4.496310710906982, 4.708648681640625, 4.930534362792969, 5.161909580230713, 5.402614116668701, 5.652365684509277, 5.910740375518799, 6.177148818969727, 6.450812816619873, 6.730737686157227, 7.015689849853516, 7.304171085357666, 7.594394683837891, 7.884270191192627, 8.171388626098633, 8.453018188476562, 8.726115226745605, 8.987337112426758, 9.233086585998535, 9.45956039428711, 9.662829399108887, 9.838930130004883, 9.983981132507324, 10.094315528869629, 10.165621757507324, 10.19417953491211, 10.17701530456543, 10.112052917480469, 9.998230934143066, 9.835590362548828, 9.625308990478516, 9.369684219360352, 9.072059631347656, 8.736698150634766, 8.368613243103027, 7.973364353179932, 7.556840896606445, 7.12504243850708, 6.683874130249023, 6.238964080810547, 5.795517921447754, 5.3582072257995605, 4.931097507476807, 4.517612457275391, 4.1205291748046875, 3.7419962882995605, 3.3835763931274414, 3.046297311782837, 2.7307140827178955, 2.436974048614502, 2.164881944656372, 1.913961410522461, 1.6835142374038696, 1.4726718664169312, 1.280442237854004, 1.1057496070861816, 0.9474689960479736, 0.8044535517692566, 0.6755583882331848, 0.5596585273742676, 0.4556629955768585, 0.36252540349960327, 0.27925172448158264, 0.20490507781505585, 0.13860884308815002, 0.07954785972833633, 0.026968318969011307, -0.019823329523205757, -0.06146231293678284, -0.09852804243564606, -0.13154703378677368, -0.16099607944488525, -0.1873055249452591, -0.21086271107196808, -0.2320152372121811, -0.25107428431510925, -0.26831772923469543, -0.2839931547641754, -0.2983206510543823, -0.31149551272392273, -0.3236906826496124, -0.3350589871406555, -0.34573519229888916, -0.3558380603790283, -0.3654719293117523, -0.37472838163375854, -0.3836875557899475, -0.39241960644721985, -0.40098559856414795, -0.4094387888908386, -0.4178253710269928, -0.42618528008461, -0.4345530569553375, -0.44295835494995117, -0.4514264762401581, -0.45997902750968933, -0.4686341881752014, -0.4774071276187897, -0.4863104224205017, -0.49535423517227173, -0.5045466423034668, -0.5138937830924988, -0.523400068283081, -0.5330684781074524, -0.5429003834724426, -0.5528960227966309, -0.5621314644813538, -0.570799708366394, -0.5790740847587585, -0.5871104001998901, -0.5950484871864319, -0.6030141711235046, -0.611120879650116, -0.61947101354599, -0.6281576156616211, -0.6372655034065247, -0.6468725204467773, -0.6570507884025574, -0.6678675413131714, -0.6793862581253052, -0.691667377948761, -0.7047691941261292, -0.7187485694885254, -0.7336616516113281, -0.7495643496513367, -0.7665131092071533, -0.7845651507377625, -0.8037794232368469, -0.8242166638374329, -0.8459399342536926, -0.8690152764320374, -0.8935118317604065, -0.9195024967193604, -0.9470639824867249, -0.9762776494026184, -1.0072295665740967, -1.0400108098983765, -1.0747183561325073, -1.1114548444747925, -1.1503294706344604, -1.1914581060409546, -1.2349637746810913, -1.2809773683547974, -1.3296372890472412, -1.3810909986495972, -1.4354944229125977, -1.4930131435394287, -1.5538221597671509, -1.6181068420410156, -1.686063289642334, -1.7578984498977661, -1.8338305950164795, -1.914089560508728, -1.9989172220230103, -2.0885674953460693, -2.1833062171936035, -2.2834110260009766, -2.389172077178955, -2.500889778137207, -2.618875741958618, -2.7434511184692383, -2.8749449253082275, -3.01369309425354, -3.160034418106079, -3.314310073852539, -3.4768571853637695, -3.6480064392089844, -3.8280749320983887, -4.017360687255859, -4.216133117675781, -4.424624443054199, -4.64301872253418, -4.871436595916748, -5.109922885894775, -5.358426570892334, -5.616783618927002, -5.884692192077637, -6.161689281463623, -6.447126388549805, -6.740138053894043, -7.039614677429199, -7.344173431396484, -7.652129650115967, -7.961471080780029, -8.2698392868042, -8.574515342712402, -8.872418403625488, -9.160114288330078, -9.433850288391113, -9.689593315124512, -9.923110008239746, -10.130054473876953, -10.30609130859375, -10.447032928466797, -10.54900074005127, -10.608592987060547, -10.623050689697266, -10.590423583984375, -10.509696960449219, -10.380899429321289, -10.205147743225098, -9.98465347290039, -9.722661018371582, -9.42333984375, -9.091623306274414, -8.733019828796387, -8.353395462036133, -7.9578857421875, -7.551731586456299, -7.140089988708496, -6.727872371673584, -6.319611549377441, -5.919363021850586, -5.530643463134766, -5.156397819519043, -4.798995494842529, -4.460249900817871, -4.141452789306641, -3.8434245586395264, -3.5665676593780518, -3.3109259605407715, -3.076244592666626, -2.862025022506714, -2.66757869720459, -2.492074728012085, -2.334582805633545, -2.194108247756958, -2.069624423980713, -1.960098147392273, -1.8645099401474, -1.7818711996078491, -1.7112363576889038, -1.65171217918396, -1.6024647951126099, -1.5627230405807495, -1.5317811965942383, -1.5089994668960571, -1.4938037395477295, -1.4856836795806885, -1.4841910600662231, -1.4889367818832397, -1.4995884895324707, -1.515866994857788, -1.537543773651123, -1.5644373893737793, -1.5964106321334839, -1.633367896080017, -1.6752523183822632, -1.7220432758331299, -1.7737540006637573, -1.8304295539855957, -1.8921451568603516, -1.9590034484863281, -2.0311341285705566, -2.1086907386779785, -2.1918509006500244, -2.280813694000244, -2.375798463821411, -2.4770429134368896, -2.5848021507263184, -2.6993467807769775, -2.8209593296051025, -2.949934244155884, -3.0865728855133057, -3.2311811447143555, -3.3840651512145996, -3.5455269813537598, -3.715857982635498, -3.8953332901000977, -4.084203243255615, -4.2826828956604, -4.4909443855285645, -4.70910120010376, -4.93719482421875, -5.175178527832031, -5.42289924621582, -5.6800761222839355, -5.9462761878967285, -6.220892906188965, -6.503116607666016, -6.791909694671631, -7.085976600646973, -7.3837385177612305, -7.68330717086792, -7.982468128204346, -8.27866268157959, -8.489163398742676, -8.61737060546875, -8.66693115234375, -8.641947746276855, -8.547128677368164, -8.387869834899902, -8.17025375366211, -7.900979995727539, -7.587240695953369, -7.236544132232666, -6.856518268585205, -6.4547038078308105, -6.038356304168701, -5.614275932312012, -5.18866491317749, -4.767030715942383, -4.354124069213867, -3.9539144039154053, -3.5696017742156982, -3.2036499977111816, -2.857842206954956, -2.53334903717041, -2.2308027744293213, -1.9503754377365112, -1.6918545961380005, -1.4547157287597656, -1.238188624382019, -1.0413168668746948, -0.8630103468894958, -0.7020899057388306, -0.557325541973114, -0.4274674952030182, -0.31127169728279114, -0.2075195014476776, -0.11503328382968903, -0.03268745541572571, 0.040583495050668716, 0.10578006505966187, 0.16383503377437592, 0.21561264991760254, 0.2619093656539917, 0.3034557104110718, 0.34091898798942566, 0.3749067485332489, 0.4059704542160034, 0.43460971117019653, 0.4612763226032257, 0.48637863993644714, 0.5102857947349548, 0.533331573009491, 0.555818498134613, 0.5780215263366699, 0.6001916527748108, 0.6225588917732239, 0.6453359127044678, 0.6687203645706177, 0.6928979158401489, 0.7180445194244385, 0.7443287968635559, 0.7719141840934753, 0.8009608387947083, 0.8316274285316467, 0.8640729784965515, 0.8984584808349609, 0.9349481463432312, 0.9737113118171692, 1.014923334121704, 1.058767318725586, 1.1054353713989258, 1.1551294326782227, 1.2080632448196411, 1.2644630670547485, 1.3245692253112793, 1.3886369466781616, 1.4569381475448608, 1.5297622680664062, 1.6074175834655762, 1.690232515335083, 1.7785567045211792, 1.8727619647979736, 1.9732437133789062, 2.0804216861724854, 2.1947402954101562, 2.3166701793670654, 2.4467077255249023, 2.585374593734741, 2.7332186698913574, 2.890810966491699, 3.0587453842163086, 3.2376348972320557, 3.428107261657715, 3.630800724029541, 3.846355438232422, 4.075404644012451, 4.318562030792236, 4.5764079093933105, 4.849469184875488, 5.13819694519043, 5.442937850952148, 5.76390266418457, 6.101123809814453, 6.453835487365723, 6.820990085601807, 7.201193809509277, 7.592634201049805, 7.993009567260742, 8.399457931518555, 8.808494567871094, 9.215953826904297, 9.616957664489746, 10.005903244018555, 10.376487731933594, 10.721778869628906, 11.034342765808105, 11.306426048278809, 11.530208587646484, 11.698111534118652, 11.80316162109375, 11.839377403259277, 11.802160263061523, 11.688653945922852, 11.498022079467773, 11.2316255569458, 10.893058776855469, 10.488039016723633, 10.024152755737305, 9.510472297668457, 8.957097053527832, 8.374649047851562, 7.773774147033691, 7.164697647094727, 6.556853771209717, 5.958613395690918, 5.37711238861084, 4.81817626953125, 4.286320209503174, 3.784817934036255, 3.3158087730407715, 2.8804361820220947, 2.4789962768554688, 2.1110870838165283, 1.7757515907287598, 1.4716088771820068, 1.1969693899154663, 0.949934720993042, 0.7284802794456482, 0.5305240750312805, 0.35398054122924805, 0.19680269062519073, 0.05701373517513275, -0.06727034598588943, -0.17782564461231232, -0.27631109952926636, -0.3642641305923462, -0.4431001543998718, -0.5141147971153259, -0.5784884691238403, -0.6372923851013184, -0.6914955973625183, -0.7419728636741638, -0.7895124554634094, -0.8348244428634644, -0.8785486221313477, -0.9212623238563538, -0.9634877443313599, -1.0056989192962646, -1.048328161239624, -1.0917725563049316, -1.1363989114761353, -1.1825494766235352, -1.2305458784103394, -1.2806943655014038, -1.3332887887954712, -1.388614296913147, -1.446950912475586, -1.508575439453125, -1.5737651586532593, -1.6427987813949585, -1.7159593105316162, -1.7935354709625244, -1.8758231401443481, -1.963126540184021, -2.0557594299316406, -2.1540451049804688, -2.2583184242248535, -2.3689234256744385, -2.486215829849243, -2.6105599403381348, -2.7423295974731445, -2.8819050788879395, -3.0296709537506104, -3.18601393699646, -3.351317882537842, -3.5259597301483154, -3.7103023529052734, -3.9046883583068848, -4.109430313110352, -4.324799060821533, -4.551013469696045, -4.788222312927246, -5.0364885330200195, -5.295769214630127, -5.515526294708252, -5.698909282684326, -5.848718166351318, -5.967467308044434, -6.057446002960205, -6.120768070220947, -6.159418106079102, -6.175282955169678, -6.170185089111328, -6.145898818969727, -6.1041669845581055, -6.046709060668945, -5.975222110748291, -5.891380786895752, -5.796831130981445, -5.6931843757629395, -5.582006454467773, -5.464807987213135, -5.34303617477417, -5.218062877655029, -5.091177940368652, -4.96358060836792, -4.836376667022705, -4.7105712890625, -4.587071418762207, -4.466681957244873, -4.35011100769043, -4.237969875335693, -4.130779266357422, -4.028973579406738, -3.932907819747925, -3.842864513397217, -3.759059429168701, -3.6816494464874268, -3.6107401847839355, -3.5463919639587402, -3.4886276721954346, -3.4374380111694336, -3.3927884101867676, -3.354624032974243, -3.3228747844696045, -3.2974600791931152, -3.278292655944824, -3.265281915664673, -3.2583374977111816, -3.2573719024658203, -3.262301445007324, -3.27305006980896, -3.289548635482788, -3.3117380142211914, -3.3395681381225586, -3.372999429702759, -3.4120032787323, -3.4565608501434326, -3.5066640377044678, -3.562314033508301, -3.623521089553833, -3.6903038024902344, -3.7626867294311523, -3.84070086479187, -3.9243805408477783, -4.013761520385742, -4.108880043029785, -4.209769248962402, -4.316455841064453, -4.428959369659424, -4.547286033630371, -4.671425819396973, -4.80134916305542, -4.9370012283325195, -5.078295707702637, -5.225111484527588, -5.377285480499268, -5.534605979919434, -5.696805953979492, -5.863556385040283, -6.034458160400391, -6.209036350250244, -6.3867316246032715, -6.566893577575684, -6.748775482177734, -6.931529521942139, -7.114201545715332, -7.2957305908203125, -7.474949359893799, -7.65058708190918, -7.82127571105957, -7.985561847686768, -8.14192008972168, -8.288773536682129, -8.424513816833496, -8.54753589630127, -8.656262397766113, -8.749188423156738, -8.82491397857666, -8.882184028625488, -8.91993522644043, -8.937325477600098, -8.9337739944458, -8.908988952636719, -8.862988471984863, -8.795222282409668, -8.705572128295898, -8.594348907470703, -8.46227741241455, -8.31047248840332, -8.140400886535645, -7.953832626342773, -7.752790451049805, -7.539487361907959, -7.316263198852539, -7.085524082183838, -6.849679470062256, -6.611088752746582, -6.372011661529541, -6.1345672607421875, -5.900702476501465, -5.672170639038086, -5.450514316558838, -5.237059593200684, -5.0329179763793945, -4.838992118835449, -4.655984878540039, -4.484416961669922, -4.324641704559326, -4.176865577697754, -4.041164875030518, -3.9175069332122803, -3.8057682514190674, -3.7057509422302246, -3.6172001361846924, -3.539818048477173, -3.4732773303985596, -3.417232036590576, -3.371328353881836, -3.335211992263794, -3.3085362911224365, -3.290966033935547, -3.282184362411499, -3.281893253326416, -3.2898178100585938, -3.3057079315185547, -3.3293373584747314, -3.3605055809020996, -3.3990366458892822, -3.4447784423828125, -3.497601270675659, -3.557396650314331, -3.6240742206573486, -3.6975607872009277, -3.777796506881714, -3.864732503890991, -3.958327293395996, -4.058543682098389, -4.165344715118408, -4.278687953948975, -4.398523330688477, -4.524785995483398, -4.657392501831055, -4.7962327003479, -4.941165924072266, -5.092011451721191, -5.248544216156006, -5.410484790802002, -5.577491760253906, -5.749154567718506, -5.924984455108643, -6.104406356811523, -6.2867512702941895, -6.471247673034668, -6.657017230987549, -6.843068599700928, -7.028294563293457, -7.211470603942871, -7.39125919342041, -7.566211700439453, -7.734781742095947, -7.89533805847168, -8.046182632446289, -8.185575485229492, -8.311765670776367, -8.423022270202637, -8.517675399780273, -8.594158172607422, -8.65104866027832, -8.687116622924805, -8.701364517211914, -8.69306468963623, -8.661799430847168, -8.6074800491333, -8.530364990234375, -8.431065559387207, -8.31053638458252, -8.170063018798828, -8.011226654052734, -7.835864543914795, -7.646029472351074, -7.443929195404053, -7.231875896453857, -7.012228488922119, -6.787337779998779, -6.5594987869262695, -6.330904483795166, -6.103612422943115, -5.879511833190918, -5.660306453704834, -5.447499752044678, -5.242388725280762, -5.046065330505371, -4.85942268371582, -4.683164119720459, -4.517817974090576, -4.363752365112305, -4.221194267272949, -4.090244770050049, -3.970900774002075, -3.8630683422088623, -3.7665822505950928, -3.681220769882202, -3.606718063354492, -3.542778730392456, -3.4890878200531006, -3.4453201293945312, -3.4111485481262207, -3.386251449584961, -3.370316743850708, -3.3630475997924805, -3.3641645908355713, -3.373408794403076, -3.390542984008789, -3.4153528213500977, -3.4476468563079834, -3.487255573272705, -3.534031629562378, -3.58784818649292, -3.6485965251922607, -3.7161853313446045, -3.790537118911743, -3.871586561203003, -3.9592766761779785, -4.053556442260742, -4.1543755531311035, -4.261682987213135, -4.375420093536377, -4.495517253875732, -4.621888637542725, -4.7544264793396, -4.892995357513428, -5.037425518035889, -5.187506675720215, -5.342979907989502, -5.503531455993652, -5.668784141540527, -5.838290214538574, -6.0115227699279785, -6.187869071960449, -6.3666229248046875, -6.546978950500488, -6.728025436401367, -6.908745288848877, -7.088008403778076, -7.263887405395508, -7.434388637542725, -7.527000904083252, -7.547210216522217, -7.500783920288086, -7.3938093185424805, -7.232691764831543, -7.024099826812744, -6.774876117706299, -6.491919040679932, -6.182051658630371, -5.851886749267578, -5.507696628570557, -5.155307769775391, -4.8000102043151855, -4.446497440338135, -4.0988311767578125, -3.7604329586029053, -3.434095621109009, -3.1220126152038574, -2.8258228302001953, -2.546661376953125, -2.285219430923462, -2.0418026447296143, -1.8163909912109375, -1.6086962223052979, -1.418213129043579, -1.2442691326141357, -1.086065649986267, -0.9427158236503601, -0.8132764101028442, -0.6967743039131165, -0.5922286510467529, -0.4986685812473297, -0.4151473343372345, -0.34075286984443665, -0.2746157646179199, -0.21591460704803467, -0.16387945413589478, -0.11779355257749557, -0.07699374854564667, -0.040869832038879395, -0.008863039314746857, 0.019536053761839867, 0.04479008913040161, 0.06731779873371124, 0.08749702572822571, 0.10566788911819458, 0.12213589251041412, 0.1371750682592392, 0.15103092789649963, 0.16392339766025543, 0.17604951560497284, 0.18758602440357208, 0.19869175553321838, 0.20950990915298462, 0.2201700359582901, 0.23079006373882294, 0.24147792160511017, 0.25233322381973267, 0.26344868540763855, 0.274911493062973, 0.28680455684661865, 0.2992075979709625, 0.3121982216835022, 0.3258528411388397, 0.34024763107299805, 0.3554593026638031, 0.3715659976005554, 0.38864797353744507, 0.40678831934928894, 0.42607375979423523, 0.4465952515602112, 0.46844878792762756, 0.4917360544204712, 0.5165651440620422, 0.5430513024330139, 0.571317732334137, 0.6014963388442993, 0.633728563785553, 0.6681662797927856, 0.7049728035926819, 0.7443236708641052, 0.7864079475402832, 0.831429123878479, 0.8796064853668213, 0.9311761260032654, 0.986392617225647, 1.0455302000045776, 1.1088842153549194, 1.1767730712890625, 1.2495396137237549, 1.3275527954101562, 1.4112098217010498, 1.5009379386901855, 1.5971959829330444, 1.700476884841919, 1.8113092184066772, 1.930259108543396, 2.057931900024414, 2.194973945617676, 2.3420729637145996, 2.49996018409729, 2.6691744327545166, 2.8502910137176514, 3.043914556503296, 3.250669240951538, 3.4711904525756836, 3.706111431121826, 3.956050395965576, 4.221591949462891, 4.50326681137085, 4.801525115966797, 5.116706848144531, 5.449004173278809, 5.7984185218811035, 6.164709091186523, 6.547336101531982, 6.945394039154053, 7.357537746429443, 7.781905174255371, 8.216032981872559, 8.656773567199707, 9.100217819213867, 9.541629791259766, 9.975401878356934, 10.395041465759277, 10.793208122253418, 11.161802291870117, 11.49212646484375, 11.775129318237305, 12.001728057861328, 12.16321086883545, 12.251697540283203, 12.260629653930664, 12.18525505065918, 12.023051261901855, 11.774032592773438, 11.440908432006836, 11.029051780700684, 10.546276092529297, 10.002432823181152, 9.4088716506958, 8.777827262878418, 8.121784210205078, 7.452892303466797, 6.782467842102051, 6.120617389678955, 5.475996494293213, 4.855687141418457, 4.265187740325928, 3.708486557006836, 3.1881940364837646, 2.70571231842041, 2.2614188194274902, 1.8548537492752075, 1.4848958253860474, 1.1499227285385132, 0.8479523658752441, 0.5767620801925659, 0.3339886963367462, 0.11720863729715347, -0.07599849253892899, -0.2480015903711319, -0.4010820984840393, -0.5374089479446411, -0.6590219140052795, -0.7678220868110657, -0.8655681014060974, -0.9538761377334595, -1.0342236757278442, -1.1079555749893188, -1.1762909889221191, -1.240333080291748, -1.3010774850845337, -1.359421968460083, -1.416176438331604, -1.472071886062622, -1.5277698040008545, -1.5838701725006104, -1.6409196853637695, -1.699419379234314, -1.7598313093185425, -1.8225843906402588, -1.8880805969238281, -1.9566996097564697, -2.0288033485412598, -2.1047399044036865, -2.184847116470337, -2.2694549560546875, -2.358889102935791, -2.4534709453582764, -2.553521156311035, -2.659358501434326, -2.7713027000427246, -2.889671802520752, -3.0147833824157715, -3.1469526290893555, -3.2864902019500732, -3.433699131011963, -3.5888729095458984, -3.752289295196533, -3.9242053031921387, -4.104850769042969, -4.2944207191467285, -4.4930644035339355, -4.7008771896362305, -4.9178853034973145, -5.144032001495361, -5.3791632652282715, -5.623006820678711, -5.875155448913574, -6.078813552856445, -6.237485408782959, -6.35440731048584, -6.432617664337158, -6.475021839141846, -6.484437942504883, -6.463637351989746, -6.415366172790527, -6.3423590660095215, -6.24733829498291, -6.133009910583496, -6.00204610824585, -5.857067584991455, -5.700622081756592, -5.535159111022949, -5.363010406494141, -5.186366081237793, -5.007259845733643, -4.827555179595947, -4.648935317993164, -4.472897052764893, -4.300753116607666, -4.133632183074951, -3.972484827041626, -3.8180954456329346, -3.6710898876190186, -3.5319507122039795, -3.401028871536255, -3.278560161590576, -3.164677143096924, -3.0594260692596436, -2.962777614593506, -2.8746421337127686, -2.7948801517486572, -2.723313808441162, -2.6597368717193604, -2.6039233207702637, -2.5556344985961914, -2.514627456665039, -2.480658769607544, -2.443432331085205, -2.4039621353149414, -2.3631398677825928, -2.3217451572418213, -2.280453681945801, -2.2398459911346436, -2.2004175186157227, -2.162585735321045, -2.1267004013061523, -2.0930497646331787, -2.061868906021118, -2.03334641456604, -2.007631778717041, -1.9848397970199585, -1.965057611465454, -1.9483484029769897, -1.9347566366195679, -1.9243115186691284, -1.917030930519104, -1.9129244089126587, -1.9119958877563477, -1.9142457246780396, -1.9196735620498657, -1.9282793998718262, -1.9400657415390015, -1.9550381898880005, -1.9732071161270142, -1.9945886135101318, -2.01920485496521, -2.0470848083496094, -2.07826566696167, -2.1127912998199463, -2.1507151126861572, -2.1920979022979736, -2.2370097637176514, -2.285529136657715, -2.337743043899536, -2.3937480449676514, -2.453648090362549, -2.5175564289093018, -2.5855941772460938, -2.6578900814056396, -2.7345805168151855, -2.8158082962036133, -2.9017226696014404, -2.9924778938293457, -3.0882325172424316, -3.189147472381592, -3.29538631439209, -3.4071109294891357, -3.524482011795044, -3.6476547718048096, -3.776777505874634, -3.9119865894317627, -4.053404808044434, -4.201136112213135, -4.355258941650391, -4.515824317932129, -4.6828460693359375, -4.856295585632324, -5.036093711853027, -5.222102642059326, -5.414114475250244, -5.611843585968018, -5.814915657043457, -6.022854804992676, -6.235074520111084, -6.450864315032959, -6.669381618499756, -6.889638423919678, -7.110496520996094, -7.330658435821533, -7.548666954040527, -7.762904167175293, -7.971596717834473, -8.172830581665039, -8.36456298828125, -8.544655799865723, -8.710899353027344, -8.861061096191406, -8.992932319641113, -9.10438060760498, -9.193412780761719, -9.258240699768066, -9.297343254089355, -9.309529304504395, -9.293991088867188, -9.250356674194336, -9.178714752197266, -9.079639434814453, -8.954184532165527, -8.80387020111084, -8.630642890930176, -8.4368257522583, -8.225050926208496, -7.9981842041015625, -7.759246349334717, -7.511328220367432, -7.257513523101807, -7.000804901123047, -6.744060516357422, -6.489242076873779, -6.238203525543213, -5.992653846740723, -5.754130840301514, -5.523983478546143, -5.3033623695373535, -5.0932207107543945, -4.894317150115967, -4.7072272300720215, -4.532355308532715, -4.369953155517578, -4.220134258270264, -4.082895755767822, -3.9581329822540283, -3.845660448074341, -3.7452266216278076, -3.6565299034118652, -3.5792317390441895, -3.5129709243774414, -3.4573721885681152, -3.4120566844940186, -3.376649856567383, -3.3507866859436035, -3.334118127822876, -3.3263144493103027, -3.3270678520202637, -3.336094617843628, -3.353137493133545, -3.3779637813568115, -3.410367727279663, -3.4501683712005615, -3.497208595275879, -3.55135440826416, -3.612492322921753, -3.6805269718170166, -3.7553796768188477, -3.836984395980835, -3.9252851009368896, -4.020232677459717, -4.121780872344971, -4.229881763458252, -4.344481945037842, -4.465517997741699, -4.592910289764404, -4.726557731628418, -4.866332054138184, -5.01207160949707, -5.163572788238525, -5.320585250854492, -5.482802391052246, -5.6498541831970215, -5.821297645568848, -5.996612071990967, -6.175187587738037, -6.356320381164551, -6.539203643798828, -6.722923755645752, -6.906455993652344, -7.088662147521973, -7.268291473388672, -7.443982124328613, -7.614272117614746, -7.777608394622803, -7.932361125946045, -8.076848030090332, -8.209356307983398, -8.328177452087402, -8.43163776397705, -8.518139839172363, -8.586203575134277, -8.634509086608887, -8.66193962097168, -8.667620658874512, -8.650958061218262, -8.611662864685059, -8.549779891967773, -8.465692520141602, -8.360126495361328, -8.234139442443848, -8.08909797668457, -7.926643371582031, -7.748655796051025, -7.557201385498047, -7.354482173919678, -7.142781734466553, -6.924411296844482, -6.701657772064209, -6.476738452911377, -6.251760005950928, -6.028686046600342, -5.809310436248779, -5.595242023468018, -5.387890338897705, -5.1884660720825195, -4.997981071472168, -4.817254066467285, -4.646925449371338, -4.487468242645264, -4.33920431137085, -4.202322483062744, -4.076895713806152, -3.962898015975952, -3.860220432281494, -3.768688917160034, -3.688076972961426, -3.618119716644287, -3.558525323867798, -3.5089855194091797, -3.469184160232544, -3.438805103302002, -3.4175384044647217, -3.4050843715667725, -3.4011590480804443, -3.405496120452881, -3.417848825454712, -3.4379920959472656, -3.4657223224639893, -3.5008583068847656, -3.5432395935058594, -3.592726469039917, -3.649198293685913, -3.7125513553619385, -3.7826974391937256, -3.859560251235962, -3.9430742263793945, -4.033179759979248, -4.129821300506592, -4.2329421043396, -4.34248161315918, -4.458369255065918, -4.580522537231445, -4.708837032318115, -4.843186378479004, -4.9834113121032715, -5.129316329956055, -5.280661582946777, -5.437156677246094, -5.598451614379883, -5.764130592346191, -5.933704376220703, -6.106602668762207, -6.282166481018066, -6.4596428871154785, -6.638178825378418, -6.816816329956055, -6.994492053985596, -7.1700358390808105, -7.342172622680664, -7.509531021118164, -7.670650005340576, -7.823994159698486, -7.967970848083496, -8.100953102111816, -8.221308708190918, -8.327427864074707, -8.417760848999023, -8.490856170654297, -8.54539966583252, -8.580254554748535, -8.594500541687012, -8.587465286254883, -8.558762550354004, -8.508304595947266, -8.436326026916504, -8.343381881713867, -8.230344772338867, -8.09839153289795, -7.948969841003418, -7.783771514892578, -7.604685306549072, -7.41375207901001, -7.2131147384643555, -7.004966735839844, -6.791502952575684, -6.574875831604004, -6.357152462005615, -6.140280723571777, -5.926063537597656, -5.716134548187256, -5.511949062347412, -5.3147735595703125, -5.125686168670654, -4.945580959320068, -4.775174617767334, -4.615019798278809, -4.465517044067383, -4.326930999755859, -4.199407577514648, -4.082987308502197, -3.9776244163513184, -3.883200168609619, -3.7995381355285645, -3.72641658782959, -3.6635818481445312, -3.6107571125030518, -3.567652463912964, -3.533972978591919, -3.5094246864318848, -3.493720769882202, -3.4865853786468506, -3.4877569675445557, -3.496990919113159, -3.514061212539673, -3.538761854171753, -3.570906162261963, -3.6103272438049316, -3.656877279281616, -3.710426092147827, -3.770860195159912, -3.8380796909332275, -3.911997079849243, -3.9925343990325928, -4.079619407653809, -4.173183917999268, -4.273158550262451, -4.379469871520996, -4.492035388946533, -4.610759735107422, -4.735528945922852, -4.82009744644165, -4.868595600128174, -4.884974479675293, -4.873006820678711, -4.836282730102539, -4.778208255767822, -4.70199728012085, -4.610665798187256, -4.507026195526123, -4.393680572509766, -4.273017883300781, -4.147212982177734, -4.018224239349365, -3.8877992630004883, -3.757479190826416, -3.6286070346832275, -3.5023369789123535, -3.379645586013794, -3.261345624923706, -3.1480987071990967, -3.04042911529541, -2.938739776611328, -2.843324661254883, -2.754383087158203, -2.6720337867736816, -2.5963263511657715, -2.5272531509399414, -2.4647600650787354, -2.4087560176849365, -2.359121561050415, -2.3157167434692383, -2.278388261795044, -2.246974468231201, -2.22131085395813, -2.2012343406677246, -2.186587333679199, -2.1772196292877197, -2.17299222946167, -2.1737775802612305, -2.1794631481170654, -2.189950704574585, -2.2051584720611572, -2.2250208854675293, -2.2494900226593018, -2.278534173965454, -2.3121395111083984, -2.350309133529663, -2.3930628299713135, -2.4404373168945312, -2.492485523223877, -2.5492756366729736, -2.610891819000244, -2.6774322986602783, -2.7490100860595703, -2.8257503509521484, -2.9077913761138916, -2.995281934738159, -3.08838152885437, -3.187257766723633, -3.2920854091644287, -3.4030442237854004, -3.5203170776367188, -3.6440865993499756, -3.7745330333709717, -3.911829948425293, -4.056140899658203, -4.207614421844482, -4.366377353668213, -4.532530784606934, -4.706140518188477, -4.887231826782227, -5.075777530670166, -5.271689414978027, -5.474806308746338, -5.684882640838623, -5.90157413482666, -6.124425411224365, -6.352852821350098, -6.5861310958862305, -6.823378562927246, -7.063542366027832, -7.305384159088135, -7.5474724769592285, -7.788173675537109, -8.02564811706543, -8.257855415344238, -8.482563972473145, -8.697367668151855, -8.899715423583984, -9.08695125579834, -9.256361961364746, -9.405237197875977, -9.530943870544434, -9.631002426147461, -9.703169822692871, -9.74553108215332, -9.756575584411621, -9.73528003692627, -9.681164741516113, -9.594345092773438, -9.47554874420166, -9.325159072875977, -9.144275665283203, -8.934671401977539, -8.698725700378418, -8.4393310546875, -8.159790992736816, -7.863703727722168, -7.55483341217041, -7.236998081207275, -6.91395378112793, -6.589299201965332, -6.266392230987549, -5.948287487030029, -5.637692928314209, -5.336944580078125, -5.047994613647461, -4.772419452667236, -4.511434078216553, -4.265917778015137, -4.036445617675781, -3.823322057723999, -3.626619577407837, -3.4462130069732666, -3.2818167209625244, -3.1330158710479736, -2.999298334121704, -2.8800811767578125, -2.7747347354888916, -2.6826024055480957, -2.603019952774048, -2.535327434539795, -2.4788830280303955, -2.4330713748931885, -2.397310495376587, -2.3710575103759766, -2.3538119792938232, -2.345118522644043, -2.3445680141448975, -2.351797580718994, -2.3430449962615967, -2.320780038833618, -2.2872934341430664, -2.24468731880188, -2.194871664047241, -2.1395645141601562, -2.080296516418457, -2.0184168815612793, -1.9551023244857788, -1.8913681507110596, -1.8280789852142334, -1.76596200466156, -1.7056190967559814, -1.6475398540496826, -1.592113971710205, -1.539643406867981, -1.4903538227081299, -1.4444050788879395, -1.4019016027450562, -1.3629014492034912, -1.3274239301681519, -1.2954579591751099, -1.266968011856079, -1.2419002056121826, -1.2201870679855347, -1.2017524242401123, -1.1865147352218628, -1.1743903160095215, -1.1652965545654297, -1.1591533422470093, -1.1558855772018433, -1.1554243564605713, -1.1577084064483643, -1.1626847982406616, -1.1703100204467773, -1.1805500984191895, -1.1933817863464355, -1.2087920904159546, -1.2267792224884033, -1.2473523616790771, -1.2705318927764893, -1.2963496446609497, -1.3248491287231445, -1.3560850620269775, -1.3901242017745972, -1.4270447492599487, -1.4669373035430908, -1.509904146194458, -1.5560599565505981, -1.605531930923462, -1.6584596633911133, -1.7149957418441772, -1.775305986404419, -1.839569091796875, -1.9079777002334595, -1.9807379245758057, -2.058069944381714, -2.140207529067993, -2.2273991107940674, -2.3199069499969482, -2.418006658554077, -2.5219879150390625, -2.6321535110473633, -2.7488179206848145, -2.872307062149048, -3.0029561519622803, -3.141108989715576, -3.2871134281158447, -3.4413204193115234, -3.604078769683838, -3.7757301330566406, -3.9566047191619873, -4.147012233734131, -4.34723424911499, -4.5575151443481445, -4.778048038482666, -5.0089616775512695, -5.250305652618408, -5.502029895782471, -5.763964653015137, -6.035797595977783, -6.317046165466309, -6.607031345367432, -6.90484619140625, -7.20932674407959, -7.51901912689209, -7.832149505615234, -8.146599769592285, -8.459884643554688, -8.76913833618164, -9.071114540100098, -9.362198829650879, -9.63844108581543, -9.895606994628906, -10.129261016845703, -10.334864616394043, -10.507911682128906, -10.64407730102539, -10.739389419555664, -10.790412902832031, -10.79442310333252, -10.748497009277344, -10.650843620300293, -10.500923156738281, -10.299513816833496, -10.0487060546875, -9.751845359802246, -9.4133939743042, -9.03874397277832, -8.63398551940918, -8.205648422241211, -7.760437965393066, -7.304987907409668, -6.845637798309326, -6.388251304626465, -5.938079357147217, -5.499671459197998, -5.076832294464111, -4.672611713409424, -4.289333343505859, -3.928642749786377, -3.5915732383728027, -3.2786202430725098, -2.989820957183838, -2.7248330116271973, -2.4830098152160645, -2.2634682655334473, -2.0651519298553467, -1.8868844509124756, -1.7274162769317627, -1.5854624509811401, -1.4597347974777222, -1.3489665985107422, -1.2519325017929077, -1.1674625873565674, -1.0944530963897705, -1.0318729877471924, -0.9787680506706238, -0.9342626929283142, -0.8975595831871033, -0.867938220500946, -0.8447523713111877, -0.8274267315864563, -0.8154529929161072, -0.808385968208313, -0.8058393597602844, -0.8074814081192017, -0.8130308389663696, -0.8222531080245972, -0.8349564671516418, -0.8509886860847473, -0.8702338337898254, -0.8926094174385071, -0.918063759803772, -0.9465739727020264, -0.9781435132026672, -1.012800931930542, -1.0505980253219604, -1.0916087627410889, -1.1359283924102783, -1.1836720705032349, -1.2349750995635986, -1.2899914979934692, -1.3488942384719849, -1.4118751287460327, -1.4791438579559326, -1.5509289503097534, -1.6274770498275757, -1.7090532779693604, -1.7959411144256592, -1.8884423971176147, -1.986877202987671, -2.091583490371704, -2.2029168605804443, -2.3212502002716064, -2.446971893310547, -2.5804855823516846, -2.72220778465271, -2.872565269470215, -3.0319924354553223, -3.200927972793579, -3.379808187484741, -3.5690624713897705, -3.7691049575805664, -3.980325222015381, -4.2030768394470215, -4.437664031982422, -4.684326171875, -4.943218231201172, -5.214387893676758, -5.497751712799072, -5.793064594268799, -6.099889278411865, -6.417557239532471, -6.745131492614746, -7.081363677978516, -7.424653053283691, -7.773000717163086, -8.123973846435547, -8.4746675491333, -8.821682929992676, -9.161116600036621, -9.488570213317871, -9.79918098449707, -10.087691307067871, -10.348543167114258, -10.57601261138916, -10.764389991760254, -10.908182144165039, -11.002349853515625, -11.042557716369629, -11.025424003601074, -10.948745727539062, -10.811684608459473, -10.614887237548828, -10.360529899597168, -10.05227279663086, -9.695130348205566, -9.295256614685059, -8.85968017578125, -8.395989418029785, -7.912011623382568, -7.41550350189209, -6.913880348205566, -6.4139838218688965, -5.921921253204346, -5.442951202392578, -4.981436252593994, -4.540835857391357, -4.123744964599609, -3.7319562435150146, -3.3665454387664795, -3.0279645919799805, -2.716139078140259, -2.430565118789673, -2.170397996902466, -1.9345340728759766, -1.7216840982437134, -1.5304349660873413, -1.3593021631240845, -1.2067735195159912, -1.0713435411453247, -0.9515411853790283, -0.8459500670433044, -0.7532234191894531, -0.6720945239067078, -0.6013830304145813, -0.5399978756904602, -0.48693791031837463, -0.44129085540771484, -0.40223026275634766, -0.3690117597579956, -0.34096840023994446, -0.3174688518047333, -0.2979586720466614, -0.28195229172706604, -0.2690258324146271, -0.2588103115558624, -0.25098544359207153, -0.2452741116285324, -0.2414373904466629, -0.23926988244056702, -0.23859582841396332, -0.23926541209220886, -0.24115155637264252, -0.2441471815109253, -0.248162642121315, -0.25312352180480957, -0.2589688003063202, -0.26564905047416687, -0.27100157737731934, -0.27522799372673035, -0.27851247787475586, -0.28102222084999084, -0.28290823101997375, -0.2843061685562134, -0.2853373885154724, -0.28610995411872864, -0.2867197096347809, -0.28725144267082214, -0.28777992725372314, -0.28837087750434875, -0.2890821397304535, -0.2899644672870636, -0.29106250405311584, -0.29241564869880676, -0.2940587103366852, -0.29602277278900146, -0.2983356714248657, -0.30102279782295227, -0.3041074573993683, -0.30761152505874634, -0.31155577301979065, -0.3159602880477905, -0.32084497809410095, -0.32622969150543213, -0.33213475346565247, -0.33858102560043335, -0.34559035301208496, -0.3531857430934906, -0.36139151453971863, -0.3702336549758911, -0.3797399401664734, -0.3899401128292084, -0.40086624026298523, -0.4125526547431946, -0.4250364601612091, -0.43835747241973877, -0.45255860686302185, -0.4676860272884369, -0.4837893843650818, -0.5009220838546753, -0.5191415548324585, -0.5385094881057739, -0.5590920448303223, -0.5809604525566101, -0.60419100522995, -0.628865659236908, -0.6550723314285278, -0.6829053163528442, -0.7124655842781067, -0.7438615560531616, -0.7772092819213867, -0.8126333355903625, -0.8502669334411621, -0.890252947807312, -0.9327442646026611, -0.9779047966003418, -1.0259097814559937, -1.0769469738006592, -1.131217122077942, -1.1889348030090332, -1.250329852104187, -1.3156476020812988, -1.3851499557495117, -1.459116816520691, -1.537846565246582, -1.6216570138931274, -1.7108867168426514, -1.8058956861495972, -1.9070662260055542, -2.014803647994995, -2.1295366287231445, -2.2517178058624268, -2.381824493408203, -2.5203568935394287, -2.6678390502929688, -2.8248159885406494, -2.9918527603149414, -3.1695313453674316, -3.358445882797241, -3.5591981410980225, -3.7723891735076904, -3.9986112117767334, -4.2384352684021, -4.492397308349609, -4.760979175567627, -5.044588088989258, -5.34352970123291, -5.657975673675537, -5.9879279136657715, -6.3331756591796875, -6.693244457244873, -7.067342281341553, -7.4542951583862305, -7.852483749389648, -8.259771347045898, -8.673437118530273, -9.090105056762695, -9.505696296691895, -9.91538143157959, -10.312625885009766, -10.69017505645752, -11.040142059326172, -11.354146003723145, -11.623529434204102, -11.839654922485352, -11.994264602661133, -12.079898834228516, -12.090337753295898, -12.021042823791504, -11.868322372436523, -11.630977630615234, -11.31048583984375, -10.911012649536133, -10.439242362976074, -9.904031753540039, -9.31592082977295, -8.686549186706543, -8.028040885925293, -7.352413177490234, -6.6710591316223145, -5.9943437576293945, -5.331319808959961, -4.689567565917969, -4.07514762878418, -3.4926421642303467, -2.945258617401123, -2.434979200363159, -1.9627312421798706, -1.5285630226135254, -1.1318144798278809, -0.771274745464325, -0.4453222453594208, -0.152045339345932, 0.11065596342086792, 0.3449869453907013, 0.5531913042068481, 0.7374990582466125, 0.9000865817070007, 1.043047547340393, 1.168371558189392, 1.277931571006775, 1.373474359512329, 1.456618070602417, 1.5288511514663696, 1.5915348529815674, 1.6459076404571533, 1.6930904388427734, 1.7340933084487915, 1.7698227167129517, 1.8010880947113037, 1.8286103010177612, 1.8530279397964478, 1.8749054670333862, 1.8947389125823975, 1.9129631519317627, 1.9299577474594116, 1.9460523128509521, 1.9615319967269897, 1.97664213180542, 1.991592526435852, 2.006561517715454, 2.0216994285583496, 2.0371317863464355, 2.0438647270202637, 2.043321132659912, 2.036795139312744, 2.0254554748535156, 2.0103509426116943, 1.9924179315567017, 1.9724853038787842, 1.9512840509414673, 1.9294536113739014, 1.90755033493042, 1.8860549926757812, 1.8653801679611206, 1.8458781242370605, 1.8278470039367676, 1.811537742614746, 1.7971603870391846, 1.7848891019821167, 1.7748680114746094, 1.7672157287597656, 1.7620296478271484, 1.7593897581100464, 1.7593623399734497, 1.7620031833648682, 1.767359972000122, 1.7754749059677124, 1.7863872051239014, 1.800134539604187, 1.816754698753357, 1.8362876176834106, 1.8587756156921387, 1.884265422821045, 1.9128086566925049, 1.944462537765503, 1.9792907238006592, 2.0173637866973877, 2.0587596893310547, 2.1035642623901367, 2.1518712043762207, 2.2037832736968994, 2.2594106197357178, 2.3188726902008057, 2.3822970390319824, 2.4498205184936523, 2.521587371826172, 2.597750425338745, 2.6784701347351074, 2.7639143466949463, 2.8542568683624268, 2.9496777057647705, 3.0503616333007812, 3.15649676322937, 3.2682723999023438, 3.3858790397644043, 3.5095043182373047, 3.6393306255340576, 3.775533437728882, 3.918275833129883, 4.0677056312561035, 4.223949432373047, 4.387108325958252, 4.557249546051025, 4.734401226043701, 4.918543815612793, 5.109598636627197, 5.307421684265137, 5.511789798736572, 5.722389221191406, 5.9388041496276855, 6.160501480102539, 6.386819839477539, 6.6169538497924805, 6.849942684173584, 7.084657669067383, 7.319792747497559, 7.553857326507568, 7.785171985626221, 8.011873245239258, 8.231916427612305, 8.443097114562988, 8.64306926727295, 8.829378128051758, 8.999507904052734, 9.150927543640137, 9.281155586242676, 9.387826919555664, 9.468770980834961, 9.522086143493652, 9.54621696472168, 9.54002857208252, 9.502861976623535, 9.34872817993164, 9.087831497192383, 8.732053756713867, 8.294683456420898, 7.790002346038818, 7.2327656745910645, 6.637650966644287, 6.018735408782959, 5.389047622680664, 4.760223865509033, 4.142292022705078, 3.5435688495635986, 2.9706599712371826, 2.428544282913208, 1.9207122325897217, 1.4493404626846313, 1.0154818296432495, 0.6192562580108643, 0.2600319981575012, -0.06340905278921127, -0.35272499918937683, -0.6098881959915161, -0.837079644203186, -1.0366016626358032, -1.2108080387115479, -1.362047553062439, -1.4926221370697021, -1.6047534942626953, -1.7005600929260254, -1.782041311264038, -1.8510667085647583, -1.9093714952468872, -1.9585542678833008, -2.0000791549682617, -2.0352797508239746, -2.065363645553589, -2.0914204120635986, -2.114428758621216, -2.1352651119232178, -2.1547107696533203, -2.173462152481079, -2.1921377182006836, -2.211286783218384, -2.2313971519470215, -2.2529022693634033, -2.276188373565674, -2.301600933074951, -2.3294503688812256, -2.3600175380706787, -2.3935587406158447, -2.430309772491455, -2.4704906940460205, -2.5143086910247803, -2.5619618892669678, -2.6136412620544434, -2.6695332527160645, -2.7298221588134766, -2.794692039489746, -2.8643267154693604, -2.9389121532440186, -3.018636465072632, -3.1036903858184814, -3.194267511367798, -3.2905635833740234, -3.3927760124206543, -3.5011026859283447, -3.61574125289917, -3.7368855476379395, -3.8647241592407227, -3.9994378089904785, -4.1411943435668945, -4.290145397186279, -4.446420669555664, -4.610122203826904, -4.781317710876465, -4.960031986236572, -5.146238803863525, -5.339849948883057, -5.54070520401001, -5.748559951782227, -5.963071346282959, -6.183785915374756, -6.410123825073242, -6.64136266708374, -6.876626491546631, -7.1148681640625, -7.354857444763184, -7.5951714515686035, -7.834186553955078, -8.070075988769531, -8.300811767578125, -8.524176597595215, -8.73777961730957, -8.939087867736816, -9.125459671020508, -9.29419994354248, -9.44261360168457, -9.568082809448242, -9.66813850402832, -9.740549087524414, -9.783404350280762, -9.794222831726074, -9.771101951599121, -9.71279239654541, -9.618752479553223, -9.489188194274902, -9.325057983398438, -9.1280517578125, -8.900538444519043, -8.645485877990723, -8.366353988647461, -8.06697940826416, -7.751435279846191, -7.423907279968262, -7.088558197021484, -6.749417304992676, -6.410278797149658, -6.0746259689331055, -5.745571136474609, -5.425821304321289, -5.117660999298096, -4.822953701019287, -4.543153762817383, -4.279335021972656, -4.032222270965576, -3.8022289276123047, -3.5894997119903564, -3.393949508666992, -3.2153050899505615, -3.0531413555145264, -2.9069178104400635, -2.776007890701294, -2.6597275733947754, -2.557359218597412, -2.468170642852783, -2.391432285308838, -2.3264310359954834, -2.2724804878234863, -2.2289297580718994, -2.195168972015381, -2.170633316040039, -2.1548073291778564, -2.147224187850952, -2.1474685668945312, -2.1551737785339355, -2.1700234413146973, -2.1917479038238525, -2.220123529434204, -2.2549703121185303, -2.296149969100952, -2.3435635566711426, -2.397148370742798, -2.4568769931793213, -2.5227534770965576, -2.5948116779327393, -2.6731128692626953, -2.7577428817749023, -2.848809242248535, -2.9464399814605713, -3.05077862739563, -3.1619832515716553, -3.280221700668335, -3.4056692123413086, -3.538503646850586, -3.678900718688965, -3.8270294666290283, -3.983046770095825, -4.147089958190918, -4.319269180297852, -4.499661445617676, -4.688296318054199, -4.885150909423828, -5.090132713317871, -5.303071022033691, -5.523697853088379, -5.751636028289795, -5.986380100250244, -6.227280616760254, -6.47352409362793, -6.72411584854126, -6.97786283493042, -7.233357906341553, -7.488966941833496, -7.742819786071777, -7.9928059577941895, -8.236578941345215, -8.471569061279297, -8.6950044631958, -8.903948783874512, -9.095344543457031, -9.266080856323242, -9.413061141967773, -9.533296585083008, -9.623997688293457, -9.68267822265625, -9.707258224487305, -9.696161270141602, -9.64840316772461, -9.563654899597168, -9.442293167114258, -9.285412788391113, -9.094812393188477, -8.872947692871094, -8.622857093811035, -8.348064422607422, -8.05245304107666, -7.739312648773193, -7.412184238433838, -7.074739456176758, -6.730655670166016, -6.383510589599609, -6.036687850952148, -5.693304538726807, -5.3561577796936035, -5.027688980102539, -4.709965229034424, -4.404679775238037, -4.113160133361816, -3.8363900184631348, -3.57503604888916, -3.3294808864593506, -3.0998566150665283, -2.886082172393799, -2.687896728515625, -2.5048930644989014, -2.336548328399658, -2.1822519302368164, -2.041330099105835, -1.9130663871765137, -1.7967214584350586, -1.6915475130081177, -1.5968009233474731, -1.5117526054382324, -1.4356958866119385, -1.367952585220337, -1.3078774213790894, -1.2548606395721436, -1.2083302736282349, -1.1677526235580444, -1.1326324939727783, -1.1025127172470093, -1.076972484588623, -1.0556268692016602, -1.0381240844726562, -1.0241446495056152, -1.0133987665176392, -1.0056241750717163, -1.0005850791931152, -0.9980688095092773, -0.9978851079940796, -0.99986332654953, -1.0038514137268066, -1.0097135305404663, -1.0173290967941284, -1.0265908241271973, -1.0374035835266113, -1.0496830940246582, -1.0633549690246582, -1.0783531665802002, -1.0946192741394043, -1.1121015548706055, -1.1307543516159058, -1.1505368947982788, -1.1714128255844116, -1.1933497190475464, -1.216318130493164, -1.2402912378311157, -1.2652446031570435, -1.2911553382873535, -1.318001627922058, -1.3457629680633545, -1.37441885471344, -1.40394926071167, -1.4343341588974, -1.465552806854248, -1.4975837469100952, -1.530404806137085, -1.5639922618865967, -1.5983211994171143, -1.6333647966384888, -1.6690945625305176, -1.7054795026779175, -1.742486834526062, -1.7800809144973755, -1.8182233572006226, -1.8568733930587769, -1.8959869146347046, -1.9321743249893188, -1.9660617113113403, -1.9982104301452637, -2.029122829437256, -2.0592496395111084, -2.088994264602661, -2.118718385696411, -2.148747205734253, -2.179373025894165, -2.210860013961792, -2.2434470653533936, -2.277351140975952, -2.3127706050872803, -2.3498878479003906, -2.38887095451355, -2.4298765659332275, -2.4730513095855713, -2.51853346824646, -2.5664544105529785, -2.6169393062591553, -2.670109272003174, -2.726081132888794, -2.784968137741089, -2.846881151199341, -2.911928653717041, -2.9802162647247314, -3.051847457885742, -3.1269235610961914, -3.20554256439209, -3.287799835205078, -3.373785972595215, -3.4635872840881348, -3.557284116744995, -3.65494966506958, -3.7566487789154053, -3.8624355792999268, -3.9723525047302246, -4.086427211761475, -4.2046709060668945, -4.327075004577637, -4.453608989715576, -4.58421516418457, -4.718808174133301, -4.857268810272217, -4.9994401931762695, -5.145125389099121, -5.294081211090088, -5.446014404296875, -5.600576877593994, -5.757361888885498, -5.915900707244873, -6.075657367706299, -6.236026287078857, -6.396331310272217, -6.555822372436523, -6.713677406311035, -6.869004249572754, -7.020843029022217, -7.168171405792236, -7.309915065765381, -7.4449567794799805, -7.572149276733398, -7.690330982208252, -7.798346996307373, -7.895065784454346, -7.979405403137207, -8.050355911254883, -8.107007026672363, -8.148567199707031, -8.174394607543945, -8.184015274047852, -8.177142143249512, -8.153692245483398, -8.11379337310791, -8.057793617248535, -7.98625373840332, -7.899947166442871, -7.799841403961182, -7.6870808601379395, -7.562963962554932, -7.428915500640869, -7.28645658493042, -7.137173175811768, -6.98268461227417, -6.824613571166992, -6.664555549621582, -6.504056930541992, -6.344588279724121, -6.187529563903809, -6.034154415130615, -5.885620594024658, -5.742964744567871, -5.6070990562438965, -5.478812217712402, -5.358774185180664, -5.247541427612305, -5.145566463470459, -5.053203105926514, -4.9707207679748535, -4.898311614990234, -4.836102485656738, -4.783675193786621, -4.740631103515625, -4.706592082977295, -4.68072509765625, -4.66227388381958, -4.6505513191223145, -4.6449294090271, -4.644833564758301, -4.649734020233154, -4.659141540527344, -4.672601699829102, -4.6896891593933105, -4.7100043296813965, -4.733170509338379, -4.758827209472656, -4.7866315841674805, -4.8162522315979, -4.847370624542236, -4.879674434661865, -4.9128618240356445, -4.946634292602539, -4.980700969696045, -5.014774799346924, -5.0485734939575195, -5.081817626953125, -5.11423397064209, -5.145552635192871, -5.175509452819824, -5.203846454620361, -5.230312347412109, -5.254663944244385, -5.27666711807251, -5.296098232269287, -5.312745571136475, -5.326412200927734, -5.336913585662842, -5.3440842628479, -5.347774982452393, -5.347856044769287, -5.344217777252197, -5.336773872375488, -5.32545804977417, -5.3102288246154785, -5.291067600250244, -5.267980098724365, -5.24099588394165, -5.21016788482666, -5.175571918487549, -5.1373066902160645, -5.095491409301758, -5.050265312194824, -5.001785755157471, -4.9502272605896, -4.895777702331543, -4.838638782501221, -4.779021739959717, -4.7171478271484375, -4.653242111206055, -4.5875349044799805, -4.52025842666626, -4.451644420623779, -4.381922245025635, -4.311317443847656, -4.240049839019775, -4.168331623077393, -4.096367359161377, -4.024351119995117, -3.9524664878845215, -3.8808863162994385, -3.8097708225250244, -3.7392680644989014, -3.66951322555542, -3.5894112586975098, -3.501248836517334, -3.407094717025757, -3.308803081512451, -3.208021640777588, -3.1061978340148926, -3.0045909881591797, -2.904282808303833, -2.8061904907226562, -2.7110793590545654, -2.619576930999756, -2.53218674659729, -2.4493014812469482, -2.3712158203125, -2.298140525817871, -2.2302122116088867, -2.167505979537964, -2.1100456714630127, -2.057811737060547, -2.010751485824585, -1.9687854051589966, -1.9318140745162964, -1.8997247219085693, -1.872395396232605, -1.84969961643219, -1.8315106630325317, -1.8177039623260498, -1.8081601858139038, -1.8027671575546265, -1.8014219999313354, -1.8040320873260498, -1.8105162382125854, -1.8208057880401611, -1.8348451852798462, -1.8525922298431396, -1.8740184307098389, -1.8991092443466187, -1.9278641939163208, -1.9602971076965332, -1.996435284614563, -2.036320209503174, -2.080007314682007, -2.1275649070739746, -2.1790754795074463, -2.2346339225769043, -2.29434871673584, -2.358340263366699, -2.426741361618042, -2.499696731567383, -2.577362537384033, -2.659904956817627, -2.7475013732910156, -2.840337038040161, -2.9386067390441895, -3.042511463165283, -3.1522576808929443, -3.268056631088257, -3.390120029449463, -3.518660068511963, -3.6538848876953125, -3.795994997024536, -3.9451804161071777, -4.101614952087402, -4.265451431274414, -4.436813831329346, -4.6157917976379395, -4.802431106567383, -4.996725082397461, -5.198602676391602, -5.4079179763793945, -5.624436378479004, -5.847821235656738, -6.0776190757751465, -6.313241958618164, -6.553954124450684, -6.798852920532227, -7.046855449676514, -7.296683311462402, -7.546850681304932, -7.795655250549316, -8.041177749633789, -8.281278610229492, -8.5136137008667, -8.735651016235352, -8.94469928741455, -9.137953758239746, -9.312541961669922, -9.465597152709961, -9.594329833984375, -9.696114540100098, -9.768582344055176, -9.809711456298828, -9.817923545837402, -9.792157173156738, -9.73194408416748, -9.637447357177734, -9.50949478149414, -9.349567413330078, -9.159770011901855, -8.942774772644043, -8.701733589172363, -8.439288139343262, -8.158493041992188, -7.86269998550415, -7.555436611175537, -7.24029016494751, -6.92080020904541, -6.600362777709961, -6.282150745391846, -5.96905517578125, -5.663640022277832, -5.368119716644287, -5.084346771240234, -4.813817501068115, -4.5576863288879395, -4.3167901039123535, -4.0916748046875, -3.882631301879883, -3.6897265911102295, -3.51284122467041, -3.3517005443573, -3.2059075832366943, -3.0749709606170654, -2.958331346511841, -2.855384349822998, -2.7654993534088135, -2.688037872314453, -2.6223654747009277, -2.5678651332855225, -2.52394437789917, -2.4900429248809814, -2.4656388759613037, -2.4502499103546143, -2.4434382915496826, -2.444809913635254, -2.4540159702301025, -2.470752000808716, -2.4947574138641357, -2.525813102722168, -2.563741445541382, -2.608402729034424, -2.659693956375122, -2.7175464630126953, -2.7819228172302246, -2.8528151512145996, -2.9302420616149902, -3.0142459869384766, -3.1048905849456787, -3.2022571563720703, -3.3064422607421875, -3.417553186416626, -3.535705327987671, -3.6610169410705566, -3.7936055660247803, -3.9335825443267822, -4.081047534942627, -4.236082553863525, -4.39874267578125, -4.569052696228027, -4.7469940185546875, -4.932497024536133, -5.125430583953857, -5.325588703155518, -5.532680511474609, -5.746314525604248, -5.96598482131958, -6.191057205200195, -6.420753479003906, -6.6541361808776855, -6.890097141265869], "y": [-10.0, -9.949999809265137, -9.845866203308105, -9.69981575012207, -9.519610404968262, -9.309910774230957, -9.07337760925293, -8.811534881591797, -8.525410652160645, -8.216001510620117, -7.884577751159668, -7.53287410736084, -7.163171768188477, -6.778306007385254, -6.381607532501221, -5.976800918579102, -5.567870616912842, -5.158911228179932, -4.753973960876465, -4.356922149658203, -3.971306800842285, -3.6002626419067383, -3.24643611907959, -2.911942958831787, -2.598353624343872, -2.30670428276062, -2.0375301837921143, -1.790913701057434, -1.5665431022644043, -1.3637775182724, -1.1817127466201782, -1.0192444324493408, -0.8751280903816223, -0.748030424118042, -0.6365754008293152, -0.5393813252449036, -0.45509129762649536, -0.3823964297771454, -0.3200529217720032, -0.2668938934803009, -0.221836656332016, -0.18388639390468597, -0.15213686227798462, -0.12576894462108612, -0.10404747724533081, -0.08631695061922073, -0.07199640572071075, -0.060573894530534744, -0.05160076916217804, -0.04468589276075363, -0.03949003294110298, -0.03572046756744385, -0.03312588483095169, -0.03149164095520973, -0.030635390430688858, -0.030403053387999535, -0.030665213242173195, -0.031313829123973846, -0.032259318977594376, -0.03342795372009277, -0.034759558737277985, -0.036205489188432693, -0.03772686794400215, -0.03929302841424942, -0.04088017717003822, -0.04247025400400162, -0.044049929827451706, -0.04560976102948189, -0.04714346304535866, -0.04864730313420296, -0.05011959746479988, -0.051560256630182266, -0.05297044292092323, -0.054352276027202606, -0.055708568543195724, -0.05704265460371971, -0.05835820734500885, -0.059659119695425034, -0.06094939261674881, -0.06223307177424431, -0.06351418048143387, -0.06479666382074356, -0.0660843625664711, -0.06738100945949554, -0.06869018077850342, -0.0700153186917305, -0.07135970145463943, -0.07272646576166153, -0.07411862164735794, -0.07561080157756805, -0.07720550149679184, -0.07890567183494568, -0.08071476966142654, -0.08263667672872543, -0.08467575907707214, -0.08683683723211288, -0.08912517130374908, -0.09154652059078217, -0.09410709142684937, -0.09681359678506851, -0.09967327117919922, -0.10269387066364288, -0.10588370263576508, -0.10925167798995972, -0.11280731111764908, -0.11656078696250916, -0.12052296102046967, -0.12470544874668121, -0.1291206330060959, -0.13378173112869263, -0.138702854514122, -0.14389903843402863, -0.14938639104366302, -0.15518203377723694, -0.1613042801618576, -0.16777268052101135, -0.17460808157920837, -0.18183280527591705, -0.18947063386440277, -0.19754700362682343, -0.2060891091823578, -0.21512599289417267, -0.22468870878219604, -0.2348104864358902, -0.24552683532238007, -0.25687578320503235, -0.26889798045158386, -0.2816369831562042, -0.2951393723487854, -0.30945509672164917, -0.32463759183883667, -0.34074413776397705, -0.35783615708351135, -0.3759794235229492, -0.39524444937705994, -0.41570696234703064, -0.43744808435440063, -0.4605548679828644, -0.4851207435131073, -0.5112460255622864, -0.5390383005142212, -0.5686132907867432, -0.6000950932502747, -0.6336169838905334, -0.6693223118782043, -0.7073650360107422, -0.7479104399681091, -0.7911364436149597, -0.8372340202331543, -0.8864085674285889, -0.9388808608055115, -0.994888186454773, -1.0546855926513672, -1.1185473203659058, -1.1867679357528687, -1.2596640586853027, -1.3375756740570068, -1.4208680391311646, -1.509933352470398, -1.6051920652389526, -1.7070955038070679, -1.816127061843872, -1.9328044652938843, -2.0576813220977783, -2.1913490295410156, -2.3344390392303467, -2.4876229763031006, -2.651615619659424, -2.8271734714508057, -3.0150978565216064, -3.2162318229675293, -3.431459903717041, -3.6617062091827393, -3.907928466796875, -4.171113014221191, -4.45226526260376, -4.752399444580078, -5.072519302368164, -5.413601875305176, -5.776567459106445, -6.162246227264404, -6.571339130401611, -7.004361152648926, -7.461581707000732, -7.942943572998047, -8.447972297668457, -8.975666999816895, -9.524369239807129, -10.091622352600098, -10.667840957641602, -11.2477388381958, -11.824620246887207, -12.390235900878906, -12.93466854095459, -13.446272850036621, -13.911694526672363, -14.316010475158691, -14.643013954162598, -14.875699043273926, -14.996949195861816, -14.990456581115723, -14.841851234436035, -14.539977073669434, -14.078228950500488, -13.455784797668457, -12.678579330444336, -11.75980281829834, -10.719783782958984, -9.585150718688965, -8.387287139892578, -7.16022253036499, -5.938210964202881, -4.753305435180664, -2.561614751815796, -0.537211537361145, 1.2705183029174805, 2.8307666778564453, 4.131227493286133, 5.175596237182617, 5.97962760925293, 6.566797733306885, 6.964369773864746, 7.200325012207031, 7.3012919425964355, 7.291376113891602, 7.1916890144348145, 7.020347595214844, 6.792736530303955, 6.52188777923584, 6.218875885009766, 5.893171310424805, 5.552926063537598, 5.2051897048950195, 4.856060028076172, 4.510785102844238, 4.173829555511475, 3.8489184379577637, 3.5390756130218506, 3.2466578483581543, 2.973395824432373, 2.7204413414001465, 2.4884233474731445, 2.2775094509124756, 2.0874722003936768, 1.9177578687667847, 1.7675518989562988, 1.6358436346054077, 1.5214848518371582, 1.4232412576675415, 1.3398385047912598, 1.2699987888336182, 1.2124723196029663, 1.166060447692871, 1.1296334266662598, 1.1021426916122437, 1.0826283693313599, 1.0702232122421265, 1.0641539096832275, 1.0637385845184326, 1.0683846473693848, 1.07758367061615, 1.0909062623977661, 1.1079963445663452, 1.1285651922225952, 1.1523858308792114, 1.1792868375778198, 1.2091474533081055, 1.241892695426941, 1.2774882316589355, 1.3159370422363281, 1.3572754859924316, 1.4015706777572632, 1.448917269706726, 1.4994356632232666, 1.5532703399658203, 1.6105879545211792, 1.6715770959854126, 1.736446738243103, 1.8054262399673462, 1.8787648677825928, 1.9567320346832275, 2.039616823196411, 2.1277291774749756, 2.2213993072509766, 2.3209784030914307, 2.426839590072632, 2.539376974105835, 2.6590075492858887, 2.786170482635498, 2.9213271141052246, 3.0649609565734863, 3.217576503753662, 3.3796987533569336, 3.5518712997436523, 3.7346534729003906, 3.928617477416992, 4.134343147277832, 4.352413654327393, 4.5834059715271, 4.827883243560791, 5.086381435394287, 5.359396457672119, 5.647365093231201, 5.950643539428711, 6.26948356628418, 6.603999137878418, 6.954132556915283, 7.3196120262146, 7.699902057647705, 8.094149589538574, 8.501123428344727, 8.91914176940918, 9.346003532409668, 9.778910636901855, 10.207879066467285, 10.628095626831055, 11.033891677856445, 11.418729782104492, 11.775236129760742, 12.095261573791504, 12.370023727416992, 12.59029769897461, 12.74670696258545, 12.830079078674316, 12.831896781921387, 12.744803428649902, 12.563158988952637, 12.283591270446777, 11.905501365661621, 11.431452751159668, 10.867403984069824, 10.222702980041504, 9.509842872619629, 8.743943214416504, 7.942009925842285, 7.1220221519470215, 6.301939010620117, 5.49873161315918, 4.727532386779785, 4.000986099243164, 3.3288464546203613, 2.7178289890289307, 2.1717007160186768, 1.6915574073791504, 1.2762295007705688, 0.9227533936500549, 0.6268563270568848, 0.383409321308136, 0.18682359158992767, 0.031374603509902954, -0.08854874968528748, -0.1782652884721756, -0.24268417060375214, -0.2862377464771271, -0.31285369396209717, -0.3259555995464325, -0.3284837603569031, -0.32292863726615906, -0.311371773481369, -0.29552990198135376, -0.2767995595932007, -0.2563000023365021, -0.23491357266902924, -0.21332252025604248, -0.19204193353652954, -0.1714489758014679, -0.15180835127830505, -0.13329416513442993, -0.11600864678621292, -0.09999784082174301, -0.08526479452848434, -0.07178038358688354, -0.05949214845895767, -0.04833148047327995, -0.03821928799152374, -0.029070457443594933, -0.02079731412231922, -0.013312197290360928, -0.006529370788484812, -0.000366363616194576, 0.005255135707557201, 0.010408739559352398, 0.015163096599280834, 0.019581833854317665, 0.0237236600369215, 0.02764257602393627, 0.03138817101716995, 0.03495919331908226, 0.03840102255344391, 0.04175375774502754, 0.04505293071269989, 0.048330143094062805, 0.05161363631486893, 0.05492877960205078, 0.0582985021173954, 0.06174369528889656, 0.06528354436159134, 0.0689358040690422, 0.0727170929312706, 0.07664307951927185, 0.0807286873459816, 0.08498827368021011, 0.08943576365709305, 0.09408479183912277, 0.09894879162311554, 0.10404109209775925, 0.1093750074505806, 0.11496392637491226, 0.12082131206989288, 0.12696081399917603, 0.13339629769325256, 0.14014185965061188, 0.14721187949180603, 0.15462101995944977, 0.1623843014240265, 0.17051708698272705, 0.17903506755828857, 0.18795432150363922, 0.18876487016677856, 0.18993309140205383, 0.1914610117673874, 0.1933499425649643, 0.19560092687606812, 0.1982150673866272, 0.2011938840150833, 0.20453955233097076, 0.2082550972700119, 0.21234454214572906, 0.21681316196918488, 0.22166745364665985, 0.22691532969474792, 0.2325662225484848, 0.23863105475902557, 0.24512241780757904, 0.2520546019077301, 0.25944364070892334, 0.2673074007034302, 0.27566567063331604, 0.2845401465892792, 0.29395464062690735, 0.30393508076667786, 0.31450963020324707, 0.32570880651474, 0.3375655710697174, 0.35011550784111023, 0.36339691281318665, 0.37745097279548645, 0.39232194423675537, 0.4080572724342346, 0.42470791935920715, 0.44232845306396484, 0.46097737550735474, 0.48071733117103577, 0.5016154050827026, 0.5237434506416321, 0.547178328037262, 0.5720022916793823, 0.598303496837616, 0.6261761784553528, 0.6557212471961975, 0.6870467662811279, 0.7202683091163635, 0.7555096745491028, 0.7929033637046814, 0.83259117603302, 0.8747249841690063, 0.9194673299789429, 0.9669922590255737, 1.0174859762191772, 1.0711480379104614, 1.1281917095184326, 1.1888456344604492, 1.2533539533615112, 1.321978211402893, 1.3949980735778809, 1.4727123975753784, 1.5554405450820923, 1.6435235738754272, 1.737325668334961, 1.8372349739074707, 1.9436653852462769, 2.0570571422576904, 2.1778783798217773, 2.306626081466675, 2.443826913833618, 2.5900375843048096, 2.7458457946777344, 2.9118690490722656, 3.0887556076049805, 3.27718186378479, 3.477850914001465, 3.69148850440979, 3.918839931488037, 4.1606621742248535, 4.417716979980469, 4.690758228302002, 4.980520725250244, 5.287700653076172, 5.61293363571167, 5.9567694664001465, 6.319638252258301, 6.701809406280518, 7.103344917297363, 7.524042129516602, 7.963366985321045, 8.420374870300293, 8.89362621307373, 9.381081581115723, 9.879997253417969, 10.386809349060059, 10.89700984954834, 11.405035972595215, 11.904160499572754, 12.386415481567383, 12.842549324035645, 13.262044906616211, 13.633221626281738, 13.943434715270996, 14.179410934448242, 14.31743049621582, 14.343863487243652, 14.246517181396484, 14.015649795532227, 13.64503002166748, 13.132938385009766, 12.482990264892578, 11.704626083374023, 10.813163757324219, 9.829307556152344, 8.778120040893555, 7.687508583068848, 6.586410045623779, 5.502860069274902, 4.462215423583984, 3.4857263565063477, 2.589609384536743, 1.784675121307373, 1.0764762163162231, 0.4658662676811218, -0.05017060413956642, -0.4775691032409668, -0.8242366313934326, -1.0992026329040527, -1.311915397644043, -1.4717036485671997, -1.587399959564209, -1.6671006679534912, -1.7180399894714355, -1.746545433998108, -1.7580534219741821, -1.7571622133255005, -1.7477055788040161, -1.7328383922576904, -1.7151230573654175, -1.6966142654418945, -1.6789368391036987, -1.6633572578430176, -1.6508466005325317, -1.6421356201171875, -1.637762188911438, -1.6381125450134277, -1.643454670906067, -1.653968095779419, -1.6697667837142944, -1.6909197568893433, -1.7174664735794067, -1.7494300603866577, -1.786827802658081, -1.8296787738800049, -1.8780112266540527, -1.9318662881851196, -1.991302490234375, -2.0563979148864746, -2.1272521018981934, -2.2039875984191895, -2.286749839782715, -2.3757081031799316, -2.471054792404175, -2.573005199432373, -2.681796073913574, -2.797685384750366, -2.920950412750244, -3.0518860816955566, -3.1908023357391357, -3.3380227088928223, -3.493879795074463, -3.658712387084961, -3.8328611850738525, -4.016663074493408, -4.210444927215576, -4.414515495300293, -4.6291584968566895, -4.854619979858398, -5.091096878051758, -5.338723659515381, -5.5975542068481445, -5.867544651031494, -6.14853048324585, -6.440201759338379, -6.742076873779297, -7.053470611572266, -7.373461723327637, -7.700857162475586, -8.034153938293457, -8.371499061584473, -8.71065616607666, -9.04896354675293, -9.383308410644531, -9.710098266601562, -10.02525520324707, -10.324217796325684, -10.60196590423584, -10.85307502746582, -11.071796417236328, -11.25218391418457, -11.3882417678833, -11.474132537841797, -11.50440788269043, -11.474272727966309, -11.379878044128418, -11.218597412109375, -10.989304542541504, -10.692594528198242, -10.330937385559082, -9.908740997314453, -9.432300567626953, -8.909626007080078, -8.350152969360352, -7.764352321624756, -7.163261890411377, -6.55798864364624, -5.959212779998779, -5.376742839813232, -4.81914758682251, -4.293503284454346, -3.8052456378936768, -3.3581466674804688, -2.9543821811676025, -2.5946831703186035, -2.2720251083374023, -1.985738754272461, -1.7344026565551758, -1.5160340070724487, -1.3282630443572998, -1.1684867143630981, -1.033998966217041, -0.9220932126045227, -0.8301427960395813, -0.7556577324867249, -0.6963233947753906, -0.6500231623649597, -0.6148488521575928, -0.5891017913818359, -0.571286678314209, -0.5601006746292114, -0.5544200539588928, -0.5532840490341187, -0.5558791160583496, -0.5615224242210388, -0.5696462392807007, -0.5797834396362305, -0.5915533900260925, -0.6046500205993652, -0.6188305020332336, -0.633905291557312, -0.6497295498847961, -0.6661955118179321, -0.6832260489463806, -0.700768768787384, -0.7187917232513428, -0.7372788190841675, -0.7562269568443298, -0.7756426930427551, -0.795540452003479, -0.8159401416778564, -0.8368657231330872, -0.8583440780639648, -0.8804039359092712, -0.9030748605728149, -0.9263869524002075, -0.9503699541091919, -0.9750531911849976, -1.0004650354385376, -1.0266329050064087, -1.0535829067230225, -1.0813394784927368, -1.1099258661270142, -1.1393635272979736, -1.1696721315383911, -1.2008697986602783, -1.2329726219177246, -1.265994906425476, -1.299948811531067, -1.2872282266616821, -1.277010202407837, -1.2693215608596802, -1.2641681432724, -1.2615410089492798, -1.2614203691482544, -1.263779878616333, -1.2685898542404175, -1.2758201360702515, -1.2854418754577637, -1.2974300384521484, -1.311764121055603, -1.328429937362671, -1.3474202156066895, -1.3687350749969482, -1.3923832178115845, -1.4183818101882935, -1.4467568397521973, -1.4775434732437134, -1.5107861757278442, -1.5465389490127563, -1.5848650932312012, -1.6258374452590942, -1.6695386171340942, -1.7160608768463135, -1.7655060291290283, -1.8179858922958374, -1.873621940612793, -1.9325456619262695, -1.9948985576629639, -2.0608320236206055, -2.130507469177246, -2.204097032546997, -2.2817819118499756, -2.3637545108795166, -2.45021653175354, -2.541379451751709, -2.637464761734009, -2.7387030124664307, -2.8453333377838135, -2.9576032161712646, -3.0757670402526855, -3.200085401535034, -3.3308236598968506, -3.468249797821045, -3.6126327514648438, -3.76423978805542, -3.923332691192627, -4.090164661407471, -4.264975070953369, -4.295431613922119, -4.329739093780518, -4.367580890655518, -4.408661842346191, -4.452706813812256, -4.499459266662598, -4.548678398132324, -4.600139617919922, -4.653629302978516, -4.7089457511901855, -4.765894889831543, -4.8242902755737305, -4.883950710296631, -4.944698333740234, -5.0063581466674805, -5.068755626678467, -5.131717205047607, -5.195067405700684, -5.258630752563477, -5.32222843170166, -5.385679244995117, -5.448798656463623, -5.5114006996154785, -5.573294162750244, -5.6342878341674805, -5.694186210632324, -5.7527923583984375, -5.809909343719482, -5.865339756011963, -5.918886661529541, -5.97035551071167, -6.019556522369385, -6.066303730010986, -6.110418319702148, -6.151731014251709, -6.19008207321167, -6.22532320022583, -6.257321834564209, -6.285960674285889, -6.311140537261963, -6.332781791687012, -6.350825786590576, -6.365237236022949, -6.376004695892334, -6.383142471313477, -6.38668966293335, -6.38671350479126, -6.38330602645874, -6.376587390899658, -6.366703510284424, -6.353825092315674, -6.3381476402282715, -6.319888114929199, -6.299285411834717, -6.276596546173096, -6.252094745635986, -6.226067543029785, -6.198812484741211, -6.170636177062988, -6.141850471496582, -6.112769603729248, -6.0837082862854, -6.054976940155029, -6.026881217956543, -5.999719142913818, -5.97377872467041, -5.949335098266602, -5.926650047302246, -5.905971050262451, -5.887528419494629, -5.8715362548828125, -5.858189582824707, -5.847667217254639, -5.840127468109131, -5.83571195602417, -5.834543704986572, -5.836727619171143, -5.842350482940674, -5.851483345031738, -5.864179611206055, -5.880476951599121, -5.900397300720215, -5.923947811126709, -5.9511213302612305, -5.9818949699401855, -6.016232967376709, -6.054085731506348, -6.095388889312744, -6.140065670013428, -6.188024044036865, -6.239158630371094, -6.293349266052246, -6.350461483001709, -6.410345077514648, -6.47283411026001, -6.537746429443359, -6.604883193969727, -6.674028396606445, -6.744946479797363, -6.817386150360107, -6.891075611114502, -6.959353446960449, -7.0218706130981445, -7.078266620635986, -7.128179550170898, -7.1712541580200195, -7.207151889801025, -7.235558032989502, -7.2561936378479, -7.2688212394714355, -7.273255348205566, -7.269369125366211, -7.257101058959961, -7.2364606857299805, -7.207534313201904, -7.170485973358154, -7.1255598068237305, -7.073081016540527, -7.01345157623291, -6.94714879989624, -6.874719142913818, -6.796771049499512, -6.7139668464660645, -6.627013206481934, -6.536651134490967, -6.443644046783447, -6.348768711090088, -6.252800941467285, -6.15650749206543, -6.060634136199951, -5.965897083282471, -5.872975826263428, -5.782503128051758, -5.695064067840576, -5.611186981201172, -5.531345367431641, -5.4559526443481445, -5.385364532470703, -5.319879531860352, -5.259739875793457, -5.205136775970459, -5.156209945678711, -5.113056182861328, -5.075728893280029, -5.044245719909668, -5.018592357635498, -4.998725414276123, -4.984577655792236, -4.976060390472412, -4.97307014465332, -4.975486755371094, -4.983180999755859, -4.996013164520264, -5.01383638381958, -5.0364990234375, -5.063843727111816, -5.095709800720215, -5.131931781768799, -5.172342300415039, -5.216768264770508, -5.26503324508667, -5.316956043243408, -5.372349739074707, -5.431019306182861, -5.492763519287109, -5.557370662689209, -5.624619007110596, -5.694275379180908, -5.7660932540893555, -5.8398118019104, -5.915154933929443, -5.991829872131348, -6.069526195526123, -6.147916793823242, -6.226653575897217, -6.305371284484863, -6.38368558883667, -6.461194038391113, -6.537476062774658, -6.612096786499023, -6.684605121612549, -6.75454044342041, -6.821431636810303, -6.884803295135498, -6.944178104400635, -6.999083518981934, -7.049054145812988, -7.093640327453613, -7.132412433624268, -7.1649675369262695, -7.190937042236328, -7.2099928855896, -7.221853256225586, -7.226291179656982, -7.223138332366943, -7.212292671203613, -7.193721294403076, -7.167464256286621, -7.13363790512085, -7.092435359954834, -7.044126510620117, -6.989055633544922, -6.927639007568359, -6.860360145568848, -6.787761211395264, -6.710439682006836, -6.629036903381348, -6.544229030609131, -6.456718921661377, -6.367223262786865, -6.276464939117432, -6.185160160064697, -6.0940117835998535, -6.003697872161865, -5.914866924285889, -5.828127384185791, -5.744045257568359, -5.663137435913086, -5.58587121963501, -5.512659549713135, -5.443861961364746, -5.379785537719727, -5.320684909820557, -5.266765117645264, -5.218183517456055, -5.175055503845215, -5.137454509735107, -5.1054182052612305, -5.078951835632324, -5.058032512664795, -5.042611122131348, -5.032618045806885, -5.027966022491455, -5.02855110168457, -5.034256935119629, -5.044958114624023, -5.060518741607666, -5.08079719543457, -5.105645179748535, -5.134908676147461, -5.168430328369141, -5.206047058105469, -5.247592449188232, -5.29289436340332, -5.341774940490723, -5.394051551818848, -5.449533939361572, -5.508023738861084, -5.569314479827881, -5.6331892013549805, -5.699419975280762, -5.767766952514648, -5.837977409362793, -5.909782409667969, -5.982900142669678, -6.057031154632568, -6.13185977935791, -6.207054138183594, -6.28226375579834, -6.357122421264648, -6.431246757507324, -6.504238128662109, -6.575683116912842, -6.645155906677246, -6.712220191955566, -6.776432514190674, -6.837344646453857, -6.89450740814209, -6.947475910186768, -6.995813369750977, -7.039095878601074, -7.076920032501221, -7.1089067459106445, -7.134707450866699, -7.154012680053711, -7.166553974151611, -7.17211389541626, -7.170529365539551, -7.161696910858154, -7.1455769538879395, -7.12219762802124, -7.091656684875488, -7.0541229248046875, -7.009835243225098, -6.959102630615234, -6.9023003578186035, -6.839867115020752, -6.772296905517578, -6.700136184692383, -6.623973846435547, -6.54443359375, -6.462165355682373, -6.377835750579834, -6.292117595672607, -6.205684185028076, -6.119195938110352, -6.033295154571533, -5.948598861694336, -5.865689277648926, -5.785111904144287, -5.707368850708008, -5.632916450500488, -5.562163352966309, -5.495469093322754, -5.433143138885498, -5.375447750091553, -5.322597980499268, -5.274764060974121, -4.641924858093262, -4.032327175140381, -3.4530770778656006, -2.9099090099334717, -2.4070966243743896, -1.9474467039108276, -1.532371163368225, -1.162022352218628, -0.8354721069335938, -0.5509132742881775, -0.3058682084083557, -0.09738785773515701, 0.07776853442192078, 0.22297868132591248, 0.3416307866573334, 0.4370248317718506, 0.5122999548912048, 0.570384681224823, 0.6139658093452454, 0.6454735398292542, 0.6670778393745422, 0.6806941628456116, 0.687995433807373, 0.6904277801513672, 0.6892295479774475, 0.6854508519172668, 0.6799737215042114, 0.6735319495201111, 0.6667295694351196, 0.6600587368011475, 0.6539157032966614, 0.6486157178878784, 0.6444060802459717, 0.6414780616760254, 0.6399770379066467, 0.6400118470191956, 0.6416623592376709, 0.6449863910675049, 0.6500252485275269, 0.6568089723587036, 0.6653600335121155, 0.6756970882415771, 0.6878376603126526, 0.701800525188446, 0.7176077961921692, 0.7352863550186157, 0.7548693418502808, 0.7763970494270325, 0.799917995929718, 0.8254896998405457, 0.8531791567802429, 0.883063793182373, 0.9152315258979797, 0.9497816562652588, 0.9868253469467163, 1.0264860391616821, 1.0688997507095337, 1.1142164468765259, 1.1625995635986328, 1.214227557182312, 1.2692943811416626, 1.328009843826294, 1.3906010389328003, 1.4573129415512085, 1.5284092426300049, 1.6041735410690308, 1.6849104166030884, 1.7709463834762573, 1.8626307249069214, 1.960337519645691, 2.0644657611846924, 2.175441026687622, 2.2937161922454834, 2.4197728633880615, 2.554121494293213, 2.6973021030426025, 2.8498849868774414, 3.0124704837799072, 3.18568754196167, 3.3701930046081543, 3.5666701793670654, 3.7758243083953857, 3.9983789920806885, 4.235069751739502, 4.486635684967041, 4.753810405731201, 5.037307262420654, 5.337801933288574, 5.655914306640625, 5.9921793937683105, 6.34701681137085, 6.720694065093994, 7.113277912139893, 7.5245819091796875, 7.954102039337158, 8.4009428024292, 8.863733291625977, 9.340532302856445, 9.828726768493652, 10.324918746948242, 10.824812889099121, 11.316093444824219, 11.791656494140625, 12.243170738220215, 12.661094665527344, 13.034747123718262, 13.352486610412598, 12.661734580993652, 11.869820594787598, 10.983341217041016, 10.014622688293457, 8.98107624053955, 7.904078006744385, 6.80748176574707, 5.71591329574585, 4.653054237365723, 3.6401026248931885, 2.6945912837982178, 1.8296523094177246, 1.0537636280059814, 0.3709245026111603, -0.2188340276479721, -0.7187291383743286, -1.1344174146652222, -1.4731991291046143, -1.743307113647461, -1.9533191919326782, -2.1117100715637207, -2.2265331745147705, -2.3052191734313965, -2.354464530944824, -2.3801910877227783, -2.387552261352539, -2.380974054336548, -2.3642117977142334, -2.340416669845581, -2.3122074604034424, -2.2817366123199463, -2.250756025314331, -2.220675230026245, -2.1926143169403076, -2.1674513816833496, -2.1458630561828613, -2.1283609867095947, -2.1153228282928467, -2.1070191860198975, -2.103635787963867, -2.1052937507629395, -2.112065315246582, -2.123988628387451, -2.141077756881714, -2.1633338928222656, -2.1907520294189453, -2.22332763671875, -2.261061906814575, -2.3039655685424805, -2.3520619869232178, -2.4053902626037598, -2.464005708694458, -2.527982711791992, -2.5974137783050537, -2.6724116802215576, -2.753107786178589, -2.839653968811035, -2.932219982147217, -3.030994415283203, -3.136183500289917, -3.248008966445923, -3.3667080402374268, -3.4925310611724854, -3.6257388591766357, -3.7666015625, -3.9153943061828613, -4.072394847869873, -4.237878322601318, -4.412113666534424, -4.595356464385986, -4.787843704223633, -4.989782810211182, -5.201346397399902, -5.422658920288086, -5.653783321380615, -5.894710540771484, -6.145339488983154, -6.405459880828857, -6.6747331619262695, -6.952667713165283, -7.238595485687256, -7.53164529800415, -7.830713272094727, -8.134434700012207, -8.441155433654785, -8.7489013671875, -9.055354118347168, -9.357830047607422, -9.653265953063965, -9.938214302062988, -10.208850860595703, -10.461003303527832, -10.690193176269531, -10.891705513000488, -11.060688018798828, -11.192272186279297, -11.281728744506836, -11.3246431350708, -11.317123413085938, -11.256009101867676, -11.139089584350586, -10.95546817779541, -10.705249786376953, -10.390206336975098, -10.013875961303711, -9.581573486328125, -9.100289344787598, -8.578472137451172, -8.025714874267578, -7.452357292175293, -6.869027614593506, -6.286184310913086, -5.713674068450928, -5.160348892211914, -4.6337738037109375, -4.140035152435303, -3.683656930923462, -3.2676148414611816, -2.8934361934661865, -2.5613629817962646, -2.270552158355713, -2.0192980766296387, -1.8052512407302856, -1.625625491142273, -1.4773787260055542, -1.3573672771453857, -1.2624684572219849, -1.1896741390228271, -1.1361571550369263, -1.0993163585662842, -1.0768005847930908, -1.0665196180343628, -1.0666426420211792, -1.0755894184112549, -1.0920153856277466, -1.114793300628662, -1.1429935693740845, -1.17586350440979, -1.212807297706604, -1.2533663511276245, -1.297202229499817, -1.3440792560577393, -1.3938504457473755, -1.4464446306228638, -1.5018545389175415, -1.5601277351379395, -1.621357798576355, -1.6856776475906372, -1.7532533407211304, -1.8242799043655396, -1.8989766836166382, -1.9775846004486084, -2.06036376953125, -2.1475913524627686, -2.2395596504211426, -2.336575508117676, -2.4389588832855225, -2.547041893005371, -2.6611685752868652, -2.7816925048828125, -2.908977746963501, -3.043396234512329, -3.185326099395752, -3.335150957107544, -3.493256092071533, -3.6600265502929688, -3.8358423709869385, -4.021074295043945, -4.216078281402588, -4.421186923980713, -4.636704444885254, -4.8628926277160645, -5.099961280822754, -5.3480544090271, -5.607233047485352, -5.877457141876221, -6.15856409072876, -6.4502434730529785, -6.752011775970459, -7.063179016113281, -7.382819652557373, -7.709733009338379, -8.042407989501953, -8.378986358642578, -8.7172212600708, -9.054444313049316, -9.38753604888916, -9.712902069091797, -10.026461601257324, -10.32365608215332, -10.599474906921387, -10.848505020141602, -11.065023422241211, -11.243109703063965, -11.376809120178223, -11.46033000946045, -11.488280296325684, -11.455928802490234, -11.35949420928955, -11.196422576904297, -10.965659141540527, -10.657835960388184, -10.275391578674316, -9.822943687438965, -9.30727767944336, -8.737183570861816, -8.123152732849121, -7.476943016052246, -6.811044216156006, -6.138094902038574, -5.470294952392578, -4.818874359130859, -4.193655490875244, -3.6027414798736572, -3.0523459911346436, -2.5467593669891357, -2.0884346961975098, -1.6781697273254395, -1.3153477907180786, -0.9982138276100159, -0.7241545915603638, -0.4899631440639496, -0.29207390546798706, -0.1267605423927307, 0.009706167504191399, 0.12093908339738846, 0.2103501260280609, 0.28109538555145264, 0.3360443711280823, 0.37776777148246765, 0.408539354801178, 0.43034741282463074, 0.4449126124382019, 0.4537099301815033, 0.4579921066761017, 0.4588138461112976, 0.45705512166023254, 0.45344361662864685, 0.4485752284526825, 0.44293296337127686, 0.43690380454063416, 0.43079373240470886, 0.4248409569263458, 0.42719128727912903, 0.4265521466732025, 0.4235786199569702, 0.41884228587150574, 0.41283637285232544, 0.4059821367263794, 0.39863529801368713, 0.3910926878452301, 0.38359880447387695, 0.3763524293899536, 0.3695123493671417, 0.3632032871246338, 0.3575208783149719, 0.35253649950027466, 0.348301500082016, 0.3448508679866791, 0.3422066867351532, 0.34038078784942627, 0.3393774926662445, 0.33919557929039, 0.33983010053634644, 0.3412739932537079, 0.3435191810131073, 0.3465577960014343, 0.35038286447525024, 0.3549891412258148, 0.36037352681159973, 0.36653566360473633, 0.37347808480262756, 0.381206750869751, 0.3897310197353363, 0.39906400442123413, 0.40922263264656067, 0.4202277958393097, 0.4321044683456421, 0.4448818564414978, 0.45859336853027344, 0.4732770025730133, 0.4889752268791199, 0.5057352185249329, 0.5236091017723083, 0.5426540970802307, 0.5629327297210693, 0.5845129489898682, 0.6074687838554382, 0.6318801641464233, 0.6578336358070374, 0.6854225993156433, 0.7147476673126221, 0.7459172606468201, 0.7790480256080627, 0.8142651915550232, 0.8517036437988281, 0.8915079236030579, 0.9338334798812866, 0.9788470268249512, 1.0267274379730225, 1.0776666402816772, 1.1318705081939697, 1.1895596981048584, 1.2509706020355225, 1.316356897354126, 1.3859901428222656, 1.4601608514785767, 1.5391805171966553, 1.6233820915222168, 1.7131215333938599, 1.8087794780731201, 1.910761833190918, 2.0195019245147705, 2.1354615688323975, 2.259131669998169, 2.3910341262817383, 2.531722068786621, 2.681781530380249, 2.8418307304382324, 3.0125198364257812, 3.1945319175720215, 3.3885791301727295, 3.595402479171753, 3.8157665729522705, 4.0504560470581055, 4.300266265869141, 4.565998077392578, 4.848440647125244, 5.148360252380371, 5.46647834777832, 5.8034491539001465, 6.15982723236084, 6.536032676696777, 6.932304859161377, 7.348649501800537, 7.784775733947754, 8.240019798278809, 8.713261604309082, 9.202821731567383, 9.7063570022583, 10.22073745727539, 10.741922378540039, 11.264829635620117, 11.78321361541748, 12.281915664672852, 12.751326560974121, 13.180452346801758, 13.557029724121094, 13.867759704589844, 14.098674774169922, 14.235665321350098, 14.26517105102539, 14.175023078918457, 13.955405235290527, 13.59986686706543, 13.106290817260742, 12.477689743041992, 11.722712516784668, 10.855717658996582, 9.896347999572754, 8.86858081817627, 7.799317836761475, 6.716645240783691, 5.647989273071289, 4.618375301361084, 3.64900541305542, 2.756308078765869, 1.9515084028244019, 1.240708589553833, 0.6253762245178223, 0.1031109020113945, -0.3314526379108429, -0.685729444026947, -0.9683486223220825, -1.188452124595642, -1.3551501035690308, -1.4771316051483154, -1.5624111890792847, -1.6181880235671997, -1.6507896184921265, -1.6656757593154907, -1.6689320802688599, -1.6638020277023315, -1.652951955795288, -1.6385468244552612, -1.622322916984558, -1.6056544780731201, -1.5896128416061401, -1.5750192403793335, -1.5624897480010986, -1.5524744987487793, -1.545290231704712, -1.5411478281021118, -1.5401760339736938, -1.5424398183822632, -1.5479564666748047, -1.5567079782485962, -1.568651556968689, -1.5837275981903076, -1.601866364479065, -1.6229923963546753, -1.647029161453247, -1.673900842666626, -1.7035354375839233, -1.7358651161193848, -1.7708275318145752, -1.808366298675537, -1.8484309911727905, -1.8909767866134644, -1.9359644651412964, -1.9833595752716064, -2.0331318378448486, -2.085254669189453, -2.1397042274475098, -2.196458101272583, -2.255495309829712, -2.3167948722839355, -2.3803346157073975, -2.4460909366607666, -2.5140368938446045, -2.584141731262207, -2.6563704013824463, -2.7306807041168213, -2.8070247173309326, -2.885344982147217, -2.965575933456421, -3.0476410388946533, -3.1314520835876465, -3.2169082164764404, -3.3038952350616455, -3.392282724380493, -3.4819254875183105, -3.572659730911255, -3.664304256439209, -3.7566583156585693, -3.715970993041992, -3.6794049739837646, -3.6470248699188232, -3.618863344192505, -3.5949289798736572, -3.5752112865448, -3.5596859455108643, -3.548316717147827, -3.54106068611145, -3.5378682613372803, -3.5386874675750732, -3.543464183807373, -3.5521440505981445, -3.564673662185669, -3.581001043319702, -3.601077079772949, -3.6248557567596436, -3.6522939205169678, -3.68335223197937, -3.7179951667785645, -3.756190538406372, -3.79790997505188, -3.843127727508545, -3.8918213844299316, -3.943969964981079, -3.9995548725128174, -4.058557987213135, -4.120961666107178, -4.1867475509643555, -4.255895137786865, -4.328381538391113, -4.40418004989624, -4.4832587242126465, -4.565579414367676, -4.651094436645508, -4.739748954772949, -4.831475257873535, -4.926193714141846, -5.023809432983398, -5.124210834503174, -5.227268695831299, -5.332832336425781, -5.440728664398193, -5.550759792327881, -5.6627020835876465, -5.77630090713501, -5.891273021697998, -6.0073018074035645, -6.1240363121032715, -6.241090297698975, -6.358042240142822, -6.474431991577148, -6.589763641357422, -6.70350456237793, -6.815086841583252, -6.923910140991211, -7.029343128204346, -7.130729675292969, -7.227392196655273, -7.318638801574707, -7.403769493103027, -7.482087135314941, -7.5529046058654785, -7.615555763244629, -7.669410228729248, -7.71388053894043, -7.748440742492676, -7.772634983062744, -7.786092758178711, -7.788539409637451, -7.779809474945068, -7.759854316711426, -7.728752136230469, -7.686711311340332, -7.6340742111206055, -7.571316719055176, -7.499044895172119, -7.417988300323486, -7.328991413116455, -7.232997894287109, -7.131039142608643, -7.024214267730713, -6.913671016693115, -6.800588607788086, -6.686154365539551, -6.571545600891113, -6.457911491394043, -6.346355438232422, -6.237918853759766, -6.133571624755859, -6.034200668334961, -5.940601825714111, -5.853477954864502, -5.773436546325684, -5.700990200042725, -5.63655948638916, -5.580478191375732, -5.532999038696289, -5.4943013191223145, -5.464498043060303, -5.4436445236206055, -5.425681114196777, -5.4107561111450195, -5.398983478546143, -5.390445709228516, -5.38519811630249, -5.383272647857666, -5.384677886962891, -5.389404296875, -5.397423267364502, -5.408692359924316, -5.423152923583984, -5.440735340118408, -5.461356163024902, -5.484922885894775, -5.511331558227539, -5.540468692779541, -5.572211265563965, -5.606428623199463, -5.642979145050049, -5.681714057922363, -5.722475528717041, -5.7650957107543945, -5.8094000816345215, -5.855202674865723, -5.902310371398926, -5.9505205154418945, -5.999621391296387, -6.049391269683838, -6.099601745605469, -6.150014400482178, -6.200383186340332, -6.250454902648926, -6.29996919631958, -6.348659992218018, -6.396256923675537, -6.442485332489014, -6.487070083618164, -6.5297346115112305, -6.570204734802246, -6.608210563659668, -6.643487930297852, -6.67578125, -6.7048468589782715, -6.73045539855957, -6.75239372253418, -6.7704691886901855, -6.784511089324951, -6.794373989105225, -6.799940586090088, -6.801124095916748, -6.7978692054748535, -6.790155410766602, -6.777997016906738, -6.761445045471191, -6.740586757659912, -6.71554708480835, -6.686485767364502, -6.653598785400391, -6.617115020751953, -6.577293395996094, -6.534422397613525, -6.4888153076171875, -6.440806865692139, -6.390750408172607, -6.339012145996094, -6.285968780517578, -6.232001781463623, -6.177494525909424, -6.122827053070068, -6.068373203277588, -6.014495849609375, -5.961544990539551, -5.909854412078857, -5.859737873077393, -5.811489105224609, -5.765378952026367, -5.721653938293457, -5.680537223815918, -5.642226219177246, -5.606893062591553, -5.574686050415039, -5.54572868347168, -5.5201215744018555, -5.4979424476623535, -5.479249477386475, -5.464078426361084, -5.452448844909668, -5.444360733032227, -5.439799785614014, -5.4387359619140625, -5.44112491607666, -5.446911811828613, -5.456027507781982, -5.468394756317139, -5.48392391204834, -5.5025177001953125, -5.524069309234619, -5.548464298248291, -5.575578689575195, -5.605282306671143, -5.637436389923096, -5.671894550323486, -5.708503246307373, -5.747100353240967, -5.7875165939331055, -5.829575061798096, -5.8730902671813965, -5.917869567871094, -5.963710784912109, -6.01040506362915, -6.057735919952393, -6.105477333068848, -6.153397560119629, -6.201257705688477, -6.248812198638916, -6.295809268951416, -6.34199333190918, -6.387104511260986, -6.430880546569824, -6.473059177398682, -6.513377666473389, -6.551576614379883, -6.587400436401367, -6.620600700378418, -6.650938510894775, -6.671913146972656, -6.683298110961914, -6.684905052185059, -6.676593780517578, -6.6582841873168945, -6.629963397979736, -6.591693878173828, -6.543617248535156, -6.485959529876709, -6.419032573699951, -6.343232154846191, -6.259037494659424, -6.167004585266113, -6.067760944366455, -5.961996555328369, -5.850454330444336, -5.733919143676758, -5.613204479217529, -5.489141464233398, -5.362565040588379, -5.234302997589111, -5.105162143707275, -4.517545223236084, -3.953409194946289, -3.4187111854553223, -2.9181926250457764, -2.455317497253418, -2.032280683517456, -1.6500829458236694, -1.3086546659469604, -1.007014513015747, -0.7434437870979309, -0.5156643390655518, -0.32100772857666016, -0.1565667688846588, -0.01932607777416706, 0.09373129159212112, 0.1855405867099762, 0.25889378786087036, 0.316397100687027, 0.36044472455978394, 0.3932053744792938, 0.4166194200515747, 0.43240320682525635, 0.44205933809280396, 0.44689011573791504, 0.44801366329193115, 0.4463810324668884, 0.44279345870018005, 0.4379196763038635, 0.4323121905326843, 0.426422655582428, 0.42061617970466614, 0.4151841104030609, 0.41035589575767517, 0.40630921721458435, 0.4031793475151062, 0.4010671079158783, 0.4000457525253296, 0.4001670181751251, 0.4014662206172943, 0.40396666526794434, 0.4076831340789795, 0.41262510418891907, 0.41879919171333313, 0.42621129751205444, 0.43486830592155457, 0.44477951526641846, 0.4559577405452728, 0.46842026710510254, 0.48218971490859985, 0.49729451537132263, 0.5137695670127869, 0.5316565036773682, 0.5510044693946838, 0.5718700289726257, 0.5943179130554199, 0.6184211373329163, 0.6442614793777466, 0.6719297766685486, 0.7015266418457031, 0.7331624627113342, 0.7669582962989807, 0.8030461668968201, 0.8415699601173401, 0.8826858997344971, 0.9265632629394531, 0.9733853936195374, 1.023350477218628, 1.0766723155975342, 1.1335816383361816, 1.1943273544311523, 1.2591772079467773, 1.3284196853637695, 1.402364730834961, 1.481345772743225, 1.565721035003662, 1.6558748483657837, 1.752219796180725, 1.8551979064941406, 1.9652825593948364, 2.082980155944824, 2.208832025527954, 2.3434154987335205, 2.4873454570770264, 2.641275644302368, 2.8058996200561523, 2.9819512367248535, 3.170203685760498, 3.371469497680664, 3.5865983963012695, 3.8164734840393066, 4.062006950378418, 4.324133396148682, 4.603797912597656, 4.901947498321533, 5.219509601593018, 5.557375431060791, 5.916367530822754, 6.297210216522217, 6.700484275817871, 7.126574516296387, 7.575607776641846, 8.042747497558594, 8.52681827545166, 9.026022911071777, 9.53783893585205, 10.05889892578125, 10.584861755371094, 11.110294342041016, 11.628547668457031, 12.13166332244873, 12.610315322875977, 13.053797721862793, 13.450109481811523, 13.786123275756836, 14.047904968261719, 14.221170425415039, 14.291914939880371, 14.24720573425293, 14.076105117797852, 13.770681381225586, 13.32701301574707, 12.74606990814209, 12.034351348876953, 11.204132080078125, 10.273236274719238, 9.264272689819336, 8.20337200164795, 7.118540287017822, 6.037812232971191, 4.987429618835449, 3.990267276763916, 3.064687490463257, 2.223911762237549, 1.4759199619293213, 0.8238064050674438, 0.26646688580513, -0.20052529871463776, -0.5839887261390686, -0.8922539949417114, -1.134403944015503, -1.319667100906372, -1.4569705724716187, -1.5546387434005737, -1.6202137470245361, -1.6603721380233765, -1.6809096336364746, -1.6867740154266357, -1.6821264028549194, -1.6704189777374268, -1.6544784307479858, -1.636589765548706, -1.6185758113861084, -1.6018705368041992, -1.5875846147537231, -1.5765637159347534, -1.5694392919540405, -1.5666717290878296, -1.5063707828521729, -1.4428702592849731, -1.377892255783081, -1.3128637075424194, -1.2489440441131592, -1.1870548725128174, -1.1279083490371704, -1.072034478187561, -1.0198076963424683, -0.9714707732200623, -0.9271572232246399, -0.8869112730026245, -0.8507061004638672, -0.8184595108032227, -0.7900475263595581, -0.7653166651725769, -0.7440935969352722, -0.7261934280395508, -0.7114270329475403, -0.6996060013771057, -0.6905473470687866, -0.684076726436615, -0.6800311207771301, -0.6782602071762085, -0.6786280870437622, -0.6810133457183838, -0.6853100657463074, -0.6914271712303162, -0.6992887258529663, -0.7088333368301392, -0.7200136780738831, -0.7327959537506104, -0.7471594214439392, -0.7630957961082458, -0.7806087136268616, -0.7997130751609802, -0.8204348087310791, -0.8428103923797607, -0.8668864965438843, -0.8927197456359863, -0.9203766584396362, -0.9499334096908569, -0.9814757704734802, -1.0150994062423706, -1.0509096384048462, -1.089021921157837, -1.129562258720398, -1.1726667881011963, -1.2184832096099854, -1.2671701908111572, -1.3188990354537964, -1.3738529682159424, -1.432228922843933, -1.4942374229431152, -1.5601036548614502, -1.6300684213638306, -1.70438814163208, -1.783336877822876, -1.8672058582305908, -1.9563053846359253, -2.0509650707244873, -2.1515347957611084, -2.258385181427002, -2.3719091415405273, -2.492520809173584, -2.6206576824188232, -2.756779432296753, -2.9013681411743164, -3.0549280643463135, -3.217984437942505, -3.3910815715789795, -3.5747814178466797, -3.7696588039398193, -3.976299285888672, -4.195291042327881, -4.427220821380615, -4.672660827636719, -4.9321608543396, -5.206232070922852, -5.495330810546875, -5.7998366355896, -6.120028018951416, -6.456052303314209, -6.807888507843018, -7.175307750701904, -7.557825088500977, -7.9546427726745605, -8.364591598510742, -8.786059379577637, -9.216917991638184, -9.654448509216309, -10.095253944396973, -10.535188674926758, -10.969287872314453, -11.39171028137207, -11.795710563659668, -12.1736421585083, -12.517013549804688, -12.81660270690918, -13.062644958496094, -13.245115280151367, -13.3441743850708, -13.349907875061035, -13.25369644165039, -13.048912048339844, -12.731635093688965, -12.30129623413086, -11.761190414428711, -11.118759155273438, -10.385588645935059, -9.577056884765625, -8.711653709411621, -7.809985637664795, -6.893592834472656, -5.983672618865967, -5.099867820739746, -4.24941349029541, -3.4471211433410645, -2.70436692237854, -2.0289292335510254, -1.425115942955017, -0.8941196799278259, -0.4345225691795349, -0.04287262633442879, 0.2857348620891571, 0.5571224689483643, 0.7775731086730957, 0.9534643292427063, 1.090994954109192, 1.1959960460662842, 1.2738131284713745, 1.3292450904846191, 1.366525650024414, 1.389333963394165, 1.4008264541625977, 1.4036781787872314, 1.400132179260254, 1.3920493125915527, 1.3809565305709839, 1.368093729019165, 1.3544554710388184, 1.3408293724060059, 1.3278294801712036, 1.3159258365631104, 1.3054699897766113, 1.296716570854187, 1.2898424863815308, 1.2849619388580322, 1.2821401357650757, 1.2814037799835205, 1.2827507257461548, 1.2861567735671997, 1.2915819883346558, 1.2989755868911743, 1.3082796335220337, 1.319432020187378, 1.332369089126587, 1.3470268249511719, 1.3633426427841187, 1.381256103515625, 1.3372008800506592, 1.2963746786117554, 1.2589542865753174, 1.225041389465332, 1.1946756839752197, 1.1678484678268433, 1.1445132493972778, 1.1245954036712646, 1.1080001592636108, 1.0946195125579834, 1.0843383073806763, 1.0770384073257446, 1.0726031064987183, 1.0709199905395508, 1.071883201599121, 1.0753955841064453, 1.0813698768615723, 1.089729905128479, 1.100411057472229, 1.1133607625961304, 1.128538727760315, 1.1459171772003174, 1.1654804944992065, 1.1872252225875854, 1.2111600637435913, 1.2373052835464478, 1.2656928300857544, 1.2963663339614868, 1.3293801546096802, 1.364800214767456, 1.402703046798706, 1.44317626953125, 1.4863183498382568, 1.532238483428955, 1.5810569524765015, 1.632905125617981, 1.6879255771636963, 1.7462719678878784, 1.8081098794937134, 1.873616337776184, 1.9429807662963867, 2.016404390335083, 2.094101667404175, 2.1762990951538086, 2.2632365226745605, 2.3551669120788574, 2.4523561000823975, 2.5550835132598877, 2.6636416912078857, 2.7783350944519043, 2.8994812965393066, 3.027409553527832, 3.162458658218384, 3.3049774169921875, 3.455321788787842, 3.6138525009155273, 3.780932664871216, 3.956923246383667, 4.1421799659729, 4.337045192718506, 4.541845321655273, 4.756877422332764, 4.982405662536621, 5.218643665313721, 5.4657464027404785, 5.72379207611084, 5.992764472961426, 6.272531986236572, 6.562826156616211, 6.863212585449219, 7.1730637550354, 7.491525173187256, 7.817483425140381, 8.149526596069336, 8.485907554626465, 8.824508666992188, 9.162803649902344, 9.497827529907227, 9.826151847839355, 10.143872261047363, 10.446609497070312, 10.729531288146973, 10.98740005493164, 11.214645385742188, 11.405479431152344, 11.554040908813477, 11.654585838317871, 11.701708793640137, 11.690601348876953, 11.617323875427246, 11.479095458984375, 11.274553298950195, 11.003987312316895, 10.669507026672363, 10.275116920471191, 9.826693534851074, 9.331838607788086, 8.799617767333984, 8.240195274353027, 7.66439151763916, 7.083194255828857, 6.497585296630859, 5.918073654174805, 5.354244232177734, 4.814428329467773, 4.305474281311035, 3.8326313495635986, 3.3995320796966553, 3.008272647857666, 2.659562110900879, 2.3529207706451416, 2.086904287338257, 1.8593331575393677, 1.6675100326538086, 1.5084174871444702, 1.3788844347000122, 1.2757229804992676, 1.195833683013916, 1.1362823247909546, 1.0943522453308105, 1.0675756931304932, 1.0537478923797607, 1.0509302616119385, 1.0574421882629395, 1.071847915649414, 1.092938780784607, 1.1197129487991333, 1.1513547897338867, 1.1872142553329468, 1.2267862558364868, 1.2696925401687622, 1.3156639337539673, 1.3645256757736206, 1.4161827564239502, 1.4706089496612549, 1.5278352499008179, 1.5879420042037964, 1.6510508060455322, 1.7173184156417847, 1.7869317531585693, 1.8601034879684448, 1.9370685815811157, 2.0180819034576416, 2.1034157276153564, 2.1933581829071045, 2.2882120609283447, 2.388293504714966, 2.493931531906128, 2.60546612739563, 2.7232491970062256, 2.8476414680480957, 2.979013681411743, 3.1177430152893066, 3.2642126083374023, 3.418809413909912, 3.581921100616455, 3.753931999206543, 3.9352197647094727, 4.126150131225586, 4.32706880569458, 4.538296222686768, 4.760116100311279, 4.9927659034729, 5.236422538757324, 5.4911885261535645, 5.757072448730469, 6.033970355987549, 6.321642875671387, 6.619686603546143, 6.927507400512695, 7.244288444519043, 7.568952560424805, 7.9001288414001465, 8.236112594604492, 8.574827194213867, 8.913786888122559, 9.250062942504883, 9.58026123046875, 9.90049934387207, 10.20640754699707, 10.493147850036621, 10.755452156066895, 10.987690925598145, 11.18398380279541, 11.338336944580078, 11.444828033447266, 11.49782657623291, 11.49224853515625, 11.423835754394531, 11.289444923400879, 11.087325096130371, 10.807378768920898, 10.451196670532227, 10.022541046142578, 9.527390480041504, 8.973835945129395, 8.371825218200684, 7.7327752113342285, 7.069060802459717, 6.393438816070557, 5.718448638916016, 5.055846691131592, 4.416121959686279, 3.8081281185150146, 3.238858222961426, 2.7133591175079346, 2.234776020050049, 1.8045027256011963, 1.422408938407898, 1.0871094465255737, 0.7962489724159241, 0.5467776656150818, 0.33520159125328064, 0.15779702365398407, 0.010784933343529701, -0.10953468829393387, -0.20668524503707886, -0.28394800424575806, -0.34432297945022583, -0.3905107080936432, -0.4249095618724823, -0.4496244788169861, -0.4664832353591919, -0.4770573079586029, -0.482685387134552, -0.4844977557659149, -0.48344019055366516, -0.4802970588207245, -0.4757128059864044, -0.4702115058898926, -0.4642146825790405, -0.4580571949481964, -0.45200100541114807, -0.44624757766723633, -0.44094815850257874, -0.4362131655216217, -0.4321196377277374, -0.4287179708480835, -0.42603743076324463, -0.42409056425094604, -0.42287734150886536, -0.422387957572937, -0.4226056933403015, -0.4235087037086487, -0.42507192492485046, -0.42726820707321167, -0.4300694167613983, -0.4334472119808197, -0.437373548746109, -0.4418211579322815, -0.44676390290260315, -0.4521768093109131, -0.458036333322525, -0.46432027220726013, -0.4710078537464142, -0.4780796468257904, -0.4855175018310547, -0.49330443143844604, -0.5014246106147766, -0.5098630785942078, -0.5186058878898621, -0.5276397466659546, -0.536952018737793, -0.546530544757843, -0.5563637018203735, -0.5664400458335876, -0.5767485499382019, -0.5872781872749329, -0.5980179309844971, -0.6089568138122559, -0.6200838685035706, -0.6313877105712891, -0.6428568959236145, -0.6452504396438599, -0.6488137245178223, -0.6535436511039734, -0.6594370007514954, -0.6664912700653076, -0.6747055053710938, -0.6840810775756836, -0.6946223974227905, -0.706337034702301, -0.7192363739013672, -0.7333358526229858, -0.7486550807952881, -0.7652183175086975, -0.783054530620575, -0.8021973967552185, -0.8226856589317322, -0.8445632457733154, -0.8678793907165527, -0.8926887512207031, -0.9190515875816345, -0.9470338821411133, -0.9767078161239624, -1.0081514120101929, -1.0414495468139648, -1.0766932964324951, -1.113981008529663, -1.1534181833267212, -1.195117712020874, -1.2392007112503052, -1.2857964038848877, -1.3350424766540527, -1.3870859146118164, -1.4420833587646484, -1.5002009868621826, -1.5616157054901123, -1.6265153884887695, -1.695098876953125, -1.7675774097442627, -1.8441742658615112, -1.9251255989074707, -2.010680913925171, -2.1011030673980713, -2.196669578552246, -2.297671318054199, -2.404414653778076, -2.5172195434570312, -2.636420726776123, -2.762366533279419, -2.8954195976257324, -3.035953998565674, -3.1843557357788086, -3.341019868850708, -3.5063493251800537, -3.6807501316070557, -3.8646295070648193, -4.058390140533447, -4.262424468994141, -4.477108001708984, -4.702789306640625, -4.93978214263916, -5.188349723815918, -5.448692798614502, -5.720931529998779, -6.00508451461792, -6.301047325134277, -6.608564376831055, -6.92719841003418, -7.256298542022705, -7.5949625968933105, -7.941995620727539, -8.295866966247559, -8.654666900634766, -9.016059875488281, -9.377243041992188, -9.734905242919922, -10.085203170776367, -10.423733711242676, -10.745545387268066, -11.04515266418457, -11.316598892211914, -11.55354118347168, -11.749385833740234, -11.897469520568848, -11.99128532409668, -12.024759292602539, -11.99255657196045, -11.890419960021973, -11.715508460998535, -11.466712951660156, -11.144917488098145, -10.753175735473633, -10.296775817871094, -9.783163070678711, -9.221714973449707, -8.623383522033691, -8.000202178955078, -7.364730358123779, -6.729447364807129, -6.1061787605285645, -5.505587577819824, -4.936777591705322, -4.398298740386963, -3.8963420391082764, -3.435316562652588, -3.0179147720336914, -2.645261764526367, -2.317126750946045, -2.032167911529541, -1.7881871461868286, -1.5823760032653809, -1.411538004875183, -1.2722803354263306, -1.1611698865890503, -1.0748544931411743, -1.0101523399353027, -0.9641117453575134, -0.934048056602478, -0.9175615906715393, -0.91254061460495, -0.9171541333198547, -0.9298370480537415, -0.9492707252502441, -0.9743612408638, -1.0042163133621216, -1.038122296333313, -1.0755223035812378, -1.1159954071044922, -1.1592381000518799, -1.2050471305847168, -1.2533046007156372, -1.3039644956588745, -1.3570420742034912, -1.4126031398773193, -1.4707568883895874, -1.5316483974456787, -1.5954535007476807, -1.6623742580413818, -1.7326349020004272, -1.8064796924591064, -1.8841700553894043, -1.965983510017395, -2.0522119998931885, -2.1431612968444824, -2.2391505241394043, -2.340510368347168, -2.447584867477417, -2.5607287883758545, -2.6803085803985596, -2.806701183319092, -2.940293073654175, -3.0814785957336426, -3.2306599617004395, -3.3882431983947754, -3.5546364784240723, -3.7302467823028564, -3.9154741764068604, -4.110708236694336, -4.316320419311523, -4.532655239105225, -4.760022163391113, -4.998682975769043, -5.248838424682617, -5.510611534118652, -5.784029483795166, -6.069002628326416, -6.365297317504883, -6.672510623931885, -6.990036964416504, -7.317034721374512, -7.6523871421813965, -7.994663715362549, -8.342077255249023, -8.692442893981934, -9.043132781982422, -9.391047477722168, -9.73257827758789, -10.063592910766602, -10.37942886352539, -10.67491626739502, -10.944416999816895, -10.383661270141602, -9.771240234375, -9.112977027893066, -8.417091369628906, -7.693760395050049, -6.954543590545654, -6.211706638336182, -5.477518081665039, -4.763584136962891, -4.08027458190918, -3.436286687850952, -2.8383724689483643, -2.2912309169769287, -1.7975492477416992, -1.358167052268982, -0.9723249673843384, -0.6379621624946594, -0.3520289659500122, -0.11078764498233795, 0.08991694450378418, 0.25442755222320557, 0.3870900571346283, 0.49211350083351135, 0.5734705924987793, 0.6348327398300171, 0.6795337796211243, 0.7105553150177002, 0.7305287718772888, 0.7417487502098083, 0.746194064617157, 0.7455536723136902, 0.7412546873092651, 0.734490692615509, 0.7262501120567322, 0.7173427939414978, 0.708424985408783, 0.7000220417976379, 0.6925492286682129, 0.68632972240448, 0.681611180305481, 0.6785798072814941, 0.6773728132247925, 0.6780886054039001, 0.6807965040206909, 0.6855438351631165, 0.6923628449440002, 0.7012758255004883, 0.7122997045516968, 0.7254499793052673, 0.7407434582710266, 0.7582008242607117, 0.777849018573761, 0.79972243309021, 0.8238645195960999, 0.8503289818763733, 0.8791804909706116, 0.9104956984519958, 0.9443638324737549, 0.9808873534202576, 1.0201826095581055, 1.0623805522918701, 1.1076267957687378, 1.1560832262039185, 1.2079277038574219, 1.2633554935455322, 1.3225795030593872, 1.3858317136764526, 1.4533635377883911, 1.525447130203247, 1.6023762226104736, 1.6844675540924072, 1.7720615863800049, 1.8655239343643188, 1.965246558189392, 2.0716490745544434, 2.1851792335510254, 2.3063156604766846, 2.4355669021606445, 2.5734739303588867, 2.720609426498413, 2.8775794506073, 3.045022487640381, 3.22360897064209, 3.4140396118164062, 3.617044448852539, 3.8333778381347656, 4.063814640045166, 4.309142589569092, 4.570155620574951, 4.847639560699463, 5.142359733581543, 5.455041885375977, 5.786346912384033, 6.136845588684082, 6.506979465484619, 6.897021293640137, 7.307020664215088, 7.736745834350586, 8.185608863830566, 8.65258502960205, 9.136115074157715, 9.6282377243042, 10.125383377075195, 10.623027801513672, 11.11559772491455, 11.596385955810547, 12.0574951171875, 12.489819526672363, 12.883089065551758, 13.225995063781738, 13.506412506103516, 13.711745262145996, 13.8294038772583, 13.847418785095215, 13.755175590515137, 13.544246673583984, 13.209239959716797, 12.748610496520996, 12.165316581726074, 11.467212677001953, 10.667097091674805, 9.78233528137207, 8.834053993225098, 7.845956802368164, 6.842865943908691, 5.8491716384887695, 4.88734769821167, 3.976722240447998, 3.1326138973236084, 2.365900993347168, 1.6830101013183594, 1.0862581729888916, 0.5744486451148987, 0.14360657334327698, -0.21224986016750336, -0.500382661819458, -0.7287047505378723, -0.9052739143371582, -1.0379154682159424, -1.1339625120162964, -1.200096607208252, -1.2422682046890259, -1.2656757831573486, -1.2747853994369507, -1.2733776569366455, -1.2646092176437378, -1.2510817050933838, -1.234911561012268, -1.2177979946136475, -1.2010867595672607, -1.1858271360397339, -1.1728233098983765, -1.1626801490783691, -1.155841588973999, -1.152624249458313, -1.153246521949768, -1.1578514575958252, -1.166527509689331, -1.179324746131897, -1.1962682008743286, -1.217368721961975, -1.2426323890686035, -1.2720664739608765, -1.3056857585906982, -1.3435163497924805, -1.3855990171432495, -1.4319919347763062, -1.4827719926834106, -1.5380364656448364, -1.5979037284851074, -1.662514328956604, -1.7320307493209839, -1.8066381216049194, -1.8865443468093872, -1.9719797372817993, -2.063197135925293, -2.1604719161987305, -2.264101266860962, -2.3744044303894043, -2.4917211532592773, -2.6164121627807617, -2.748857259750366, -2.8894543647766113, -3.0386178493499756, -3.1967761516571045, -3.3643696308135986, -3.54184627532959, -3.729658603668213, -3.9282567501068115, -4.138083457946777, -4.359564304351807, -4.593100547790527, -4.839053630828857, -5.0977349281311035, -5.369386672973633, -5.654162883758545, -5.95210599899292, -6.263120651245117, -6.586941719055176, -6.92310094833374, -7.270884990692139, -7.629293441772461, -7.493341445922852, -7.349358081817627, -7.196996212005615, -7.036209583282471, -6.867253303527832, -6.690670013427734, -6.507264614105225, -6.318068981170654, -6.124301910400391, -5.927321910858154, -5.728583335876465, -5.529587745666504, -5.3318400382995605, -5.136807918548584, -4.945885181427002, -4.76036262512207, -4.58140230178833, -4.4100236892700195, -4.247089862823486, -4.09330415725708, -3.9492123126983643, -3.815207004547119, -3.691538095474243, -3.578324794769287, -3.4755709171295166, -3.3831799030303955, -3.300971746444702, -3.228698968887329, -3.1660614013671875, -3.1127219200134277, -3.0683181285858154, -3.0324745178222656, -3.004812717437744, -2.9849600791931152, -2.9725561141967773, -2.9672586917877197, -2.9687485694885254, -2.976731777191162, -2.9909424781799316, -3.0111448764801025, -3.0371317863464355, -3.068727493286133, -3.1057848930358887, -3.1481854915618896, -3.1958389282226562, -3.2486798763275146, -3.306668281555176, -3.369786262512207, -3.4380369186401367, -3.511441707611084, -3.5900392532348633, -3.6738827228546143, -3.76303768157959, -3.8575797080993652, -3.957592248916626, -4.063163757324219, -4.174385070800781, -4.291346549987793, -4.414134502410889, -4.542828559875488, -4.677496910095215, -4.818192005157471, -4.96494722366333, -5.117770195007324, -5.276637554168701, -5.441490173339844, -5.612224578857422, -5.7886857986450195, -5.970660209655762, -6.157866477966309, -6.349946022033691, -6.546455383300781, -6.746852397918701, -6.950490474700928, -7.1566057205200195, -7.364309310913086, -7.57257604598999, -7.780240058898926, -7.985987186431885, -8.188350677490234, -8.385714530944824, -8.576314926147461, -8.758249282836914, -8.929492950439453, -9.087918281555176, -9.231324195861816, -9.357474327087402, -9.46413803100586, -9.54914665222168, -9.610448837280273, -9.646180152893066, -9.654728889465332, -9.634807586669922, -9.58552360534668, -9.506438255310059, -9.397621154785156, -9.259690284729004, -9.09383487701416, -8.901811599731445, -8.685925483703613, -8.44898509979248, -8.185325622558594, -7.898719787597656, -7.593338489532471, -7.2736382484436035, -6.9442315101623535, -6.609752178192139, -6.27471923828125, -5.943411827087402, -5.619757652282715, -5.307248115539551, -5.008871555328369, -4.727078914642334, -4.463772296905518, -4.220315456390381, -3.997565984725952, -3.7959232330322266, -3.6153836250305176, -3.4556045532226562, -3.3159680366516113, -3.195645570755005, -3.093656301498413, -3.0089199542999268, -2.94030499458313, -2.8866665363311768, -2.8468782901763916, -2.8198585510253906, -2.804586887359619, -2.800119400024414, -2.805595636367798, -2.8202433586120605, -2.8433797359466553, -2.8744099140167236, -2.9128246307373047, -2.9581944942474365, -3.0101656913757324, -3.068453550338745, -3.132835865020752, -3.2031474113464355, -3.2792727947235107, -3.361140727996826, -3.4487175941467285, -3.5420022010803223, -3.641019821166992, -3.745816469192505, -3.856454849243164, -3.9730076789855957, -4.095553874969482, -4.224173069000244, -4.3589396476745605, -4.499917507171631, -4.647156238555908, -4.8006815910339355, -4.960492134094238, -5.126550674438477, -5.2987775802612305, -5.477041244506836, -5.66115140914917, -5.850849151611328, -6.045795440673828, -6.24556303024292, -6.449624061584473, -6.657339572906494, -6.867948055267334, -7.080554962158203, -7.294120788574219, -7.5074543952941895, -7.719203948974609, -7.927852630615234, -8.131715774536133, -8.328944206237793, -8.517531394958496, -8.695327758789062, -8.860057830810547, -9.009352684020996, -9.14078426361084, -9.251914024353027, -9.340343475341797, -9.40378189086914, -9.440113067626953, -9.447473526000977, -9.424330711364746, -9.369556427001953, -9.282504081726074, -9.163066864013672, -9.011728286743164, -8.829587936401367, -8.618372917175293, -8.380414009094238, -8.11860466003418, -7.836328029632568, -7.537364959716797, -7.225780963897705, -6.905803680419922, -6.581692218780518, -6.257611274719238, -5.937511444091797, -5.625027656555176, -5.323397636413574, -5.035400390625, -4.763322353363037, -4.508945941925049, -4.273558616638184, -4.057981491088867, -3.862607955932617, -3.6874592304229736, -3.532238245010376, -3.3963892459869385, -3.2791566848754883, -3.1796388626098633, -3.0968375205993652, -3.0297014713287354, -2.977163076400757, -2.93816876411438, -2.9117019176483154, -2.8968019485473633, -2.8925764560699463, -2.8982093334198, -2.912966012954712, -2.93619441986084, -2.9673256874084473, -3.005868911743164, -3.05141019821167, -3.1036057472229004, -3.162177085876465, -3.226905107498169, -3.297624349594116, -3.3742170333862305, -3.456606388092041, -3.5447514057159424, -3.6386420726776123, -3.7382917404174805, -3.8437342643737793, -3.955016851425171, -4.072196006774902, -4.195332050323486, -4.324483871459961, -4.4597039222717285, -4.60103178024292, -4.748488903045654, -4.902072906494141, -5.061750411987305, -5.227449417114258, -5.399053573608398, -5.576391696929932, -5.759231090545654, -5.947267055511475, -6.140114784240723, -6.337296962738037, -6.538235187530518, -6.742238998413086, -6.948495388031006, -7.156059741973877, -7.363844871520996, -7.570616722106934, -7.774986267089844, -7.97540807723999, -8.17017936706543, -8.357447624206543, -8.535221099853516, -8.701379776000977, -8.84679889678955, -8.968899726867676, -8.360508918762207, -7.729096412658691, -7.082942962646484, -6.431039333343506, -5.78263521194458, -5.146773338317871, -4.531860828399658, -3.945305824279785, -3.393247604370117, -2.8803982734680176, -2.4099884033203125, -1.9838093519210815, -1.6023321151733398, -1.2648802995681763, -0.9698351621627808, -0.7148499488830566, -0.49705877900123596, -0.31326642632484436, -0.16011305153369904, -0.03420914709568024, 0.06775858998298645, 0.14894899725914001, 0.2123125195503235, 0.2605576515197754, 0.2961338460445404, 0.3212272822856903, 0.3377661406993866, 0.34743237495422363, 0.3516780734062195, 0.35174453258514404, 0.34868234395980835, 0.34337201714515686, 0.33654388785362244, 0.32879728078842163, 0.320618212223053, 0.31239578127861023, 0.30443692207336426, 0.2969795763492584, 0.2902044951915741, 0.28424543142318726, 0.2791981101036072, 0.2751278877258301, 0.27207642793655396, 0.27006715536117554, 0.2691100835800171, 0.26920562982559204, 0.2703479528427124, 0.2725276052951813, 0.27573370933532715, 0.2799556255340576, 0.2851845920085907, 0.2914145588874817, 0.2986433804035187, 0.3068732023239136, 0.316111296415329, 0.3263702690601349, 0.33766862750053406, 0.3500308394432068, 0.36348778009414673, 0.37807685136795044, 0.3938421905040741, 0.41083502769470215, 0.4291137754917145, 0.44874438643455505, 0.4698006510734558, 0.49236446619033813, 0.5165263414382935, 0.5423856377601624, 0.5700514316558838, 0.5996425747871399, 0.6312887072563171, 0.6651306748390198, 0.7013214826583862, 0.7400269508361816, 0.7814269065856934, 0.8257156610488892, 0.8731037378311157, 0.9238185286521912, 0.9781058430671692, 1.036231279373169, 1.0984816551208496, 1.1651663780212402, 1.2366198301315308, 1.3132025003433228, 1.3953031301498413, 1.483341097831726, 1.577768087387085, 1.6790708303451538, 1.7877730131149292, 1.9044381380081177, 2.0296716690063477, 2.164123296737671, 2.30849027633667, 2.4635183811187744, 2.6300048828125, 2.808799982070923, 3.000808000564575, 3.2069873809814453, 3.428351402282715, 3.6659655570983887, 3.9209437370300293, 4.192102432250977, 4.480341911315918, 4.786525726318359, 5.111462116241455, 5.4558796882629395, 5.820400238037109, 6.205500602722168, 6.611466884613037, 7.038340091705322, 7.485851287841797, 7.953343391418457, 8.439680099487305, 8.943144798278809, 9.461324691772461, 9.99098014831543, 10.527914047241211, 11.06683349609375, 11.601212501525879, 12.123181343078613, 12.62343692779541, 13.091217041015625, 13.514338493347168, 13.87934684753418, 14.171802520751953, 14.37671184539795, 14.479146957397461, 14.465043067932129, 14.322154998779297, 14.041119575500488, 13.616558074951172, 13.048072814941406, 12.341017723083496, 11.506889343261719, 10.563215255737305, 9.532861709594727, 8.442788124084473, 7.32234525680542, 6.201298713684082, 5.107839584350586, 4.0668206214904785, 3.0984253883361816, 2.217400550842285, 1.432866096496582, 0.7486440539360046, 0.16396604478359222, -0.32559117674827576, -0.7270973324775696, -1.049306869506836, -1.3018245697021484, -1.49443781375885, -1.6366245746612549, -1.7372223138809204, -1.8042317628860474, -1.8447258472442627, -1.8648345470428467, -1.869781255722046, -1.863950490951538, -1.8509719371795654, -1.8338117599487305, -1.8148627281188965, -1.7960293292999268, -1.7788068056106567, -1.7643505334854126, -1.7535383701324463, -1.7470238208770752, -1.7452819347381592, -1.7486484050750732, -1.7573519945144653, -1.771541953086853, -1.7913106679916382, -1.8167120218276978, -1.8477762937545776, -1.8845221996307373, -1.926966667175293, -1.9751317501068115, -2.029050827026367, -2.088773012161255, -2.1543655395507812, -2.225917100906372, -2.3035380840301514, -2.387362241744995, -2.477546215057373, -2.574270248413086, -2.677736520767212, -2.7881691455841064, -2.9058117866516113, -3.0309274196624756, -3.163795232772827, -3.304708242416382, -3.4539713859558105, -3.611896514892578, -3.778799295425415, -3.9549942016601562, -4.140788555145264, -4.336475849151611, -4.5423264503479, -4.758581161499023, -4.985436916351318, -5.22303581237793, -5.47144889831543, -5.730660438537598, -6.000548362731934, -6.280860900878906, -6.571192741394043, -6.8709564208984375, -7.179354190826416, -7.49534273147583, -7.817601203918457, -8.144493103027344, -7.911733150482178, -7.665533065795898, -7.406703948974609, -7.136514186859131, -6.856656074523926, -6.569183826446533, -6.276432037353516, -5.980926990509033, -5.6852922439575195, -5.392153739929199, -5.104053020477295, -4.823370456695557, -4.552262783050537, -4.292611598968506, -4.045995235443115, -3.8136696815490723, -3.596566915512085, -3.39530611038208, -3.210214138031006, -3.041353225708008, -2.8885552883148193, -2.751457691192627, -2.629540205001831, -2.522160768508911, -2.4285900592803955, -2.348040819168091, -2.2796967029571533, -2.222733736038208, -2.176340341567993, -2.1397321224212646, -2.1121649742126465, -2.092942476272583, -2.081422805786133, -2.0770223140716553, -2.0792174339294434, -2.0875446796417236, -2.10159969329834, -2.1210365295410156, -2.1455636024475098, -2.174941301345825, -2.1083946228027344, -2.0487284660339355, -1.9957399368286133, -1.9491931200027466, -1.9088294506072998, -1.8743776082992554, -1.8455603122711182, -1.8221017122268677, -1.8037322759628296, -1.7901932001113892, -1.7812402248382568, -1.7766451835632324, -1.776199221611023, -1.7797129154205322, -1.7870177030563354, -1.7979656457901, -1.8124302625656128, -1.830305576324463, -1.8515061140060425, -1.8759658336639404, -1.9036381244659424, -1.9344944953918457, -1.9685239791870117, -2.005732536315918, -2.046142101287842, -2.089790105819702, -2.136728048324585, -2.1870217323303223, -2.240750551223755, -2.2980058193206787, -2.358891725540161, -2.4235239028930664, -2.4920287132263184, -2.5645434856414795, -2.6412160396575928, -2.722202777862549, -2.8076696395874023, -2.8977911472320557, -2.992748975753784, -3.0927317142486572, -3.1979334354400635, -3.308553695678711, -3.4247941970825195, -3.5468592643737793, -3.674952507019043, -3.809274911880493, -3.9500226974487305, -4.097383499145508, -4.2515339851379395, -4.412633419036865, -4.580821514129639, -4.756210803985596, -4.938880443572998, -5.128870010375977, -5.326169967651367, -5.53071403503418, -5.742366313934326, -5.960911273956299, -6.186041355133057, -6.417342185974121, -6.6542792320251465, -6.896180152893066, -7.142220973968506, -7.3914079666137695, -7.642563343048096, -7.894308090209961, -8.145051002502441, -8.392974853515625, -8.636034965515137, -8.871950149536133, -9.098217964172363, -9.312117576599121, -9.510743141174316, -9.69103717803955, -9.849833488464355, -9.983930587768555, -10.090160369873047, -10.165483474731445, -10.20709228515625, -10.212522506713867, -10.179770469665527, -10.10741138458252, -9.994706153869629, -9.841694831848145, -9.649266242980957, -9.419198036193848, -9.154153823852539, -8.85764217376709, -8.533939361572266, -8.187957763671875, -7.8250932693481445, -7.451042175292969, -7.071600437164307, -6.692471027374268, -6.319073677062988, -5.956384658813477, -5.608804702758789, -5.280066967010498, -4.973182201385498, -4.690426826477051, -4.4333600997924805, -4.195876121520996, -3.9788565635681152, -3.782707929611206, -3.607424020767212, -3.4526541233062744, -3.31777286529541, -3.2019448280334473, -3.1041858196258545, -3.0234169960021973, -2.9585111141204834, -2.908332347869873, -2.8717665672302246, -2.8477466106414795, -2.8352692127227783, -2.8334083557128906, -2.841322183609009, -2.858257532119751, -2.8835501670837402, -2.9166228771209717, -2.9569835662841797, -3.004218101501465, -3.0579872131347656, -3.118018627166748, -3.1841018199920654, -3.256080389022827, -3.3338472843170166, -3.417337417602539, -3.506521463394165, -3.6014013290405273, -3.7020034790039062, -3.80837345123291, -3.9205715656280518, -4.03866720199585, -4.1627326011657715, -4.292839527130127, -4.42905330657959, -4.571425914764404, -4.719992160797119, -4.874761581420898, -5.0357136726379395, -5.202789783477783, -5.375885486602783, -5.554841995239258, -5.739439487457275, -5.929384231567383, -6.124301910400391, -6.323725700378418, -6.527085781097412, -6.733698844909668, -6.942756652832031, -7.153316497802734, -7.364291667938232, -7.574441432952881, -7.7823686599731445, -7.986512660980225, -8.185152053833008, -8.376405715942383, -8.558247566223145, -8.72851848602295, -8.8849515914917, -9.025199890136719, -9.146883964538574, -9.247631072998047, -9.325136184692383, -9.377227783203125, -9.401935577392578, -9.397566795349121, -9.36277961730957, -9.296658515930176, -9.19877815246582, -9.06926155090332, -8.908814430236816, -8.718750953674316, -8.500986099243164, -8.25800895690918, -7.992830276489258, -7.708905220031738, -7.410036087036133, -7.1002583503723145, -6.783720016479492, -6.464555740356445, -6.146766662597656, -5.834110260009766, -5.530009746551514, -5.237479209899902, -4.959076404571533, -4.696876049041748, -4.452463626861572, -4.226953983306885, -4.021018981933594, -3.834932804107666, -3.668623447418213, -3.5217278003692627, -3.393649101257324, -3.283612012863159, -3.1907131671905518, -3.1139681339263916, -3.052351236343384, -3.004829168319702, -2.9703879356384277, -2.9480555057525635, -2.9369163513183594, -2.9361236095428467, -2.9449055194854736, -2.9625697135925293, -2.98850417137146, -3.0221755504608154, -3.063126564025879, -3.1109721660614014, -3.1653943061828613, -3.2261366844177246, -3.292999029159546, -3.3658316135406494, -3.444528818130493, -3.5290231704711914, -3.619281053543091, -3.7152953147888184, -3.8170814514160156, -3.9246714115142822, -4.038109302520752, -4.157444477081299, -4.282729148864746, -4.414010524749756, -4.551326274871826, -4.694698810577393, -4.844130039215088, -4.999593734741211, -5.161029815673828, -5.328336238861084, -5.501361846923828, -5.679898262023926, -5.863670825958252, -6.052328586578369, -6.24543571472168, -6.442461967468262, -6.642770767211914, -6.84561014175415, -7.050104141235352, -7.255241394042969, -7.459869384765625, -7.662687301635742, -7.862242698669434, -8.056931495666504, -8.245000839233398, -8.424554824829102, -8.593573570251465, -8.749926567077637, -8.891406059265137, -9.015756607055664, -9.120720863342285, -9.204090118408203, -9.263760566711426, -9.297798156738281, -9.304506301879883, -9.282496452331543, -9.230756759643555, -9.148715019226074, -9.036293029785156, -8.893950462341309, -8.722708702087402, -8.52415657043457, -8.300433158874512, -8.054186820983887, -7.788515567779541, -7.506882667541504, -7.213017463684082, -6.910806179046631, -6.6041765213012695, -6.296985149383545, -5.992908954620361, -5.695354461669922, -5.407378196716309, -5.1316328048706055, -4.870331287384033, -4.6252312660217285, -4.397640705108643, -4.188437461853027, -3.998105764389038, -3.8267767429351807, -3.6742796897888184, -3.540194034576416, -3.423900842666626, -3.324632406234741, -3.2415177822113037, -3.1736245155334473, -3.1199915409088135, -3.0796597003936768, -3.0516951084136963, -3.0352060794830322, -3.029358148574829, -3.033381700515747, -3.0465786457061768, -3.068324327468872, -3.0980687141418457, -3.13533353805542, -3.179710626602173, -3.2308571338653564, -3.2884910106658936, -3.352386236190796, -3.4223666191101074, -3.498300552368164, -3.580096483230591, -3.6676952838897705, -3.7610669136047363, -3.860203981399536, -3.965116500854492, -4.075827598571777, -4.192366600036621, -4.3147664070129395, -4.443055629730225, -4.577254295349121, -4.717369079589844, -4.8633856773376465, -5.015263557434082, -5.172929763793945, -5.336270332336426, -5.505125999450684, -5.679279327392578, -5.8584513664245605, -5.581213474273682, -5.305078029632568, -5.03238582611084, -4.765296459197998, -4.505768775939941, -4.2555389404296875, -4.016097545623779, -3.788682222366333, -3.5742673873901367, -3.3735697269439697, -3.1870574951171875, -3.014967203140259, -2.857325315475464, -2.7139742374420166, -2.584599494934082, -2.4687578678131104, -2.365905523300171, -2.2754242420196533, -2.196646213531494, -2.1288750171661377, -2.071404457092285, -2.0235352516174316, -1.9845870733261108, -1.9539097547531128, -1.9308903217315674, -1.91495943069458, -1.9055943489074707, -1.9023219347000122, -1.9047187566757202, -1.9124114513397217, -1.9250750541687012, -1.9424320459365845, -1.9642497301101685, -1.99033784866333, -2.0205466747283936, -2.0547635555267334, -2.0929110050201416, -2.134943962097168, -2.180846691131592, -2.2306323051452637, -2.28433895111084, -2.3420283794403076, -2.4037842750549316, -2.4697113037109375, -2.5399322509765625, -2.6145880222320557, -2.693835496902466, -2.777846574783325, -2.866807699203491, -2.9609174728393555, -3.060386896133423, -3.1654369831085205, -3.2762985229492188, -3.393209218978882, -3.516413450241089, -3.6461596488952637, -3.782697916030884, -3.9262776374816895, -4.077143669128418, -4.235534191131592, -4.401673793792725, -4.575771808624268, -4.758012294769287, -4.948550701141357, -5.147503852844238, -5.354940891265869, -5.570873737335205, -5.795243740081787, -6.027909755706787, -6.268631458282471, -6.517053604125977, -6.772688388824463, -7.0348944664001465, -7.302857875823975, -7.575569152832031, -7.851799964904785, -8.130084991455078, -8.408699035644531, -8.685637474060059, -8.958606719970703, -9.22501277923584, -9.481961250305176, -9.726268768310547, -9.954482078552246, -10.162919998168945, -10.347725868225098, -10.504940032958984, -10.630599975585938, -10.720848083496094, -10.772072792053223, -10.781051635742188, -10.745116233825684, -10.662304878234863, -10.531525611877441, -10.352682113647461, -10.126778602600098, -9.855979919433594, -9.54361629486084, -9.194130897521973, -8.812963485717773, -8.406379699707031, -7.971652030944824, -7.516327381134033, -7.048236846923828, -6.575207710266113, -6.104778289794922, -5.6439385414123535, -5.19891357421875, -4.7750020027160645, -4.376479148864746, -4.006556987762451, -3.6674070358276367, -3.360227108001709, -3.0853450298309326, -2.8423454761505127, -2.6302077770233154, -2.447446584701538, -2.292243003845215, -2.162565231323242, -2.0562708377838135, -1.9711936712265015, -1.9052112102508545, -1.8562965393066406, -1.8225551843643188, -1.8022487163543701, -1.7938084602355957, -1.795841097831726, -1.8071272373199463, -1.8266154527664185, -1.8534133434295654, -1.8867764472961426, -1.9260954856872559, -1.9708842039108276, -2.020766019821167, -2.0754618644714355, -2.134779691696167, -2.1986021995544434, -2.266878366470337, -2.339613914489746, -2.4168639183044434, -2.2642698287963867, -2.1203958988189697, -1.9859144687652588, -1.8612322807312012, -1.7465300559997559, -1.6418009996414185, -1.5468846559524536, -1.4614996910095215, -1.3852720260620117, -1.3177599906921387, -1.2584768533706665, -1.2069091796875, -1.162532925605774, -1.1248265504837036, -1.0932811498641968, -1.0674083232879639, -1.0467469692230225, -1.0308666229248047, -1.0193709135055542, -1.0118992328643799, -1.0081267356872559, -1.007764458656311, -1.0105587244033813, -1.016289472579956, -1.0247690677642822, -1.035840392112732, -1.049375057220459, -1.065271258354187, -1.0834522247314453, -1.1038644313812256, -1.1264756917953491, -1.1512737274169922, -1.178264856338501, -1.2074724435806274, -1.238936424255371, -1.2727112770080566, -1.3088665008544922, -1.3474851846694946, -1.3886632919311523, -1.432510256767273, -1.4791477918624878, -1.528710126876831, -1.5813440084457397, -1.6372087001800537, -1.6964759826660156, -1.7593305110931396, -1.8259700536727905, -1.8966057300567627, -1.9714624881744385, -2.050779104232788, -2.1348092555999756, -2.223820924758911, -2.3180975914001465, -2.4179375171661377, -2.5236551761627197, -2.635580062866211, -2.7540571689605713, -2.8794467449188232, -3.0121235847473145, -3.1524760723114014, -3.3009045124053955, -3.457820415496826, -3.623642921447754, -3.798797130584717, -3.983708620071411, -4.178800106048584, -4.384483337402344, -4.601154804229736, -4.829183578491211, -5.068902492523193, -5.32059383392334, -5.584474563598633, -5.8606791496276855, -6.149235248565674, -6.450042247772217, -6.762841701507568, -7.087186336517334, -7.422400951385498, -7.767547607421875, -8.121378898620605, -8.482292175292969, -8.848282814025879, -9.216897010803223, -9.585183143615723, -9.949651718139648, -10.30624771118164, -10.650323867797852, -10.976653099060059, -11.279446601867676, -11.552422523498535, -11.788901329040527, -11.98195743560791, -12.124616622924805, -12.210103034973145, -12.232144355773926, -12.185300827026367, -12.06533432006836, -11.8695650100708, -11.59720516204834, -11.24962329864502, -10.83051586151123, -10.33515739440918, -9.771961212158203, -9.151644706726074, -8.486823081970215, -7.791440486907959, -7.080098628997803, -6.367331504821777, -5.666897296905518, -4.991160869598389, -4.35060977935791, -3.7535431385040283, -3.2059385776519775, -2.7114880084991455, -2.271771192550659, -1.886530876159668, -1.5540040731430054, -1.2712767124176025, -1.0346256494522095, -0.8398289084434509, -0.6824293732643127, -0.5579473972320557, -0.4620424211025238, -0.39062726497650146, -0.3399428427219391, -0.3065996468067169, -0.28759393095970154, -0.28030481934547424, -0.28247833251953125, -0.29220256209373474, -0.3078780472278595, -0.32818537950515747, -0.3520530164241791, -0.37862542271614075, -0.4072335362434387, -0.43736743927001953, -0.46865177154541016, -0.5008238554000854, -0.5337144732475281, -0.5672316551208496, -0.6013461351394653, -0.6360798478126526, -0.6714956164360046, -0.7076893448829651, -0.7447830438613892, -0.7829198837280273, -0.8222596645355225, -0.8629759550094604, -0.905253529548645, -0.9492867588996887, -0.9952786564826965, -1.0434401035308838, -1.0939894914627075, -1.1471531391143799, -1.2031655311584473, -1.2622696161270142, -1.32471764087677, -1.3907718658447266, -1.4607057571411133, -1.534804344177246, -1.6133657693862915, -1.6967018842697144, -1.7851390838623047, -1.8790196180343628, -1.978702187538147, -2.0845625400543213, -2.1969945430755615, -2.3164100646972656, -2.443239688873291, -2.577932119369507, -2.720953941345215, -2.8727900981903076, -3.033939838409424, -3.2049179077148438, -3.386249542236328, -3.578467845916748, -3.782109260559082, -3.997706413269043, -4.2257819175720215, -4.466838836669922, -4.721346378326416, -4.989730358123779, -5.272351264953613, -5.56948709487915, -5.881306171417236, -6.207840919494629, -6.548950672149658, -6.904286861419678, -7.273244857788086, -7.654914379119873, -8.048025131225586, -8.450883865356445, -8.861310005187988, -9.276567459106445, -9.693297386169434, -10.107455253601074, -10.51425552368164, -10.908133506774902, -11.282730102539062, -11.630908966064453, -11.944822311401367, -12.216021537780762, -12.435647964477539, -12.594682693481445, -12.684286117553711, -12.69620418548584, -12.623244285583496, -12.459787368774414, -12.202309608459473, -11.84985637664795, -11.404428482055664, -10.871219635009766, -10.258642196655273, -9.578134536743164, -8.84371280670166, -8.071313858032227, -7.277959823608398, -6.480842113494873, -5.696398735046387, -4.93949556350708, -4.222771167755127, -3.5562069416046143, -2.946934700012207, -2.3992676734924316, -1.914919376373291, -1.4933557510375977, -1.1322228908538818, -0.827799916267395, -0.5754336714744568, -0.36992600560188293, -0.20585863292217255, -0.07784824818372726, 0.01926499418914318, 0.09028881043195724, 0.13960038125514984, 0.1711076945066452, 0.1882409006357193, 0.1939651072025299, 0.19080746173858643, 0.1808929592370987, 0.16598476469516754, 0.147525817155838, 0.12667988240718842, 0.10437042266130447, 0.08131644874811172, 0.05806506425142288, 0.03502039611339569, 0.012468947097659111, -0.009398382157087326, -0.03046746924519539, -0.05068499967455864, -0.0700450912117958, -0.08857820183038712, -0.105973020195961, -0.12236690521240234, -0.13789492845535278, -0.15268780291080475, -0.16687053442001343, -0.18056155741214752, -0.19387224316596985, -0.20690681040287018, -0.2197623997926712, -0.23252935707569122, -0.2452915608882904, -0.2581269145011902, -0.27110782265663147, -0.2843016982078552, -0.29777151346206665, -0.311576247215271, -0.3257714509963989, -0.319174200296402, -0.31326571106910706, -0.3080727756023407, -0.3036099374294281, -0.29988235235214233, -0.29688769578933716, -0.2946183979511261, -0.2930629551410675, -0.2922075688838959, -0.29203709959983826, -0.29253607988357544, -0.2936895191669464, -0.29548344016075134, -0.29790541529655457, -0.3009450137615204, -0.30459389090538025, -0.3088463246822357, -0.3136990964412689, -0.3191518187522888, -0.32520684599876404, -0.33186954259872437, -0.3391481339931488, -0.3470539152622223, -0.35560110211372375, -0.3648070693016052, -0.37469223141670227, -0.38528013229370117, -0.3965975046157837, -0.4086743891239166, -0.4215441346168518, -0.43524351716041565, -0.44981294870376587, -0.4652964174747467, -0.48174184560775757, -0.4992011785507202, -0.5177305936813354, -0.5373906493186951, -0.5582466125488281, -0.5803688168525696, -0.6038328409194946, -0.628719687461853, -0.6551164984703064, -0.6831167340278625, -0.7128204703330994, -0.7443352341651917, -0.7777760028839111, -0.8132661581039429, -0.8509377837181091, -0.8909324407577515, -0.9334017634391785, -0.9785080552101135, -1.0264251232147217, -1.0773391723632812, -1.1314494609832764, -1.188969373703003, -1.2501269578933716, -1.3151665925979614, -1.3843494653701782, -1.4579548835754395, -1.5362814664840698, -1.6196478605270386, -1.7083947658538818, -1.8028854131698608, -1.903506875038147, -2.010671615600586, -2.1248185634613037, -2.246413469314575, -2.375951051712036, -2.5139544010162354, -2.6609768867492676, -2.817601203918457, -2.9844393730163574, -3.162132978439331, -3.3513503074645996, -3.5527842044830322, -3.7671494483947754, -3.9951770305633545, -4.237607955932617, -4.495184421539307, -4.7686381340026855, -5.0586771965026855, -5.365967273712158, -5.691108226776123, -6.034609317779541, -6.396852970123291, -6.778054714202881, -7.17821741104126, -7.597069263458252, -8.034001350402832, -8.487988471984863, -8.957499504089355, -9.440404891967773, -9.933865547180176, -10.434219360351562, -10.936871528625488, -11.43618106842041, -11.925363540649414, -12.396422386169434, -12.840121269226074, -13.246013641357422, -13.602555274963379, -13.887818336486816, -14.08812141418457, -14.18984603881836, -14.18017578125, -14.047981262207031, -13.784784317016602, -13.38575267791748, -12.850604057312012, -12.184296607971191, -11.397383689880371, -10.49383544921875, -9.494876861572266, -8.426061630249023, -7.315754413604736, -6.1933088302612305, -5.0871357917785645, -4.022921085357666, -3.0222065448760986, -2.101468324661255, -1.2717607021331787, -0.5388741493225098, 0.09609301388263702, 0.6358986496925354, 1.0862038135528564, 1.4546284675598145, 1.7499072551727295, 1.9811943769454956, 2.1575355529785156, 2.2875003814697266, 2.378951072692871, 2.43892240524292, 2.4735827445983887, 2.488250255584717, 2.4874465465545654, 2.4749677181243896, 2.453965663909912, 2.4270308017730713, 2.396268844604492, 2.3633744716644287, 2.329695463180542, 2.2962887287139893, 2.2639708518981934, 2.2333600521087646, 2.204911470413208, 2.1789486408233643, 2.1556882858276367, 2.1352624893188477, 2.1177356243133545, 2.1031198501586914, 2.091386556625366, 2.08247709274292, 2.0763096809387207, 2.0727875232696533, 2.0718023777008057, 2.073239803314209, 2.076981782913208, 2.082908868789673, 2.0909035205841064, 2.100849151611328, 2.112632989883423, 2.126145839691162, 2.141282081604004, 2.15794038772583, 2.176023483276367, 2.104461193084717, 2.0384297370910645, 1.9780608415603638, 1.9233976602554321, 1.874411940574646, 1.8310192823410034, 1.7930924892425537, 1.7604726552963257, 1.7329797744750977, 1.7104207277297974, 1.692596197128296, 1.679307222366333, 1.6703593730926514, 1.6655666828155518, 1.6647549867630005, 1.6677637100219727, 1.6744476556777954, 1.684678554534912, 1.6983453035354614, 1.715354561805725, 1.735630750656128, 1.7591161727905273, 1.7857705354690552, 1.815570592880249, 1.8485097885131836, 1.884597897529602, 1.9238601922988892, 1.9663368463516235, 2.012083053588867, 2.0611679553985596, 2.1136741638183594, 2.1696977615356445, 2.2293472290039062, 2.2927439212799072, 2.360020875930786, 2.4313228130340576, 2.506805419921875, 2.5866353511810303, 2.670990228652954, 2.760056495666504, 2.8540308475494385, 2.953118085861206, 3.0575308799743652, 3.1674892902374268, 3.2832183837890625, 3.4049479961395264, 3.5329108238220215, 3.66733980178833, 3.8084664344787598, 3.956517219543457, 4.111711025238037, 4.27425479888916, 4.444338798522949, 4.622129917144775, 4.807768821716309, 5.001358509063721, 5.202957630157471, 5.412572860717773, 5.630144119262695, 5.855535984039307, 6.088521480560303, 6.328768730163574, 6.57582426071167, 6.829094886779785, 7.087830543518066, 7.351102352142334, 7.61778450012207, 7.88653564453125, 8.155777931213379, 8.423684120178223, 8.68816089630127, 8.946843147277832, 9.197093963623047, 9.43600845336914, 9.660435676574707, 9.867005348205566, 10.052179336547852, 10.212310791015625, 10.343722343444824, 10.4428129196167, 10.50616455078125, 10.53067684173584, 10.513704299926758, 10.453203201293945, 10.347870826721191, 10.197266578674316, 10.001921653747559, 9.763400077819824, 9.48432731628418, 9.168364524841309, 7.961520671844482, 6.739767074584961, 5.530052185058594, 4.358353614807129, 3.2478723526000977, 2.2176318168640137, 1.2816184759140015, 0.4484989047050476, -0.27814576029777527, -0.8991896510124207, -1.4190927743911743, -1.8449410200119019, -2.185518980026245, -2.4504969120025635, -2.6497769355773926, -2.79300594329834, -2.8892455101013184, -2.9467735290527344, -2.9729864597320557, -2.9743785858154297, -2.956568479537964, -2.9243569374084473, -2.8818023204803467, -2.8323001861572266, -2.7786645889282227, -2.7232041358947754, -2.6677932739257812, -2.6139354705810547, -2.5628199577331543, -2.515371799468994, -2.4722957611083984, -2.4341139793395996, -2.4011993408203125, -2.3738040924072266, -2.352083444595337, -2.336118221282959, -2.3259317874908447, -2.321505546569824, -2.32279109954834, -2.3297226428985596, -2.342224359512329, -2.360217571258545, -2.3836281299591064, -2.4123897552490234, -2.44644832611084, -2.4857640266418457, -2.5303146839141846, -2.5800955295562744, -2.6351218223571777, -2.6954281330108643, -2.7610690593719482, -2.8321192264556885, -2.9086720943450928, -2.990840196609497, -3.078754186630249, -3.172560930252075, -3.2724239826202393, -3.3785197734832764, -3.4910387992858887, -3.6101808547973633, -3.7361550331115723, -3.869176149368286, -4.009461402893066, -4.157227516174316, -4.312687873840332, -4.476044654846191, -4.647487163543701, -4.827183246612549, -5.015273094177246, -5.211859703063965, -5.417003154754639, -5.630704402923584, -5.852898120880127, -6.083437442779541, -6.32207727432251, -6.568460464477539, -6.822098255157471, -7.0823493003845215, -7.348402500152588, -7.6192522048950195, -7.8936767578125, -8.170218467712402, -8.447161674499512, -8.722515106201172, -8.994001388549805, -9.259040832519531, -9.51476001739502, -9.757996559143066, -9.985321998596191, -10.193078994750977, -10.377434730529785, -10.534459114074707, -10.660211563110352, -10.750859260559082, -10.802809715270996, -10.812856674194336, -10.778339385986328, -10.697300910949707, -10.56864070892334, -10.392247200012207, -10.169099807739258, -9.891590118408203, -9.563017845153809, -9.188002586364746, -8.772396087646484, -8.323111534118652, -7.84788703918457, -7.3549957275390625, -6.852917671203613, -6.350006580352783, -5.8541717529296875, -5.3726019859313965, -4.911544322967529, -4.476153373718262, -4.070417404174805, -3.6971476078033447, -3.358034610748291, -3.053748846054077, -2.784076690673828, -2.5480730533599854, -2.3442206382751465, -2.1705853939056396, -2.0249555110931396, -1.9049670696258545, -1.8082058429718018, -1.732290506362915, -1.674936056137085, -1.6339980363845825, -1.6075037717819214, -1.593668818473816, -1.590904712677002, -1.5978184938430786, -1.6132062673568726, -1.6360435485839844, -1.6654722690582275, -1.7007869482040405, -1.7414199113845825, -1.7869271039962769, -1.8369734287261963, -1.8913204669952393, -1.949813723564148, -2.0123720169067383, -2.078977346420288, -2.1496663093566895, -2.224522590637207, -2.3036701679229736, -2.387267827987671, -2.47550368309021, -2.568591833114624, -2.666767120361328, -2.7702841758728027, -2.8794124126434326, -2.994433879852295, -3.1156418323516846, -3.2433364391326904, -3.377823829650879, -3.519412040710449, -3.668408155441284, -3.8251149654388428, -3.9898266792297363, -4.1628241539001465, -4.344368934631348, -4.534697532653809, -4.734012126922607, -4.942473411560059, -5.160189151763916, -5.387202262878418, -5.623477458953857, -5.8688859939575195, -6.123188018798828, -6.386013507843018, -6.6568403244018555, -6.934971809387207, -7.219511985778809, -7.509339332580566, -7.803079128265381, -8.099080085754395, -8.3953857421875, -8.689713478088379, -8.979440689086914, -9.261585235595703, -9.532814979553223, -9.789449691772461, -10.027494430541992, -10.242680549621582, -10.430537223815918, -10.586479187011719, -10.705925941467285, -10.784442901611328, -10.817911148071289, -10.802703857421875, -10.73588752746582, -10.6154146194458, -10.44030475616455, -10.210801124572754, -9.928478240966797, -9.596294403076172, -9.218576431274414, -8.800924301147461, -8.3500394821167, -7.873487949371338, -7.379403591156006, -6.876163482666016, -6.372048854827881, -5.874924182891846, -5.3919572830200195, -4.921044826507568, -4.4680304527282715, -4.0377349853515625, -3.6339032649993896, -3.2592031955718994, -2.915281295776367, -2.602855920791626, -2.321837902069092, -2.071467161178589, -1.8504531383514404, -1.657110571861267, -1.4894843101501465, -1.345458984375, -1.2228509187698364, -1.1194825172424316, -1.033239483833313, -0.9621127247810364, -0.9042273759841919, -0.85785973072052, -0.8214462995529175, -0.793584942817688, -0.7730317115783691, -0.7586933374404907, -0.7496175169944763, -0.7449817657470703, -0.744081437587738, -0.7463177442550659, -0.7511857748031616, -0.758263349533081, -0.7672004103660583, -0.7777094841003418, -0.7895566821098328, -0.8025539517402649, -0.8165519833564758, -0.8314341306686401, -0.84711092710495, -0.8635155558586121, -0.8805996179580688, -0.8983297944068909, -0.9166850447654724, -0.9356538653373718, -0.9552324414253235, -0.9754228591918945, -0.9962313771247864, -1.0176677703857422, -1.0397437810897827, -1.0624728202819824, -1.0858688354492188, -1.1099460124969482, -1.134718418121338, -1.160199522972107, -1.1864017248153687, -1.21333646774292, -1.2410138845443726, -1.2694425582885742, -1.2986294031143188, -1.3285796642303467, -1.3592965602874756, -1.3907815217971802, -1.423033595085144, -1.456049919128418, -1.4898251295089722, -1.5243514776229858, -1.5596188306808472, -1.5956141948699951, -1.6323219537734985, -1.6697237491607666, -1.7077980041503906, -1.7465202808380127, -1.7858625650405884, -1.825793981552124, -1.8662797212600708, -1.907281517982483, -1.948757529258728, -1.990661859512329, -2.032944679260254, -2.075552463531494, -2.118427038192749, -2.161506175994873, -2.204723596572876, -2.2480080127716064, -2.2578611373901367, -2.2710487842559814, -2.287548065185547, -2.30733585357666, -2.330390453338623, -2.3566946983337402, -2.3862357139587402, -2.419006586074829, -2.4550065994262695, -2.4942429065704346, -2.536729574203491, -2.5824875831604004, -2.6315464973449707, -2.6839425563812256, -2.7397193908691406, -2.7989275455474854, -2.861624240875244, -2.927872657775879, -2.997741460800171, -3.0713043212890625, -3.148638963699341, -3.2298269271850586, -3.3149518966674805, -3.404099464416504, -3.4973552227020264, -3.594804286956787, -3.696528911590576, -3.802608013153076, -3.913114547729492, -4.028113842010498, -4.147661209106445, -4.271799087524414, -4.400555610656738, -4.533940315246582, -4.671939849853516, -4.814517498016357, -4.961604595184326, -5.113100528717041, -5.268864631652832, -5.428712844848633, -5.592411518096924, -5.759672164916992, -5.930144786834717, -6.103412628173828, -6.278985500335693, -6.456294059753418, -6.634683609008789, -6.813411235809326, -6.991638660430908, -7.168429374694824, -7.34274959564209, -7.513465404510498, -7.679347515106201, -7.83907413482666, -7.991241931915283, -8.13437557220459, -8.266945838928223, -8.387388229370117, -8.494128227233887, -8.585610389709473, -8.660331726074219, -8.716879844665527, -8.753969192504883, -8.770487785339355, -8.765534400939941, -8.738462448120117, -8.688915252685547, -8.616859436035156, -8.52260971069336, -8.406843185424805, -8.270601272583008, -8.115286827087402, -7.942640781402588, -7.754706382751465, -7.553788661956787, -7.342398166656494, -7.123188018798828, -6.898887634277344, -6.67223596572876, -6.445913314819336, -6.222480773925781, -6.004326820373535, -5.7936224937438965, -5.592287540435791, -5.401970863342285, -5.22403621673584, -5.059566497802734, -4.909370422363281, -4.774001121520996, -4.653778553009033, -4.548819065093994, -4.459062576293945, -4.384305000305176, -4.3242292404174805, -4.278431415557861, -4.246449947357178, -4.227787971496582, -4.221933841705322, -4.2283782958984375, -4.246629238128662, -4.276222229003906, -4.311829090118408, -4.353235721588135, -4.400242328643799, -4.447921276092529, -4.496213912963867, -4.545047283172607, -4.594333171844482, -4.6439690589904785, -4.693838119506836, -4.743810176849365, -4.7937421798706055, -4.843476295471191, -4.892843246459961, -4.941661834716797, -4.989738464355469, -5.036870002746582, -5.082841873168945, -5.127432823181152, -5.170412063598633, -5.211544513702393, -5.250588893890381, -5.287302017211914, -5.321439743041992, -5.352757930755615, -5.381016254425049, -5.405979633331299, -5.427420616149902, -5.445122241973877, -5.458880424499512, -5.468505859375, -5.473827362060547, -5.47469425201416, -5.470978260040283, -5.4625749588012695, -5.449408531188965, -5.431429386138916, -5.408619403839111, -5.3809895515441895, -5.348584175109863, -5.3114776611328125, -5.269775867462158, -5.223616123199463, -5.1731648445129395, -5.118617057800293, -5.060193061828613, -4.998137474060059, -4.932714939117432, -4.8642096519470215, -4.792919635772705, -4.719153881072998, -4.643230438232422, -4.5654706954956055, -4.4861979484558105, -4.405731678009033, -4.324388027191162, -4.242472171783447, -4.160279273986816, -4.078090667724609, -3.9961719512939453, -3.914771556854248, -3.834118604660034, -3.754422903060913, -3.6758735179901123, -3.598639488220215, -3.5228683948516846, -3.4486873149871826, -3.376204252243042, -3.305506944656372, -3.2366652488708496, -3.169731855392456, -3.104743003845215, -3.041719913482666, -2.868492364883423, -2.707786798477173, -2.559706926345825, -2.424180507659912, -2.3009870052337646, -2.1897835731506348, -2.0901291370391846, -2.001509666442871, -1.9233591556549072, -1.8550792932510376, -1.7960561513900757, -1.7456752061843872, -1.703332781791687, -1.6684463024139404, -1.6404613256454468, -1.6188572645187378, -1.603151559829712, -1.5929017066955566, -1.5877071619033813, -1.5872089862823486, -1.5910899639129639, -1.5990731716156006, -1.6109204292297363, -1.6264307498931885, -1.6454381942749023, -1.6678098440170288, -1.6934435367584229, -1.7222659587860107, -1.7542306184768677, -1.7893155813217163, -1.8275223970413208, -1.8688737154006958, -1.91341233253479, -1.9611998796463013, -2.012315273284912, -2.0668537616729736, -2.1249265670776367, -2.186659574508667, -2.252192497253418, -2.32167911529541, -2.395285129547119, -2.4731898307800293, -2.555584192276001, -2.642670154571533, -2.734661102294922, -2.8317811489105225, -2.9342637062072754, -3.042351722717285, -3.1562957763671875, -3.276353359222412, -3.4027884006500244, -3.53586745262146, -3.6758596897125244, -3.823033332824707, -3.9776527881622314, -4.139975070953369, -4.310245513916016, -4.488692283630371, -4.675520896911621, -4.870906352996826, -5.074986457824707, -5.287849426269531, -5.509527206420898, -5.739977836608887, -5.979075908660889, -6.226593971252441, -6.482186794281006, -6.7453694343566895, -7.015500068664551, -7.291753768920898, -7.573101997375488, -7.858286380767822, -8.145797729492188, -8.433849334716797, -8.720362663269043, -9.00294303894043, -9.278879165649414, -9.545133590698242, -9.798355102539062, -10.034900665283203, -10.250874519348145, -10.442187309265137, -10.604631423950195, -10.733985900878906, -10.826139450073242, -10.877236366271973, -10.883837699890137, -10.843093872070312, -10.752923011779785, -10.612177848815918, -10.42078971862793, -10.17988109588623, -9.891828536987305, -9.560264587402344, -9.190018653869629, -8.786982536315918, -8.357921600341797, -7.910218238830566, -7.451596736907959, -6.989813804626465, -6.53236722946167, -6.077280521392822, -5.6313371658325195, -5.200559616088867, -4.790063858032227, -4.403973579406738, -4.0453925132751465, -3.7164244651794434, -3.418243885040283, -3.151193380355835, -2.9149057865142822, -2.70843505859375, -2.530388832092285, -2.3790535926818848, -2.2525084018707275, -2.1487228870391846, -2.0656394958496094, -2.001237630844116, -1.953585147857666, -1.9208719730377197, -1.9014348983764648, -1.893770456314087, -1.8965413570404053, -1.908575177192688, -1.928860068321228, -1.9565356969833374, -1.990883708000183, -2.031315565109253, -2.0773613452911377, -2.1286563873291016, -2.184931516647339, -2.2460005283355713, -2.311750650405884, -2.3821332454681396, -2.4571549892425537, -2.5368707180023193, -2.6213767528533936, -2.7108044624328613, -2.8053152561187744, -2.9050960540771484, -3.010354518890381, -3.1213157176971436, -3.238218069076538, -3.36130952835083, -3.4908456802368164, -3.6270840167999268, -3.770282030105591, -3.920691967010498, -4.07855749130249, -4.244107723236084, -4.4175519943237305, -4.59907341003418, -4.788821220397949, -4.986903667449951, -5.193376541137695, -5.408233642578125, -5.631393909454346, -5.862687587738037, -6.101842403411865, -6.348465442657471, -6.602024555206299, -6.861830234527588, -7.12701416015625, -7.396507263183594, -7.6690192222595215, -7.943017959594727, -8.216708183288574, -8.488018035888672, -8.754583358764648, -9.013744354248047, -9.262547492980957], "z": [10.0, 9.633333206176758, 9.386394500732422, 9.242918014526367, 9.186662673950195, 9.202041625976562, 9.27444076538086, 9.390336990356445, 9.537337303161621, 9.704184532165527, 9.880752563476562, 10.058052062988281, 10.228242874145508, 10.384649276733398, 10.521770477294922, 10.635278701782227, 10.721994400024414, 10.779839515686035, 10.807765007019043, 10.805652618408203, 10.774194717407227, 10.714761734008789, 10.62926197052002, 10.519996643066406, 10.38952922821045, 10.240555763244629, 10.075801849365234, 9.897931098937988, 9.709478378295898, 9.512795448303223, 9.310019493103027, 9.103057861328125, 8.893577575683594, 8.683015823364258, 8.472585678100586, 8.263300895690918, 8.055986404418945, 7.8513078689575195, 7.649787902832031, 7.4518280029296875, 7.257726669311523, 7.067698001861572, 6.881886005401611, 6.700377941131592, 6.523214817047119, 6.350402355194092, 6.181918621063232, 6.017719268798828, 5.8577446937561035, 5.701923370361328, 5.550174236297607, 5.402411937713623, 5.258546352386475, 5.118484973907471, 4.982136249542236, 4.8494062423706055, 4.720202922821045, 4.594435691833496, 4.472014427185059, 4.352851867675781, 4.236861705780029, 4.123960494995117, 4.014066219329834, 3.9070987701416016, 3.802980661392212, 3.7016360759735107, 3.6029913425445557, 3.506974697113037, 3.413516044616699, 3.322547674179077, 3.2340033054351807, 3.1478183269500732, 3.063930034637451, 2.9822776317596436, 2.902801275253296, 2.8254435062408447, 2.750147819519043, 2.6768593788146973, 2.605525016784668, 2.536092519760132, 2.4685113430023193, 2.4027326107025146, 2.33870792388916, 2.27639102935791, 2.2157363891601562, 2.1566996574401855, 2.0992379188537598, 2.043309450149536, 1.9888733625411987, 1.9358899593353271, 1.8843207359313965, 1.8341280221939087, 1.7852754592895508, 1.737727403640747, 1.6914492845535278, 1.6464074850082397, 1.602569341659546, 1.5599029064178467, 1.5183770656585693, 1.4779620170593262, 1.4386281967163086, 1.400347113609314, 1.3630911111831665, 1.3268332481384277, 1.2915472984313965, 1.2572078704833984, 1.223790168762207, 1.1912702322006226, 1.1596245765686035, 1.1288305521011353, 1.09886634349823, 1.0697104930877686, 1.0413423776626587, 1.0137418508529663, 0.9868895411491394, 0.9607666730880737, 0.9353550672531128, 0.9106371402740479, 0.8865960240364075, 0.8632153868675232, 0.8404794931411743, 0.8183733224868774, 0.7968823909759521, 0.7759929895401001, 0.7556918859481812, 0.7359667420387268, 0.7168057560920715, 0.6981979012489319, 0.6801329255104065, 0.6626012921333313, 0.6455944180488586, 0.629104495048523, 0.6131247878074646, 0.5976493954658508, 0.5826737284660339, 0.5681941509246826, 0.554208517074585, 0.5407159328460693, 0.5277171730995178, 0.5152145624160767, 0.5032125115394592, 0.4917173683643341, 0.4807378947734833, 0.47028541564941406, 0.4603741765022278, 0.4510217308998108, 0.4422492980957031, 0.4340822696685791, 0.4265507459640503, 0.4196900725364685, 0.413541704416275, 0.4081538915634155, 0.4035826325416565, 0.39989277720451355, 0.3971591889858246, 0.39546826481819153, 0.39491933584213257, 0.3956267535686493, 0.3977218270301819, 0.4013552963733673, 0.4067001938819885, 0.41395488381385803, 0.4233468472957611, 0.4351368248462677, 0.44962358474731445, 0.4671494662761688, 0.48810654878616333, 0.5129439234733582, 0.5421757102012634, 0.5763903856277466, 0.6162614226341248, 0.6625589728355408, 0.7161632776260376, 0.7780799269676208, 0.8494565486907959, 0.9316015839576721, 1.026004672050476, 1.134359359741211, 1.25858736038208, 1.4008638858795166, 1.5636451244354248, 1.749694585800171, 1.9621096849441528, 2.204345703125, 2.4802348613739014, 2.7939980030059814, 3.150244951248169, 3.5539591312408447, 4.010456562042236, 4.525319576263428, 5.103882312774658, 5.751290798187256, 6.472250938415527, 7.270702362060547, 8.149422645568848, 9.109554290771484, 10.150078773498535, 11.267242431640625, 12.453990936279297, 13.699466705322266, 14.98863410949707, 16.302143096923828, 17.61650276184082, 18.90468978881836, 20.137178421020508, 21.283472061157227, 22.31396484375, 23.202045440673828, 23.926145553588867, 24.471487045288086, 24.83124542236328, 25.00693702697754, 25.007980346679688, 24.85049057006836, 24.447050094604492, 23.845436096191406, 23.101797103881836, 22.27326011657715, 21.41190528869629, 20.560802459716797, 19.75218963623047, 19.007434844970703, 18.33819580078125, 17.74823570251465, 17.23539924621582, 16.79347801208496, 16.413793563842773, 16.086444854736328, 15.80125904083252, 15.548439979553223, 15.319019317626953, 15.10511589050293, 14.900068283081055, 14.698471069335938, 14.496137619018555, 14.290006637573242, 14.078025817871094, 13.859007835388184, 13.632481575012207, 13.398544311523438, 13.157721519470215, 12.910845756530762, 12.658940315246582, 12.4031343460083, 12.144586563110352, 11.88443374633789, 11.623746871948242, 11.363509178161621, 11.104598999023438, 10.847782135009766, 10.593717575073242, 10.34295654296875, 10.095954895019531, 9.853079795837402, 9.614623069763184, 9.38080883026123, 9.151805877685547, 8.927734375, 8.708678245544434, 8.494686126708984, 8.285785675048828, 8.08198070526123, 7.8832621574401855, 7.689608097076416, 7.500988960266113, 7.317368984222412, 7.138708114624023, 6.964966297149658, 6.7961015701293945, 6.63207483291626, 6.472849369049072, 6.3183913230896, 6.16867208480835, 6.023670196533203, 5.883369445800781, 5.747763156890869, 5.616852760314941, 5.490652084350586, 5.369184494018555, 5.252487659454346, 5.140614986419678, 5.03363561630249, 4.931637287139893, 4.834728717803955, 4.743041515350342, 4.656733512878418, 4.575991630554199, 4.501034736633301, 4.432117462158203, 4.369535446166992, 4.313628673553467, 4.264787197113037, 4.223456859588623, 4.1901469230651855, 4.16543436050415, 4.1499738693237305, 4.144505023956299, 4.149862766265869, 4.166985034942627, 4.196924686431885, 4.2408599853515625, 4.30010461807251, 4.376121520996094, 4.4705305099487305, 4.585119724273682, 4.721855163574219, 4.882884979248047, 5.07054328918457, 5.287347316741943, 5.5359883308410645, 5.819314479827881, 6.14030122756958, 6.502006530761719, 6.907512664794922, 7.359842777252197, 7.861410140991211, 8.414163589477539, 9.019405364990234, 9.677579879760742, 10.388045310974121, 11.148825645446777, 11.956376075744629, 12.805355072021484, 13.688455581665039, 14.596298217773438, 15.517441749572754, 16.438518524169922, 17.344539642333984, 18.219356536865234, 19.046306610107422, 19.808977127075195, 20.4920597076416, 21.082212448120117, 21.568851470947266, 21.944761276245117, 22.206478118896484, 22.354393005371094, 22.39253807067871, 22.32813835144043, 22.17093276977539, 21.932401657104492, 21.624954223632812, 21.261184692382812, 20.853225708007812, 20.41227912902832, 19.948291778564453, 19.46979522705078, 18.983863830566406, 18.496177673339844, 18.011154174804688, 17.532102584838867, 17.061410903930664, 16.60071563720703, 16.151058197021484, 15.713032722473145, 15.286897659301758, 14.872671127319336, 14.470210075378418, 14.079261779785156, 13.69951057434082, 13.330605506896973, 12.972182273864746, 12.623878479003906, 12.28533935546875, 11.956225395202637, 11.636214256286621, 11.32500171661377, 11.022299766540527, 10.727837562561035, 10.44135856628418, 10.162620544433594, 9.89139461517334, 9.627461433410645, 9.370612144470215, 9.120646476745605, 8.877372741699219, 8.640604972839355, 8.410164833068848, 8.185880661010742, 7.967584609985352, 7.755115032196045, 7.54831600189209, 7.347034454345703, 7.151122570037842, 6.960436820983887, 6.774837017059326, 6.594188213348389, 6.418358325958252, 6.247217655181885, 6.080642223358154, 5.9185099601745605, 5.760702610015869, 5.607104778289795, 5.457604885101318, 5.312093257904053, 5.170464038848877, 5.032614231109619, 4.89844274520874, 4.767852306365967, 4.640747547149658, 4.517035961151123, 4.396626949310303, 4.279433727264404, 4.165370464324951, 4.054354190826416, 3.9463047981262207, 3.8411431312561035, 3.73879337310791, 3.639181137084961, 3.542234182357788, 3.447882652282715, 3.356058120727539, 3.2666945457458496, 3.179727554321289, 3.0950944423675537, 3.0127344131469727, 2.932588815689087, 2.854600191116333, 2.7787132263183594, 2.7048628330230713, 2.6329939365386963, 2.563053846359253, 2.494990825653076, 2.428755283355713, 2.3642985820770264, 2.3015737533569336, 2.240535259246826, 2.1811389923095703, 2.1233417987823486, 2.0671021938323975, 2.0123798847198486, 1.9591355323791504, 1.9073313474655151, 1.8569303750991821, 1.8078972101211548, 1.7601971626281738, 1.7137969732284546, 1.6686643362045288, 1.6247680187225342, 1.582077980041504, 1.5405652523040771, 1.500201940536499, 1.4609612226486206, 1.422817349433899, 1.385745882987976, 1.349723219871521, 1.3147271871566772, 1.2807364463806152, 1.247731328010559, 1.2156929969787598, 1.184604287147522, 1.1544491052627563, 1.1252130270004272, 1.096882939338684, 1.06944739818573, 1.0428967475891113, 1.0172232389450073, 0.9924208521842957, 0.9684858918190002, 0.9454169273376465, 0.9232151508331299, 0.9018843173980713, 0.8814314603805542, 0.8618668913841248, 0.8432045578956604, 0.8254625797271729, 0.8086637854576111, 0.7928358316421509, 0.7780122756958008, 0.7642330527305603, 0.7515450716018677, 0.7400033473968506, 0.7296720147132874, 0.7206251621246338, 0.7129483819007874, 0.706740140914917, 0.7021135091781616, 0.6991978287696838, 0.6981412768363953, 0.6991127729415894, 0.702305257320404, 0.7079384922981262, 0.7162626385688782, 0.7275625467300415, 0.7421621084213257, 0.7604293823242188, 0.7827826142311096, 0.8096965551376343, 0.8417100310325623, 0.8794340491294861, 0.9235610365867615, 0.9748752117156982, 1.0342637300491333, 1.102729082107544, 1.1814032793045044, 1.271561861038208, 1.3746397495269775, 1.4922486543655396, 1.6261932849884033, 1.778489351272583, 1.9513802528381348, 2.147352695465088, 2.3691492080688477, 2.6197783946990967, 2.9025161266326904, 3.220900058746338, 3.5787124633789062, 3.9799439907073975, 4.428741455078125, 4.929324150085449, 5.485874652862549, 6.102384090423584, 6.7824602127075195, 7.529083251953125, 8.344313621520996, 9.228950500488281, 10.182148933410645, 11.201011657714844, 12.28018569946289, 13.411492347717285, 14.582544326782227, 15.777406692504883, 16.976709365844727, 18.15807342529297, 19.29688262939453, 20.367401123046875, 21.344196319580078, 22.203765869140625, 22.926164627075195, 23.49649429321289, 23.905990600585938, 24.152591705322266, 24.24087142944336, 24.181373596191406, 23.989431381225586, 23.683673858642578, 23.28443145751953, 22.812232971191406, 22.28656005859375, 21.724946975708008, 21.142423629760742, 20.551300048828125, 19.96121597290039, 19.379352569580078, 18.810773849487305, 18.258787155151367, 17.725330352783203, 17.2112979888916, 16.716835021972656, 16.2415771484375, 15.784836769104004, 15.345739364624023, 14.923327445983887, 14.516627311706543, 14.124700546264648, 13.746663093566895, 13.381706237792969, 13.029098510742188, 12.688186645507812, 12.358393669128418, 12.039207458496094, 11.730180740356445, 11.430919647216797, 11.141081809997559, 10.860363960266113, 10.588504791259766, 10.325275421142578, 10.070476531982422, 9.82394027709961, 9.58552074432373, 9.355100631713867, 9.132583618164062, 8.917898178100586, 8.710996627807617, 8.511855125427246, 8.320472717285156, 8.136877059936523, 7.961122512817383, 7.793291091918945, 7.633497714996338, 7.48189115524292, 7.3386549949646, 7.204014301300049, 7.078235626220703, 6.961633682250977, 6.8545732498168945, 6.757473945617676, 6.670816421508789, 6.595146656036377, 6.531079292297363, 6.479306697845459, 6.440601825714111, 6.415823936462402, 6.4059247970581055, 6.411952495574951, 6.435056209564209, 6.476487159729004, 6.537601947784424, 6.619859218597412, 6.72481632232666, 6.854121208190918, 7.009498596191406, 7.192732810974121, 7.405639171600342, 7.650031089782715, 7.927675247192383, 8.240233421325684, 8.589198112487793, 8.975807189941406, 9.40095043182373, 9.86506462097168, 10.368008613586426, 10.908944129943848, 11.486201286315918, 12.097158432006836, 12.738128662109375, 13.404279708862305, 14.089580535888672, 14.786811828613281, 15.487629890441895, 16.18271255493164, 16.861984252929688, 17.51491355895996, 18.130884170532227, 18.699621200561523, 19.211633682250977, 19.65865135192871, 20.034011840820312, 20.33296012878418, 20.55284309387207, 20.693172454833984, 20.755544662475586, 20.743444442749023, 20.661945343017578, 20.517343521118164, 20.316757202148438, 20.067733764648438, 19.777896881103516, 19.454635620117188, 19.104875564575195, 18.73451805114746, 18.348861694335938, 17.95256233215332, 17.54962158203125, 17.143409729003906, 16.736719131469727, 16.331806182861328, 15.930471420288086, 15.53411865234375, 15.143818855285645, 14.760367393493652, 14.384334564208984, 14.01611614227295, 13.655963897705078, 13.304019927978516, 12.960344314575195, 12.624933242797852, 12.297734260559082, 11.978662490844727, 11.667604446411133, 11.364433288574219, 11.069007873535156, 10.781180381774902, 10.500798225402832, 10.227705001831055, 9.961746215820312, 9.702765464782715, 9.45060920715332, 9.205124855041504, 8.966163635253906, 8.7335786819458, 8.507225036621094, 8.286962509155273, 8.072652816772461, 7.864161014556885, 7.661357402801514, 7.464113235473633, 7.272304058074951, 7.085809707641602, 6.904512882232666, 6.728298664093018, 6.557057857513428, 6.390683174133301, 6.229071617126465, 6.0721235275268555, 5.919742584228516, 5.771836757659912, 5.628316402435303, 5.489096641540527, 5.354095458984375, 5.223234176635742, 5.096438407897949, 4.973637104034424, 4.854762077331543, 4.73923397064209, 4.626937389373779, 4.5177717208862305, 4.411647796630859, 4.3084869384765625, 4.208218574523926, 4.110780715942383, 4.016116619110107, 3.9241764545440674, 3.8349153995513916, 3.748293161392212, 3.664273977279663, 3.582826852798462, 3.5039238929748535, 3.4275424480438232, 3.3536629676818848, 3.282271146774292, 3.213355779647827, 3.146911144256592, 3.0829358100891113, 3.0214335918426514, 2.9624133110046387, 2.9058899879455566, 2.851884603500366, 2.800424814224243, 2.7515456676483154, 2.7052900791168213, 2.6617090702056885, 2.620863437652588, 2.5828239917755127, 2.5476725101470947, 2.515502691268921, 2.486421823501587, 2.4605510234832764, 2.4380276203155518, 2.419006109237671, 2.4036595821380615, 2.392181873321533, 2.384789228439331, 2.3817226886749268, 2.3832499980926514, 2.3896679878234863, 2.401305913925171, 2.418527126312256, 2.441732883453369, 2.471365213394165, 2.5079102516174316, 2.55190110206604, 2.603921890258789, 2.664611577987671, 2.7298264503479004, 2.799252510070801, 2.8726344108581543, 2.9497649669647217, 3.030478000640869, 3.1146421432495117, 3.202155113220215, 3.292938470840454, 3.386934757232666, 3.484102249145508, 3.5844130516052246, 3.687849760055542, 3.794402837753296, 3.9040679931640625, 4.016845226287842, 4.132735729217529, 4.251739025115967, 4.373854637145996, 4.4990763664245605, 4.6273932456970215, 4.758786678314209, 4.893230438232422, 5.03068733215332, 5.171109676361084, 5.3144354820251465, 5.460590362548828, 5.609485149383545, 5.761012554168701, 5.915050983428955, 6.07145881652832, 6.230078220367432, 6.3907318115234375, 6.553222179412842, 6.7173357009887695, 6.882837295532227, 7.049476146697998, 7.216982364654541, 7.385071277618408, 7.553442001342773, 7.721780776977539, 7.8897624015808105, 8.057051658630371, 8.223307609558105, 8.388184547424316, 8.551334381103516, 8.712409973144531, 8.871070861816406, 9.026981353759766, 9.17982006072998, 9.329275131225586, 9.475055694580078, 9.616887092590332, 9.754520416259766, 9.88772964477539, 10.016317367553711, 10.14011287689209, 10.258978843688965, 10.372809410095215, 10.481529235839844, 10.585098266601562, 10.683509826660156, 10.776787757873535, 10.864991188049316, 10.94820785522461, 11.026556968688965, 11.100187301635742, 11.169272422790527, 11.234013557434082, 11.294632911682129, 11.3513765335083, 11.40450668334961, 11.454305648803711, 11.501069068908691, 11.545106887817383, 11.586739540100098, 11.626296997070312, 11.664118766784668, 11.70054817199707, 11.735933303833008, 11.770627975463867, 11.804986000061035, 11.839362144470215, 11.874112129211426, 11.909590721130371, 11.946147918701172, 11.98413372039795, 12.023893356323242, 12.065767288208008, 12.110091209411621, 12.157194137573242, 12.207396507263184, 12.261012077331543, 12.318346977233887, 12.379693031311035, 12.445332527160645, 12.515535354614258, 12.590555191040039, 12.67063045501709, 12.755980491638184, 12.84680461883545, 12.943281173706055, 13.045150756835938, 13.152084350585938, 13.263675689697266, 13.379448890686035, 13.498858451843262, 13.621294975280762, 13.746084213256836, 13.872498512268066, 13.999760627746582, 14.127050399780273, 14.253515243530273, 14.378279685974121, 14.50045394897461, 14.619150161743164, 14.73348617553711, 14.842605590820312, 14.945687294006348, 15.041952133178711, 15.130681991577148, 15.211224555969238, 15.283002853393555, 15.345524787902832, 15.39838695526123, 15.441279411315918, 15.473989486694336, 15.496397972106934, 15.50848388671875, 15.51031494140625, 15.50204849243164, 15.48392391204834, 15.456252098083496, 15.419414520263672, 15.37385082244873, 15.320049285888672, 15.25854206085205, 15.18989372253418, 15.11469554901123, 15.033555030822754, 14.94709300994873, 14.85593318939209, 14.760699272155762, 14.662009239196777, 14.560473442077637, 14.456686973571777, 14.351232528686523, 14.244672775268555, 14.137554168701172, 14.030401229858398, 13.923722267150879, 13.818001747131348, 13.713706016540527, 13.611281394958496, 13.511154174804688, 13.413735389709473, 13.319415092468262, 13.228567123413086, 13.14155101776123, 13.058707237243652, 12.980364799499512, 12.90683650970459, 12.838420867919922, 12.775403022766113, 12.71805477142334, 12.666632652282715, 12.621380805969238, 12.582527160644531, 12.550284385681152, 12.524847984313965, 12.50639820098877, 12.495092391967773, 12.491069793701172, 12.49444580078125, 12.505311012268066, 12.523727416992188, 12.549729347229004, 12.5833158493042, 12.624452590942383, 12.673066139221191, 12.729040145874023, 12.792217254638672, 12.86238956451416, 12.939302444458008, 13.022647857666016, 13.112066268920898, 13.207141876220703, 13.307403564453125, 13.412324905395508, 13.521327018737793, 13.633776664733887, 13.748991012573242, 13.866243362426758, 13.984766006469727, 14.103755950927734, 14.22238540649414, 14.339804649353027, 14.455156326293945, 14.567583084106445, 14.676238059997559, 14.780293464660645, 14.87895393371582, 14.971468925476074, 15.057135581970215, 15.13531494140625, 15.205436706542969, 15.267007827758789, 15.31961727142334, 15.36293888092041, 15.396737098693848, 15.420866012573242, 15.435267448425293, 15.439970016479492, 15.435088157653809, 15.42081069946289, 15.397401809692383, 15.365190505981445, 15.324563026428223, 15.275958061218262, 15.219857215881348, 15.15677547454834, 15.087258338928223, 15.011869430541992, 14.93118953704834, 14.845804214477539, 14.756304740905762, 14.663278579711914, 14.567307472229004, 14.468962669372559, 14.368805885314941, 14.267382621765137, 14.165221214294434, 14.062835693359375, 13.960719108581543, 13.859349250793457, 13.75918197631836, 13.66065788269043, 13.564197540283203, 13.47020435333252, 13.379064559936523, 13.29114818572998, 13.206809997558594, 13.126387596130371, 13.05020523071289, 12.978570938110352, 12.911781311035156, 12.850115776062012, 12.793840408325195, 12.743209838867188, 12.698461532592773, 12.659817695617676, 12.627486228942871, 12.60165786743164, 12.58250617980957, 12.570185661315918, 12.564828872680664, 12.566546440124512, 12.57542610168457, 12.591526985168457, 12.61488151550293, 12.645488739013672, 12.683314323425293, 12.728289604187012, 12.780303001403809, 12.839204788208008, 12.904799461364746, 12.976844787597656, 13.05505084991455, 13.139078140258789, 13.228536605834961, 13.322983741760254, 13.42192554473877, 13.524818420410156, 13.631070137023926, 13.740041732788086, 13.851054191589355, 13.963386535644531, 14.07629108428955, 14.18898868560791, 14.300687789916992, 14.410581588745117, 14.517867088317871, 14.621745109558105, 14.721437454223633, 14.816192626953125, 14.905296325683594, 14.988080978393555, 15.063932418823242, 15.132302284240723, 15.192708015441895, 15.244745254516602, 15.288086891174316, 15.322486877441406, 15.347784042358398, 15.363899230957031, 15.370832443237305, 15.36866569519043, 15.357551574707031, 15.337715148925781, 15.309441566467285, 15.273075103759766, 15.229009628295898, 15.177682876586914, 15.11956787109375, 15.05516529083252, 14.985001564025879, 14.90961742401123, 14.829564094543457, 14.745399475097656, 14.623223304748535, 14.463884353637695, 14.269842147827148, 14.044723510742188, 13.792901992797852, 13.519125938415527, 13.228192329406738, 12.92470645904541, 12.612897872924805, 12.2965087890625, 11.978742599487305, 11.66224479675293, 11.34913444519043, 11.041044235229492, 10.739182472229004, 10.444395065307617, 10.157230377197266, 9.877997398376465, 9.60682201385498, 9.343692779541016, 9.088496208190918, 8.84105110168457, 8.6011323928833, 8.368488311767578, 8.142858505249023, 7.923975944519043, 7.711583137512207, 7.505430221557617, 7.30527925491333, 7.110906600952148, 6.922101974487305, 6.738667964935303, 6.560421466827393, 6.387190341949463, 6.218814373016357, 6.055142879486084, 5.896035671234131, 5.741359710693359, 5.5909905433654785, 5.444810390472412, 5.302708148956299, 5.164579391479492, 5.030323505401611, 4.899847507476807, 4.773062229156494, 4.64988374710083, 4.530232906341553, 4.414035797119141, 4.301223278045654, 4.191730499267578, 4.085498809814453, 3.982473134994507, 3.8826050758361816, 3.78585147857666, 3.6921751499176025, 3.6015448570251465, 3.51393723487854, 3.429335117340088, 3.3477299213409424, 3.2691214084625244, 3.193519353866577, 3.120943307876587, 3.051424980163574, 2.9850077629089355, 2.921750545501709, 2.861726760864258, 2.805027723312378, 2.7517647743225098, 2.7020702362060547, 2.656102180480957, 2.6140453815460205, 2.576115846633911, 2.542564868927002, 2.5136826038360596, 2.4898035526275635, 2.4713127613067627, 2.4586503505706787, 2.4523203372955322, 2.4528980255126953, 2.46103835105896, 2.4774858951568604, 2.5030860900878906, 2.538796901702881, 2.5857014656066895, 2.6450228691101074, 2.7181384563446045, 2.80659556388855, 2.9121286869049072, 3.036674737930298, 3.1823902130126953, 3.3516645431518555, 3.547133684158325, 3.7716867923736572, 4.028470039367676, 4.32088041305542, 4.652546405792236, 5.027299404144287, 5.449118614196777, 5.922054767608643, 6.4501261711120605, 7.037173271179199, 7.686159610748291, 8.39925479888916, 9.177534103393555, 10.020636558532715, 10.926399230957031, 11.890491485595703, 12.813940048217773, 13.669175148010254, 14.431827545166016, 15.081947326660156, 15.605043411254883, 15.99278736114502, 16.243234634399414, 16.360532760620117, 16.354135513305664, 16.237632751464844, 16.027368545532227, 15.741020202636719, 15.3962984085083, 15.009894371032715, 14.596718788146973, 14.169466018676758, 13.738438606262207, 13.311601638793945, 12.894783973693848, 12.491965293884277, 12.105606079101562, 11.736970901489258, 11.386423110961914, 11.05368423461914, 10.738046646118164, 10.438538551330566, 10.15404987335205, 9.883429527282715, 9.625540733337402, 9.379312515258789, 9.143757820129395, 8.917984962463379, 8.701208114624023, 8.492738723754883, 8.291980743408203, 8.09842586517334, 7.911640167236328, 7.731259822845459, 7.556978702545166, 7.388543128967285, 7.225742816925049, 7.068406581878662, 6.916396617889404, 6.769604206085205, 6.627945899963379, 6.491361141204834, 6.3598103523254395, 6.233274936676025, 6.111752033233643, 5.9952592849731445, 5.8838300704956055, 5.777517318725586, 5.676392078399658, 5.5805439949035645, 5.490083694458008, 5.405143737792969, 5.325879096984863, 5.252470970153809, 5.185126304626465, 5.124083042144775, 5.06960916519165, 5.022008895874023, 4.98162317276001, 4.9488348960876465, 4.924070835113525, 4.907805442810059, 4.900566577911377, 4.902936935424805, 4.915560245513916, 4.939144134521484, 4.9744648933410645, 5.022371768951416, 5.083788871765137, 5.159718990325928, 5.251245975494385, 5.359535217285156, 5.4858317375183105, 5.631457805633545, 5.797808647155762, 5.986340045928955, 6.198558330535889, 6.435998916625977, 6.700205326080322, 6.992695331573486, 7.314922332763672, 7.668229103088379, 8.053789138793945, 8.472539901733398, 8.925106048583984, 9.411715507507324, 9.932104110717773, 10.485421180725098, 11.070128440856934, 11.683910369873047, 12.323587417602539, 12.985061645507812, 13.663275718688965, 14.352225303649902, 15.045005798339844, 15.733919143676758, 16.410640716552734, 17.065458297729492, 17.68839454650879, 18.269594192504883, 18.799732208251953, 19.270421981811523, 19.674612045288086, 20.00690460205078, 20.263792037963867, 20.44378089904785, 20.547378540039062, 20.57697105407715, 20.536603927612305, 20.43165397644043, 20.268489837646484, 20.05409049987793, 19.795698165893555, 19.500499725341797, 19.175378799438477, 18.826719284057617, 18.460281372070312, 18.081132888793945, 17.693635940551758, 17.301462173461914, 16.90764617919922, 16.51464080810547, 16.12440299987793, 15.738454818725586, 15.357964515686035, 14.983804702758789, 14.616615295410156, 14.256850242614746, 13.904818534851074, 13.56071949005127, 13.2246675491333, 12.89671802520752, 12.576879501342773, 12.265130043029785, 11.961423873901367, 11.665704727172852, 11.37790298461914, 11.097949028015137, 10.825769424438477, 10.561295509338379, 10.304459571838379, 10.055201530456543, 9.813468933105469, 9.579217910766602, 9.352415084838867, 9.133038520812988, 8.921080589294434, 8.716547966003418, 8.519465446472168, 8.329874038696289, 8.14783763885498, 7.973442077636719, 7.806798934936523, 7.64804744720459, 7.4973578453063965, 7.354934215545654, 7.221018314361572, 7.095892429351807, 6.979884147644043, 6.87337064743042, 6.776783466339111, 6.690612316131592, 6.615411758422852, 6.551804542541504, 6.500489711761475, 6.462246894836426, 6.4379401206970215, 6.428525924682617, 6.435056686401367, 6.458683013916016, 6.500659942626953, 6.562343597412109, 6.645192623138428, 6.750762939453125, 6.8806986808776855, 7.0367207527160645, 7.220605373382568, 7.434159278869629, 7.6791839599609375, 7.957431316375732, 8.270545959472656, 8.61999797821045, 9.007002830505371, 9.432422637939453, 9.896662712097168, 10.39954948425293, 10.940210342407227, 11.516939163208008, 12.127080917358398, 12.766918182373047, 13.431591033935547, 14.1150484085083, 14.810063362121582, 15.508296966552734, 16.2004451751709, 16.876466751098633, 17.52587890625, 18.137123107910156, 18.698884963989258, 19.200632095336914, 19.633121490478516, 19.988876342773438, 20.2625732421875, 20.451274871826172, 20.55453109741211, 20.57430076599121, 20.514726638793945, 20.381776809692383, 20.182815551757812, 19.926116943359375, 19.620405197143555, 19.2744140625, 18.896543502807617, 18.494577407836914, 18.07550811767578, 17.645429611206055, 17.209518432617188, 16.77204132080078, 16.336435317993164, 15.905384063720703, 15.48092269897461, 15.06454086303711, 14.65727710723877, 14.259808540344238, 13.872532844543457, 13.495628356933594, 13.129115104675293, 12.772895812988281, 12.426793098449707, 12.090571403503418, 11.763967514038086, 11.446695327758789, 11.13846206665039, 10.838974952697754, 10.547948837280273, 10.26510238647461, 9.990168571472168, 9.722888946533203, 9.463018417358398, 9.210315704345703, 8.964569091796875, 8.725571632385254, 8.493119239807129, 8.267011642456055, 8.047059059143066, 7.833074569702148, 7.624881744384766, 7.422309875488281, 7.22519588470459, 7.033382415771484, 6.846718788146973, 6.6650614738464355, 6.488270282745361, 6.316211700439453, 6.148756504058838, 5.985780715942383, 5.8271636962890625, 5.672788619995117, 5.522542953491211, 5.376318454742432, 5.2340087890625, 5.095511436462402, 4.960727691650391, 4.82956075668335, 4.7019171714782715, 4.577706813812256, 4.456840991973877, 4.339235305786133, 4.224807262420654, 4.113476276397705, 4.005165100097656, 3.899799346923828, 3.7973060607910156, 3.697615623474121, 3.600660562515259, 3.506376028060913, 3.4146993160247803, 3.325570583343506, 3.2389323711395264, 3.1547300815582275, 3.072911262512207, 2.99342679977417, 2.916229724884033, 2.8412766456604004, 2.768526315689087, 2.697941541671753, 2.629488229751587, 2.5631353855133057, 2.49885630607605, 2.4366281032562256, 2.376431941986084, 2.3182544708251953, 2.262086868286133, 2.207925796508789, 2.1557741165161133, 2.1056418418884277, 2.0575456619262695, 2.0115110874176025, 1.9675724506378174, 1.925774097442627, 1.8861720561981201, 1.8488348722457886, 1.813845157623291, 1.7813018560409546, 1.7513216733932495, 1.7240415811538696, 1.6996214389801025, 1.6782469749450684, 1.6601331233978271, 1.6455274820327759, 1.6347153186798096, 1.6280239820480347, 1.6258286237716675, 1.6285581588745117, 1.6367028951644897, 1.6508221626281738, 1.6715530157089233, 1.6996207237243652, 1.735849380493164, 1.7811744213104248, 1.8366563320159912, 1.9034948348999023, 1.9830455780029297, 2.076836347579956, 2.1865861415863037, 2.314222812652588, 2.4619014263153076, 2.632023811340332, 2.8272526264190674, 3.0505261421203613, 3.3050661087036133, 3.5943777561187744, 3.922241687774658, 4.292690277099609, 4.709963798522949, 5.1784467697143555, 5.702569007873535, 6.286675453186035, 6.934846878051758, 7.6506757736206055, 8.436370849609375, 9.292798042297363, 10.21906852722168, 11.212108612060547, 12.266223907470703, 13.37271499633789, 14.519579887390137, 15.691393852233887, 16.869401931762695, 18.03190803527832, 19.15500259399414, 20.213603973388672, 21.182830810546875, 22.03952407836914, 22.76384925842285, 23.340730667114258, 23.76094627380371, 24.0217227935791, 24.12674903869629, 24.085582733154297, 23.912574768066406, 23.625455856323242, 23.243812561035156, 22.787622451782227, 22.27600860595703, 21.726333618164062, 21.153610229492188, 20.570253372192383, 19.98607635498047, 19.40848731994629, 18.842784881591797, 18.29251480102539, 17.759828567504883, 17.245811462402344, 16.75077247619629, 16.274484634399414, 15.816367149353027, 15.375616073608398, 14.951345443725586, 14.542648315429688, 14.148636817932129, 13.768465995788574, 13.401351928710938, 13.046574592590332, 12.703481674194336, 12.371482849121094, 12.050047874450684, 11.738700866699219, 11.437015533447266, 11.144606590270996, 10.861130714416504, 10.586274147033691, 10.319754600524902, 10.061315536499023, 9.810721397399902, 9.56775951385498, 9.332230567932129, 9.103957176208496, 8.882770538330078, 8.668519973754883, 8.461063385009766, 8.260272979736328, 8.066028594970703, 7.878222942352295, 7.6967573165893555, 7.521542549133301, 7.352498531341553, 7.189553260803223, 7.032645225524902, 6.881720066070557, 6.736732006072998, 6.597643852233887, 6.4644269943237305, 6.337059020996094, 6.2155280113220215, 6.099828243255615, 5.98996114730835, 5.885937213897705, 5.7877726554870605, 5.695490837097168, 5.609121799468994, 5.528700828552246, 5.4542694091796875, 5.385872840881348, 5.323561191558838, 5.267387390136719, 5.217405796051025, 5.173672676086426, 5.136242866516113, 5.105170249938965, 5.080504417419434, 5.058221817016602, 5.037883758544922, 5.0191450119018555, 5.001740455627441, 4.985472202301025, 4.97020149230957, 4.955836772918701, 4.942329406738281, 4.929663181304932, 4.917853355407715, 4.906938076019287, 4.896976470947266, 4.888044834136963, 4.880234241485596, 4.873648166656494, 4.868401527404785, 4.864617824554443, 4.862428665161133, 4.861972808837891, 4.863397121429443, 4.866852760314941, 4.872498512268066, 4.880497932434082, 4.89102029800415, 4.904240608215332, 4.920340061187744, 4.939504623413086, 4.9619269371032715, 4.987805366516113, 5.017343521118164, 5.050752639770508, 5.088248252868652, 5.1300530433654785, 5.176395893096924, 5.227510929107666, 5.283637523651123, 5.345020294189453, 5.411908149719238, 5.48455286026001, 5.5632100105285645, 5.648134708404541, 5.739583492279053, 5.837809085845947, 5.943061351776123, 6.055582046508789, 6.175604820251465, 6.303348541259766, 6.439017295837402, 6.582793712615967, 6.734835624694824, 6.895270824432373, 7.0641913414001465, 7.2416486740112305, 7.427647590637207, 7.622140407562256, 7.825018882751465, 8.036109924316406, 8.255169868469238, 8.4818754196167, 8.71582317352295, 8.956522941589355, 9.203390121459961, 9.455753326416016, 9.712843894958496, 9.97380256652832, 10.237679481506348, 10.50344181060791, 10.769980430603027, 11.03611946105957, 11.300625801086426, 11.562227249145508, 11.819628715515137, 12.071527481079102, 12.316631317138672, 12.553685188293457, 12.78148365020752, 12.998895645141602, 13.20488166809082, 13.398512840270996, 13.578980445861816, 13.74561595916748, 13.897895812988281, 14.035446166992188, 14.158048629760742, 14.26563835144043, 14.358299255371094, 14.436258316040039, 14.499872207641602, 14.549622535705566, 14.586094856262207, 14.609970092773438, 14.622008323669434, 14.623034477233887, 14.613921165466309, 14.5955810546875, 14.568950653076172, 14.534979820251465, 14.494623184204102, 14.448832511901855, 14.398550033569336, 14.344701766967773, 14.287834167480469, 14.22846794128418, 14.167102813720703, 14.104218482971191, 14.040273666381836, 13.975706100463867, 13.910937309265137, 13.846366882324219, 13.782378196716309, 13.719338417053223, 13.65759563446045, 13.597481727600098, 13.539313316345215, 13.483389854431152, 13.429996490478516, 13.379403114318848, 13.331863403320312, 13.287616729736328, 13.246885299682617, 13.209878921508789, 13.176791191101074, 13.147797584533691, 13.12306022644043, 13.10272216796875, 13.086912155151367, 13.075737953186035, 13.069291114807129, 13.06764030456543, 13.07083797454834, 13.078911781311035, 13.09186840057373, 13.10969066619873, 13.132338523864746, 13.159743309020996, 13.191813468933105, 13.228426933288574, 13.269436836242676, 13.314665794372559, 13.363908767700195, 13.416930198669434, 13.473467826843262, 13.533227920532227, 13.595890998840332, 13.661111831665039, 13.728516578674316, 13.797710418701172, 13.868277549743652, 13.93978214263916, 14.011775016784668, 14.083791732788086, 14.155363082885742, 14.226014137268066, 14.295269966125488, 14.36266040802002, 14.427724838256836, 14.490015983581543, 14.549104690551758, 14.604586601257324, 14.656082153320312, 14.703243255615234, 14.745758056640625, 14.78334903717041, 14.815781593322754, 14.84286117553711, 14.864436149597168, 14.880401611328125, 14.890693664550781, 14.895295143127441, 14.894229888916016, 14.88756275177002, 14.87540054321289, 14.857885360717773, 14.835193634033203, 14.807534217834473, 14.775145530700684, 14.738289833068848, 14.697251319885254, 14.652335166931152, 14.603859901428223, 14.55215835571289, 14.497572898864746, 14.440451622009277, 14.381150245666504, 14.320023536682129, 14.257428169250488, 14.193717956542969, 14.129244804382324, 14.064353942871094, 13.999385833740234, 13.934672355651855, 13.870539665222168, 13.807303428649902, 13.745268821716309, 13.684732437133789, 13.625980377197266, 13.569287300109863, 13.514917373657227, 13.46312141418457, 13.414139747619629, 13.368199348449707, 13.325516700744629, 13.286293029785156, 13.250717163085938, 13.218964576721191, 13.191195487976074, 13.167555809020996, 13.148176193237305, 13.133170127868652, 13.122635841369629, 13.11665153503418, 13.115279197692871, 13.118559837341309, 13.126513481140137, 13.139140129089355, 13.156416893005371, 13.17829704284668, 13.204710960388184, 13.235563278198242, 13.270731925964355, 13.31006908416748, 13.353401184082031, 13.40052604675293, 13.451214790344238, 13.505210876464844, 13.562233924865723, 13.621578216552734, 13.682476043701172, 13.744105339050293, 13.805597305297852, 13.866046905517578, 13.924528121948242, 13.980104446411133, 14.031839370727539, 14.078816413879395, 14.120146751403809, 14.154986381530762, 14.182548522949219, 14.20211124420166, 14.213035583496094, 14.214766502380371, 14.206847190856934, 14.188916206359863, 14.160719871520996, 14.122103691101074, 14.073017120361328, 14.013508796691895, 13.943719863891602, 13.836982727050781, 13.694648742675781, 13.519371032714844, 13.314728736877441, 13.084869384765625, 12.834195137023926, 12.567102432250977, 12.287781715393066, 12.00007152557373, 11.707371711730957, 11.412601470947266, 11.118194580078125, 10.826118469238281, 10.537914276123047, 10.25475025177002, 9.977472305297852, 9.706659317016602, 9.442676544189453, 9.18571662902832, 8.935844421386719, 8.693028450012207, 8.457164764404297, 8.228106498718262, 8.005672454833984, 7.789665222167969, 7.579878330230713, 7.376104831695557, 7.178139686584473, 6.985784530639648, 6.798848628997803, 6.617149829864502, 6.440515041351318, 6.26878023147583, 6.101790904998779, 5.939399242401123, 5.781466007232666, 5.6278581619262695, 5.478450775146484, 5.333123207092285, 5.191761016845703, 5.05425500869751, 4.920499801635742, 4.790395736694336, 4.663846492767334, 4.540759563446045, 4.421046257019043, 4.304622173309326, 4.191405296325684, 4.08131742477417, 3.9742844104766846, 3.870234489440918, 3.7690999507904053, 3.670815944671631, 3.5753211975097656, 3.482558012008667, 3.392472505569458, 3.30501389503479, 3.2201359272003174, 3.13779616355896, 3.0579569339752197, 2.9805843830108643, 2.9056506156921387, 2.833132266998291, 2.763012409210205, 2.6952803134918213, 2.629931926727295, 2.5669713020324707, 2.5064103603363037, 2.4482712745666504, 2.3925862312316895, 2.3393988609313965, 2.288766384124756, 2.240760564804077, 2.195469856262207, 2.153001546859741, 2.1134836673736572, 2.077068567276001, 2.043935775756836, 2.0142955780029297, 1.9883930683135986, 1.9665133953094482, 1.9489867687225342, 1.9361950159072876, 1.92857825756073, 1.9266433715820312, 1.9309725761413574, 1.9422341585159302, 1.9611939191818237, 1.9887280464172363, 2.0258378982543945, 2.0736658573150635, 2.1335132122039795, 2.206860065460205, 2.2953855991363525, 2.400991201400757, 2.5258243083953857, 2.672302007675171, 2.843135118484497, 3.041350841522217, 3.270312547683716, 3.533733367919922, 3.835454225540161, 4.179561138153076, 4.570336818695068, 5.01218843460083, 5.509541988372803, 6.066699028015137, 6.687646865844727, 7.375819683074951, 8.133805274963379, 8.962994575500488, 9.86318588256836, 10.8321533203125, 11.865208625793457, 12.954782485961914, 14.090086936950684, 15.256917953491211, 16.437652587890625, 17.611530303955078, 18.75523567199707, 19.843847274780273, 20.852092742919922, 21.75583839416504, 22.533700942993164, 23.1685733795166, 23.648880004882812, 23.96938705444336, 24.131425857543945, 24.14252471923828, 24.015487670898438, 23.76707649230957, 23.41648292541504, 22.983810424804688, 22.488733291625977, 21.949438095092773, 21.38192367553711, 20.79962730407715, 20.213342666625977, 19.631349563598633, 19.059690475463867, 18.50250816345215, 17.962419509887695, 17.44085121154785, 16.9383487701416, 16.454845428466797, 15.989852905273438, 15.542633056640625, 15.112310409545898, 14.697957038879395, 14.298650741577148, 13.913507461547852, 13.541707038879395, 13.18249797821045, 12.835206031799316, 12.499226570129395, 12.174026489257812, 11.859132766723633, 11.55368423461914, 11.257065773010254, 10.968730926513672, 10.68820571899414, 10.415079116821289, 10.148998260498047, 9.889664649963379, 9.636819839477539, 9.390246391296387, 9.149754524230957, 8.915177345275879, 8.686368942260742, 8.463194847106934, 8.24553394317627, 8.033270835876465, 7.826295852661133, 7.624504566192627, 7.427793979644775, 7.2360639572143555, 7.049214839935303, 6.867149353027344, 6.689769744873047, 6.5169806480407715, 6.348687171936035, 6.184794902801514, 6.025211811065674, 5.869846820831299, 5.7186102867126465, 5.571415424346924, 5.428176403045654, 5.2888102531433105, 5.15323543548584, 5.021373748779297, 4.893149375915527, 4.768489360809326, 4.647324085235596, 4.529585838317871, 4.415212154388428, 4.304141998291016, 4.196320056915283, 4.091692924499512, 3.990213394165039, 3.8918368816375732, 3.7965247631073, 3.7042429447174072, 3.6149630546569824, 3.5286624431610107, 3.445324659347534, 3.3649404048919678, 3.2875077724456787, 3.213033437728882, 3.1415324211120605, 3.0730302333831787, 3.0075626373291016, 2.9451777935028076, 2.885936975479126, 2.82991623878479, 2.777208089828491, 2.7279229164123535, 2.6821916103363037, 2.640166997909546, 2.602027416229248, 2.5679798126220703, 2.538261651992798, 2.513145685195923, 2.4929440021514893, 2.4780125617980957, 2.4687564373016357, 2.465634822845459, 2.4691684246063232, 2.4799461364746094, 2.4986321926116943, 2.525975227355957, 2.562817335128784, 2.6101036071777344, 2.6688926219940186, 2.7403676509857178, 2.82584810256958, 2.9268012046813965, 3.0448524951934814, 3.181797504425049, 3.3396100997924805, 3.5204508304595947, 3.7266693115234375, 3.960803985595703, 4.225574970245361, 4.523869037628174, 4.858709812164307, 5.233221054077148, 5.650565147399902, 6.113867282867432, 6.626110553741455, 7.190006256103516, 7.807833194732666, 8.481245994567871, 9.211051940917969, 9.99696159362793, 10.837324142456055, 11.728853225708008, 12.666370391845703, 13.642593383789062, 14.646973609924316, 15.666424751281738, 16.685476303100586, 17.68663787841797, 18.65097999572754, 19.55893898010254, 20.391298294067383, 21.130279541015625, 21.76062774658203, 22.27060317993164, 22.65271759033203, 22.904165267944336, 23.0268497467041, 23.02703285217285, 22.91465187072754, 22.701478958129883, 22.401243209838867, 22.02864646911621, 21.598472595214844, 21.12481689453125, 20.620529174804688, 20.096858978271484, 19.563289642333984, 19.027515411376953, 18.49555778503418, 17.971927642822266, 17.45985221862793, 16.96149444580078, 16.478168487548828, 16.010540008544922, 15.558791160583496, 15.122759819030762, 14.70205020904541, 14.296119689941406, 13.904341697692871, 13.526055335998535, 13.160595893859863, 12.8073148727417, 12.465596199035645, 12.13486385345459, 11.814583778381348, 11.504263877868652, 11.203454971313477, 10.91174602508545, 10.62876033782959, 10.354156494140625, 10.08761978149414, 9.828862190246582, 9.577617645263672, 9.333641052246094, 9.096705436706543, 8.866598129272461, 8.643121719360352, 8.426091194152832, 8.21533203125, 8.01068115234375, 7.811981678009033, 7.619088649749756, 7.4318623542785645, 7.249423027038574, 7.071575164794922, 6.898153305053711, 6.729015350341797, 6.564039707183838, 6.4031195640563965, 6.246161460876465, 6.093080520629883, 5.943800449371338, 5.798250675201416, 5.656364440917969, 5.518078804016113, 5.383334636688232, 5.252074241638184, 5.124242782592773, 4.999786376953125, 4.878653526306152, 4.760794639587402, 4.646162033081055, 4.534709930419922, 4.426393985748291, 4.321174144744873, 4.219010353088379, 4.119867324829102, 4.023712635040283, 3.9305155277252197, 3.8402509689331055, 3.752896785736084, 3.6684350967407227, 3.586852788925171, 3.5081424713134766, 3.4323010444641113, 3.359332799911499, 3.289247989654541, 3.2220637798309326, 3.157805919647217, 3.096508502960205, 3.038214921951294, 2.9829790592193604, 2.930866241455078, 2.8819541931152344, 2.836334466934204, 2.7941136360168457, 2.755415201187134, 2.7203805446624756, 2.689171314239502, 2.6619720458984375, 2.638990879058838, 2.6204633712768555, 2.6066553592681885, 2.5978643894195557, 2.5944249629974365, 2.596710681915283, 2.6051392555236816, 2.620175361633301, 2.642336368560791, 2.672196388244629, 2.7103915214538574, 2.757624864578247, 2.8146727085113525, 2.8823885917663574, 2.961709976196289, 3.0536627769470215, 3.159365653991699, 3.2800352573394775, 3.4169867038726807, 3.571636915206909, 3.74550199508667, 3.940194606781006, 4.157414436340332, 4.3989386558532715, 4.666600704193115, 4.962268352508545, 5.287808895111084, 5.645046710968018, 6.035710334777832, 6.461366176605225, 6.923340797424316, 7.422628402709961, 7.959788799285889, 8.534828186035156, 9.14708137512207, 9.795077323913574, 10.476424217224121, 11.187690734863281, 11.924318313598633, 12.680569648742676, 13.449519157409668, 14.223106384277344, 14.992267608642578, 15.74713134765625, 16.477304458618164, 17.172222137451172, 17.821552276611328, 18.415637969970703, 18.9459171295166, 19.40532875061035, 19.78862953186035, 20.09260368347168, 20.3161563873291, 20.460275650024414, 20.526952743530273, 20.519927978515625, 20.444406509399414, 20.306711196899414, 20.1138973236084, 19.87339210510254, 19.5926513671875, 19.278886795043945, 18.9388484954834, 18.578664779663086, 18.203771591186523, 17.81887435913086, 17.42795181274414, 17.03430938720703, 16.64063835144043, 16.249088287353516, 15.861344337463379, 15.47869873046875, 15.102129936218262, 14.732354164123535, 14.369884490966797, 14.015076637268066, 13.668160438537598, 13.329276084899902, 12.998493194580078, 12.675832748413086, 12.361278533935547, 12.054789543151855, 11.75631046295166, 11.465773582458496, 11.183107376098633, 10.908236503601074, 10.641088485717773, 10.38159465789795, 10.129691123962402, 9.885319709777832, 9.648431777954102, 9.418990135192871, 9.196967124938965, 8.98234748840332, 8.775131225585938, 8.575335502624512, 8.382993698120117, 8.198158264160156, 8.020907402038574, 7.851339340209961, 7.689581394195557, 7.53579044342041, 7.390154838562012, 7.252900123596191, 7.124290943145752, 7.004634857177734, 6.894287109375, 6.793656349182129, 6.7032060623168945, 6.6234636306762695, 6.555022239685059, 6.498548984527588, 6.454789161682129, 6.424570560455322, 6.408812522888184, 6.408527374267578, 6.424826145172119, 6.458921909332275, 6.512131214141846, 6.585873603820801, 6.681670188903809, 6.801133632659912, 6.945962429046631, 7.117918491363525, 7.318809986114502, 7.550455093383789, 7.814644813537598, 8.113090515136719, 8.447359085083008, 8.81879997253418, 9.22845458984375, 9.676950454711914, 10.164392471313477, 10.69023323059082, 11.253149032592773, 11.850912094116211, 12.480271339416504, 13.136860847473145, 13.815129280090332, 14.508330345153809, 15.208558082580566, 15.906862258911133, 16.59343910217285, 17.257904052734375, 17.88862419128418, 18.474023818969727, 19.00309944152832, 19.465953826904297, 19.854299545288086, 20.16188621520996, 20.38479995727539, 20.521625518798828, 20.573427200317383, 20.543582916259766, 20.437467575073242, 20.26203727722168, 20.025352478027344, 19.73609733581543, 19.40312957763672, 19.035083770751953, 18.64006233215332, 18.225431442260742, 17.79766845703125, 17.362327575683594, 16.924034118652344, 16.48653793334961, 16.05280303955078, 15.625092506408691, 15.205086708068848, 14.793973922729492, 14.392547607421875, 14.00129222869873, 13.620450019836426, 13.25008487701416, 12.890128135681152, 12.540417671203613, 12.200732231140137, 11.870805740356445, 11.550353050231934, 11.2390775680542, 10.936680793762207, 10.642868995666504, 10.357354164123535, 10.079861640930176, 9.810127258300781, 9.547897338867188, 9.29293155670166, 9.045001029968262, 8.803887367248535, 8.569382667541504, 8.341288566589355, 8.119414329528809, 7.903579235076904, 7.693609237670898, 7.489336967468262, 7.29060173034668, 7.0972490310668945, 6.909129619598389, 6.726099491119385, 6.548019886016846, 6.374756336212158, 6.206178665161133, 6.042160987854004, 5.8825812339782715, 5.727321147918701, 5.576266765594482, 5.429306507110596, 5.286332130432129, 5.1472392082214355, 5.011926174163818, 4.8802947998046875, 4.752248764038086, 4.627695083618164, 4.506543159484863, 4.388706207275391, 4.274097919464111, 4.162635803222656, 4.054239749908447, 3.9488308429718018, 3.8463332653045654, 3.746673583984375, 3.6497795581817627, 3.555581569671631, 3.4640114307403564, 3.3750035762786865, 3.2884936332702637, 3.2043678760528564, 3.122565269470215, 3.043027400970459, 2.965698719024658, 2.890526294708252, 2.817460536956787, 2.746453285217285, 2.677459478378296, 2.610436201095581, 2.545342445373535, 2.482140064239502, 2.4207923412323, 2.3612658977508545, 2.3035285472869873, 2.247551202774048, 2.1933066844940186, 2.140770673751831, 2.089921236038208, 2.0407395362854004, 1.9932085275650024, 1.9473154544830322, 1.9030499458312988, 1.8604053258895874, 1.8193782567977905, 1.7799696922302246, 1.7421845197677612, 1.706032156944275, 1.6715271472930908, 1.6386891603469849, 1.607543706893921, 1.5781227350234985, 1.5504653453826904, 1.5246179103851318, 1.5006355047225952, 1.4785822629928589, 1.458532691001892, 1.4405723810195923, 1.4247993230819702, 1.4113255739212036, 1.4002779722213745, 1.3918004035949707, 1.3860554695129395, 1.3832262754440308, 1.3835190534591675, 1.3871651887893677, 1.394424319267273, 1.405587077140808, 1.4209789037704468, 1.4409632682800293, 1.4659454822540283, 1.4963778257369995, 1.5327636003494263, 1.575662612915039, 1.6256965398788452, 1.6835544109344482, 1.7499996423721313, 1.8258752822875977, 1.9121116399765015, 2.0097317695617676, 2.119858503341675, 2.243720531463623, 2.3826565742492676, 2.538120746612549, 2.7116832733154297, 2.9050323963165283, 3.119968891143799, 3.358400821685791, 3.6223294734954834, 3.9138307571411133, 4.23502779006958, 4.588054656982422, 4.975007057189941, 5.397881984710693, 5.858500957489014, 6.358420372009277, 6.898821830749512, 7.480390548706055, 8.10317611694336, 8.766448020935059, 9.468541145324707, 10.206707000732422, 10.976983070373535, 11.77408504486084, 12.591349601745605, 13.420730590820312, 14.25287914276123, 15.07730770111084, 15.882657051086426, 16.65705108642578, 17.388540267944336, 18.06560707092285, 18.677688598632812, 19.215696334838867, 19.67245101928711, 20.04303741455078, 20.324989318847656, 20.51833152770996, 20.625457763671875, 20.65085220336914, 20.600709915161133, 20.482486724853516, 20.303693771362305, 20.072328567504883, 19.796493530273438, 19.484067916870117, 19.14246368408203, 18.778430938720703, 18.397964477539062, 18.006250381469727, 17.607677459716797, 17.20587921142578, 16.803802490234375, 16.403789520263672, 16.007667541503906, 15.616823196411133, 15.232295989990234, 14.85483455657959, 14.484966278076172, 14.12304401397705, 13.769285202026367, 13.423811912536621, 13.086671829223633, 12.757859230041504, 12.437334060668945, 12.125027656555176, 11.820858001708984, 11.524731636047363, 11.236553192138672, 10.956222534179688, 10.683642387390137, 10.418718338012695, 10.16136360168457, 9.91149616241455, 9.669039726257324, 9.433931350708008, 9.20611572265625, 8.98554801940918, 8.772197723388672, 8.566047668457031, 8.367096900939941, 8.175358772277832, 7.990869522094727, 7.813683032989502, 7.6438775062561035, 7.481555461883545, 7.32684850692749, 7.1799187660217285, 7.040961742401123, 6.910210609436035, 6.78794002532959, 6.674469470977783, 6.570168972015381, 6.475462436676025, 6.390833377838135, 6.316830635070801, 6.2540740966796875, 6.2032599449157715, 6.165168285369873, 6.14066743850708, 6.130721569061279, 6.136394023895264, 6.15885591506958, 6.199386119842529, 6.259376525878906, 6.340330123901367, 6.4438605308532715, 6.571682929992676, 6.7256059646606445, 6.907512664794922, 7.11933708190918, 7.363030433654785, 7.640519618988037, 7.953649044036865, 8.304115295410156, 8.69338321685791, 9.122587203979492, 9.592422485351562, 10.10301399230957, 10.653786659240723, 11.24332046508789, 11.80312728881836, 12.317873001098633, 12.77469539642334, 13.163540840148926, 13.47740364074707, 13.712420463562012, 13.867785453796387, 13.945505142211914, 13.949995040893555, 13.887575149536133, 13.765908241271973, 13.593430519104004, 13.37883186340332, 13.13060474395752, 12.856706619262695, 12.564311981201172, 12.259675979614258, 11.948079109191895, 11.633843421936035, 11.320398330688477, 11.010370254516602, 10.705698013305664, 10.407745361328125, 10.117412567138672, 9.835233688354492, 9.561463356018066, 9.296154975891113, 9.039212226867676, 8.79044246673584, 8.549591064453125, 8.316367149353027, 8.090466499328613, 7.871580600738525, 7.659411430358887, 7.453671932220459, 7.254092216491699, 7.060420989990234, 6.872424125671387, 6.68988561630249, 6.5126051902771, 6.340398788452148, 6.173095703125, 6.010537624359131, 5.8525776863098145, 5.6990790367126465, 5.549914360046387, 5.404964447021484, 5.26411771774292, 5.127269744873047, 4.994322299957275, 4.865184307098389, 4.739769458770752, 4.617998123168945, 4.499796390533447, 4.385095596313477, 4.273833274841309, 4.165953159332275, 4.061404228210449, 3.960143566131592, 3.862133264541626, 3.767343521118164, 3.675752878189087, 3.5873470306396484, 3.502121686935425, 3.4200825691223145, 3.3412458896636963, 3.2656400203704834, 3.1933066844940186, 3.124302864074707, 3.058701276779175, 2.996593713760376, 2.9380922317504883, 2.8833320140838623, 2.8324742317199707, 2.7857091426849365, 2.743260383605957, 2.705387830734253, 2.672393798828125, 2.644627809524536, 2.6224918365478516, 2.6064491271972656, 2.597029447555542, 2.5948400497436523, 2.6005735397338867, 2.6150197982788086, 2.639077663421631, 2.67376708984375, 2.720244884490967, 2.7798194885253906, 2.8539679050445557, 2.9443531036376953, 3.0528416633605957, 3.181523323059082, 3.3327274322509766, 3.509040594100952, 3.713318109512329, 3.948695421218872, 4.218587875366211, 4.5266852378845215, 4.876928329467773, 5.273473739624023, 5.720278263092041, 6.221213340759277, 6.779910087585449, 7.3995680809021, 8.082716941833496, 8.830934524536133, 9.64452075958252, 10.522139549255371, 11.460450172424316, 12.453744888305664, 13.49362850189209, 14.568804740905762, 15.664993286132812, 16.765052795410156, 17.849355697631836, 18.896425247192383, 19.883867263793945, 20.789522171020508, 21.592782974243164, 22.275922775268555, 22.825321197509766, 23.23238754272461, 23.49408531188965, 23.612974166870117, 23.596757888793945, 23.457426071166992, 23.210100173950195, 22.871755599975586, 22.459978103637695, 21.991878509521484, 21.48325538635254, 20.948034286499023, 20.397977828979492, 19.842618942260742, 19.28937339782715, 18.743755340576172, 18.209657669067383, 17.689651489257812, 17.185264587402344, 16.697240829467773, 16.22575569152832, 15.770593643188477, 15.331284523010254, 14.907208442687988, 14.49767017364502, 14.101951599121094, 13.719347953796387, 13.349187850952148, 12.990845680236816, 12.643747329711914, 12.307369232177734, 11.981240272521973, 11.664934158325195, 11.358068466186523, 11.060296058654785, 10.771307945251465, 10.49082088470459, 10.218582153320312, 9.954358100891113, 9.697941780090332, 9.449140548706055, 9.207782745361328, 8.973712921142578, 8.746790885925293, 8.526893615722656, 8.313911437988281, 8.10775089263916, 7.908336639404297, 7.715606212615967, 7.529516696929932, 7.350042819976807, 7.177179336547852, 7.010941028594971, 6.851365566253662, 6.698515892028809, 6.552481174468994, 6.413380146026611, 6.281363487243652, 6.156617164611816, 6.039367198944092, 5.9298810958862305, 5.828474521636963, 5.735515117645264, 5.65142822265625, 5.576701641082764, 5.511893272399902, 5.457636833190918, 5.41464900970459, 5.3837385177612305, 5.365810394287109, 5.361877918243408, 5.373067378997803, 5.400627136230469, 5.445932865142822, 5.510494232177734, 5.595959186553955, 5.7041120529174805, 5.836874485015869, 5.996295928955078, 6.184540748596191, 6.403868198394775, 6.629928112030029, 6.858486175537109, 7.085743427276611, 7.308318138122559, 7.523231029510498, 7.727895259857178, 7.920112609863281, 8.098065376281738, 8.260310173034668, 8.40576171875, 8.533681869506836, 8.643651962280273, 8.735555648803711, 8.809542655944824, 8.866003036499023, 8.905526161193848, 8.928873062133789, 8.93693733215332, 8.93071460723877, 8.911269187927246, 8.879707336425781, 8.837154388427734, 8.78472900390625, 8.723530769348145, 8.654623031616211, 8.579021453857422, 8.497692108154297, 8.411539077758789, 8.321407318115234, 8.228083610534668, 8.132288932800293, 8.034692764282227, 7.9359049797058105, 7.836487293243408, 7.7369537353515625, 7.63777494430542, 7.539384365081787, 7.44218111038208, 7.346534729003906, 7.25278902053833, 7.1612653732299805, 7.072268486022949, 6.986086368560791, 6.9029974937438965, 6.823270797729492, 6.7471699714660645, 6.67495584487915, 6.606889724731445, 6.543234825134277, 6.484259128570557, 6.430238246917725, 6.3814568519592285, 6.338212013244629, 6.300813674926758, 6.269588470458984, 6.2448811531066895, 6.227055549621582, 6.216498851776123, 6.213620185852051, 6.218856334686279, 6.232668876647949, 6.255548477172852, 6.288014888763428, 6.330617427825928, 6.383935451507568, 6.4485764503479, 6.525177955627441, 6.614400863647461, 6.7169318199157715, 6.833474636077881, 6.96474552154541, 7.111467361450195, 7.274358749389648, 7.454123497009277, 7.651436805725098, 7.866929054260254, 8.101166725158691, 8.354630470275879, 8.627693176269531, 8.920589447021484, 9.23338794708252, 9.565960884094238, 9.917948722839355, 10.288732528686523, 10.677396774291992, 11.08270263671875, 11.503066062927246, 11.93653392791748, 12.380779266357422, 12.833100318908691, 13.290433883666992, 13.74938678741455, 14.20627498626709, 14.65718936920166, 15.098067283630371, 15.524784088134766, 15.933252334594727, 16.319530487060547, 16.6799259185791, 17.0111083984375, 17.310197830200195, 17.574058532714844, 17.800125122070312, 17.986499786376953, 18.131980895996094, 18.236101150512695, 18.299108505249023, 18.321918487548828, 18.306062698364258, 18.253589630126953, 18.166967391967773, 18.04897689819336, 17.90260887145996, 17.730958938598633, 17.53714370727539, 17.32421112060547, 17.095096588134766, 16.85256004333496, 16.599164962768555, 16.33725929260254, 16.06895637512207, 15.796152114868164, 15.520523071289062, 15.243542671203613, 14.966498374938965, 14.690508842468262, 14.416543006896973, 14.145440101623535, 13.877923011779785, 13.614620208740234, 13.356074333190918, 13.102763175964355, 12.85510540008545, 12.613472938537598, 12.378201484680176, 12.149599075317383, 11.927948951721191, 11.713521957397461, 11.506575584411621, 11.307365417480469, 11.116144180297852, 10.933170318603516, 10.758708000183105, 10.59303092956543, 10.43642807006836, 10.289205551147461, 10.151688575744629, 10.024222373962402, 9.907180786132812, 9.800960540771484, 9.705988883972168, 9.622722625732422, 9.551650047302246, 9.493291854858398, 9.448200225830078, 9.416960716247559, 9.400187492370605, 9.398523330688477, 9.412633895874023, 9.443206787109375, 9.49094009399414, 9.556534767150879, 9.64068603515625, 9.744068145751953, 9.867319107055664, 10.011019706726074, 10.175674438476562, 10.361684799194336, 10.569321632385254, 10.798693656921387, 11.049715042114258, 11.32206916809082, 11.615174293518066, 11.928147315979004, 12.259770393371582, 12.6084623336792, 12.97225570678711, 13.348784446716309, 13.73527717590332, 14.128572463989258, 14.525139808654785, 14.921131134033203, 15.312434196472168, 15.694756507873535, 16.063718795776367, 16.414960861206055, 16.744264602661133, 17.04766845703125, 17.321578979492188, 17.56288719177246, 17.769052505493164, 17.93817710876465, 18.06903648376465, 18.161104202270508, 18.214536666870117, 18.230127334594727, 18.209245681762695, 18.153757095336914, 18.06592559814453, 17.948322296142578, 17.803714752197266, 17.634986877441406, 17.445045471191406, 17.23674964904785, 17.012863159179688, 16.775991439819336, 16.528566360473633, 16.272823333740234, 16.010787963867188, 15.744279861450195, 15.474920272827148, 15.204141616821289, 14.93320083618164, 14.663196563720703, 14.395086288452148, 14.129704475402832, 13.867773056030273, 13.609926223754883, 13.35671329498291, 13.108622550964355, 12.866082191467285, 12.629478454589844, 12.399158477783203, 12.175443649291992, 11.95863151550293, 11.749005317687988, 11.546838760375977, 11.352399826049805, 11.165955543518066, 10.987775802612305, 10.818138122558594, 10.657329559326172, 10.50565242767334, 10.363423347473145, 10.230978012084961, 10.108674049377441, 9.996892929077148, 9.896039962768555, 9.806549072265625, 9.728882789611816, 9.663533210754395, 9.611019134521484, 9.571893692016602, 9.546733856201172, 9.536144256591797, 9.540754318237305, 9.561210632324219, 9.598172187805176, 9.652304649353027, 9.724268913269043, 9.814708709716797, 9.924240112304688, 10.05342960357666, 10.202778816223145, 10.372698783874512, 10.563488960266113, 10.775303840637207, 11.008126258850098, 11.261736869812012, 11.535676002502441, 11.829214096069336, 12.140830039978027, 12.468564987182617, 12.757622718811035, 12.999189376831055, 13.187108993530273, 13.317831039428711, 13.39024543762207, 13.40542221069336, 13.366267204284668, 13.277122497558594, 13.143353462219238, 12.970931053161621, 12.766069412231445, 12.534903526306152, 12.283244132995605, 12.016406059265137, 11.739091873168945, 11.455349922180176, 11.16856575012207, 10.881494522094727, 10.596320152282715, 10.314718246459961, 10.037934303283691, 9.766851425170898, 9.502067565917969, 9.243946075439453, 8.992676734924316, 8.748316764831543, 8.510825157165527, 8.280097007751465, 8.055978775024414, 7.838292121887207, 7.6268415451049805, 7.4214253425598145, 7.2218427658081055, 7.027894973754883, 6.839392185211182, 6.6561503410339355, 6.477995872497559, 6.304762363433838, 6.136293888092041, 5.972440242767334, 5.813061237335205, 5.658021926879883, 5.507194519042969, 5.360456943511963, 5.2176923751831055, 5.078789710998535, 4.94364070892334, 4.812143325805664, 4.684197902679443, 4.559708595275879, 4.438583850860596, 4.32073450088501, 4.206075191497803, 4.094522953033447, 3.9859979152679443, 3.8804233074188232, 3.777724504470825, 3.677830457687378, 3.580672264099121, 3.4861836433410645, 3.394301414489746, 3.304965019226074, 3.2181167602539062, 3.1337010860443115, 3.051666736602783, 2.971964120864868, 2.894547700881958, 2.8193752765655518, 2.7464072704315186, 2.6756091117858887, 2.6069493293762207, 2.540400981903076, 2.475942373275757, 2.4135560989379883, 2.353231191635132, 2.2949624061584473, 2.2387516498565674, 2.1846084594726562, 2.1325507164001465, 2.082606554031372, 2.0348143577575684, 1.989225149154663, 1.945904016494751, 1.904931664466858, 1.8664065599441528, 1.8304482698440552, 1.7971993684768677, 1.766829252243042, 1.7395380735397339, 1.7155612707138062, 1.6951745748519897, 1.6786998510360718, 1.666512131690979, 1.6590477228164673, 1.6568127870559692, 1.6603940725326538, 1.6704708337783813, 1.6878280639648438, 1.7133724689483643, 1.7481495141983032, 1.7933635711669922, 1.8503414392471313, 1.9205870628356934, 2.0058014392852783, 2.1079018115997314, 2.22904372215271, 2.3716397285461426, 2.5383787155151367, 2.732241630554199, 2.956511974334717, 3.2147793769836426, 3.5109336376190186, 3.849142551422119, 4.233810901641846, 4.669516563415527, 5.1609110832214355, 5.712584495544434, 6.328884124755859, 7.013677597045898, 7.7700605392456055, 8.600005149841309, 9.503948211669922, 10.48034381866455, 11.52518367767334, 12.631540298461914, 13.789163589477539, 14.984217643737793, 16.19919776916504, 17.41313934326172, 18.602149963378906, 19.740314483642578, 20.80097007751465, 21.758262634277344, 22.58885955810547, 23.273643493652344, 23.79915428161621, 24.158567428588867, 24.352081298828125, 24.38663673400879, 24.275012969970703, 24.034460067749023, 23.685068130493164, 23.248106002807617, 22.744531631469727, 22.193805694580078, 21.61309242248535, 21.016815185546875, 20.416549682617188, 19.821157455444336, 19.23706817626953, 18.668659210205078, 18.118648529052734, 17.588481903076172, 17.07865333557129, 16.589006423950195, 16.118942260742188, 15.6676025390625, 15.233994483947754, 14.817078590393066, 14.415831565856934, 14.029282569885254, 13.656533241271973, 13.296770095825195, 12.94926643371582, 12.61337661743164, 12.288533210754395, 11.974239349365234, 11.670062065124512, 11.37562370300293, 11.090595245361328, 10.814692497253418, 10.547670364379883, 10.289318084716797, 10.03945541381836, 9.797932624816895, 9.56462574005127, 9.339437484741211, 9.122297286987305, 8.913158416748047, 8.711999893188477, 8.518826484680176, 8.333671569824219, 8.156596183776855, 7.9876909255981445, 7.827081203460693, 7.674925327301025, 7.5314202308654785, 7.396803855895996, 7.271356582641602, 7.155407905578613, 7.049339294433594, 6.953587532043457, 6.868650436401367, 6.795091152191162, 6.733543872833252, 6.684718132019043, 6.649404048919678, 6.628476619720459, 6.6229023933410645, 6.633739471435547, 6.662144660949707, 6.709370136260986, 6.776767253875732, 6.865779876708984, 6.977940559387207, 7.114857196807861, 7.278200149536133, 7.469677448272705, 7.691007614135742, 7.9438796043396, 8.196869850158691, 8.444259643554688, 8.681071281433105, 8.903059959411621, 9.106707572937012, 9.289217948913574, 9.44849681854248, 9.583122253417969, 9.692304611206055, 9.775833129882812, 9.83401107788086, 9.867588996887207, 9.877681732177734, 9.865697860717773, 9.833259582519531, 9.782132148742676, 9.714159965515137, 9.631208419799805, 9.535120010375977, 9.42767333984375, 9.310555458068848, 9.185343742370605, 9.053491592407227, 8.916321754455566, 8.775029182434082, 8.630678176879883, 8.484216690063477, 8.33647632598877, 8.188188552856445, 8.039989471435547, 7.892432689666748, 7.745999813079834, 7.601108074188232, 7.458118915557861, 7.317347049713135, 7.179068088531494, 7.04352331161499, 6.910926342010498, 6.781467914581299, 6.655320167541504, 6.530147075653076, 6.406069278717041, 6.283217430114746, 6.161727428436279, 6.0417327880859375, 5.923364162445068, 5.806745529174805, 5.69199275970459, 5.579213619232178, 5.468506336212158, 5.359961986541748, 5.253661632537842, 5.149680137634277, 5.048085689544678, 4.948939323425293, 4.852298736572266, 4.758216381072998, 4.66674280166626, 4.577925205230713, 4.491809844970703, 4.408443450927734, 4.327872276306152, 4.250144958496094, 4.175311088562012, 4.103425025939941, 4.034543514251709, 3.9687294960021973, 3.9060511589050293, 3.846583604812622, 3.790409564971924, 3.7376203536987305, 3.6883177757263184, 3.6426141262054443, 3.6006336212158203, 3.5625147819519043, 3.5284104347229004, 3.4984896183013916, 3.4729394912719727, 3.4519665241241455, 3.4357988834381104, 3.424687385559082, 3.41890811920166, 3.418764591217041, 3.424589157104492, 3.43674635887146, 3.455634355545044, 3.4816877841949463, 3.5153794288635254, 3.5572237968444824, 3.6077778339385986, 3.6676440238952637, 3.73747181892395, 3.8179593086242676, 3.909852981567383, 4.013949394226074, 4.1310930252075195, 4.2621750831604, 4.408130168914795, 4.5699310302734375, 4.748580455780029, 4.945102691650391, 5.160531520843506, 5.3958916664123535, 5.652180194854736, 5.930344104766846, 6.2312493324279785, 6.555646896362305, 6.904138088226318, 7.277126789093018, 7.674774169921875, 8.09694766998291, 8.543167114257812, 9.01254940032959, 9.503758430480957, 10.014958381652832, 10.543771743774414, 11.087255477905273, 11.641894340515137, 12.203604698181152, 12.767777442932129, 13.329339027404785, 13.882843017578125, 14.422589302062988, 14.942774772644043, 15.437653541564941, 15.901718139648438, 16.329879760742188, 16.7176456451416, 17.061262130737305, 17.35784339904785, 17.605457305908203, 17.803159713745117, 17.95098304748535, 18.04989242553711, 18.10169219970703, 18.108896255493164, 18.074594497680664, 18.00229835510254, 17.895790100097656, 17.758975982666016, 17.595775604248047, 17.409526824951172, 17.20347023010254, 16.980684280395508, 16.744047164916992, 16.49620819091797, 16.239582061767578, 15.976338386535645, 15.708405494689941, 15.437490463256836, 15.165087699890137, 14.892501831054688, 14.62086296081543, 14.351151466369629, 14.08421516418457, 13.820786476135254, 13.56149959564209, 13.30690860748291, 13.0574951171875, 12.813688278198242, 12.575867652893066, 12.344378471374512, 12.119534492492676, 11.901632308959961, 11.690947532653809, 11.487750053405762, 11.292304992675781, 11.104873657226562, 10.925724983215332, 10.755131721496582, 10.59338092803955, 10.440770149230957, 10.297616004943848, 10.164253234863281, 10.041040420532227, 9.928357124328613, 9.826613426208496, 9.736245155334473, 9.65771770477295, 9.591526985168457, 9.538199424743652, 9.498295783996582, 9.47240161895752, 9.461133003234863, 9.465131759643555, 9.48505973815918, 9.52159309387207, 9.575417518615723, 9.647214889526367, 9.737655639648438, 9.847380638122559, 9.976985931396484, 10.127004623413086, 10.297882080078125, 10.489950180053711, 10.703400611877441, 10.938250541687012, 11.194314002990723, 11.471163749694824, 11.768096923828125, 12.084105491638184, 12.417840957641602, 12.767590522766113, 13.131260871887207, 13.506366729736328, 13.890032768249512, 14.279011726379395, 14.669717788696289, 15.058274269104004, 15.440581321716309, 15.812397003173828, 16.169437408447266, 16.50748634338379, 16.822498321533203, 17.110733032226562, 17.36884307861328, 17.593990325927734, 17.783910751342773, 17.93698501586914, 18.052255630493164, 18.12944221496582, 18.168914794921875, 18.171642303466797, 18.139131546020508, 18.073335647583008, 17.9765682220459, 17.851409912109375, 17.700603485107422, 17.526975631713867, 17.333358764648438, 17.122520446777344, 16.89711570739746, 16.65964698791504, 16.412439346313477, 16.15761947631836, 15.897119522094727, 15.632667541503906, 15.365804672241211, 15.09788990020752, 14.830120086669922, 14.563541412353516, 14.299067497253418, 14.037493705749512, 13.779516220092773, 13.525742530822754, 13.276705741882324, 13.032878875732422, 12.794681549072266, 12.562492370605469, 12.336655616760254, 12.117491722106934, 11.905299186706543, 11.700364112854004, 11.50296401977539, 11.313371658325195, 11.13186264038086, 10.958714485168457, 10.79421329498291, 10.638657569885254, 10.49235725402832, 10.355640411376953, 10.228856086730957, 10.112371444702148, 10.00658130645752, 9.911901473999023, 9.828779220581055, 9.757685661315918, 9.69912338256836, 9.653621673583984, 9.621737480163574, 9.604053497314453, 9.601176261901855, 9.613731384277344, 9.642359733581543, 9.687707901000977, 9.750423431396484, 9.831140518188477, 9.93047046661377, 10.048983573913574, 10.187191009521484, 10.345529556274414, 10.524330139160156, 10.723796844482422, 10.943979263305664, 11.184737205505371, 11.445714950561523, 11.726304054260254, 12.025615692138672, 12.342449188232422, 12.67526912689209, 13.022185325622559, 13.380941390991211, 13.74891185760498, 14.123120307922363, 14.50025749206543, 14.876726150512695, 15.248698234558105, 15.612183570861816, 15.963116645812988, 16.297456741333008, 16.611289978027344, 16.900930404663086, 17.163036346435547, 17.39469337463379, 17.593505859375, 17.75765037536621, 17.885923385620117, 17.977746963500977, 18.033172607421875, 18.052833557128906, 18.037899017333984, 17.99000358581543, 17.91115951538086, 17.803678512573242, 17.67007827758789, 17.51300048828125, 17.335124969482422, 17.13912010192871, 16.92757225036621, 16.70294761657715, 16.46756362915039, 16.223562240600586, 15.972906112670898, 15.717371940612793, 15.458553314208984, 15.197872161865234, 14.936583518981934, 14.675797462463379, 14.416487693786621, 14.15950870513916, 13.905610084533691, 13.655449867248535, 13.4096097946167, 13.168601989746094, 12.932886123657227, 12.702875137329102, 12.47894287109375, 12.26143741607666, 12.050680160522461, 11.846978187561035, 11.650626182556152, 11.4619140625, 11.2811279296875, 11.108556747436523, 10.94449520111084, 10.78924560546875, 10.643122673034668, 10.50645637512207, 10.379594802856445, 10.262901306152344, 10.15676498413086, 10.061596870422363, 9.97783088684082, 9.905927658081055, 9.846373558044434, 9.79967975616455, 9.766382217407227, 9.747040748596191, 9.742234230041504, 9.75256061553955, 9.756792068481445, 9.752321243286133, 9.737265586853027, 9.710389137268066, 9.671011924743652, 9.618927955627441, 9.554320335388184, 9.477682113647461, 9.389741897583008, 9.291396141052246, 9.18365478515625, 9.067587852478027, 8.944284439086914, 8.814824104309082, 8.680246353149414, 8.541535377502441, 8.39961051940918, 8.255313873291016, 8.109411239624023, 7.962590217590332, 7.815464496612549, 7.668576240539551, 7.522402763366699, 7.377361297607422, 7.233815670013428, 7.092082500457764, 6.9524359703063965, 6.8151140213012695, 6.680324554443359, 6.548247814178467, 6.419042587280273, 6.292849540710449, 6.169793128967285, 6.04998779296875, 5.933537483215332, 5.820539951324463, 5.71108865737915, 5.605275630950928, 5.503190994262695, 5.404928207397461, 5.310583114624023, 5.220256805419922, 5.134057521820068, 5.052100658416748, 4.974513530731201, 4.901434421539307, 4.833014488220215, 4.7694220542907715, 4.710842132568359, 4.6574788093566895, 4.609559059143066, 4.567333221435547, 4.531078338623047, 4.501100540161133, 4.477737903594971, 4.461362838745117, 4.452385902404785, 4.451258659362793, 4.458476543426514, 4.474581241607666, 4.500165939331055, 4.535876750946045, 4.5824174880981445, 4.640549182891846, 4.711095333099365, 4.794942378997803, 4.893039703369141, 5.006400108337402, 5.136097431182861, 5.283262252807617, 5.449077129364014, 5.634765148162842, 5.841580390930176, 6.070788860321045, 6.323648929595947, 6.601384162902832, 6.905149936676025, 7.235997200012207, 7.594822883605957, 7.9823198318481445, 8.39891529083252, 8.844707489013672, 9.319389343261719, 9.822184562683105, 10.351764678955078, 10.906189918518066, 11.482841491699219, 12.07837963104248, 12.688720703125, 13.309039115905762, 13.93380069732666, 14.556838989257812, 15.17147159576416, 15.770652770996094, 16.347169876098633, 16.893863677978516, 17.40387725830078, 17.87090492248535, 18.28942108154297, 18.6549015045166, 18.963973999023438, 19.213626861572266, 19.402172088623047, 19.5292911529541, 19.595983505249023, 19.604461669921875, 19.557987213134766, 19.460660934448242, 19.317201614379883, 19.13271141052246, 18.912460327148438, 18.661691665649414, 18.385461807250977, 18.08852195739746, 17.775232315063477, 17.44951057434082, 17.114809036254883, 16.774126052856445, 16.430023193359375, 16.08465576171875, 15.739821434020996, 15.396995544433594, 15.057380676269531, 14.72194766998291, 14.391471862792969, 14.066569328308105, 13.747724533081055, 13.435319900512695, 13.12965202331543, 12.830955505371094, 12.539411544799805, 12.25516414642334, 11.978327751159668, 11.708998680114746, 11.447256088256836, 11.193172454833984, 10.946818351745605, 10.708261489868164, 10.477574348449707, 10.254837036132812, 10.034626007080078, 9.816718101501465, 9.601027488708496, 9.387572288513184, 9.176441192626953, 8.967771530151367, 8.761727333068848, 8.55848503112793, 8.358219146728516, 8.161096572875977, 7.9672698974609375, 7.776872634887695, 7.590019226074219, 7.406804084777832, 7.227301597595215, 7.051567554473877, 6.879642009735107, 6.711548328399658, 6.547297954559326, 6.3868889808654785, 6.230311870574951, 6.077547550201416, 5.928570747375488, 5.783351421356201, 5.641855716705322, 5.504045486450195, 5.369881629943848, 5.239324569702148, 5.112332820892334, 4.988867282867432, 4.8688883781433105, 4.752358913421631, 4.639243125915527, 4.5295090675354, 4.423127174377441, 4.320071697235107, 4.2203216552734375, 4.1238603591918945, 4.03067684173584, 3.940765857696533, 3.8541290760040283, 3.770775079727173, 3.690720796585083, 3.6139919757843018, 3.5406246185302734, 3.4706647396087646, 3.4041712284088135, 3.3412153720855713, 3.281883478164673, 3.2262778282165527, 3.1745188236236572, 3.12674617767334, 3.0831215381622314, 3.0438308715820312, 3.0090863704681396, 2.979130268096924, 2.954237461090088, 2.9347188472747803, 2.9209253787994385, 2.913252353668213, 2.9121434688568115, 2.9180965423583984, 2.931668519973755, 2.9534809589385986, 2.9842262268066406, 3.024674892425537, 3.07568097114563, 3.1381900310516357, 3.2132458686828613, 3.3019964694976807, 3.4057016372680664, 3.5257375240325928, 3.663601875305176, 3.8209152221679688, 3.999422550201416, 4.20098876953125, 4.427591800689697, 4.681307792663574, 4.964293003082275, 5.278752326965332, 5.626902103424072, 6.010915756225586, 6.432860374450684, 6.894613265991211, 7.397765159606934, 7.943502426147461, 8.532475471496582, 9.164650917053223, 9.839151382446289, 10.554096221923828, 11.306438446044922, 12.091830253601074, 12.904512405395508, 13.737255096435547, 14.58137321472168, 15.426817893981934, 16.262372970581055, 17.075952529907227, 17.855009078979492, 18.587017059326172, 19.260019302368164, 19.86203956604004, 20.38272476196289, 20.813913345336914, 21.150070190429688, 21.388547897338867, 21.529645919799805, 21.576454162597656, 21.534528732299805, 21.411413192749023, 21.216073989868164, 20.95831298828125, 20.64822006225586, 20.29567527770996, 19.909975051879883, 19.499557495117188, 19.071847915649414, 18.633180618286133, 18.18882179260254, 17.74302864074707, 17.299152374267578, 16.85976219177246, 16.4267635345459, 16.001523971557617, 15.584980010986328, 15.177734375, 14.780136108398438, 14.392343521118164, 14.014381408691406, 13.646178245544434, 13.287598609924316, 12.93846607208252, 12.598579406738281, 12.26772403717041, 11.945683479309082, 11.632238388061523, 11.327174186706543, 11.03028392791748, 10.74136734008789, 10.460229873657227, 10.186687469482422, 9.920563697814941, 9.661687850952148, 9.40989875793457, 9.165040969848633, 8.926968574523926, 8.695542335510254, 8.470629692077637, 8.252106666564941, 8.03985595703125, 7.833769798278809, 7.633748531341553, 7.43970251083374, 7.25154972076416, 7.069221019744873, 6.8926568031311035, 6.721810340881348, 6.556647777557373, 6.397150039672852, 6.243313312530518, 6.095151901245117, 5.95269775390625, 5.816005229949951, 5.685150623321533, 5.560237407684326, 5.4413957595825195, 5.328788757324219, 5.222613334655762, 5.123106956481934, 5.030549049377441, 4.945267677307129, 4.867644786834717, 4.798121929168701, 4.737205505371094, 4.685476303100586, 4.643595218658447, 4.612313270568848, 4.592478275299072, 4.585046768188477, 4.591092109680176, 4.611813545227051, 4.648549556732178, 4.702783584594727, 4.776154518127441, 4.870462894439697, 4.98767614364624, 5.129929065704346, 5.299520015716553, 5.498901844024658, 5.730663776397705, 5.997501373291016, 6.302176475524902, 6.647459983825684, 7.036054611206055, 7.470499515533447, 7.953047275543213, 8.485518455505371, 9.06912899017334, 9.704292297363281, 10.390403747558594, 11.1256103515625, 11.906585693359375, 12.728321075439453, 13.583953857421875, 14.464672088623047, 15.359701156616211, 16.256431579589844, 17.140674591064453, 17.997095108032227, 18.809776306152344, 19.562936782836914, 20.241718292236328, 20.832998275756836, 21.32613754272461, 21.713594436645508, 21.9913272857666, 22.158926010131836, 22.219493865966797, 22.17924690246582, 22.046939849853516, 21.833145141601562, 21.54950714111328, 21.20801544189453, 20.820384979248047, 20.39756965637207, 19.949419021606445, 19.48448371887207, 19.00995445251465, 18.531686782836914, 18.054306030273438, 17.58134651184082, 17.11541748046875, 16.658357620239258, 16.211400985717773, 15.775304794311523, 15.350470542907715, 14.937039375305176, 14.534966468811035, 14.144082069396973, 13.764138221740723, 13.394838333129883, 13.03586196899414, 12.686882019042969, 12.34757137298584, 12.01761531829834, 11.696708679199219, 11.384560585021973, 11.080897331237793, 10.785457611083984, 10.497993469238281, 10.218271255493164, 9.946064949035645, 9.681163787841797, 9.423360824584961, 9.172459602355957, 8.928271293640137, 8.690614700317383, 8.459314346313477, 8.234199523925781, 8.015107154846191, 7.801878929138184, 7.594359397888184, 7.392399311065674, 7.195854187011719, 7.004582405090332, 6.818447113037109, 6.6373162269592285, 6.461060047149658, 6.289553642272949, 6.122675895690918, 5.960252285003662, 5.80216121673584, 5.648284912109375, 5.498509407043457, 5.352725505828857, 5.2108259201049805, 5.0727081298828125, 4.938271999359131, 4.80742073059082, 4.680060386657715, 4.556098937988281, 4.435448169708252, 4.318021774291992, 4.203735828399658, 4.092508792877197, 3.9842617511749268, 3.878917932510376, 3.776402473449707, 3.676643133163452, 3.5795695781707764, 3.4851133823394775, 3.3932085037231445, 3.303790330886841, 3.216797351837158, 3.1321685314178467, 3.0498464107513428, 2.969774007797241, 2.891897201538086, 2.8161637783050537, 2.742522716522217, 2.670926094055176, 2.6013269424438477, 2.5336809158325195, 2.4679455757141113, 2.4040801525115967, 2.3420467376708984, 2.2818093299865723, 2.2233338356018066, 2.1665890216827393, 2.1115458011627197, 2.058178424835205, 2.006463050842285, 1.9563792943954468, 1.9079097509384155, 1.861040472984314, 1.8157612085342407, 1.7720656394958496, 1.7299518585205078, 1.689422607421875, 1.6504857540130615, 1.6131551265716553, 1.5774505138397217, 1.5433990955352783, 1.5110355615615845, 1.480403184890747, 1.4515552520751953, 1.4245554208755493, 1.399479627609253, 1.376417636871338, 1.3554739952087402, 1.33677077293396, 1.3204492330551147, 1.3066723346710205, 1.2956279516220093, 1.2875311374664307, 1.2826288938522339, 1.281203269958496, 1.2835763692855835, 1.2901153564453125, 1.3012385368347168, 1.317421793937683, 1.3392058610916138, 1.3672044277191162, 1.402113914489746, 1.4447228908538818, 1.4959237575531006, 1.556725263595581, 1.628265142440796, 1.7118253707885742, 1.8088473081588745, 1.920947790145874, 2.0499355792999268, 2.197828531265259, 2.366868734359741, 2.559537410736084, 2.778566598892212, 3.0269455909729004, 3.307921886444092, 3.624992847442627, 3.981884479522705, 4.382513999938965, 4.830931663513184, 5.331235885620117, 5.887457370758057, 6.50340461730957, 7.182467460632324, 7.927371978759766, 8.73989200592041, 9.62050724029541, 10.568037033081055, 11.579240798950195, 12.647491455078125, 13.763079643249512, 14.912983894348145, 16.0808162689209, 17.24702262878418, 18.389379501342773, 19.483823776245117, 20.505590438842773, 21.430625915527344, 22.237123489379883, 22.905603408813477, 23.421669006347656, 23.777124404907227, 23.97051429748535, 24.00705337524414, 23.897924423217773, 23.65907859802246, 23.309715270996094, 22.870668411254883, 22.36288070678711, 21.8061580657959, 21.218250274658203, 20.61431121826172, 20.00668716430664, 19.40496063232422, 18.81618309020996, 18.245222091674805, 17.695138931274414, 17.16756820678711, 16.663074493408203, 16.18144416809082, 15.721942901611328, 15.283499717712402, 14.864862442016602, 14.464703559875488, 14.081693649291992, 13.714554786682129, 13.362089157104492, 13.02319622039795, 12.696880340576172, 12.382248878479004, 12.078506469726562, 11.784954071044922, 11.500972747802734, 11.226018905639648, 10.959615707397461, 10.701342582702637, 10.45082950592041, 10.207748413085938, 9.971808433532715, 9.742749214172363, 9.520339012145996, 9.304367065429688, 9.09464168548584, 8.890989303588867, 8.693248748779297, 8.501274108886719, 8.314927101135254, 8.134079933166504, 7.958611011505127, 7.788407325744629, 7.623362064361572, 7.463373184204102, 7.308342456817627, 7.1563239097595215, 7.007151126861572, 6.860712051391602, 6.716935634613037, 6.575782299041748, 6.4372382164001465, 6.301304340362549, 6.167994499206543, 6.037330150604248, 5.909336566925049, 5.784041404724121, 5.661472797393799, 5.541658878326416, 5.424625396728516, 5.310398101806641, 5.198999404907227, 5.090452194213867, 4.984776496887207, 4.881992340087891, 4.7821197509765625, 4.685179233551025, 4.591190814971924, 4.500176906585693, 4.412162780761719, 4.327175140380859, 4.245244026184082, 4.166405200958252, 4.090697765350342, 4.018167018890381, 3.9488649368286133, 3.882850408554077, 3.820190668106079, 3.7609620094299316, 3.7052512168884277, 3.653156280517578, 3.6047873497009277, 3.5602688789367676, 3.519739866256714, 3.483356237411499, 3.4512925148010254, 3.4237422943115234, 3.400921583175659, 3.3830697536468506, 3.370452404022217, 3.3633627891540527, 3.3621251583099365, 3.3670966625213623, 3.378669500350952, 3.397274971008301, 3.4233856201171875, 3.457517385482788, 3.5002336502075195, 3.552147150039673, 3.6139228343963623, 3.6862804889678955, 3.76999568939209, 3.8659017086029053, 3.97489070892334, 4.097911357879639, 4.235968589782715, 4.390119552612305, 4.561467170715332, 4.751153945922852, 4.960348606109619, 5.190232276916504, 5.441980361938477, 5.716736793518066, 6.015588760375977, 6.339529037475586, 6.68941593170166, 7.065928936004639, 7.469512462615967, 7.900321006774902, 8.358155250549316, 8.842394828796387, 9.351937294006348, 9.8851318359375, 10.439724922180176, 11.012819290161133, 11.60084056854248, 12.199540138244629, 12.804012298583984, 13.408753395080566, 14.007752418518066, 14.594614028930664, 15.162726402282715, 15.705445289611816, 16.216312408447266, 16.689271926879883, 17.11888885498047, 17.41895866394043, 17.584535598754883, 17.618175506591797, 17.528932571411133, 17.330894470214844, 17.04149055480957, 16.679746627807617, 16.264724731445312, 15.814257621765137, 15.344085693359375, 14.867358207702637, 14.3944730758667, 13.933175086975098, 13.4888277053833, 13.064774513244629, 12.662734985351562, 12.283186912536621, 11.925711631774902, 11.589282035827637, 11.272500038146973, 10.973774909973145, 10.691455841064453, 10.42392635345459, 10.169663429260254, 9.927275657653809, 9.695521354675293, 9.473310470581055, 9.259705543518066, 9.053906440734863, 8.855244636535645, 8.663162231445312, 8.477201461791992, 8.296990394592285, 8.12222957611084, 7.952680587768555, 7.788155555725098, 7.628510475158691, 7.473635673522949, 7.323452472686768, 7.177906513214111, 7.03696346282959, 6.900609970092773, 6.768846035003662, 6.641688346862793, 6.519166469573975, 6.4013237953186035, 6.288216590881348, 6.179914474487305, 6.076500415802002, 5.9780731201171875, 5.8847455978393555, 5.7966485023498535, 5.713929653167725, 5.636756896972656, 5.565320014953613, 5.499830722808838, 5.440526962280273, 5.387673854827881, 5.341566562652588, 5.302532196044922, 5.270933628082275, 5.247171878814697, 5.231688499450684, 5.224969387054443, 5.227548599243164, 5.240009784698486, 5.262989521026611, 5.297181606292725, 5.343338489532471, 5.402273178100586, 5.474862098693848, 5.562044620513916, 5.664821147918701, 5.784254550933838, 5.9214630126953125, 6.077616214752197, 6.25392484664917, 6.4516282081604, 6.67197847366333, 6.916219234466553, 7.185559272766113, 7.481140613555908, 7.803997993469238, 8.155014991760254, 8.534872055053711, 8.943984985351562, 9.382441520690918, 9.849929809570312, 10.345667839050293, 10.868328094482422, 11.415972709655762, 11.985992431640625, 12.575060844421387, 13.179112434387207, 13.793342590332031, 14.412242889404297, 15.02967643737793, 15.63899040222168, 16.233165740966797, 16.80501937866211, 17.347412109375, 17.852548599243164, 18.31310272216797, 18.722522735595703, 19.075300216674805, 19.367204666137695, 19.595447540283203, 19.758758544921875, 19.857397079467773, 19.893051147460938, 19.86869239807129, 19.78835105895996, 19.65687370300293, 19.479658126831055, 19.26238441467285, 19.01079559326172, 18.730487823486328, 18.426761627197266, 18.104503631591797, 17.768117904663086, 17.42149543762207, 17.068004608154297, 16.710521697998047, 16.35145378112793, 15.992793083190918, 15.636168479919434, 15.282889366149902, 14.933998107910156, 14.590315818786621, 14.252481460571289, 13.920988082885742, 13.596209526062012, 13.278426170349121, 12.967849731445312, 12.664631843566895, 12.368886947631836, 12.080695152282715, 11.800114631652832, 11.527189254760742, 11.261954307556152, 11.004437446594238, 10.754666328430176, 10.512673377990723, 10.278493881225586, 10.05217170715332, 9.833761215209961, 9.623332023620605, 9.420967102050781, 9.226766586303711, 9.040854454040527, 8.863374710083008, 8.694499015808105, 8.53442668914795, 8.383389472961426, 8.241654396057129, 8.109524726867676, 7.987348556518555, 7.875517845153809, 7.774474620819092, 7.684712886810303, 7.606785774230957, 7.541306495666504, 7.488953113555908, 7.450472354888916, 7.426682949066162, 7.418476104736328, 7.426819801330566, 7.452756881713867, 7.497405052185059, 7.561951160430908, 7.647647857666016, 7.755803108215332, 7.887765407562256, 8.044907569885254, 8.228602409362793, 8.440191268920898, 8.680949211120605, 8.95203685760498, 9.254448890686035, 9.588950157165527, 9.95600414276123, 10.355697631835938, 10.787652015686035, 11.250936508178711, 11.74398422241211, 12.264503479003906, 12.80941390991211, 13.374789237976074, 13.955836296081543, 14.54690170288086, 15.141528129577637, 15.732549667358398, 16.3122501373291, 16.872562408447266, 17.405315399169922, 17.902515411376953, 18.356651306152344, 18.760990142822266, 19.109844207763672, 19.398818969726562, 19.624954223632812, 19.78683090209961, 19.88455581665039, 19.919689178466797, 19.895084381103516, 19.814672470092773, 19.682546615600586, 19.50347328186035, 19.282665252685547, 19.025548934936523, 18.737567901611328, 18.423995971679688, 18.089815139770508, 17.73961067199707, 17.377504348754883, 17.007139205932617, 16.63166618347168, 16.253761291503906, 15.8756685256958, 15.49923038482666, 15.12593936920166, 14.756982803344727, 14.393287658691406, 14.035563468933105, 13.68433952331543, 13.34000015258789, 13.002809524536133, 12.672937393188477, 12.350480079650879, 12.03547477722168, 11.727913856506348, 11.427756309509277, 11.134932518005371, 10.849357604980469, 10.570927619934082, 10.299530982971191, 10.035048484802246, 9.777355194091797, 9.526323318481445, 9.28182315826416, 9.04372501373291, 8.811898231506348, 8.586214065551758, 8.366544723510742, 8.152762413024902, 7.944743633270264, 7.74236536026001, 7.54550838470459, 7.354054927825928, 7.1678900718688965, 6.98690128326416, 6.810979843139648, 6.640019416809082, 6.473916530609131, 6.312570571899414, 6.155884265899658, 6.003763198852539, 5.85611629486084, 5.712855339050293, 5.57389497756958, 5.43915319442749, 5.30855131149292, 5.182013034820557, 5.059464931488037, 4.940837860107422, 4.826064109802246, 4.715079307556152, 4.607821941375732, 4.504233360290527, 4.404257774353027, 4.307840824127197, 4.214932441711426, 4.12548303604126, 4.039446830749512, 3.9567792415618896, 3.8774378299713135, 3.801382303237915, 3.728573799133301, 3.6589748859405518, 3.5925495624542236, 3.5292630195617676, 3.469081163406372, 3.411970376968384, 3.357897996902466, 3.306830406188965, 3.258735179901123, 3.213578224182129, 3.17069149017334, 3.1300203800201416, 3.0915277004241943, 3.055192470550537, 3.0210070610046387, 2.9889771938323975, 2.9591195583343506, 2.9314615726470947, 2.906041145324707, 2.8829054832458496, 2.8621115684509277, 2.8437254428863525, 2.827822208404541, 2.8144869804382324, 2.80381441116333, 2.7959089279174805, 2.7908852100372314, 2.7888693809509277, 2.789998769760132, 2.7944223880767822, 2.802302360534668, 2.813814163208008, 2.8291473388671875, 2.8485066890716553, 2.8721120357513428, 2.900200366973877, 2.9330263137817383, 2.9708621501922607, 3.0139992237091064, 3.062748908996582, 3.1174423694610596, 3.178431749343872, 3.2460906505584717, 3.3208134174346924, 3.403015613555908, 3.4931328296661377, 3.5916213989257812, 3.6989552974700928, 3.815624713897705, 3.942134380340576, 4.078998565673828, 4.226738452911377, 4.385876178741455, 4.556927680969238, 4.740396976470947, 4.936764717102051, 5.146480560302734, 5.369948863983154, 5.607515811920166, 5.859455108642578, 6.125951766967773, 6.4070820808410645, 6.7027974128723145, 7.012903213500977, 7.337038516998291, 7.674659252166748, 8.025017738342285, 8.387147903442383, 8.759849548339844, 9.141684532165527, 9.530969619750977, 9.92577838897705, 10.323954582214355, 10.723128318786621, 11.120745658874512, 11.51409912109375, 11.90038013458252, 12.276724815368652, 12.640274047851562, 12.988237380981445, 13.31795597076416, 13.626967430114746, 13.91306209564209, 14.174342155456543, 14.409258842468262, 14.616646766662598, 14.795745849609375, 14.946200370788574, 15.068058967590332, 15.161746978759766, 15.22803783416748, 15.268013000488281, 15.283016204833984, 15.2746000289917, 15.24448013305664, 15.194480895996094, 15.126492500305176, 15.042427062988281, 14.944186210632324, 14.83362865447998, 14.71254825592041, 14.582656860351562, 14.445575714111328, 14.302824020385742, 14.15582275390625, 14.005891799926758, 13.854255676269531, 13.702051162719727, 13.550332069396973, 13.400077819824219, 13.252204895019531, 13.107337951660156, 12.966053009033203, 12.828890800476074, 12.69613265991211, 12.568024635314941, 12.444780349731445, 12.326581001281738, 12.213581085205078, 12.10590648651123, 12.003657341003418, 11.906907081604004, 11.815705299377441, 11.730079650878906, 11.650029182434082, 11.57553482055664, 11.506549835205078, 11.443005561828613, 11.384808540344238, 11.331843376159668, 11.283967018127441, 11.241015434265137, 11.202798843383789, 11.16910171508789, 11.139688491821289, 11.114294052124023, 11.092635154724121, 11.074402809143066, 11.059267044067383, 11.04687786102295, 11.036867141723633, 11.028848648071289, 11.022422790527344, 11.017176628112793, 11.012688636779785, 11.008530616760254, 11.00426959991455, 10.999476432800293, 10.993721008300781, 10.98658561706543, 10.977660179138184, 10.966550827026367, 10.952881813049316, 10.936300277709961, 10.916475296020508, 10.893108367919922, 10.865925788879395, 10.834691047668457, 10.799200057983398, 10.759282112121582, 10.714805603027344, 10.665672302246094, 10.611823081970215, 10.553231239318848, 10.48990535736084, 10.421886444091797, 10.349247932434082, 10.272088050842285, 10.190535545349121, 10.10473918914795, 10.014871597290039, 9.921120643615723, 9.823690414428711, 9.722799301147461, 9.618673324584961, 9.511547088623047, 9.401658058166504, 9.289249420166016, 9.174561500549316, 9.05783462524414, 8.939305305480957, 8.819208145141602, 8.69776725769043, 8.571085929870605, 8.439717292785645, 8.304280281066895, 8.165427207946777, 8.02381706237793, 7.880097389221191, 7.734885215759277, 7.588758945465088, 7.442251682281494, 7.295848846435547, 7.149985313415527, 7.0050482749938965, 6.8613786697387695, 6.719273567199707, 6.578991889953613, 6.440755844116211, 6.304756164550781, 6.1711554527282715, 6.040092468261719, 5.911684989929199, 5.7860331535339355, 5.66322135925293, 5.5433220863342285, 5.426397800445557, 5.312502861022949, 5.201685905456543, 5.093989849090576, 4.989455699920654, 4.88812255859375, 4.790030002593994, 4.695217132568359, 4.603726387023926, 4.515603065490723, 4.430896759033203, 4.3496623039245605, 4.271961688995361, 4.197864055633545, 4.127448081970215, 4.060801982879639, 3.998025894165039, 3.939232349395752, 3.8845481872558594, 3.8341164588928223, 3.788097858428955, 3.7466723918914795, 3.710041046142578, 3.678428888320923, 3.6520862579345703, 3.6312925815582275, 3.61635684967041, 3.6076228618621826, 3.6054704189300537, 3.610318899154663, 3.6226305961608887, 3.6429147720336914, 3.671729564666748, 3.709686756134033, 3.7574548721313477, 3.8157618045806885, 3.8853988647460938, 3.9672224521636963, 4.0621562004089355, 4.1711931228637695, 4.295392990112305, 4.435883522033691, 4.593855857849121, 4.770557403564453, 4.967284202575684, 5.185368537902832, 5.426161289215088, 5.69101095199585, 5.981234550476074, 6.298086643218994, 6.642714977264404, 7.016113758087158, 7.419065952301025, 7.852081775665283, 8.315324783325195, 8.808537483215332, 9.330962181091309, 9.881258964538574, 10.457433700561523, 11.056767463684082, 11.67577075958252, 12.310151100158691, 12.954815864562988, 13.603914260864258, 14.250910758972168, 14.888714790344238, 15.509849548339844, 16.106666564941406, 16.671585083007812, 17.197368621826172, 17.677391052246094, 18.10589599609375, 18.47821617126465, 18.79095458984375, 19.042083740234375, 19.230987548828125, 19.35841178894043, 19.426361083984375, 19.43715476989746, 19.394075393676758, 19.30118751525879, 19.163116455078125, 18.984840393066406, 18.77147674560547, 18.528108596801758, 18.2596435546875, 17.97068214416504, 17.665456771850586, 17.3477725982666, 17.020999908447266, 16.688066482543945, 16.351482391357422, 16.013376235961914, 15.675520896911621, 15.339391708374023, 15.00619125366211, 14.676901817321777, 14.352312088012695, 14.03305721282959, 13.719643592834473, 13.412474632263184, 13.111870765686035, 12.818087577819824, 12.531329154968262, 12.251763343811035, 11.979525566101074, 11.71473217010498, 11.457486152648926, 11.207880020141602, 10.966002464294434, 10.73194408416748, 10.505797386169434, 10.287664413452148, 10.077655792236328, 9.875895500183105, 9.682524681091309, 9.497700691223145, 9.321606636047363, 9.154446601867676, 8.996455192565918, 8.847894668579102, 8.709063529968262, 8.58029556274414, 8.461966514587402, 8.354493141174316, 8.258341789245605, 8.174026489257812, 8.102115631103516, 8.043235778808594, 7.998067855834961, 7.967357158660889, 7.951910495758057, 7.952597141265869, 7.970347881317139, 8.006153106689453, 8.061059951782227, 8.136163711547852, 8.232596397399902, 8.351520538330078, 8.49410343170166, 8.66150188446045, 8.854830741882324, 9.075132369995117, 9.323336601257324, 9.600212097167969, 9.906316757202148, 10.241935729980469]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('90eb7b0c-ff92-438a-8f70-6c4c069612d7');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Selecting the z-axis and the label rho
    X = point_cloud[:,2]
    y = point_cloud[:,3]

.. code:: ipython3

    fig = px.line(title='Trajectory of the Lorenz solution, projected along the z-axis')
    fig.add_scatter(y=X, name='X')
    fig.add_scatter(y=y, name='y')
    fig.show()



.. raw:: html

    <div>
    
    
                <div id="cbe0859b-66a2-4562-afb2-2876abcc7740" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("cbe0859b-66a2-4562-afb2-2876abcc7740")) {
                        Plotly.newPlot(
                            'cbe0859b-66a2-4562-afb2-2876abcc7740',
                            [{"name": "X", "type": "scatter", "y": [10.0, 9.633333206176758, 9.386394500732422, 9.242918014526367, 9.186662673950195, 9.202041625976562, 9.27444076538086, 9.390336990356445, 9.537337303161621, 9.704184532165527, 9.880752563476562, 10.058052062988281, 10.228242874145508, 10.384649276733398, 10.521770477294922, 10.635278701782227, 10.721994400024414, 10.779839515686035, 10.807765007019043, 10.805652618408203, 10.774194717407227, 10.714761734008789, 10.62926197052002, 10.519996643066406, 10.38952922821045, 10.240555763244629, 10.075801849365234, 9.897931098937988, 9.709478378295898, 9.512795448303223, 9.310019493103027, 9.103057861328125, 8.893577575683594, 8.683015823364258, 8.472585678100586, 8.263300895690918, 8.055986404418945, 7.8513078689575195, 7.649787902832031, 7.4518280029296875, 7.257726669311523, 7.067698001861572, 6.881886005401611, 6.700377941131592, 6.523214817047119, 6.350402355194092, 6.181918621063232, 6.017719268798828, 5.8577446937561035, 5.701923370361328, 5.550174236297607, 5.402411937713623, 5.258546352386475, 5.118484973907471, 4.982136249542236, 4.8494062423706055, 4.720202922821045, 4.594435691833496, 4.472014427185059, 4.352851867675781, 4.236861705780029, 4.123960494995117, 4.014066219329834, 3.9070987701416016, 3.802980661392212, 3.7016360759735107, 3.6029913425445557, 3.506974697113037, 3.413516044616699, 3.322547674179077, 3.2340033054351807, 3.1478183269500732, 3.063930034637451, 2.9822776317596436, 2.902801275253296, 2.8254435062408447, 2.750147819519043, 2.6768593788146973, 2.605525016784668, 2.536092519760132, 2.4685113430023193, 2.4027326107025146, 2.33870792388916, 2.27639102935791, 2.2157363891601562, 2.1566996574401855, 2.0992379188537598, 2.043309450149536, 1.9888733625411987, 1.9358899593353271, 1.8843207359313965, 1.8341280221939087, 1.7852754592895508, 1.737727403640747, 1.6914492845535278, 1.6464074850082397, 1.602569341659546, 1.5599029064178467, 1.5183770656585693, 1.4779620170593262, 1.4386281967163086, 1.400347113609314, 1.3630911111831665, 1.3268332481384277, 1.2915472984313965, 1.2572078704833984, 1.223790168762207, 1.1912702322006226, 1.1596245765686035, 1.1288305521011353, 1.09886634349823, 1.0697104930877686, 1.0413423776626587, 1.0137418508529663, 0.9868895411491394, 0.9607666730880737, 0.9353550672531128, 0.9106371402740479, 0.8865960240364075, 0.8632153868675232, 0.8404794931411743, 0.8183733224868774, 0.7968823909759521, 0.7759929895401001, 0.7556918859481812, 0.7359667420387268, 0.7168057560920715, 0.6981979012489319, 0.6801329255104065, 0.6626012921333313, 0.6455944180488586, 0.629104495048523, 0.6131247878074646, 0.5976493954658508, 0.5826737284660339, 0.5681941509246826, 0.554208517074585, 0.5407159328460693, 0.5277171730995178, 0.5152145624160767, 0.5032125115394592, 0.4917173683643341, 0.4807378947734833, 0.47028541564941406, 0.4603741765022278, 0.4510217308998108, 0.4422492980957031, 0.4340822696685791, 0.4265507459640503, 0.4196900725364685, 0.413541704416275, 0.4081538915634155, 0.4035826325416565, 0.39989277720451355, 0.3971591889858246, 0.39546826481819153, 0.39491933584213257, 0.3956267535686493, 0.3977218270301819, 0.4013552963733673, 0.4067001938819885, 0.41395488381385803, 0.4233468472957611, 0.4351368248462677, 0.44962358474731445, 0.4671494662761688, 0.48810654878616333, 0.5129439234733582, 0.5421757102012634, 0.5763903856277466, 0.6162614226341248, 0.6625589728355408, 0.7161632776260376, 0.7780799269676208, 0.8494565486907959, 0.9316015839576721, 1.026004672050476, 1.134359359741211, 1.25858736038208, 1.4008638858795166, 1.5636451244354248, 1.749694585800171, 1.9621096849441528, 2.204345703125, 2.4802348613739014, 2.7939980030059814, 3.150244951248169, 3.5539591312408447, 4.010456562042236, 4.525319576263428, 5.103882312774658, 5.751290798187256, 6.472250938415527, 7.270702362060547, 8.149422645568848, 9.109554290771484, 10.150078773498535, 11.267242431640625, 12.453990936279297, 13.699466705322266, 14.98863410949707, 16.302143096923828, 17.61650276184082, 18.90468978881836, 20.137178421020508, 21.283472061157227, 22.31396484375, 23.202045440673828, 23.926145553588867, 24.471487045288086, 24.83124542236328, 25.00693702697754, 25.007980346679688, 24.85049057006836, 24.447050094604492, 23.845436096191406, 23.101797103881836, 22.27326011657715, 21.41190528869629, 20.560802459716797, 19.75218963623047, 19.007434844970703, 18.33819580078125, 17.74823570251465, 17.23539924621582, 16.79347801208496, 16.413793563842773, 16.086444854736328, 15.80125904083252, 15.548439979553223, 15.319019317626953, 15.10511589050293, 14.900068283081055, 14.698471069335938, 14.496137619018555, 14.290006637573242, 14.078025817871094, 13.859007835388184, 13.632481575012207, 13.398544311523438, 13.157721519470215, 12.910845756530762, 12.658940315246582, 12.4031343460083, 12.144586563110352, 11.88443374633789, 11.623746871948242, 11.363509178161621, 11.104598999023438, 10.847782135009766, 10.593717575073242, 10.34295654296875, 10.095954895019531, 9.853079795837402, 9.614623069763184, 9.38080883026123, 9.151805877685547, 8.927734375, 8.708678245544434, 8.494686126708984, 8.285785675048828, 8.08198070526123, 7.8832621574401855, 7.689608097076416, 7.500988960266113, 7.317368984222412, 7.138708114624023, 6.964966297149658, 6.7961015701293945, 6.63207483291626, 6.472849369049072, 6.3183913230896, 6.16867208480835, 6.023670196533203, 5.883369445800781, 5.747763156890869, 5.616852760314941, 5.490652084350586, 5.369184494018555, 5.252487659454346, 5.140614986419678, 5.03363561630249, 4.931637287139893, 4.834728717803955, 4.743041515350342, 4.656733512878418, 4.575991630554199, 4.501034736633301, 4.432117462158203, 4.369535446166992, 4.313628673553467, 4.264787197113037, 4.223456859588623, 4.1901469230651855, 4.16543436050415, 4.1499738693237305, 4.144505023956299, 4.149862766265869, 4.166985034942627, 4.196924686431885, 4.2408599853515625, 4.30010461807251, 4.376121520996094, 4.4705305099487305, 4.585119724273682, 4.721855163574219, 4.882884979248047, 5.07054328918457, 5.287347316741943, 5.5359883308410645, 5.819314479827881, 6.14030122756958, 6.502006530761719, 6.907512664794922, 7.359842777252197, 7.861410140991211, 8.414163589477539, 9.019405364990234, 9.677579879760742, 10.388045310974121, 11.148825645446777, 11.956376075744629, 12.805355072021484, 13.688455581665039, 14.596298217773438, 15.517441749572754, 16.438518524169922, 17.344539642333984, 18.219356536865234, 19.046306610107422, 19.808977127075195, 20.4920597076416, 21.082212448120117, 21.568851470947266, 21.944761276245117, 22.206478118896484, 22.354393005371094, 22.39253807067871, 22.32813835144043, 22.17093276977539, 21.932401657104492, 21.624954223632812, 21.261184692382812, 20.853225708007812, 20.41227912902832, 19.948291778564453, 19.46979522705078, 18.983863830566406, 18.496177673339844, 18.011154174804688, 17.532102584838867, 17.061410903930664, 16.60071563720703, 16.151058197021484, 15.713032722473145, 15.286897659301758, 14.872671127319336, 14.470210075378418, 14.079261779785156, 13.69951057434082, 13.330605506896973, 12.972182273864746, 12.623878479003906, 12.28533935546875, 11.956225395202637, 11.636214256286621, 11.32500171661377, 11.022299766540527, 10.727837562561035, 10.44135856628418, 10.162620544433594, 9.89139461517334, 9.627461433410645, 9.370612144470215, 9.120646476745605, 8.877372741699219, 8.640604972839355, 8.410164833068848, 8.185880661010742, 7.967584609985352, 7.755115032196045, 7.54831600189209, 7.347034454345703, 7.151122570037842, 6.960436820983887, 6.774837017059326, 6.594188213348389, 6.418358325958252, 6.247217655181885, 6.080642223358154, 5.9185099601745605, 5.760702610015869, 5.607104778289795, 5.457604885101318, 5.312093257904053, 5.170464038848877, 5.032614231109619, 4.89844274520874, 4.767852306365967, 4.640747547149658, 4.517035961151123, 4.396626949310303, 4.279433727264404, 4.165370464324951, 4.054354190826416, 3.9463047981262207, 3.8411431312561035, 3.73879337310791, 3.639181137084961, 3.542234182357788, 3.447882652282715, 3.356058120727539, 3.2666945457458496, 3.179727554321289, 3.0950944423675537, 3.0127344131469727, 2.932588815689087, 2.854600191116333, 2.7787132263183594, 2.7048628330230713, 2.6329939365386963, 2.563053846359253, 2.494990825653076, 2.428755283355713, 2.3642985820770264, 2.3015737533569336, 2.240535259246826, 2.1811389923095703, 2.1233417987823486, 2.0671021938323975, 2.0123798847198486, 1.9591355323791504, 1.9073313474655151, 1.8569303750991821, 1.8078972101211548, 1.7601971626281738, 1.7137969732284546, 1.6686643362045288, 1.6247680187225342, 1.582077980041504, 1.5405652523040771, 1.500201940536499, 1.4609612226486206, 1.422817349433899, 1.385745882987976, 1.349723219871521, 1.3147271871566772, 1.2807364463806152, 1.247731328010559, 1.2156929969787598, 1.184604287147522, 1.1544491052627563, 1.1252130270004272, 1.096882939338684, 1.06944739818573, 1.0428967475891113, 1.0172232389450073, 0.9924208521842957, 0.9684858918190002, 0.9454169273376465, 0.9232151508331299, 0.9018843173980713, 0.8814314603805542, 0.8618668913841248, 0.8432045578956604, 0.8254625797271729, 0.8086637854576111, 0.7928358316421509, 0.7780122756958008, 0.7642330527305603, 0.7515450716018677, 0.7400033473968506, 0.7296720147132874, 0.7206251621246338, 0.7129483819007874, 0.706740140914917, 0.7021135091781616, 0.6991978287696838, 0.6981412768363953, 0.6991127729415894, 0.702305257320404, 0.7079384922981262, 0.7162626385688782, 0.7275625467300415, 0.7421621084213257, 0.7604293823242188, 0.7827826142311096, 0.8096965551376343, 0.8417100310325623, 0.8794340491294861, 0.9235610365867615, 0.9748752117156982, 1.0342637300491333, 1.102729082107544, 1.1814032793045044, 1.271561861038208, 1.3746397495269775, 1.4922486543655396, 1.6261932849884033, 1.778489351272583, 1.9513802528381348, 2.147352695465088, 2.3691492080688477, 2.6197783946990967, 2.9025161266326904, 3.220900058746338, 3.5787124633789062, 3.9799439907073975, 4.428741455078125, 4.929324150085449, 5.485874652862549, 6.102384090423584, 6.7824602127075195, 7.529083251953125, 8.344313621520996, 9.228950500488281, 10.182148933410645, 11.201011657714844, 12.28018569946289, 13.411492347717285, 14.582544326782227, 15.777406692504883, 16.976709365844727, 18.15807342529297, 19.29688262939453, 20.367401123046875, 21.344196319580078, 22.203765869140625, 22.926164627075195, 23.49649429321289, 23.905990600585938, 24.152591705322266, 24.24087142944336, 24.181373596191406, 23.989431381225586, 23.683673858642578, 23.28443145751953, 22.812232971191406, 22.28656005859375, 21.724946975708008, 21.142423629760742, 20.551300048828125, 19.96121597290039, 19.379352569580078, 18.810773849487305, 18.258787155151367, 17.725330352783203, 17.2112979888916, 16.716835021972656, 16.2415771484375, 15.784836769104004, 15.345739364624023, 14.923327445983887, 14.516627311706543, 14.124700546264648, 13.746663093566895, 13.381706237792969, 13.029098510742188, 12.688186645507812, 12.358393669128418, 12.039207458496094, 11.730180740356445, 11.430919647216797, 11.141081809997559, 10.860363960266113, 10.588504791259766, 10.325275421142578, 10.070476531982422, 9.82394027709961, 9.58552074432373, 9.355100631713867, 9.132583618164062, 8.917898178100586, 8.710996627807617, 8.511855125427246, 8.320472717285156, 8.136877059936523, 7.961122512817383, 7.793291091918945, 7.633497714996338, 7.48189115524292, 7.3386549949646, 7.204014301300049, 7.078235626220703, 6.961633682250977, 6.8545732498168945, 6.757473945617676, 6.670816421508789, 6.595146656036377, 6.531079292297363, 6.479306697845459, 6.440601825714111, 6.415823936462402, 6.4059247970581055, 6.411952495574951, 6.435056209564209, 6.476487159729004, 6.537601947784424, 6.619859218597412, 6.72481632232666, 6.854121208190918, 7.009498596191406, 7.192732810974121, 7.405639171600342, 7.650031089782715, 7.927675247192383, 8.240233421325684, 8.589198112487793, 8.975807189941406, 9.40095043182373, 9.86506462097168, 10.368008613586426, 10.908944129943848, 11.486201286315918, 12.097158432006836, 12.738128662109375, 13.404279708862305, 14.089580535888672, 14.786811828613281, 15.487629890441895, 16.18271255493164, 16.861984252929688, 17.51491355895996, 18.130884170532227, 18.699621200561523, 19.211633682250977, 19.65865135192871, 20.034011840820312, 20.33296012878418, 20.55284309387207, 20.693172454833984, 20.755544662475586, 20.743444442749023, 20.661945343017578, 20.517343521118164, 20.316757202148438, 20.067733764648438, 19.777896881103516, 19.454635620117188, 19.104875564575195, 18.73451805114746, 18.348861694335938, 17.95256233215332, 17.54962158203125, 17.143409729003906, 16.736719131469727, 16.331806182861328, 15.930471420288086, 15.53411865234375, 15.143818855285645, 14.760367393493652, 14.384334564208984, 14.01611614227295, 13.655963897705078, 13.304019927978516, 12.960344314575195, 12.624933242797852, 12.297734260559082, 11.978662490844727, 11.667604446411133, 11.364433288574219, 11.069007873535156, 10.781180381774902, 10.500798225402832, 10.227705001831055, 9.961746215820312, 9.702765464782715, 9.45060920715332, 9.205124855041504, 8.966163635253906, 8.7335786819458, 8.507225036621094, 8.286962509155273, 8.072652816772461, 7.864161014556885, 7.661357402801514, 7.464113235473633, 7.272304058074951, 7.085809707641602, 6.904512882232666, 6.728298664093018, 6.557057857513428, 6.390683174133301, 6.229071617126465, 6.0721235275268555, 5.919742584228516, 5.771836757659912, 5.628316402435303, 5.489096641540527, 5.354095458984375, 5.223234176635742, 5.096438407897949, 4.973637104034424, 4.854762077331543, 4.73923397064209, 4.626937389373779, 4.5177717208862305, 4.411647796630859, 4.3084869384765625, 4.208218574523926, 4.110780715942383, 4.016116619110107, 3.9241764545440674, 3.8349153995513916, 3.748293161392212, 3.664273977279663, 3.582826852798462, 3.5039238929748535, 3.4275424480438232, 3.3536629676818848, 3.282271146774292, 3.213355779647827, 3.146911144256592, 3.0829358100891113, 3.0214335918426514, 2.9624133110046387, 2.9058899879455566, 2.851884603500366, 2.800424814224243, 2.7515456676483154, 2.7052900791168213, 2.6617090702056885, 2.620863437652588, 2.5828239917755127, 2.5476725101470947, 2.515502691268921, 2.486421823501587, 2.4605510234832764, 2.4380276203155518, 2.419006109237671, 2.4036595821380615, 2.392181873321533, 2.384789228439331, 2.3817226886749268, 2.3832499980926514, 2.3896679878234863, 2.401305913925171, 2.418527126312256, 2.441732883453369, 2.471365213394165, 2.5079102516174316, 2.55190110206604, 2.603921890258789, 2.664611577987671, 2.7298264503479004, 2.799252510070801, 2.8726344108581543, 2.9497649669647217, 3.030478000640869, 3.1146421432495117, 3.202155113220215, 3.292938470840454, 3.386934757232666, 3.484102249145508, 3.5844130516052246, 3.687849760055542, 3.794402837753296, 3.9040679931640625, 4.016845226287842, 4.132735729217529, 4.251739025115967, 4.373854637145996, 4.4990763664245605, 4.6273932456970215, 4.758786678314209, 4.893230438232422, 5.03068733215332, 5.171109676361084, 5.3144354820251465, 5.460590362548828, 5.609485149383545, 5.761012554168701, 5.915050983428955, 6.07145881652832, 6.230078220367432, 6.3907318115234375, 6.553222179412842, 6.7173357009887695, 6.882837295532227, 7.049476146697998, 7.216982364654541, 7.385071277618408, 7.553442001342773, 7.721780776977539, 7.8897624015808105, 8.057051658630371, 8.223307609558105, 8.388184547424316, 8.551334381103516, 8.712409973144531, 8.871070861816406, 9.026981353759766, 9.17982006072998, 9.329275131225586, 9.475055694580078, 9.616887092590332, 9.754520416259766, 9.88772964477539, 10.016317367553711, 10.14011287689209, 10.258978843688965, 10.372809410095215, 10.481529235839844, 10.585098266601562, 10.683509826660156, 10.776787757873535, 10.864991188049316, 10.94820785522461, 11.026556968688965, 11.100187301635742, 11.169272422790527, 11.234013557434082, 11.294632911682129, 11.3513765335083, 11.40450668334961, 11.454305648803711, 11.501069068908691, 11.545106887817383, 11.586739540100098, 11.626296997070312, 11.664118766784668, 11.70054817199707, 11.735933303833008, 11.770627975463867, 11.804986000061035, 11.839362144470215, 11.874112129211426, 11.909590721130371, 11.946147918701172, 11.98413372039795, 12.023893356323242, 12.065767288208008, 12.110091209411621, 12.157194137573242, 12.207396507263184, 12.261012077331543, 12.318346977233887, 12.379693031311035, 12.445332527160645, 12.515535354614258, 12.590555191040039, 12.67063045501709, 12.755980491638184, 12.84680461883545, 12.943281173706055, 13.045150756835938, 13.152084350585938, 13.263675689697266, 13.379448890686035, 13.498858451843262, 13.621294975280762, 13.746084213256836, 13.872498512268066, 13.999760627746582, 14.127050399780273, 14.253515243530273, 14.378279685974121, 14.50045394897461, 14.619150161743164, 14.73348617553711, 14.842605590820312, 14.945687294006348, 15.041952133178711, 15.130681991577148, 15.211224555969238, 15.283002853393555, 15.345524787902832, 15.39838695526123, 15.441279411315918, 15.473989486694336, 15.496397972106934, 15.50848388671875, 15.51031494140625, 15.50204849243164, 15.48392391204834, 15.456252098083496, 15.419414520263672, 15.37385082244873, 15.320049285888672, 15.25854206085205, 15.18989372253418, 15.11469554901123, 15.033555030822754, 14.94709300994873, 14.85593318939209, 14.760699272155762, 14.662009239196777, 14.560473442077637, 14.456686973571777, 14.351232528686523, 14.244672775268555, 14.137554168701172, 14.030401229858398, 13.923722267150879, 13.818001747131348, 13.713706016540527, 13.611281394958496, 13.511154174804688, 13.413735389709473, 13.319415092468262, 13.228567123413086, 13.14155101776123, 13.058707237243652, 12.980364799499512, 12.90683650970459, 12.838420867919922, 12.775403022766113, 12.71805477142334, 12.666632652282715, 12.621380805969238, 12.582527160644531, 12.550284385681152, 12.524847984313965, 12.50639820098877, 12.495092391967773, 12.491069793701172, 12.49444580078125, 12.505311012268066, 12.523727416992188, 12.549729347229004, 12.5833158493042, 12.624452590942383, 12.673066139221191, 12.729040145874023, 12.792217254638672, 12.86238956451416, 12.939302444458008, 13.022647857666016, 13.112066268920898, 13.207141876220703, 13.307403564453125, 13.412324905395508, 13.521327018737793, 13.633776664733887, 13.748991012573242, 13.866243362426758, 13.984766006469727, 14.103755950927734, 14.22238540649414, 14.339804649353027, 14.455156326293945, 14.567583084106445, 14.676238059997559, 14.780293464660645, 14.87895393371582, 14.971468925476074, 15.057135581970215, 15.13531494140625, 15.205436706542969, 15.267007827758789, 15.31961727142334, 15.36293888092041, 15.396737098693848, 15.420866012573242, 15.435267448425293, 15.439970016479492, 15.435088157653809, 15.42081069946289, 15.397401809692383, 15.365190505981445, 15.324563026428223, 15.275958061218262, 15.219857215881348, 15.15677547454834, 15.087258338928223, 15.011869430541992, 14.93118953704834, 14.845804214477539, 14.756304740905762, 14.663278579711914, 14.567307472229004, 14.468962669372559, 14.368805885314941, 14.267382621765137, 14.165221214294434, 14.062835693359375, 13.960719108581543, 13.859349250793457, 13.75918197631836, 13.66065788269043, 13.564197540283203, 13.47020435333252, 13.379064559936523, 13.29114818572998, 13.206809997558594, 13.126387596130371, 13.05020523071289, 12.978570938110352, 12.911781311035156, 12.850115776062012, 12.793840408325195, 12.743209838867188, 12.698461532592773, 12.659817695617676, 12.627486228942871, 12.60165786743164, 12.58250617980957, 12.570185661315918, 12.564828872680664, 12.566546440124512, 12.57542610168457, 12.591526985168457, 12.61488151550293, 12.645488739013672, 12.683314323425293, 12.728289604187012, 12.780303001403809, 12.839204788208008, 12.904799461364746, 12.976844787597656, 13.05505084991455, 13.139078140258789, 13.228536605834961, 13.322983741760254, 13.42192554473877, 13.524818420410156, 13.631070137023926, 13.740041732788086, 13.851054191589355, 13.963386535644531, 14.07629108428955, 14.18898868560791, 14.300687789916992, 14.410581588745117, 14.517867088317871, 14.621745109558105, 14.721437454223633, 14.816192626953125, 14.905296325683594, 14.988080978393555, 15.063932418823242, 15.132302284240723, 15.192708015441895, 15.244745254516602, 15.288086891174316, 15.322486877441406, 15.347784042358398, 15.363899230957031, 15.370832443237305, 15.36866569519043, 15.357551574707031, 15.337715148925781, 15.309441566467285, 15.273075103759766, 15.229009628295898, 15.177682876586914, 15.11956787109375, 15.05516529083252, 14.985001564025879, 14.90961742401123, 14.829564094543457, 14.745399475097656, 14.623223304748535, 14.463884353637695, 14.269842147827148, 14.044723510742188, 13.792901992797852, 13.519125938415527, 13.228192329406738, 12.92470645904541, 12.612897872924805, 12.2965087890625, 11.978742599487305, 11.66224479675293, 11.34913444519043, 11.041044235229492, 10.739182472229004, 10.444395065307617, 10.157230377197266, 9.877997398376465, 9.60682201385498, 9.343692779541016, 9.088496208190918, 8.84105110168457, 8.6011323928833, 8.368488311767578, 8.142858505249023, 7.923975944519043, 7.711583137512207, 7.505430221557617, 7.30527925491333, 7.110906600952148, 6.922101974487305, 6.738667964935303, 6.560421466827393, 6.387190341949463, 6.218814373016357, 6.055142879486084, 5.896035671234131, 5.741359710693359, 5.5909905433654785, 5.444810390472412, 5.302708148956299, 5.164579391479492, 5.030323505401611, 4.899847507476807, 4.773062229156494, 4.64988374710083, 4.530232906341553, 4.414035797119141, 4.301223278045654, 4.191730499267578, 4.085498809814453, 3.982473134994507, 3.8826050758361816, 3.78585147857666, 3.6921751499176025, 3.6015448570251465, 3.51393723487854, 3.429335117340088, 3.3477299213409424, 3.2691214084625244, 3.193519353866577, 3.120943307876587, 3.051424980163574, 2.9850077629089355, 2.921750545501709, 2.861726760864258, 2.805027723312378, 2.7517647743225098, 2.7020702362060547, 2.656102180480957, 2.6140453815460205, 2.576115846633911, 2.542564868927002, 2.5136826038360596, 2.4898035526275635, 2.4713127613067627, 2.4586503505706787, 2.4523203372955322, 2.4528980255126953, 2.46103835105896, 2.4774858951568604, 2.5030860900878906, 2.538796901702881, 2.5857014656066895, 2.6450228691101074, 2.7181384563446045, 2.80659556388855, 2.9121286869049072, 3.036674737930298, 3.1823902130126953, 3.3516645431518555, 3.547133684158325, 3.7716867923736572, 4.028470039367676, 4.32088041305542, 4.652546405792236, 5.027299404144287, 5.449118614196777, 5.922054767608643, 6.4501261711120605, 7.037173271179199, 7.686159610748291, 8.39925479888916, 9.177534103393555, 10.020636558532715, 10.926399230957031, 11.890491485595703, 12.813940048217773, 13.669175148010254, 14.431827545166016, 15.081947326660156, 15.605043411254883, 15.99278736114502, 16.243234634399414, 16.360532760620117, 16.354135513305664, 16.237632751464844, 16.027368545532227, 15.741020202636719, 15.3962984085083, 15.009894371032715, 14.596718788146973, 14.169466018676758, 13.738438606262207, 13.311601638793945, 12.894783973693848, 12.491965293884277, 12.105606079101562, 11.736970901489258, 11.386423110961914, 11.05368423461914, 10.738046646118164, 10.438538551330566, 10.15404987335205, 9.883429527282715, 9.625540733337402, 9.379312515258789, 9.143757820129395, 8.917984962463379, 8.701208114624023, 8.492738723754883, 8.291980743408203, 8.09842586517334, 7.911640167236328, 7.731259822845459, 7.556978702545166, 7.388543128967285, 7.225742816925049, 7.068406581878662, 6.916396617889404, 6.769604206085205, 6.627945899963379, 6.491361141204834, 6.3598103523254395, 6.233274936676025, 6.111752033233643, 5.9952592849731445, 5.8838300704956055, 5.777517318725586, 5.676392078399658, 5.5805439949035645, 5.490083694458008, 5.405143737792969, 5.325879096984863, 5.252470970153809, 5.185126304626465, 5.124083042144775, 5.06960916519165, 5.022008895874023, 4.98162317276001, 4.9488348960876465, 4.924070835113525, 4.907805442810059, 4.900566577911377, 4.902936935424805, 4.915560245513916, 4.939144134521484, 4.9744648933410645, 5.022371768951416, 5.083788871765137, 5.159718990325928, 5.251245975494385, 5.359535217285156, 5.4858317375183105, 5.631457805633545, 5.797808647155762, 5.986340045928955, 6.198558330535889, 6.435998916625977, 6.700205326080322, 6.992695331573486, 7.314922332763672, 7.668229103088379, 8.053789138793945, 8.472539901733398, 8.925106048583984, 9.411715507507324, 9.932104110717773, 10.485421180725098, 11.070128440856934, 11.683910369873047, 12.323587417602539, 12.985061645507812, 13.663275718688965, 14.352225303649902, 15.045005798339844, 15.733919143676758, 16.410640716552734, 17.065458297729492, 17.68839454650879, 18.269594192504883, 18.799732208251953, 19.270421981811523, 19.674612045288086, 20.00690460205078, 20.263792037963867, 20.44378089904785, 20.547378540039062, 20.57697105407715, 20.536603927612305, 20.43165397644043, 20.268489837646484, 20.05409049987793, 19.795698165893555, 19.500499725341797, 19.175378799438477, 18.826719284057617, 18.460281372070312, 18.081132888793945, 17.693635940551758, 17.301462173461914, 16.90764617919922, 16.51464080810547, 16.12440299987793, 15.738454818725586, 15.357964515686035, 14.983804702758789, 14.616615295410156, 14.256850242614746, 13.904818534851074, 13.56071949005127, 13.2246675491333, 12.89671802520752, 12.576879501342773, 12.265130043029785, 11.961423873901367, 11.665704727172852, 11.37790298461914, 11.097949028015137, 10.825769424438477, 10.561295509338379, 10.304459571838379, 10.055201530456543, 9.813468933105469, 9.579217910766602, 9.352415084838867, 9.133038520812988, 8.921080589294434, 8.716547966003418, 8.519465446472168, 8.329874038696289, 8.14783763885498, 7.973442077636719, 7.806798934936523, 7.64804744720459, 7.4973578453063965, 7.354934215545654, 7.221018314361572, 7.095892429351807, 6.979884147644043, 6.87337064743042, 6.776783466339111, 6.690612316131592, 6.615411758422852, 6.551804542541504, 6.500489711761475, 6.462246894836426, 6.4379401206970215, 6.428525924682617, 6.435056686401367, 6.458683013916016, 6.500659942626953, 6.562343597412109, 6.645192623138428, 6.750762939453125, 6.8806986808776855, 7.0367207527160645, 7.220605373382568, 7.434159278869629, 7.6791839599609375, 7.957431316375732, 8.270545959472656, 8.61999797821045, 9.007002830505371, 9.432422637939453, 9.896662712097168, 10.39954948425293, 10.940210342407227, 11.516939163208008, 12.127080917358398, 12.766918182373047, 13.431591033935547, 14.1150484085083, 14.810063362121582, 15.508296966552734, 16.2004451751709, 16.876466751098633, 17.52587890625, 18.137123107910156, 18.698884963989258, 19.200632095336914, 19.633121490478516, 19.988876342773438, 20.2625732421875, 20.451274871826172, 20.55453109741211, 20.57430076599121, 20.514726638793945, 20.381776809692383, 20.182815551757812, 19.926116943359375, 19.620405197143555, 19.2744140625, 18.896543502807617, 18.494577407836914, 18.07550811767578, 17.645429611206055, 17.209518432617188, 16.77204132080078, 16.336435317993164, 15.905384063720703, 15.48092269897461, 15.06454086303711, 14.65727710723877, 14.259808540344238, 13.872532844543457, 13.495628356933594, 13.129115104675293, 12.772895812988281, 12.426793098449707, 12.090571403503418, 11.763967514038086, 11.446695327758789, 11.13846206665039, 10.838974952697754, 10.547948837280273, 10.26510238647461, 9.990168571472168, 9.722888946533203, 9.463018417358398, 9.210315704345703, 8.964569091796875, 8.725571632385254, 8.493119239807129, 8.267011642456055, 8.047059059143066, 7.833074569702148, 7.624881744384766, 7.422309875488281, 7.22519588470459, 7.033382415771484, 6.846718788146973, 6.6650614738464355, 6.488270282745361, 6.316211700439453, 6.148756504058838, 5.985780715942383, 5.8271636962890625, 5.672788619995117, 5.522542953491211, 5.376318454742432, 5.2340087890625, 5.095511436462402, 4.960727691650391, 4.82956075668335, 4.7019171714782715, 4.577706813812256, 4.456840991973877, 4.339235305786133, 4.224807262420654, 4.113476276397705, 4.005165100097656, 3.899799346923828, 3.7973060607910156, 3.697615623474121, 3.600660562515259, 3.506376028060913, 3.4146993160247803, 3.325570583343506, 3.2389323711395264, 3.1547300815582275, 3.072911262512207, 2.99342679977417, 2.916229724884033, 2.8412766456604004, 2.768526315689087, 2.697941541671753, 2.629488229751587, 2.5631353855133057, 2.49885630607605, 2.4366281032562256, 2.376431941986084, 2.3182544708251953, 2.262086868286133, 2.207925796508789, 2.1557741165161133, 2.1056418418884277, 2.0575456619262695, 2.0115110874176025, 1.9675724506378174, 1.925774097442627, 1.8861720561981201, 1.8488348722457886, 1.813845157623291, 1.7813018560409546, 1.7513216733932495, 1.7240415811538696, 1.6996214389801025, 1.6782469749450684, 1.6601331233978271, 1.6455274820327759, 1.6347153186798096, 1.6280239820480347, 1.6258286237716675, 1.6285581588745117, 1.6367028951644897, 1.6508221626281738, 1.6715530157089233, 1.6996207237243652, 1.735849380493164, 1.7811744213104248, 1.8366563320159912, 1.9034948348999023, 1.9830455780029297, 2.076836347579956, 2.1865861415863037, 2.314222812652588, 2.4619014263153076, 2.632023811340332, 2.8272526264190674, 3.0505261421203613, 3.3050661087036133, 3.5943777561187744, 3.922241687774658, 4.292690277099609, 4.709963798522949, 5.1784467697143555, 5.702569007873535, 6.286675453186035, 6.934846878051758, 7.6506757736206055, 8.436370849609375, 9.292798042297363, 10.21906852722168, 11.212108612060547, 12.266223907470703, 13.37271499633789, 14.519579887390137, 15.691393852233887, 16.869401931762695, 18.03190803527832, 19.15500259399414, 20.213603973388672, 21.182830810546875, 22.03952407836914, 22.76384925842285, 23.340730667114258, 23.76094627380371, 24.0217227935791, 24.12674903869629, 24.085582733154297, 23.912574768066406, 23.625455856323242, 23.243812561035156, 22.787622451782227, 22.27600860595703, 21.726333618164062, 21.153610229492188, 20.570253372192383, 19.98607635498047, 19.40848731994629, 18.842784881591797, 18.29251480102539, 17.759828567504883, 17.245811462402344, 16.75077247619629, 16.274484634399414, 15.816367149353027, 15.375616073608398, 14.951345443725586, 14.542648315429688, 14.148636817932129, 13.768465995788574, 13.401351928710938, 13.046574592590332, 12.703481674194336, 12.371482849121094, 12.050047874450684, 11.738700866699219, 11.437015533447266, 11.144606590270996, 10.861130714416504, 10.586274147033691, 10.319754600524902, 10.061315536499023, 9.810721397399902, 9.56775951385498, 9.332230567932129, 9.103957176208496, 8.882770538330078, 8.668519973754883, 8.461063385009766, 8.260272979736328, 8.066028594970703, 7.878222942352295, 7.6967573165893555, 7.521542549133301, 7.352498531341553, 7.189553260803223, 7.032645225524902, 6.881720066070557, 6.736732006072998, 6.597643852233887, 6.4644269943237305, 6.337059020996094, 6.2155280113220215, 6.099828243255615, 5.98996114730835, 5.885937213897705, 5.7877726554870605, 5.695490837097168, 5.609121799468994, 5.528700828552246, 5.4542694091796875, 5.385872840881348, 5.323561191558838, 5.267387390136719, 5.217405796051025, 5.173672676086426, 5.136242866516113, 5.105170249938965, 5.080504417419434, 5.058221817016602, 5.037883758544922, 5.0191450119018555, 5.001740455627441, 4.985472202301025, 4.97020149230957, 4.955836772918701, 4.942329406738281, 4.929663181304932, 4.917853355407715, 4.906938076019287, 4.896976470947266, 4.888044834136963, 4.880234241485596, 4.873648166656494, 4.868401527404785, 4.864617824554443, 4.862428665161133, 4.861972808837891, 4.863397121429443, 4.866852760314941, 4.872498512268066, 4.880497932434082, 4.89102029800415, 4.904240608215332, 4.920340061187744, 4.939504623413086, 4.9619269371032715, 4.987805366516113, 5.017343521118164, 5.050752639770508, 5.088248252868652, 5.1300530433654785, 5.176395893096924, 5.227510929107666, 5.283637523651123, 5.345020294189453, 5.411908149719238, 5.48455286026001, 5.5632100105285645, 5.648134708404541, 5.739583492279053, 5.837809085845947, 5.943061351776123, 6.055582046508789, 6.175604820251465, 6.303348541259766, 6.439017295837402, 6.582793712615967, 6.734835624694824, 6.895270824432373, 7.0641913414001465, 7.2416486740112305, 7.427647590637207, 7.622140407562256, 7.825018882751465, 8.036109924316406, 8.255169868469238, 8.4818754196167, 8.71582317352295, 8.956522941589355, 9.203390121459961, 9.455753326416016, 9.712843894958496, 9.97380256652832, 10.237679481506348, 10.50344181060791, 10.769980430603027, 11.03611946105957, 11.300625801086426, 11.562227249145508, 11.819628715515137, 12.071527481079102, 12.316631317138672, 12.553685188293457, 12.78148365020752, 12.998895645141602, 13.20488166809082, 13.398512840270996, 13.578980445861816, 13.74561595916748, 13.897895812988281, 14.035446166992188, 14.158048629760742, 14.26563835144043, 14.358299255371094, 14.436258316040039, 14.499872207641602, 14.549622535705566, 14.586094856262207, 14.609970092773438, 14.622008323669434, 14.623034477233887, 14.613921165466309, 14.5955810546875, 14.568950653076172, 14.534979820251465, 14.494623184204102, 14.448832511901855, 14.398550033569336, 14.344701766967773, 14.287834167480469, 14.22846794128418, 14.167102813720703, 14.104218482971191, 14.040273666381836, 13.975706100463867, 13.910937309265137, 13.846366882324219, 13.782378196716309, 13.719338417053223, 13.65759563446045, 13.597481727600098, 13.539313316345215, 13.483389854431152, 13.429996490478516, 13.379403114318848, 13.331863403320312, 13.287616729736328, 13.246885299682617, 13.209878921508789, 13.176791191101074, 13.147797584533691, 13.12306022644043, 13.10272216796875, 13.086912155151367, 13.075737953186035, 13.069291114807129, 13.06764030456543, 13.07083797454834, 13.078911781311035, 13.09186840057373, 13.10969066619873, 13.132338523864746, 13.159743309020996, 13.191813468933105, 13.228426933288574, 13.269436836242676, 13.314665794372559, 13.363908767700195, 13.416930198669434, 13.473467826843262, 13.533227920532227, 13.595890998840332, 13.661111831665039, 13.728516578674316, 13.797710418701172, 13.868277549743652, 13.93978214263916, 14.011775016784668, 14.083791732788086, 14.155363082885742, 14.226014137268066, 14.295269966125488, 14.36266040802002, 14.427724838256836, 14.490015983581543, 14.549104690551758, 14.604586601257324, 14.656082153320312, 14.703243255615234, 14.745758056640625, 14.78334903717041, 14.815781593322754, 14.84286117553711, 14.864436149597168, 14.880401611328125, 14.890693664550781, 14.895295143127441, 14.894229888916016, 14.88756275177002, 14.87540054321289, 14.857885360717773, 14.835193634033203, 14.807534217834473, 14.775145530700684, 14.738289833068848, 14.697251319885254, 14.652335166931152, 14.603859901428223, 14.55215835571289, 14.497572898864746, 14.440451622009277, 14.381150245666504, 14.320023536682129, 14.257428169250488, 14.193717956542969, 14.129244804382324, 14.064353942871094, 13.999385833740234, 13.934672355651855, 13.870539665222168, 13.807303428649902, 13.745268821716309, 13.684732437133789, 13.625980377197266, 13.569287300109863, 13.514917373657227, 13.46312141418457, 13.414139747619629, 13.368199348449707, 13.325516700744629, 13.286293029785156, 13.250717163085938, 13.218964576721191, 13.191195487976074, 13.167555809020996, 13.148176193237305, 13.133170127868652, 13.122635841369629, 13.11665153503418, 13.115279197692871, 13.118559837341309, 13.126513481140137, 13.139140129089355, 13.156416893005371, 13.17829704284668, 13.204710960388184, 13.235563278198242, 13.270731925964355, 13.31006908416748, 13.353401184082031, 13.40052604675293, 13.451214790344238, 13.505210876464844, 13.562233924865723, 13.621578216552734, 13.682476043701172, 13.744105339050293, 13.805597305297852, 13.866046905517578, 13.924528121948242, 13.980104446411133, 14.031839370727539, 14.078816413879395, 14.120146751403809, 14.154986381530762, 14.182548522949219, 14.20211124420166, 14.213035583496094, 14.214766502380371, 14.206847190856934, 14.188916206359863, 14.160719871520996, 14.122103691101074, 14.073017120361328, 14.013508796691895, 13.943719863891602, 13.836982727050781, 13.694648742675781, 13.519371032714844, 13.314728736877441, 13.084869384765625, 12.834195137023926, 12.567102432250977, 12.287781715393066, 12.00007152557373, 11.707371711730957, 11.412601470947266, 11.118194580078125, 10.826118469238281, 10.537914276123047, 10.25475025177002, 9.977472305297852, 9.706659317016602, 9.442676544189453, 9.18571662902832, 8.935844421386719, 8.693028450012207, 8.457164764404297, 8.228106498718262, 8.005672454833984, 7.789665222167969, 7.579878330230713, 7.376104831695557, 7.178139686584473, 6.985784530639648, 6.798848628997803, 6.617149829864502, 6.440515041351318, 6.26878023147583, 6.101790904998779, 5.939399242401123, 5.781466007232666, 5.6278581619262695, 5.478450775146484, 5.333123207092285, 5.191761016845703, 5.05425500869751, 4.920499801635742, 4.790395736694336, 4.663846492767334, 4.540759563446045, 4.421046257019043, 4.304622173309326, 4.191405296325684, 4.08131742477417, 3.9742844104766846, 3.870234489440918, 3.7690999507904053, 3.670815944671631, 3.5753211975097656, 3.482558012008667, 3.392472505569458, 3.30501389503479, 3.2201359272003174, 3.13779616355896, 3.0579569339752197, 2.9805843830108643, 2.9056506156921387, 2.833132266998291, 2.763012409210205, 2.6952803134918213, 2.629931926727295, 2.5669713020324707, 2.5064103603363037, 2.4482712745666504, 2.3925862312316895, 2.3393988609313965, 2.288766384124756, 2.240760564804077, 2.195469856262207, 2.153001546859741, 2.1134836673736572, 2.077068567276001, 2.043935775756836, 2.0142955780029297, 1.9883930683135986, 1.9665133953094482, 1.9489867687225342, 1.9361950159072876, 1.92857825756073, 1.9266433715820312, 1.9309725761413574, 1.9422341585159302, 1.9611939191818237, 1.9887280464172363, 2.0258378982543945, 2.0736658573150635, 2.1335132122039795, 2.206860065460205, 2.2953855991363525, 2.400991201400757, 2.5258243083953857, 2.672302007675171, 2.843135118484497, 3.041350841522217, 3.270312547683716, 3.533733367919922, 3.835454225540161, 4.179561138153076, 4.570336818695068, 5.01218843460083, 5.509541988372803, 6.066699028015137, 6.687646865844727, 7.375819683074951, 8.133805274963379, 8.962994575500488, 9.86318588256836, 10.8321533203125, 11.865208625793457, 12.954782485961914, 14.090086936950684, 15.256917953491211, 16.437652587890625, 17.611530303955078, 18.75523567199707, 19.843847274780273, 20.852092742919922, 21.75583839416504, 22.533700942993164, 23.1685733795166, 23.648880004882812, 23.96938705444336, 24.131425857543945, 24.14252471923828, 24.015487670898438, 23.76707649230957, 23.41648292541504, 22.983810424804688, 22.488733291625977, 21.949438095092773, 21.38192367553711, 20.79962730407715, 20.213342666625977, 19.631349563598633, 19.059690475463867, 18.50250816345215, 17.962419509887695, 17.44085121154785, 16.9383487701416, 16.454845428466797, 15.989852905273438, 15.542633056640625, 15.112310409545898, 14.697957038879395, 14.298650741577148, 13.913507461547852, 13.541707038879395, 13.18249797821045, 12.835206031799316, 12.499226570129395, 12.174026489257812, 11.859132766723633, 11.55368423461914, 11.257065773010254, 10.968730926513672, 10.68820571899414, 10.415079116821289, 10.148998260498047, 9.889664649963379, 9.636819839477539, 9.390246391296387, 9.149754524230957, 8.915177345275879, 8.686368942260742, 8.463194847106934, 8.24553394317627, 8.033270835876465, 7.826295852661133, 7.624504566192627, 7.427793979644775, 7.2360639572143555, 7.049214839935303, 6.867149353027344, 6.689769744873047, 6.5169806480407715, 6.348687171936035, 6.184794902801514, 6.025211811065674, 5.869846820831299, 5.7186102867126465, 5.571415424346924, 5.428176403045654, 5.2888102531433105, 5.15323543548584, 5.021373748779297, 4.893149375915527, 4.768489360809326, 4.647324085235596, 4.529585838317871, 4.415212154388428, 4.304141998291016, 4.196320056915283, 4.091692924499512, 3.990213394165039, 3.8918368816375732, 3.7965247631073, 3.7042429447174072, 3.6149630546569824, 3.5286624431610107, 3.445324659347534, 3.3649404048919678, 3.2875077724456787, 3.213033437728882, 3.1415324211120605, 3.0730302333831787, 3.0075626373291016, 2.9451777935028076, 2.885936975479126, 2.82991623878479, 2.777208089828491, 2.7279229164123535, 2.6821916103363037, 2.640166997909546, 2.602027416229248, 2.5679798126220703, 2.538261651992798, 2.513145685195923, 2.4929440021514893, 2.4780125617980957, 2.4687564373016357, 2.465634822845459, 2.4691684246063232, 2.4799461364746094, 2.4986321926116943, 2.525975227355957, 2.562817335128784, 2.6101036071777344, 2.6688926219940186, 2.7403676509857178, 2.82584810256958, 2.9268012046813965, 3.0448524951934814, 3.181797504425049, 3.3396100997924805, 3.5204508304595947, 3.7266693115234375, 3.960803985595703, 4.225574970245361, 4.523869037628174, 4.858709812164307, 5.233221054077148, 5.650565147399902, 6.113867282867432, 6.626110553741455, 7.190006256103516, 7.807833194732666, 8.481245994567871, 9.211051940917969, 9.99696159362793, 10.837324142456055, 11.728853225708008, 12.666370391845703, 13.642593383789062, 14.646973609924316, 15.666424751281738, 16.685476303100586, 17.68663787841797, 18.65097999572754, 19.55893898010254, 20.391298294067383, 21.130279541015625, 21.76062774658203, 22.27060317993164, 22.65271759033203, 22.904165267944336, 23.0268497467041, 23.02703285217285, 22.91465187072754, 22.701478958129883, 22.401243209838867, 22.02864646911621, 21.598472595214844, 21.12481689453125, 20.620529174804688, 20.096858978271484, 19.563289642333984, 19.027515411376953, 18.49555778503418, 17.971927642822266, 17.45985221862793, 16.96149444580078, 16.478168487548828, 16.010540008544922, 15.558791160583496, 15.122759819030762, 14.70205020904541, 14.296119689941406, 13.904341697692871, 13.526055335998535, 13.160595893859863, 12.8073148727417, 12.465596199035645, 12.13486385345459, 11.814583778381348, 11.504263877868652, 11.203454971313477, 10.91174602508545, 10.62876033782959, 10.354156494140625, 10.08761978149414, 9.828862190246582, 9.577617645263672, 9.333641052246094, 9.096705436706543, 8.866598129272461, 8.643121719360352, 8.426091194152832, 8.21533203125, 8.01068115234375, 7.811981678009033, 7.619088649749756, 7.4318623542785645, 7.249423027038574, 7.071575164794922, 6.898153305053711, 6.729015350341797, 6.564039707183838, 6.4031195640563965, 6.246161460876465, 6.093080520629883, 5.943800449371338, 5.798250675201416, 5.656364440917969, 5.518078804016113, 5.383334636688232, 5.252074241638184, 5.124242782592773, 4.999786376953125, 4.878653526306152, 4.760794639587402, 4.646162033081055, 4.534709930419922, 4.426393985748291, 4.321174144744873, 4.219010353088379, 4.119867324829102, 4.023712635040283, 3.9305155277252197, 3.8402509689331055, 3.752896785736084, 3.6684350967407227, 3.586852788925171, 3.5081424713134766, 3.4323010444641113, 3.359332799911499, 3.289247989654541, 3.2220637798309326, 3.157805919647217, 3.096508502960205, 3.038214921951294, 2.9829790592193604, 2.930866241455078, 2.8819541931152344, 2.836334466934204, 2.7941136360168457, 2.755415201187134, 2.7203805446624756, 2.689171314239502, 2.6619720458984375, 2.638990879058838, 2.6204633712768555, 2.6066553592681885, 2.5978643894195557, 2.5944249629974365, 2.596710681915283, 2.6051392555236816, 2.620175361633301, 2.642336368560791, 2.672196388244629, 2.7103915214538574, 2.757624864578247, 2.8146727085113525, 2.8823885917663574, 2.961709976196289, 3.0536627769470215, 3.159365653991699, 3.2800352573394775, 3.4169867038726807, 3.571636915206909, 3.74550199508667, 3.940194606781006, 4.157414436340332, 4.3989386558532715, 4.666600704193115, 4.962268352508545, 5.287808895111084, 5.645046710968018, 6.035710334777832, 6.461366176605225, 6.923340797424316, 7.422628402709961, 7.959788799285889, 8.534828186035156, 9.14708137512207, 9.795077323913574, 10.476424217224121, 11.187690734863281, 11.924318313598633, 12.680569648742676, 13.449519157409668, 14.223106384277344, 14.992267608642578, 15.74713134765625, 16.477304458618164, 17.172222137451172, 17.821552276611328, 18.415637969970703, 18.9459171295166, 19.40532875061035, 19.78862953186035, 20.09260368347168, 20.3161563873291, 20.460275650024414, 20.526952743530273, 20.519927978515625, 20.444406509399414, 20.306711196899414, 20.1138973236084, 19.87339210510254, 19.5926513671875, 19.278886795043945, 18.9388484954834, 18.578664779663086, 18.203771591186523, 17.81887435913086, 17.42795181274414, 17.03430938720703, 16.64063835144043, 16.249088287353516, 15.861344337463379, 15.47869873046875, 15.102129936218262, 14.732354164123535, 14.369884490966797, 14.015076637268066, 13.668160438537598, 13.329276084899902, 12.998493194580078, 12.675832748413086, 12.361278533935547, 12.054789543151855, 11.75631046295166, 11.465773582458496, 11.183107376098633, 10.908236503601074, 10.641088485717773, 10.38159465789795, 10.129691123962402, 9.885319709777832, 9.648431777954102, 9.418990135192871, 9.196967124938965, 8.98234748840332, 8.775131225585938, 8.575335502624512, 8.382993698120117, 8.198158264160156, 8.020907402038574, 7.851339340209961, 7.689581394195557, 7.53579044342041, 7.390154838562012, 7.252900123596191, 7.124290943145752, 7.004634857177734, 6.894287109375, 6.793656349182129, 6.7032060623168945, 6.6234636306762695, 6.555022239685059, 6.498548984527588, 6.454789161682129, 6.424570560455322, 6.408812522888184, 6.408527374267578, 6.424826145172119, 6.458921909332275, 6.512131214141846, 6.585873603820801, 6.681670188903809, 6.801133632659912, 6.945962429046631, 7.117918491363525, 7.318809986114502, 7.550455093383789, 7.814644813537598, 8.113090515136719, 8.447359085083008, 8.81879997253418, 9.22845458984375, 9.676950454711914, 10.164392471313477, 10.69023323059082, 11.253149032592773, 11.850912094116211, 12.480271339416504, 13.136860847473145, 13.815129280090332, 14.508330345153809, 15.208558082580566, 15.906862258911133, 16.59343910217285, 17.257904052734375, 17.88862419128418, 18.474023818969727, 19.00309944152832, 19.465953826904297, 19.854299545288086, 20.16188621520996, 20.38479995727539, 20.521625518798828, 20.573427200317383, 20.543582916259766, 20.437467575073242, 20.26203727722168, 20.025352478027344, 19.73609733581543, 19.40312957763672, 19.035083770751953, 18.64006233215332, 18.225431442260742, 17.79766845703125, 17.362327575683594, 16.924034118652344, 16.48653793334961, 16.05280303955078, 15.625092506408691, 15.205086708068848, 14.793973922729492, 14.392547607421875, 14.00129222869873, 13.620450019836426, 13.25008487701416, 12.890128135681152, 12.540417671203613, 12.200732231140137, 11.870805740356445, 11.550353050231934, 11.2390775680542, 10.936680793762207, 10.642868995666504, 10.357354164123535, 10.079861640930176, 9.810127258300781, 9.547897338867188, 9.29293155670166, 9.045001029968262, 8.803887367248535, 8.569382667541504, 8.341288566589355, 8.119414329528809, 7.903579235076904, 7.693609237670898, 7.489336967468262, 7.29060173034668, 7.0972490310668945, 6.909129619598389, 6.726099491119385, 6.548019886016846, 6.374756336212158, 6.206178665161133, 6.042160987854004, 5.8825812339782715, 5.727321147918701, 5.576266765594482, 5.429306507110596, 5.286332130432129, 5.1472392082214355, 5.011926174163818, 4.8802947998046875, 4.752248764038086, 4.627695083618164, 4.506543159484863, 4.388706207275391, 4.274097919464111, 4.162635803222656, 4.054239749908447, 3.9488308429718018, 3.8463332653045654, 3.746673583984375, 3.6497795581817627, 3.555581569671631, 3.4640114307403564, 3.3750035762786865, 3.2884936332702637, 3.2043678760528564, 3.122565269470215, 3.043027400970459, 2.965698719024658, 2.890526294708252, 2.817460536956787, 2.746453285217285, 2.677459478378296, 2.610436201095581, 2.545342445373535, 2.482140064239502, 2.4207923412323, 2.3612658977508545, 2.3035285472869873, 2.247551202774048, 2.1933066844940186, 2.140770673751831, 2.089921236038208, 2.0407395362854004, 1.9932085275650024, 1.9473154544830322, 1.9030499458312988, 1.8604053258895874, 1.8193782567977905, 1.7799696922302246, 1.7421845197677612, 1.706032156944275, 1.6715271472930908, 1.6386891603469849, 1.607543706893921, 1.5781227350234985, 1.5504653453826904, 1.5246179103851318, 1.5006355047225952, 1.4785822629928589, 1.458532691001892, 1.4405723810195923, 1.4247993230819702, 1.4113255739212036, 1.4002779722213745, 1.3918004035949707, 1.3860554695129395, 1.3832262754440308, 1.3835190534591675, 1.3871651887893677, 1.394424319267273, 1.405587077140808, 1.4209789037704468, 1.4409632682800293, 1.4659454822540283, 1.4963778257369995, 1.5327636003494263, 1.575662612915039, 1.6256965398788452, 1.6835544109344482, 1.7499996423721313, 1.8258752822875977, 1.9121116399765015, 2.0097317695617676, 2.119858503341675, 2.243720531463623, 2.3826565742492676, 2.538120746612549, 2.7116832733154297, 2.9050323963165283, 3.119968891143799, 3.358400821685791, 3.6223294734954834, 3.9138307571411133, 4.23502779006958, 4.588054656982422, 4.975007057189941, 5.397881984710693, 5.858500957489014, 6.358420372009277, 6.898821830749512, 7.480390548706055, 8.10317611694336, 8.766448020935059, 9.468541145324707, 10.206707000732422, 10.976983070373535, 11.77408504486084, 12.591349601745605, 13.420730590820312, 14.25287914276123, 15.07730770111084, 15.882657051086426, 16.65705108642578, 17.388540267944336, 18.06560707092285, 18.677688598632812, 19.215696334838867, 19.67245101928711, 20.04303741455078, 20.324989318847656, 20.51833152770996, 20.625457763671875, 20.65085220336914, 20.600709915161133, 20.482486724853516, 20.303693771362305, 20.072328567504883, 19.796493530273438, 19.484067916870117, 19.14246368408203, 18.778430938720703, 18.397964477539062, 18.006250381469727, 17.607677459716797, 17.20587921142578, 16.803802490234375, 16.403789520263672, 16.007667541503906, 15.616823196411133, 15.232295989990234, 14.85483455657959, 14.484966278076172, 14.12304401397705, 13.769285202026367, 13.423811912536621, 13.086671829223633, 12.757859230041504, 12.437334060668945, 12.125027656555176, 11.820858001708984, 11.524731636047363, 11.236553192138672, 10.956222534179688, 10.683642387390137, 10.418718338012695, 10.16136360168457, 9.91149616241455, 9.669039726257324, 9.433931350708008, 9.20611572265625, 8.98554801940918, 8.772197723388672, 8.566047668457031, 8.367096900939941, 8.175358772277832, 7.990869522094727, 7.813683032989502, 7.6438775062561035, 7.481555461883545, 7.32684850692749, 7.1799187660217285, 7.040961742401123, 6.910210609436035, 6.78794002532959, 6.674469470977783, 6.570168972015381, 6.475462436676025, 6.390833377838135, 6.316830635070801, 6.2540740966796875, 6.2032599449157715, 6.165168285369873, 6.14066743850708, 6.130721569061279, 6.136394023895264, 6.15885591506958, 6.199386119842529, 6.259376525878906, 6.340330123901367, 6.4438605308532715, 6.571682929992676, 6.7256059646606445, 6.907512664794922, 7.11933708190918, 7.363030433654785, 7.640519618988037, 7.953649044036865, 8.304115295410156, 8.69338321685791, 9.122587203979492, 9.592422485351562, 10.10301399230957, 10.653786659240723, 11.24332046508789, 11.80312728881836, 12.317873001098633, 12.77469539642334, 13.163540840148926, 13.47740364074707, 13.712420463562012, 13.867785453796387, 13.945505142211914, 13.949995040893555, 13.887575149536133, 13.765908241271973, 13.593430519104004, 13.37883186340332, 13.13060474395752, 12.856706619262695, 12.564311981201172, 12.259675979614258, 11.948079109191895, 11.633843421936035, 11.320398330688477, 11.010370254516602, 10.705698013305664, 10.407745361328125, 10.117412567138672, 9.835233688354492, 9.561463356018066, 9.296154975891113, 9.039212226867676, 8.79044246673584, 8.549591064453125, 8.316367149353027, 8.090466499328613, 7.871580600738525, 7.659411430358887, 7.453671932220459, 7.254092216491699, 7.060420989990234, 6.872424125671387, 6.68988561630249, 6.5126051902771, 6.340398788452148, 6.173095703125, 6.010537624359131, 5.8525776863098145, 5.6990790367126465, 5.549914360046387, 5.404964447021484, 5.26411771774292, 5.127269744873047, 4.994322299957275, 4.865184307098389, 4.739769458770752, 4.617998123168945, 4.499796390533447, 4.385095596313477, 4.273833274841309, 4.165953159332275, 4.061404228210449, 3.960143566131592, 3.862133264541626, 3.767343521118164, 3.675752878189087, 3.5873470306396484, 3.502121686935425, 3.4200825691223145, 3.3412458896636963, 3.2656400203704834, 3.1933066844940186, 3.124302864074707, 3.058701276779175, 2.996593713760376, 2.9380922317504883, 2.8833320140838623, 2.8324742317199707, 2.7857091426849365, 2.743260383605957, 2.705387830734253, 2.672393798828125, 2.644627809524536, 2.6224918365478516, 2.6064491271972656, 2.597029447555542, 2.5948400497436523, 2.6005735397338867, 2.6150197982788086, 2.639077663421631, 2.67376708984375, 2.720244884490967, 2.7798194885253906, 2.8539679050445557, 2.9443531036376953, 3.0528416633605957, 3.181523323059082, 3.3327274322509766, 3.509040594100952, 3.713318109512329, 3.948695421218872, 4.218587875366211, 4.5266852378845215, 4.876928329467773, 5.273473739624023, 5.720278263092041, 6.221213340759277, 6.779910087585449, 7.3995680809021, 8.082716941833496, 8.830934524536133, 9.64452075958252, 10.522139549255371, 11.460450172424316, 12.453744888305664, 13.49362850189209, 14.568804740905762, 15.664993286132812, 16.765052795410156, 17.849355697631836, 18.896425247192383, 19.883867263793945, 20.789522171020508, 21.592782974243164, 22.275922775268555, 22.825321197509766, 23.23238754272461, 23.49408531188965, 23.612974166870117, 23.596757888793945, 23.457426071166992, 23.210100173950195, 22.871755599975586, 22.459978103637695, 21.991878509521484, 21.48325538635254, 20.948034286499023, 20.397977828979492, 19.842618942260742, 19.28937339782715, 18.743755340576172, 18.209657669067383, 17.689651489257812, 17.185264587402344, 16.697240829467773, 16.22575569152832, 15.770593643188477, 15.331284523010254, 14.907208442687988, 14.49767017364502, 14.101951599121094, 13.719347953796387, 13.349187850952148, 12.990845680236816, 12.643747329711914, 12.307369232177734, 11.981240272521973, 11.664934158325195, 11.358068466186523, 11.060296058654785, 10.771307945251465, 10.49082088470459, 10.218582153320312, 9.954358100891113, 9.697941780090332, 9.449140548706055, 9.207782745361328, 8.973712921142578, 8.746790885925293, 8.526893615722656, 8.313911437988281, 8.10775089263916, 7.908336639404297, 7.715606212615967, 7.529516696929932, 7.350042819976807, 7.177179336547852, 7.010941028594971, 6.851365566253662, 6.698515892028809, 6.552481174468994, 6.413380146026611, 6.281363487243652, 6.156617164611816, 6.039367198944092, 5.9298810958862305, 5.828474521636963, 5.735515117645264, 5.65142822265625, 5.576701641082764, 5.511893272399902, 5.457636833190918, 5.41464900970459, 5.3837385177612305, 5.365810394287109, 5.361877918243408, 5.373067378997803, 5.400627136230469, 5.445932865142822, 5.510494232177734, 5.595959186553955, 5.7041120529174805, 5.836874485015869, 5.996295928955078, 6.184540748596191, 6.403868198394775, 6.629928112030029, 6.858486175537109, 7.085743427276611, 7.308318138122559, 7.523231029510498, 7.727895259857178, 7.920112609863281, 8.098065376281738, 8.260310173034668, 8.40576171875, 8.533681869506836, 8.643651962280273, 8.735555648803711, 8.809542655944824, 8.866003036499023, 8.905526161193848, 8.928873062133789, 8.93693733215332, 8.93071460723877, 8.911269187927246, 8.879707336425781, 8.837154388427734, 8.78472900390625, 8.723530769348145, 8.654623031616211, 8.579021453857422, 8.497692108154297, 8.411539077758789, 8.321407318115234, 8.228083610534668, 8.132288932800293, 8.034692764282227, 7.9359049797058105, 7.836487293243408, 7.7369537353515625, 7.63777494430542, 7.539384365081787, 7.44218111038208, 7.346534729003906, 7.25278902053833, 7.1612653732299805, 7.072268486022949, 6.986086368560791, 6.9029974937438965, 6.823270797729492, 6.7471699714660645, 6.67495584487915, 6.606889724731445, 6.543234825134277, 6.484259128570557, 6.430238246917725, 6.3814568519592285, 6.338212013244629, 6.300813674926758, 6.269588470458984, 6.2448811531066895, 6.227055549621582, 6.216498851776123, 6.213620185852051, 6.218856334686279, 6.232668876647949, 6.255548477172852, 6.288014888763428, 6.330617427825928, 6.383935451507568, 6.4485764503479, 6.525177955627441, 6.614400863647461, 6.7169318199157715, 6.833474636077881, 6.96474552154541, 7.111467361450195, 7.274358749389648, 7.454123497009277, 7.651436805725098, 7.866929054260254, 8.101166725158691, 8.354630470275879, 8.627693176269531, 8.920589447021484, 9.23338794708252, 9.565960884094238, 9.917948722839355, 10.288732528686523, 10.677396774291992, 11.08270263671875, 11.503066062927246, 11.93653392791748, 12.380779266357422, 12.833100318908691, 13.290433883666992, 13.74938678741455, 14.20627498626709, 14.65718936920166, 15.098067283630371, 15.524784088134766, 15.933252334594727, 16.319530487060547, 16.6799259185791, 17.0111083984375, 17.310197830200195, 17.574058532714844, 17.800125122070312, 17.986499786376953, 18.131980895996094, 18.236101150512695, 18.299108505249023, 18.321918487548828, 18.306062698364258, 18.253589630126953, 18.166967391967773, 18.04897689819336, 17.90260887145996, 17.730958938598633, 17.53714370727539, 17.32421112060547, 17.095096588134766, 16.85256004333496, 16.599164962768555, 16.33725929260254, 16.06895637512207, 15.796152114868164, 15.520523071289062, 15.243542671203613, 14.966498374938965, 14.690508842468262, 14.416543006896973, 14.145440101623535, 13.877923011779785, 13.614620208740234, 13.356074333190918, 13.102763175964355, 12.85510540008545, 12.613472938537598, 12.378201484680176, 12.149599075317383, 11.927948951721191, 11.713521957397461, 11.506575584411621, 11.307365417480469, 11.116144180297852, 10.933170318603516, 10.758708000183105, 10.59303092956543, 10.43642807006836, 10.289205551147461, 10.151688575744629, 10.024222373962402, 9.907180786132812, 9.800960540771484, 9.705988883972168, 9.622722625732422, 9.551650047302246, 9.493291854858398, 9.448200225830078, 9.416960716247559, 9.400187492370605, 9.398523330688477, 9.412633895874023, 9.443206787109375, 9.49094009399414, 9.556534767150879, 9.64068603515625, 9.744068145751953, 9.867319107055664, 10.011019706726074, 10.175674438476562, 10.361684799194336, 10.569321632385254, 10.798693656921387, 11.049715042114258, 11.32206916809082, 11.615174293518066, 11.928147315979004, 12.259770393371582, 12.6084623336792, 12.97225570678711, 13.348784446716309, 13.73527717590332, 14.128572463989258, 14.525139808654785, 14.921131134033203, 15.312434196472168, 15.694756507873535, 16.063718795776367, 16.414960861206055, 16.744264602661133, 17.04766845703125, 17.321578979492188, 17.56288719177246, 17.769052505493164, 17.93817710876465, 18.06903648376465, 18.161104202270508, 18.214536666870117, 18.230127334594727, 18.209245681762695, 18.153757095336914, 18.06592559814453, 17.948322296142578, 17.803714752197266, 17.634986877441406, 17.445045471191406, 17.23674964904785, 17.012863159179688, 16.775991439819336, 16.528566360473633, 16.272823333740234, 16.010787963867188, 15.744279861450195, 15.474920272827148, 15.204141616821289, 14.93320083618164, 14.663196563720703, 14.395086288452148, 14.129704475402832, 13.867773056030273, 13.609926223754883, 13.35671329498291, 13.108622550964355, 12.866082191467285, 12.629478454589844, 12.399158477783203, 12.175443649291992, 11.95863151550293, 11.749005317687988, 11.546838760375977, 11.352399826049805, 11.165955543518066, 10.987775802612305, 10.818138122558594, 10.657329559326172, 10.50565242767334, 10.363423347473145, 10.230978012084961, 10.108674049377441, 9.996892929077148, 9.896039962768555, 9.806549072265625, 9.728882789611816, 9.663533210754395, 9.611019134521484, 9.571893692016602, 9.546733856201172, 9.536144256591797, 9.540754318237305, 9.561210632324219, 9.598172187805176, 9.652304649353027, 9.724268913269043, 9.814708709716797, 9.924240112304688, 10.05342960357666, 10.202778816223145, 10.372698783874512, 10.563488960266113, 10.775303840637207, 11.008126258850098, 11.261736869812012, 11.535676002502441, 11.829214096069336, 12.140830039978027, 12.468564987182617, 12.757622718811035, 12.999189376831055, 13.187108993530273, 13.317831039428711, 13.39024543762207, 13.40542221069336, 13.366267204284668, 13.277122497558594, 13.143353462219238, 12.970931053161621, 12.766069412231445, 12.534903526306152, 12.283244132995605, 12.016406059265137, 11.739091873168945, 11.455349922180176, 11.16856575012207, 10.881494522094727, 10.596320152282715, 10.314718246459961, 10.037934303283691, 9.766851425170898, 9.502067565917969, 9.243946075439453, 8.992676734924316, 8.748316764831543, 8.510825157165527, 8.280097007751465, 8.055978775024414, 7.838292121887207, 7.6268415451049805, 7.4214253425598145, 7.2218427658081055, 7.027894973754883, 6.839392185211182, 6.6561503410339355, 6.477995872497559, 6.304762363433838, 6.136293888092041, 5.972440242767334, 5.813061237335205, 5.658021926879883, 5.507194519042969, 5.360456943511963, 5.2176923751831055, 5.078789710998535, 4.94364070892334, 4.812143325805664, 4.684197902679443, 4.559708595275879, 4.438583850860596, 4.32073450088501, 4.206075191497803, 4.094522953033447, 3.9859979152679443, 3.8804233074188232, 3.777724504470825, 3.677830457687378, 3.580672264099121, 3.4861836433410645, 3.394301414489746, 3.304965019226074, 3.2181167602539062, 3.1337010860443115, 3.051666736602783, 2.971964120864868, 2.894547700881958, 2.8193752765655518, 2.7464072704315186, 2.6756091117858887, 2.6069493293762207, 2.540400981903076, 2.475942373275757, 2.4135560989379883, 2.353231191635132, 2.2949624061584473, 2.2387516498565674, 2.1846084594726562, 2.1325507164001465, 2.082606554031372, 2.0348143577575684, 1.989225149154663, 1.945904016494751, 1.904931664466858, 1.8664065599441528, 1.8304482698440552, 1.7971993684768677, 1.766829252243042, 1.7395380735397339, 1.7155612707138062, 1.6951745748519897, 1.6786998510360718, 1.666512131690979, 1.6590477228164673, 1.6568127870559692, 1.6603940725326538, 1.6704708337783813, 1.6878280639648438, 1.7133724689483643, 1.7481495141983032, 1.7933635711669922, 1.8503414392471313, 1.9205870628356934, 2.0058014392852783, 2.1079018115997314, 2.22904372215271, 2.3716397285461426, 2.5383787155151367, 2.732241630554199, 2.956511974334717, 3.2147793769836426, 3.5109336376190186, 3.849142551422119, 4.233810901641846, 4.669516563415527, 5.1609110832214355, 5.712584495544434, 6.328884124755859, 7.013677597045898, 7.7700605392456055, 8.600005149841309, 9.503948211669922, 10.48034381866455, 11.52518367767334, 12.631540298461914, 13.789163589477539, 14.984217643737793, 16.19919776916504, 17.41313934326172, 18.602149963378906, 19.740314483642578, 20.80097007751465, 21.758262634277344, 22.58885955810547, 23.273643493652344, 23.79915428161621, 24.158567428588867, 24.352081298828125, 24.38663673400879, 24.275012969970703, 24.034460067749023, 23.685068130493164, 23.248106002807617, 22.744531631469727, 22.193805694580078, 21.61309242248535, 21.016815185546875, 20.416549682617188, 19.821157455444336, 19.23706817626953, 18.668659210205078, 18.118648529052734, 17.588481903076172, 17.07865333557129, 16.589006423950195, 16.118942260742188, 15.6676025390625, 15.233994483947754, 14.817078590393066, 14.415831565856934, 14.029282569885254, 13.656533241271973, 13.296770095825195, 12.94926643371582, 12.61337661743164, 12.288533210754395, 11.974239349365234, 11.670062065124512, 11.37562370300293, 11.090595245361328, 10.814692497253418, 10.547670364379883, 10.289318084716797, 10.03945541381836, 9.797932624816895, 9.56462574005127, 9.339437484741211, 9.122297286987305, 8.913158416748047, 8.711999893188477, 8.518826484680176, 8.333671569824219, 8.156596183776855, 7.9876909255981445, 7.827081203460693, 7.674925327301025, 7.5314202308654785, 7.396803855895996, 7.271356582641602, 7.155407905578613, 7.049339294433594, 6.953587532043457, 6.868650436401367, 6.795091152191162, 6.733543872833252, 6.684718132019043, 6.649404048919678, 6.628476619720459, 6.6229023933410645, 6.633739471435547, 6.662144660949707, 6.709370136260986, 6.776767253875732, 6.865779876708984, 6.977940559387207, 7.114857196807861, 7.278200149536133, 7.469677448272705, 7.691007614135742, 7.9438796043396, 8.196869850158691, 8.444259643554688, 8.681071281433105, 8.903059959411621, 9.106707572937012, 9.289217948913574, 9.44849681854248, 9.583122253417969, 9.692304611206055, 9.775833129882812, 9.83401107788086, 9.867588996887207, 9.877681732177734, 9.865697860717773, 9.833259582519531, 9.782132148742676, 9.714159965515137, 9.631208419799805, 9.535120010375977, 9.42767333984375, 9.310555458068848, 9.185343742370605, 9.053491592407227, 8.916321754455566, 8.775029182434082, 8.630678176879883, 8.484216690063477, 8.33647632598877, 8.188188552856445, 8.039989471435547, 7.892432689666748, 7.745999813079834, 7.601108074188232, 7.458118915557861, 7.317347049713135, 7.179068088531494, 7.04352331161499, 6.910926342010498, 6.781467914581299, 6.655320167541504, 6.530147075653076, 6.406069278717041, 6.283217430114746, 6.161727428436279, 6.0417327880859375, 5.923364162445068, 5.806745529174805, 5.69199275970459, 5.579213619232178, 5.468506336212158, 5.359961986541748, 5.253661632537842, 5.149680137634277, 5.048085689544678, 4.948939323425293, 4.852298736572266, 4.758216381072998, 4.66674280166626, 4.577925205230713, 4.491809844970703, 4.408443450927734, 4.327872276306152, 4.250144958496094, 4.175311088562012, 4.103425025939941, 4.034543514251709, 3.9687294960021973, 3.9060511589050293, 3.846583604812622, 3.790409564971924, 3.7376203536987305, 3.6883177757263184, 3.6426141262054443, 3.6006336212158203, 3.5625147819519043, 3.5284104347229004, 3.4984896183013916, 3.4729394912719727, 3.4519665241241455, 3.4357988834381104, 3.424687385559082, 3.41890811920166, 3.418764591217041, 3.424589157104492, 3.43674635887146, 3.455634355545044, 3.4816877841949463, 3.5153794288635254, 3.5572237968444824, 3.6077778339385986, 3.6676440238952637, 3.73747181892395, 3.8179593086242676, 3.909852981567383, 4.013949394226074, 4.1310930252075195, 4.2621750831604, 4.408130168914795, 4.5699310302734375, 4.748580455780029, 4.945102691650391, 5.160531520843506, 5.3958916664123535, 5.652180194854736, 5.930344104766846, 6.2312493324279785, 6.555646896362305, 6.904138088226318, 7.277126789093018, 7.674774169921875, 8.09694766998291, 8.543167114257812, 9.01254940032959, 9.503758430480957, 10.014958381652832, 10.543771743774414, 11.087255477905273, 11.641894340515137, 12.203604698181152, 12.767777442932129, 13.329339027404785, 13.882843017578125, 14.422589302062988, 14.942774772644043, 15.437653541564941, 15.901718139648438, 16.329879760742188, 16.7176456451416, 17.061262130737305, 17.35784339904785, 17.605457305908203, 17.803159713745117, 17.95098304748535, 18.04989242553711, 18.10169219970703, 18.108896255493164, 18.074594497680664, 18.00229835510254, 17.895790100097656, 17.758975982666016, 17.595775604248047, 17.409526824951172, 17.20347023010254, 16.980684280395508, 16.744047164916992, 16.49620819091797, 16.239582061767578, 15.976338386535645, 15.708405494689941, 15.437490463256836, 15.165087699890137, 14.892501831054688, 14.62086296081543, 14.351151466369629, 14.08421516418457, 13.820786476135254, 13.56149959564209, 13.30690860748291, 13.0574951171875, 12.813688278198242, 12.575867652893066, 12.344378471374512, 12.119534492492676, 11.901632308959961, 11.690947532653809, 11.487750053405762, 11.292304992675781, 11.104873657226562, 10.925724983215332, 10.755131721496582, 10.59338092803955, 10.440770149230957, 10.297616004943848, 10.164253234863281, 10.041040420532227, 9.928357124328613, 9.826613426208496, 9.736245155334473, 9.65771770477295, 9.591526985168457, 9.538199424743652, 9.498295783996582, 9.47240161895752, 9.461133003234863, 9.465131759643555, 9.48505973815918, 9.52159309387207, 9.575417518615723, 9.647214889526367, 9.737655639648438, 9.847380638122559, 9.976985931396484, 10.127004623413086, 10.297882080078125, 10.489950180053711, 10.703400611877441, 10.938250541687012, 11.194314002990723, 11.471163749694824, 11.768096923828125, 12.084105491638184, 12.417840957641602, 12.767590522766113, 13.131260871887207, 13.506366729736328, 13.890032768249512, 14.279011726379395, 14.669717788696289, 15.058274269104004, 15.440581321716309, 15.812397003173828, 16.169437408447266, 16.50748634338379, 16.822498321533203, 17.110733032226562, 17.36884307861328, 17.593990325927734, 17.783910751342773, 17.93698501586914, 18.052255630493164, 18.12944221496582, 18.168914794921875, 18.171642303466797, 18.139131546020508, 18.073335647583008, 17.9765682220459, 17.851409912109375, 17.700603485107422, 17.526975631713867, 17.333358764648438, 17.122520446777344, 16.89711570739746, 16.65964698791504, 16.412439346313477, 16.15761947631836, 15.897119522094727, 15.632667541503906, 15.365804672241211, 15.09788990020752, 14.830120086669922, 14.563541412353516, 14.299067497253418, 14.037493705749512, 13.779516220092773, 13.525742530822754, 13.276705741882324, 13.032878875732422, 12.794681549072266, 12.562492370605469, 12.336655616760254, 12.117491722106934, 11.905299186706543, 11.700364112854004, 11.50296401977539, 11.313371658325195, 11.13186264038086, 10.958714485168457, 10.79421329498291, 10.638657569885254, 10.49235725402832, 10.355640411376953, 10.228856086730957, 10.112371444702148, 10.00658130645752, 9.911901473999023, 9.828779220581055, 9.757685661315918, 9.69912338256836, 9.653621673583984, 9.621737480163574, 9.604053497314453, 9.601176261901855, 9.613731384277344, 9.642359733581543, 9.687707901000977, 9.750423431396484, 9.831140518188477, 9.93047046661377, 10.048983573913574, 10.187191009521484, 10.345529556274414, 10.524330139160156, 10.723796844482422, 10.943979263305664, 11.184737205505371, 11.445714950561523, 11.726304054260254, 12.025615692138672, 12.342449188232422, 12.67526912689209, 13.022185325622559, 13.380941390991211, 13.74891185760498, 14.123120307922363, 14.50025749206543, 14.876726150512695, 15.248698234558105, 15.612183570861816, 15.963116645812988, 16.297456741333008, 16.611289978027344, 16.900930404663086, 17.163036346435547, 17.39469337463379, 17.593505859375, 17.75765037536621, 17.885923385620117, 17.977746963500977, 18.033172607421875, 18.052833557128906, 18.037899017333984, 17.99000358581543, 17.91115951538086, 17.803678512573242, 17.67007827758789, 17.51300048828125, 17.335124969482422, 17.13912010192871, 16.92757225036621, 16.70294761657715, 16.46756362915039, 16.223562240600586, 15.972906112670898, 15.717371940612793, 15.458553314208984, 15.197872161865234, 14.936583518981934, 14.675797462463379, 14.416487693786621, 14.15950870513916, 13.905610084533691, 13.655449867248535, 13.4096097946167, 13.168601989746094, 12.932886123657227, 12.702875137329102, 12.47894287109375, 12.26143741607666, 12.050680160522461, 11.846978187561035, 11.650626182556152, 11.4619140625, 11.2811279296875, 11.108556747436523, 10.94449520111084, 10.78924560546875, 10.643122673034668, 10.50645637512207, 10.379594802856445, 10.262901306152344, 10.15676498413086, 10.061596870422363, 9.97783088684082, 9.905927658081055, 9.846373558044434, 9.79967975616455, 9.766382217407227, 9.747040748596191, 9.742234230041504, 9.75256061553955, 9.756792068481445, 9.752321243286133, 9.737265586853027, 9.710389137268066, 9.671011924743652, 9.618927955627441, 9.554320335388184, 9.477682113647461, 9.389741897583008, 9.291396141052246, 9.18365478515625, 9.067587852478027, 8.944284439086914, 8.814824104309082, 8.680246353149414, 8.541535377502441, 8.39961051940918, 8.255313873291016, 8.109411239624023, 7.962590217590332, 7.815464496612549, 7.668576240539551, 7.522402763366699, 7.377361297607422, 7.233815670013428, 7.092082500457764, 6.9524359703063965, 6.8151140213012695, 6.680324554443359, 6.548247814178467, 6.419042587280273, 6.292849540710449, 6.169793128967285, 6.04998779296875, 5.933537483215332, 5.820539951324463, 5.71108865737915, 5.605275630950928, 5.503190994262695, 5.404928207397461, 5.310583114624023, 5.220256805419922, 5.134057521820068, 5.052100658416748, 4.974513530731201, 4.901434421539307, 4.833014488220215, 4.7694220542907715, 4.710842132568359, 4.6574788093566895, 4.609559059143066, 4.567333221435547, 4.531078338623047, 4.501100540161133, 4.477737903594971, 4.461362838745117, 4.452385902404785, 4.451258659362793, 4.458476543426514, 4.474581241607666, 4.500165939331055, 4.535876750946045, 4.5824174880981445, 4.640549182891846, 4.711095333099365, 4.794942378997803, 4.893039703369141, 5.006400108337402, 5.136097431182861, 5.283262252807617, 5.449077129364014, 5.634765148162842, 5.841580390930176, 6.070788860321045, 6.323648929595947, 6.601384162902832, 6.905149936676025, 7.235997200012207, 7.594822883605957, 7.9823198318481445, 8.39891529083252, 8.844707489013672, 9.319389343261719, 9.822184562683105, 10.351764678955078, 10.906189918518066, 11.482841491699219, 12.07837963104248, 12.688720703125, 13.309039115905762, 13.93380069732666, 14.556838989257812, 15.17147159576416, 15.770652770996094, 16.347169876098633, 16.893863677978516, 17.40387725830078, 17.87090492248535, 18.28942108154297, 18.6549015045166, 18.963973999023438, 19.213626861572266, 19.402172088623047, 19.5292911529541, 19.595983505249023, 19.604461669921875, 19.557987213134766, 19.460660934448242, 19.317201614379883, 19.13271141052246, 18.912460327148438, 18.661691665649414, 18.385461807250977, 18.08852195739746, 17.775232315063477, 17.44951057434082, 17.114809036254883, 16.774126052856445, 16.430023193359375, 16.08465576171875, 15.739821434020996, 15.396995544433594, 15.057380676269531, 14.72194766998291, 14.391471862792969, 14.066569328308105, 13.747724533081055, 13.435319900512695, 13.12965202331543, 12.830955505371094, 12.539411544799805, 12.25516414642334, 11.978327751159668, 11.708998680114746, 11.447256088256836, 11.193172454833984, 10.946818351745605, 10.708261489868164, 10.477574348449707, 10.254837036132812, 10.034626007080078, 9.816718101501465, 9.601027488708496, 9.387572288513184, 9.176441192626953, 8.967771530151367, 8.761727333068848, 8.55848503112793, 8.358219146728516, 8.161096572875977, 7.9672698974609375, 7.776872634887695, 7.590019226074219, 7.406804084777832, 7.227301597595215, 7.051567554473877, 6.879642009735107, 6.711548328399658, 6.547297954559326, 6.3868889808654785, 6.230311870574951, 6.077547550201416, 5.928570747375488, 5.783351421356201, 5.641855716705322, 5.504045486450195, 5.369881629943848, 5.239324569702148, 5.112332820892334, 4.988867282867432, 4.8688883781433105, 4.752358913421631, 4.639243125915527, 4.5295090675354, 4.423127174377441, 4.320071697235107, 4.2203216552734375, 4.1238603591918945, 4.03067684173584, 3.940765857696533, 3.8541290760040283, 3.770775079727173, 3.690720796585083, 3.6139919757843018, 3.5406246185302734, 3.4706647396087646, 3.4041712284088135, 3.3412153720855713, 3.281883478164673, 3.2262778282165527, 3.1745188236236572, 3.12674617767334, 3.0831215381622314, 3.0438308715820312, 3.0090863704681396, 2.979130268096924, 2.954237461090088, 2.9347188472747803, 2.9209253787994385, 2.913252353668213, 2.9121434688568115, 2.9180965423583984, 2.931668519973755, 2.9534809589385986, 2.9842262268066406, 3.024674892425537, 3.07568097114563, 3.1381900310516357, 3.2132458686828613, 3.3019964694976807, 3.4057016372680664, 3.5257375240325928, 3.663601875305176, 3.8209152221679688, 3.999422550201416, 4.20098876953125, 4.427591800689697, 4.681307792663574, 4.964293003082275, 5.278752326965332, 5.626902103424072, 6.010915756225586, 6.432860374450684, 6.894613265991211, 7.397765159606934, 7.943502426147461, 8.532475471496582, 9.164650917053223, 9.839151382446289, 10.554096221923828, 11.306438446044922, 12.091830253601074, 12.904512405395508, 13.737255096435547, 14.58137321472168, 15.426817893981934, 16.262372970581055, 17.075952529907227, 17.855009078979492, 18.587017059326172, 19.260019302368164, 19.86203956604004, 20.38272476196289, 20.813913345336914, 21.150070190429688, 21.388547897338867, 21.529645919799805, 21.576454162597656, 21.534528732299805, 21.411413192749023, 21.216073989868164, 20.95831298828125, 20.64822006225586, 20.29567527770996, 19.909975051879883, 19.499557495117188, 19.071847915649414, 18.633180618286133, 18.18882179260254, 17.74302864074707, 17.299152374267578, 16.85976219177246, 16.4267635345459, 16.001523971557617, 15.584980010986328, 15.177734375, 14.780136108398438, 14.392343521118164, 14.014381408691406, 13.646178245544434, 13.287598609924316, 12.93846607208252, 12.598579406738281, 12.26772403717041, 11.945683479309082, 11.632238388061523, 11.327174186706543, 11.03028392791748, 10.74136734008789, 10.460229873657227, 10.186687469482422, 9.920563697814941, 9.661687850952148, 9.40989875793457, 9.165040969848633, 8.926968574523926, 8.695542335510254, 8.470629692077637, 8.252106666564941, 8.03985595703125, 7.833769798278809, 7.633748531341553, 7.43970251083374, 7.25154972076416, 7.069221019744873, 6.8926568031311035, 6.721810340881348, 6.556647777557373, 6.397150039672852, 6.243313312530518, 6.095151901245117, 5.95269775390625, 5.816005229949951, 5.685150623321533, 5.560237407684326, 5.4413957595825195, 5.328788757324219, 5.222613334655762, 5.123106956481934, 5.030549049377441, 4.945267677307129, 4.867644786834717, 4.798121929168701, 4.737205505371094, 4.685476303100586, 4.643595218658447, 4.612313270568848, 4.592478275299072, 4.585046768188477, 4.591092109680176, 4.611813545227051, 4.648549556732178, 4.702783584594727, 4.776154518127441, 4.870462894439697, 4.98767614364624, 5.129929065704346, 5.299520015716553, 5.498901844024658, 5.730663776397705, 5.997501373291016, 6.302176475524902, 6.647459983825684, 7.036054611206055, 7.470499515533447, 7.953047275543213, 8.485518455505371, 9.06912899017334, 9.704292297363281, 10.390403747558594, 11.1256103515625, 11.906585693359375, 12.728321075439453, 13.583953857421875, 14.464672088623047, 15.359701156616211, 16.256431579589844, 17.140674591064453, 17.997095108032227, 18.809776306152344, 19.562936782836914, 20.241718292236328, 20.832998275756836, 21.32613754272461, 21.713594436645508, 21.9913272857666, 22.158926010131836, 22.219493865966797, 22.17924690246582, 22.046939849853516, 21.833145141601562, 21.54950714111328, 21.20801544189453, 20.820384979248047, 20.39756965637207, 19.949419021606445, 19.48448371887207, 19.00995445251465, 18.531686782836914, 18.054306030273438, 17.58134651184082, 17.11541748046875, 16.658357620239258, 16.211400985717773, 15.775304794311523, 15.350470542907715, 14.937039375305176, 14.534966468811035, 14.144082069396973, 13.764138221740723, 13.394838333129883, 13.03586196899414, 12.686882019042969, 12.34757137298584, 12.01761531829834, 11.696708679199219, 11.384560585021973, 11.080897331237793, 10.785457611083984, 10.497993469238281, 10.218271255493164, 9.946064949035645, 9.681163787841797, 9.423360824584961, 9.172459602355957, 8.928271293640137, 8.690614700317383, 8.459314346313477, 8.234199523925781, 8.015107154846191, 7.801878929138184, 7.594359397888184, 7.392399311065674, 7.195854187011719, 7.004582405090332, 6.818447113037109, 6.6373162269592285, 6.461060047149658, 6.289553642272949, 6.122675895690918, 5.960252285003662, 5.80216121673584, 5.648284912109375, 5.498509407043457, 5.352725505828857, 5.2108259201049805, 5.0727081298828125, 4.938271999359131, 4.80742073059082, 4.680060386657715, 4.556098937988281, 4.435448169708252, 4.318021774291992, 4.203735828399658, 4.092508792877197, 3.9842617511749268, 3.878917932510376, 3.776402473449707, 3.676643133163452, 3.5795695781707764, 3.4851133823394775, 3.3932085037231445, 3.303790330886841, 3.216797351837158, 3.1321685314178467, 3.0498464107513428, 2.969774007797241, 2.891897201538086, 2.8161637783050537, 2.742522716522217, 2.670926094055176, 2.6013269424438477, 2.5336809158325195, 2.4679455757141113, 2.4040801525115967, 2.3420467376708984, 2.2818093299865723, 2.2233338356018066, 2.1665890216827393, 2.1115458011627197, 2.058178424835205, 2.006463050842285, 1.9563792943954468, 1.9079097509384155, 1.861040472984314, 1.8157612085342407, 1.7720656394958496, 1.7299518585205078, 1.689422607421875, 1.6504857540130615, 1.6131551265716553, 1.5774505138397217, 1.5433990955352783, 1.5110355615615845, 1.480403184890747, 1.4515552520751953, 1.4245554208755493, 1.399479627609253, 1.376417636871338, 1.3554739952087402, 1.33677077293396, 1.3204492330551147, 1.3066723346710205, 1.2956279516220093, 1.2875311374664307, 1.2826288938522339, 1.281203269958496, 1.2835763692855835, 1.2901153564453125, 1.3012385368347168, 1.317421793937683, 1.3392058610916138, 1.3672044277191162, 1.402113914489746, 1.4447228908538818, 1.4959237575531006, 1.556725263595581, 1.628265142440796, 1.7118253707885742, 1.8088473081588745, 1.920947790145874, 2.0499355792999268, 2.197828531265259, 2.366868734359741, 2.559537410736084, 2.778566598892212, 3.0269455909729004, 3.307921886444092, 3.624992847442627, 3.981884479522705, 4.382513999938965, 4.830931663513184, 5.331235885620117, 5.887457370758057, 6.50340461730957, 7.182467460632324, 7.927371978759766, 8.73989200592041, 9.62050724029541, 10.568037033081055, 11.579240798950195, 12.647491455078125, 13.763079643249512, 14.912983894348145, 16.0808162689209, 17.24702262878418, 18.389379501342773, 19.483823776245117, 20.505590438842773, 21.430625915527344, 22.237123489379883, 22.905603408813477, 23.421669006347656, 23.777124404907227, 23.97051429748535, 24.00705337524414, 23.897924423217773, 23.65907859802246, 23.309715270996094, 22.870668411254883, 22.36288070678711, 21.8061580657959, 21.218250274658203, 20.61431121826172, 20.00668716430664, 19.40496063232422, 18.81618309020996, 18.245222091674805, 17.695138931274414, 17.16756820678711, 16.663074493408203, 16.18144416809082, 15.721942901611328, 15.283499717712402, 14.864862442016602, 14.464703559875488, 14.081693649291992, 13.714554786682129, 13.362089157104492, 13.02319622039795, 12.696880340576172, 12.382248878479004, 12.078506469726562, 11.784954071044922, 11.500972747802734, 11.226018905639648, 10.959615707397461, 10.701342582702637, 10.45082950592041, 10.207748413085938, 9.971808433532715, 9.742749214172363, 9.520339012145996, 9.304367065429688, 9.09464168548584, 8.890989303588867, 8.693248748779297, 8.501274108886719, 8.314927101135254, 8.134079933166504, 7.958611011505127, 7.788407325744629, 7.623362064361572, 7.463373184204102, 7.308342456817627, 7.1563239097595215, 7.007151126861572, 6.860712051391602, 6.716935634613037, 6.575782299041748, 6.4372382164001465, 6.301304340362549, 6.167994499206543, 6.037330150604248, 5.909336566925049, 5.784041404724121, 5.661472797393799, 5.541658878326416, 5.424625396728516, 5.310398101806641, 5.198999404907227, 5.090452194213867, 4.984776496887207, 4.881992340087891, 4.7821197509765625, 4.685179233551025, 4.591190814971924, 4.500176906585693, 4.412162780761719, 4.327175140380859, 4.245244026184082, 4.166405200958252, 4.090697765350342, 4.018167018890381, 3.9488649368286133, 3.882850408554077, 3.820190668106079, 3.7609620094299316, 3.7052512168884277, 3.653156280517578, 3.6047873497009277, 3.5602688789367676, 3.519739866256714, 3.483356237411499, 3.4512925148010254, 3.4237422943115234, 3.400921583175659, 3.3830697536468506, 3.370452404022217, 3.3633627891540527, 3.3621251583099365, 3.3670966625213623, 3.378669500350952, 3.397274971008301, 3.4233856201171875, 3.457517385482788, 3.5002336502075195, 3.552147150039673, 3.6139228343963623, 3.6862804889678955, 3.76999568939209, 3.8659017086029053, 3.97489070892334, 4.097911357879639, 4.235968589782715, 4.390119552612305, 4.561467170715332, 4.751153945922852, 4.960348606109619, 5.190232276916504, 5.441980361938477, 5.716736793518066, 6.015588760375977, 6.339529037475586, 6.68941593170166, 7.065928936004639, 7.469512462615967, 7.900321006774902, 8.358155250549316, 8.842394828796387, 9.351937294006348, 9.8851318359375, 10.439724922180176, 11.012819290161133, 11.60084056854248, 12.199540138244629, 12.804012298583984, 13.408753395080566, 14.007752418518066, 14.594614028930664, 15.162726402282715, 15.705445289611816, 16.216312408447266, 16.689271926879883, 17.11888885498047, 17.41895866394043, 17.584535598754883, 17.618175506591797, 17.528932571411133, 17.330894470214844, 17.04149055480957, 16.679746627807617, 16.264724731445312, 15.814257621765137, 15.344085693359375, 14.867358207702637, 14.3944730758667, 13.933175086975098, 13.4888277053833, 13.064774513244629, 12.662734985351562, 12.283186912536621, 11.925711631774902, 11.589282035827637, 11.272500038146973, 10.973774909973145, 10.691455841064453, 10.42392635345459, 10.169663429260254, 9.927275657653809, 9.695521354675293, 9.473310470581055, 9.259705543518066, 9.053906440734863, 8.855244636535645, 8.663162231445312, 8.477201461791992, 8.296990394592285, 8.12222957611084, 7.952680587768555, 7.788155555725098, 7.628510475158691, 7.473635673522949, 7.323452472686768, 7.177906513214111, 7.03696346282959, 6.900609970092773, 6.768846035003662, 6.641688346862793, 6.519166469573975, 6.4013237953186035, 6.288216590881348, 6.179914474487305, 6.076500415802002, 5.9780731201171875, 5.8847455978393555, 5.7966485023498535, 5.713929653167725, 5.636756896972656, 5.565320014953613, 5.499830722808838, 5.440526962280273, 5.387673854827881, 5.341566562652588, 5.302532196044922, 5.270933628082275, 5.247171878814697, 5.231688499450684, 5.224969387054443, 5.227548599243164, 5.240009784698486, 5.262989521026611, 5.297181606292725, 5.343338489532471, 5.402273178100586, 5.474862098693848, 5.562044620513916, 5.664821147918701, 5.784254550933838, 5.9214630126953125, 6.077616214752197, 6.25392484664917, 6.4516282081604, 6.67197847366333, 6.916219234466553, 7.185559272766113, 7.481140613555908, 7.803997993469238, 8.155014991760254, 8.534872055053711, 8.943984985351562, 9.382441520690918, 9.849929809570312, 10.345667839050293, 10.868328094482422, 11.415972709655762, 11.985992431640625, 12.575060844421387, 13.179112434387207, 13.793342590332031, 14.412242889404297, 15.02967643737793, 15.63899040222168, 16.233165740966797, 16.80501937866211, 17.347412109375, 17.852548599243164, 18.31310272216797, 18.722522735595703, 19.075300216674805, 19.367204666137695, 19.595447540283203, 19.758758544921875, 19.857397079467773, 19.893051147460938, 19.86869239807129, 19.78835105895996, 19.65687370300293, 19.479658126831055, 19.26238441467285, 19.01079559326172, 18.730487823486328, 18.426761627197266, 18.104503631591797, 17.768117904663086, 17.42149543762207, 17.068004608154297, 16.710521697998047, 16.35145378112793, 15.992793083190918, 15.636168479919434, 15.282889366149902, 14.933998107910156, 14.590315818786621, 14.252481460571289, 13.920988082885742, 13.596209526062012, 13.278426170349121, 12.967849731445312, 12.664631843566895, 12.368886947631836, 12.080695152282715, 11.800114631652832, 11.527189254760742, 11.261954307556152, 11.004437446594238, 10.754666328430176, 10.512673377990723, 10.278493881225586, 10.05217170715332, 9.833761215209961, 9.623332023620605, 9.420967102050781, 9.226766586303711, 9.040854454040527, 8.863374710083008, 8.694499015808105, 8.53442668914795, 8.383389472961426, 8.241654396057129, 8.109524726867676, 7.987348556518555, 7.875517845153809, 7.774474620819092, 7.684712886810303, 7.606785774230957, 7.541306495666504, 7.488953113555908, 7.450472354888916, 7.426682949066162, 7.418476104736328, 7.426819801330566, 7.452756881713867, 7.497405052185059, 7.561951160430908, 7.647647857666016, 7.755803108215332, 7.887765407562256, 8.044907569885254, 8.228602409362793, 8.440191268920898, 8.680949211120605, 8.95203685760498, 9.254448890686035, 9.588950157165527, 9.95600414276123, 10.355697631835938, 10.787652015686035, 11.250936508178711, 11.74398422241211, 12.264503479003906, 12.80941390991211, 13.374789237976074, 13.955836296081543, 14.54690170288086, 15.141528129577637, 15.732549667358398, 16.3122501373291, 16.872562408447266, 17.405315399169922, 17.902515411376953, 18.356651306152344, 18.760990142822266, 19.109844207763672, 19.398818969726562, 19.624954223632812, 19.78683090209961, 19.88455581665039, 19.919689178466797, 19.895084381103516, 19.814672470092773, 19.682546615600586, 19.50347328186035, 19.282665252685547, 19.025548934936523, 18.737567901611328, 18.423995971679688, 18.089815139770508, 17.73961067199707, 17.377504348754883, 17.007139205932617, 16.63166618347168, 16.253761291503906, 15.8756685256958, 15.49923038482666, 15.12593936920166, 14.756982803344727, 14.393287658691406, 14.035563468933105, 13.68433952331543, 13.34000015258789, 13.002809524536133, 12.672937393188477, 12.350480079650879, 12.03547477722168, 11.727913856506348, 11.427756309509277, 11.134932518005371, 10.849357604980469, 10.570927619934082, 10.299530982971191, 10.035048484802246, 9.777355194091797, 9.526323318481445, 9.28182315826416, 9.04372501373291, 8.811898231506348, 8.586214065551758, 8.366544723510742, 8.152762413024902, 7.944743633270264, 7.74236536026001, 7.54550838470459, 7.354054927825928, 7.1678900718688965, 6.98690128326416, 6.810979843139648, 6.640019416809082, 6.473916530609131, 6.312570571899414, 6.155884265899658, 6.003763198852539, 5.85611629486084, 5.712855339050293, 5.57389497756958, 5.43915319442749, 5.30855131149292, 5.182013034820557, 5.059464931488037, 4.940837860107422, 4.826064109802246, 4.715079307556152, 4.607821941375732, 4.504233360290527, 4.404257774353027, 4.307840824127197, 4.214932441711426, 4.12548303604126, 4.039446830749512, 3.9567792415618896, 3.8774378299713135, 3.801382303237915, 3.728573799133301, 3.6589748859405518, 3.5925495624542236, 3.5292630195617676, 3.469081163406372, 3.411970376968384, 3.357897996902466, 3.306830406188965, 3.258735179901123, 3.213578224182129, 3.17069149017334, 3.1300203800201416, 3.0915277004241943, 3.055192470550537, 3.0210070610046387, 2.9889771938323975, 2.9591195583343506, 2.9314615726470947, 2.906041145324707, 2.8829054832458496, 2.8621115684509277, 2.8437254428863525, 2.827822208404541, 2.8144869804382324, 2.80381441116333, 2.7959089279174805, 2.7908852100372314, 2.7888693809509277, 2.789998769760132, 2.7944223880767822, 2.802302360534668, 2.813814163208008, 2.8291473388671875, 2.8485066890716553, 2.8721120357513428, 2.900200366973877, 2.9330263137817383, 2.9708621501922607, 3.0139992237091064, 3.062748908996582, 3.1174423694610596, 3.178431749343872, 3.2460906505584717, 3.3208134174346924, 3.403015613555908, 3.4931328296661377, 3.5916213989257812, 3.6989552974700928, 3.815624713897705, 3.942134380340576, 4.078998565673828, 4.226738452911377, 4.385876178741455, 4.556927680969238, 4.740396976470947, 4.936764717102051, 5.146480560302734, 5.369948863983154, 5.607515811920166, 5.859455108642578, 6.125951766967773, 6.4070820808410645, 6.7027974128723145, 7.012903213500977, 7.337038516998291, 7.674659252166748, 8.025017738342285, 8.387147903442383, 8.759849548339844, 9.141684532165527, 9.530969619750977, 9.92577838897705, 10.323954582214355, 10.723128318786621, 11.120745658874512, 11.51409912109375, 11.90038013458252, 12.276724815368652, 12.640274047851562, 12.988237380981445, 13.31795597076416, 13.626967430114746, 13.91306209564209, 14.174342155456543, 14.409258842468262, 14.616646766662598, 14.795745849609375, 14.946200370788574, 15.068058967590332, 15.161746978759766, 15.22803783416748, 15.268013000488281, 15.283016204833984, 15.2746000289917, 15.24448013305664, 15.194480895996094, 15.126492500305176, 15.042427062988281, 14.944186210632324, 14.83362865447998, 14.71254825592041, 14.582656860351562, 14.445575714111328, 14.302824020385742, 14.15582275390625, 14.005891799926758, 13.854255676269531, 13.702051162719727, 13.550332069396973, 13.400077819824219, 13.252204895019531, 13.107337951660156, 12.966053009033203, 12.828890800476074, 12.69613265991211, 12.568024635314941, 12.444780349731445, 12.326581001281738, 12.213581085205078, 12.10590648651123, 12.003657341003418, 11.906907081604004, 11.815705299377441, 11.730079650878906, 11.650029182434082, 11.57553482055664, 11.506549835205078, 11.443005561828613, 11.384808540344238, 11.331843376159668, 11.283967018127441, 11.241015434265137, 11.202798843383789, 11.16910171508789, 11.139688491821289, 11.114294052124023, 11.092635154724121, 11.074402809143066, 11.059267044067383, 11.04687786102295, 11.036867141723633, 11.028848648071289, 11.022422790527344, 11.017176628112793, 11.012688636779785, 11.008530616760254, 11.00426959991455, 10.999476432800293, 10.993721008300781, 10.98658561706543, 10.977660179138184, 10.966550827026367, 10.952881813049316, 10.936300277709961, 10.916475296020508, 10.893108367919922, 10.865925788879395, 10.834691047668457, 10.799200057983398, 10.759282112121582, 10.714805603027344, 10.665672302246094, 10.611823081970215, 10.553231239318848, 10.48990535736084, 10.421886444091797, 10.349247932434082, 10.272088050842285, 10.190535545349121, 10.10473918914795, 10.014871597290039, 9.921120643615723, 9.823690414428711, 9.722799301147461, 9.618673324584961, 9.511547088623047, 9.401658058166504, 9.289249420166016, 9.174561500549316, 9.05783462524414, 8.939305305480957, 8.819208145141602, 8.69776725769043, 8.571085929870605, 8.439717292785645, 8.304280281066895, 8.165427207946777, 8.02381706237793, 7.880097389221191, 7.734885215759277, 7.588758945465088, 7.442251682281494, 7.295848846435547, 7.149985313415527, 7.0050482749938965, 6.8613786697387695, 6.719273567199707, 6.578991889953613, 6.440755844116211, 6.304756164550781, 6.1711554527282715, 6.040092468261719, 5.911684989929199, 5.7860331535339355, 5.66322135925293, 5.5433220863342285, 5.426397800445557, 5.312502861022949, 5.201685905456543, 5.093989849090576, 4.989455699920654, 4.88812255859375, 4.790030002593994, 4.695217132568359, 4.603726387023926, 4.515603065490723, 4.430896759033203, 4.3496623039245605, 4.271961688995361, 4.197864055633545, 4.127448081970215, 4.060801982879639, 3.998025894165039, 3.939232349395752, 3.8845481872558594, 3.8341164588928223, 3.788097858428955, 3.7466723918914795, 3.710041046142578, 3.678428888320923, 3.6520862579345703, 3.6312925815582275, 3.61635684967041, 3.6076228618621826, 3.6054704189300537, 3.610318899154663, 3.6226305961608887, 3.6429147720336914, 3.671729564666748, 3.709686756134033, 3.7574548721313477, 3.8157618045806885, 3.8853988647460938, 3.9672224521636963, 4.0621562004089355, 4.1711931228637695, 4.295392990112305, 4.435883522033691, 4.593855857849121, 4.770557403564453, 4.967284202575684, 5.185368537902832, 5.426161289215088, 5.69101095199585, 5.981234550476074, 6.298086643218994, 6.642714977264404, 7.016113758087158, 7.419065952301025, 7.852081775665283, 8.315324783325195, 8.808537483215332, 9.330962181091309, 9.881258964538574, 10.457433700561523, 11.056767463684082, 11.67577075958252, 12.310151100158691, 12.954815864562988, 13.603914260864258, 14.250910758972168, 14.888714790344238, 15.509849548339844, 16.106666564941406, 16.671585083007812, 17.197368621826172, 17.677391052246094, 18.10589599609375, 18.47821617126465, 18.79095458984375, 19.042083740234375, 19.230987548828125, 19.35841178894043, 19.426361083984375, 19.43715476989746, 19.394075393676758, 19.30118751525879, 19.163116455078125, 18.984840393066406, 18.77147674560547, 18.528108596801758, 18.2596435546875, 17.97068214416504, 17.665456771850586, 17.3477725982666, 17.020999908447266, 16.688066482543945, 16.351482391357422, 16.013376235961914, 15.675520896911621, 15.339391708374023, 15.00619125366211, 14.676901817321777, 14.352312088012695, 14.03305721282959, 13.719643592834473, 13.412474632263184, 13.111870765686035, 12.818087577819824, 12.531329154968262, 12.251763343811035, 11.979525566101074, 11.71473217010498, 11.457486152648926, 11.207880020141602, 10.966002464294434, 10.73194408416748, 10.505797386169434, 10.287664413452148, 10.077655792236328, 9.875895500183105, 9.682524681091309, 9.497700691223145, 9.321606636047363, 9.154446601867676, 8.996455192565918, 8.847894668579102, 8.709063529968262, 8.58029556274414, 8.461966514587402, 8.354493141174316, 8.258341789245605, 8.174026489257812, 8.102115631103516, 8.043235778808594, 7.998067855834961, 7.967357158660889, 7.951910495758057, 7.952597141265869, 7.970347881317139, 8.006153106689453, 8.061059951782227, 8.136163711547852, 8.232596397399902, 8.351520538330078, 8.49410343170166, 8.66150188446045, 8.854830741882324, 9.075132369995117, 9.323336601257324, 9.600212097167969, 9.906316757202148, 10.241935729980469]}, {"name": "y", "type": "scatter", "y": [5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 9.5, 9.399999618530273, 9.300000190734863, 9.199999809265137, 9.100000381469727, 9.0, 8.899999618530273, 8.800000190734863, 8.699999809265137, 8.600000381469727, 8.5, 8.399999618530273, 8.300000190734863, 8.199999809265137, 8.100000381469727, 8.0, 7.900000095367432, 7.800000190734863, 7.699999809265137, 7.599999904632568, 7.5, 7.400000095367432, 7.300000190734863, 7.199999809265137, 7.099999904632568, 7.0, 6.900000095367432, 6.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 9.5, 9.399999618530273, 9.300000190734863, 9.199999809265137, 9.100000381469727, 9.0, 8.899999618530273, 8.800000190734863, 8.699999809265137, 8.600000381469727, 8.5, 8.399999618530273, 8.300000190734863, 8.199999809265137, 8.100000381469727, 8.0, 7.900000095367432, 7.800000190734863, 7.699999809265137, 7.599999904632568, 7.5, 7.400000095367432, 7.300000190734863, 7.199999809265137, 7.099999904632568, 7.0, 6.900000095367432, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 9.5, 9.399999618530273, 9.300000190734863, 9.199999809265137, 9.100000381469727, 9.0, 8.899999618530273, 8.800000190734863, 8.699999809265137, 8.600000381469727, 8.5, 8.399999618530273, 8.300000190734863, 8.199999809265137, 8.100000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0]}],
                            {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Trajectory of the Lorenz solution, projected along the z-axis"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('cbe0859b-66a2-4562-afb2-2876abcc7740');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Resampling the time series
--------------------------

It is important to find the correct time scale at which key signals take
place. Here we propose one possible resampling period: *10h*. Recall
that the unit time is *1h*. The resampler method is used to perform the
resampling.

.. code:: ipython3

    period = 10
    periodicSampler = Resampler(period=period)
    
    X_sampled, y_sampled = periodicSampler.fit_transform_resample(X, y)

.. code:: ipython3

    fig = px.line(title='Trajectory of the Lorenz solution, projected along the z-axis and resampled every 10h')
    fig.add_scatter(y=X_sampled.flatten(), name='X_sampled')
    fig.add_scatter(y=y_sampled, name='y_sampled')
    fig.show()



.. raw:: html

    <div>
    
    
                <div id="c41612dd-540c-4f6f-8c1b-9561a8342ae8" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("c41612dd-540c-4f6f-8c1b-9561a8342ae8")) {
                        Plotly.newPlot(
                            'c41612dd-540c-4f6f-8c1b-9561a8342ae8',
                            [{"name": "X_sampled", "type": "scatter", "y": [10.0, 9.880752563476562, 10.774194717407227, 9.310019493103027, 7.257726669311523, 5.550174236297607, 4.236861705780029, 3.2340033054351807, 2.4685113430023193, 1.8843207359313965, 1.4386281967163086, 1.09886634349823, 0.8404794931411743, 0.6455944180488586, 0.5032125115394592, 0.413541704416275, 0.4067001938819885, 0.6162614226341248, 1.5636451244354248, 5.103882312774658, 14.98863410949707, 24.83124542236328, 19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045, 5.9185099601745605, 4.517035961151123, 3.447882652282715, 2.6329939365386963, 2.0123798847198486, 1.5405652523040771, 1.184604287147522, 0.9232151508331299, 0.7515450716018677, 0.702305257320404, 0.9235610365867615, 1.9513802528381348, 5.485874652862549, 14.582544326782227, 23.905990600585938, 21.142423629760742, 15.784836769104004, 12.039207458496094, 9.355100631713867, 7.48189115524292, 6.479306697845459, 6.854121208190918, 9.86506462097168, 16.18271255493164, 20.693172454833984, 18.73451805114746, 14.760367393493652, 11.364433288574219, 8.7335786819458, 6.728298664093018, 5.223234176635742, 4.110780715942383, 3.282271146774292, 2.7052900791168213, 2.4036595821380615, 2.5079102516174316, 3.202155113220215, 4.251739025115967, 5.609485149383545, 7.216982364654541, 8.871070861816406, 10.258978843688965, 11.169272422790527, 11.664118766784668, 12.023893356323242, 12.590555191040039, 13.621294975280762, 14.842605590820312, 15.496397972106934, 15.18989372253418, 14.244672775268555, 13.228567123413086, 12.582527160644531, 12.5833158493042, 13.307403564453125, 14.455156326293945, 15.31961727142334, 15.324563026428223, 14.567307472229004, 13.564197540283203, 12.793840408325195, 12.57542610168457, 13.05505084991455, 14.07629108428955, 15.063932418823242, 15.357551574707031, 14.829564094543457, 12.612897872924805, 9.60682201385498, 7.30527925491333, 5.5909905433654785, 4.301223278045654, 3.3477299213409424, 2.7020702362060547, 2.4528980255126953, 3.036674737930298, 5.922054767608643, 13.669175148010254, 15.741020202636719, 11.736970901489258, 8.917984962463379, 7.068406581878662, 5.777517318725586, 5.022008895874023, 5.022371768951416, 6.435998916625977, 10.485421180725098, 17.065458297729492, 20.57697105407715, 18.081132888793945, 14.256850242614746, 11.097949028015137, 8.716547966003418, 7.095892429351807, 6.428525924682617, 7.434159278869629, 11.516939163208008, 18.137123107910156, 20.381776809692383, 16.77204132080078, 12.772895812988281, 9.722888946533203, 7.422309875488281, 5.672788619995117, 4.339235305786133, 3.325570583343506, 2.5631353855133057, 2.0115110874176025, 1.6782469749450684, 1.6996207237243652, 2.632023811340332, 6.286675453186035, 15.691393852233887, 24.0217227935791, 20.570253372192383, 15.375616073608398, 11.738700866699219, 9.103957176208496, 7.189553260803223, 5.885937213897705, 5.173672676086426, 4.955836772918701, 4.864617824554443, 4.939504623413086, 5.345020294189453, 6.303348541259766, 8.036109924316406, 10.50344181060791, 12.998895645141602, 14.436258316040039, 14.534979820251465, 13.975706100463867, 13.379403114318848, 13.075737953186035, 13.228426933288574, 13.797710418701172, 14.490015983581543, 14.880401611328125, 14.738289833068848, 14.193717956542969, 13.569287300109863, 13.167555809020996, 13.17829704284668, 13.621578216552734, 14.154986381530762, 14.013508796691895, 12.00007152557373, 9.18571662902832, 6.985784530639648, 5.333123207092285, 4.08131742477417, 3.13779616355896, 2.4482712745666504, 2.0142955780029297, 1.9887280464172363, 3.041350841522217, 7.375819683074951, 17.611530303955078, 24.14252471923828, 19.631349563598633, 14.697957038879395, 11.257065773010254, 8.686368942260742, 6.689769744873047, 5.15323543548584, 3.990213394165039, 3.1415324211120605, 2.602027416229248, 2.4986321926116943, 3.3396100997924805, 6.626110553741455, 14.646973609924316, 22.65271759033203, 20.620529174804688, 15.558791160583496, 11.814583778381348, 9.096705436706543, 7.071575164794922, 5.518078804016113, 4.321174144744873, 3.4323010444641113, 2.836334466934204, 2.5944249629974365, 2.961709976196289, 4.666600704193115, 9.14708137512207, 16.477304458618164, 20.526952743530273, 18.203771591186523, 14.369884490966797, 11.183107376098633, 8.775131225585938, 7.124290943145752, 6.408812522888184, 7.318809986114502, 11.253149032592773, 17.88862419128418, 20.437467575073242, 16.924034118652344, 12.890128135681152, 9.810127258300781, 7.489336967468262, 5.727321147918701, 4.388706207275391, 3.3750035762786865, 2.610436201095581, 2.0407395362854004, 1.6386891603469849, 1.4113255739212036, 1.4409632682800293, 2.0097317695617676, 3.9138307571411133, 8.766448020935059, 16.65705108642578, 20.65085220336914, 18.006250381469727, 14.12304401397705, 10.956222534179688, 8.566047668457031, 6.910210609436035, 6.14066743850708, 6.907512664794922, 10.653786659240723, 13.949995040893555, 11.633843421936035, 8.79044246673584, 6.68988561630249, 5.127269744873047, 3.960143566131592, 3.124302864074707, 2.644627809524536, 2.7798194885253906, 4.5266852378845215, 10.522139549255371, 20.789522171020508, 22.871755599975586, 17.689651489257812, 13.349187850952148, 10.218582153320312, 7.908336639404297, 6.281363487243652, 5.41464900970459, 5.836874485015869, 7.920112609863281, 8.928873062133789, 8.497692108154297, 7.539384365081787, 6.67495584487915, 6.227055549621582, 6.525177955627441, 8.101166725158691, 11.503066062927246, 15.933252334594727, 18.299108505249023, 17.095096588134766, 14.416543006896973, 11.927948951721191, 10.151688575744629, 9.400187492370605, 10.175674438476562, 12.97225570678711, 16.744264602661133, 18.209245681762695, 16.528566360473633, 13.867773056030273, 11.546838760375977, 9.996892929077148, 9.561210632324219, 10.775303840637207, 13.317831039428711, 12.016406059265137, 9.243946075439453, 7.027894973754883, 5.360456943511963, 4.094522953033447, 3.1337010860443115, 2.4135560989379883, 1.904931664466858, 1.6590477228164673, 2.0058014392852783, 4.233810901641846, 11.52518367767334, 22.58885955810547, 22.744531631469727, 17.07865333557129, 12.94926643371582, 10.03945541381836, 7.9876909255981445, 6.795091152191162, 6.865779876708984, 8.903059959411621, 9.865697860717773, 8.916321754455566, 7.458118915557861, 6.161727428436279, 5.048085689544678, 4.175311088562012, 3.6006336212158203, 3.424589157104492, 3.909852981567383, 5.652180194854736, 9.503758430480957, 14.942774772644043, 18.04989242553711, 16.980684280395508, 14.351151466369629, 11.901632308959961, 10.164253234863281, 9.461133003234863, 10.297882080078125, 13.131260871887207, 16.822498321533203, 18.139131546020508, 16.412439346313477, 13.779516220092773, 11.50296401977539, 10.00658130645752, 9.642359733581543, 10.943979263305664, 14.123120307922363, 17.39469337463379, 17.803678512573242, 15.717371940612793, 13.168601989746094, 11.108556747436523, 9.905927658081055, 9.710389137268066, 8.814824104309082, 7.377361297607422, 6.04998779296875, 5.052100658416748, 4.501100540161133, 4.640549182891846, 6.070788860321045, 9.822184562683105, 15.770652770996094, 19.5292911529541, 18.08852195739746, 14.72194766998291, 11.708998680114746, 9.387572288513184, 7.406804084777832, 5.783351421356201, 4.5295090675354, 3.6139919757843018, 3.0438308715820312, 2.9534809589385986, 3.8209152221679688, 6.894613265991211, 13.737255096435547, 20.813913345336914, 20.29567527770996, 16.001523971557617, 12.26772403717041, 9.40989875793457, 7.25154972076416, 5.685150623321533, 4.737205505371094, 4.776154518127441, 7.036054611206055, 13.583953857421875, 21.32613754272461, 20.820384979248047, 16.211400985717773, 12.34757137298584, 9.423360824584961, 7.195854187011719, 5.498509407043457, 4.203735828399658, 3.216797351837158, 2.4679455757141113, 1.9079097509384155, 1.5110355615615845, 1.2956279516220093, 1.402113914489746, 2.366868734359741, 5.887457370758057, 14.912983894348145, 23.777124404907227, 20.61431121826172, 15.283499717712402, 11.784954071044922, 9.304367065429688, 7.463373184204102, 6.037330150604248, 4.881992340087891, 4.018167018890381, 3.483356237411499, 3.397274971008301, 4.097911357879639, 6.339529037475586, 11.012819290161133, 16.689271926879883, 15.814257621765137, 11.589282035827637, 9.053906440734863, 7.323452472686768, 6.076500415802002, 5.341566562652588, 5.343338489532471, 6.67197847366333, 10.345667839050293, 16.233165740966797, 19.857397079467773, 18.104503631591797, 14.590315818786621, 11.527189254760742, 9.226766586303711, 7.774474620819092, 7.497405052185059, 9.254448890686035, 13.955836296081543, 19.109844207763672, 19.282665252685547, 15.8756685256958, 12.350480079650879, 9.526323318481445, 7.354054927825928, 5.712855339050293, 4.504233360290527, 3.6589748859405518, 3.1300203800201416, 2.8437254428863525, 2.813814163208008, 3.178431749343872, 4.226738452911377, 6.4070820808410645, 9.92577838897705, 13.626967430114746, 15.268013000488281, 14.582656860351562, 13.107337951660156, 11.906907081604004, 11.241015434265137, 11.028848648071289, 10.966550827026367, 10.665672302246094, 9.921120643615723, 8.819208145141602, 7.442251682281494, 6.040092468261719, 4.88812255859375, 4.060801982879639, 3.6312925815582275, 3.8157618045806885, 5.185368537902832, 8.808537483215332, 14.888714790344238, 19.230987548828125, 18.2596435546875, 15.00619125366211, 11.979525566101074, 9.682524681091309, 8.258341789245605, 8.061059951782227, 9.906316757202148]}, {"name": "y_sampled", "type": "scatter", "y": [5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.5, 13.5, 12.5, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 10.699999809265137, 9.699999809265137, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 10.699999809265137, 9.699999809265137, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 14.199999809265137, 13.199999809265137, 12.199999809265137, 11.199999809265137, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 10.699999809265137, 9.699999809265137, 8.699999809265137, 7.699999809265137, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 14.5, 13.5, 12.5, 11.5, 10.5, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.5, 13.5, 12.5, 11.5, 10.5, 9.5, 8.5, 7.5, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 14.0, 13.0, 12.0, 11.0, 10.0, 9.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0]}],
                            {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Trajectory of the Lorenz solution, projected along the z-axis and resampled every 10h"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('c41612dd-540c-4f6f-8c1b-9561a8342ae8');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Takens Embedding
----------------

In order to obtain meaningful topological features from a time series,
we use a delayed-time embedding technique, invented by F. Takens in the
late 1960s. The idea is simple: given a time series :math:`X(t)`, one
can extract a sequence of vectors of the form
:math:`X_i := [(X(t_i)), X(t_i + 2 \tau), ..., X(t_i + M \tau)]`. The
difference between :math:`t_i` and :math:`t_{i-1}` is called *stride*.

:math:`M` and :math:`\tau` are optimized automatically in this example
(they can be set by the user if needed).

.. code:: ipython3

    embedding_dimension = 10
    time_delay = 3
    TE = TakensEmbedding(
        parameters_type='search', dimension=embedding_dimension, time_delay=time_delay)

.. code:: ipython3

    TE.fit(X_sampled)
    time_delay_ = TE.time_delay_
    embedding_dimension_ = TE.dimension_
    
    print('Optimal embedding time delay based on mutual information: ', time_delay_)
    print('Optimal embedding dimension based on false nearest neighbors: ', embedding_dimension_)


.. parsed-literal::

    Optimal embedding time delay based on mutual information:  3
    Optimal embedding dimension based on false nearest neighbors:  10


.. code:: ipython3

    X_embedded, y_embedded = TE.transform_resample(X_sampled, y_sampled)

We can also “localise” our Takens embedding procedure to multiple
sliding windows over the data, rather than over the whole time series as
we just did. The result is therefore a “time series of point clouds”
with possibly interesting topologies, which we will be able to feed
directly to our homology transformers.

.. code:: ipython3

    window_width = 40
    window_stride = 5
    SW = SlidingWindow(width=window_width, stride=window_stride)
    
    X_windows, y_windows = SW.fit_transform_resample(X_embedded, y_embedded)

We can plot the Takens embedding of a specific window either by using
``plot_point_cloud``, or by using the ``plot`` method of
``SlidingWindow``, as follows (*note*: when ``embedding_dimension > 3``,
only the first three coordinates are plotted!):

.. code:: ipython3

    window_number = 3
    SW.plot(X_windows, sample=window_number)



.. raw:: html

    <div>
    
    
                <div id="4f39d97f-c102-47a4-ba9d-b6358d90d4f1" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("4f39d97f-c102-47a4-ba9d-b6358d90d4f1")) {
                        Plotly.newPlot(
                            '4f39d97f-c102-47a4-ba9d-b6358d90d4f1',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [0.6162614226341248, 1.5636451244354248, 5.103882312774658, 14.98863410949707, 24.83124542236328, 19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045, 5.9185099601745605, 4.517035961151123, 3.447882652282715, 2.6329939365386963, 2.0123798847198486, 1.5405652523040771, 1.184604287147522, 0.9232151508331299, 0.7515450716018677, 0.702305257320404, 0.9235610365867615, 1.9513802528381348, 5.485874652862549, 14.582544326782227, 23.905990600585938, 21.142423629760742, 15.784836769104004, 12.039207458496094, 9.355100631713867], "y": [14.98863410949707, 24.83124542236328, 19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045, 5.9185099601745605, 4.517035961151123, 3.447882652282715, 2.6329939365386963, 2.0123798847198486, 1.5405652523040771, 1.184604287147522, 0.9232151508331299, 0.7515450716018677, 0.702305257320404, 0.9235610365867615, 1.9513802528381348, 5.485874652862549, 14.582544326782227, 23.905990600585938, 21.142423629760742, 15.784836769104004, 12.039207458496094, 9.355100631713867, 7.48189115524292, 6.479306697845459, 6.854121208190918], "z": [15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045, 5.9185099601745605, 4.517035961151123, 3.447882652282715, 2.6329939365386963, 2.0123798847198486, 1.5405652523040771, 1.184604287147522, 0.9232151508331299, 0.7515450716018677, 0.702305257320404, 0.9235610365867615, 1.9513802528381348, 5.485874652862549, 14.582544326782227, 23.905990600585938, 21.142423629760742, 15.784836769104004, 12.039207458496094, 9.355100631713867, 7.48189115524292, 6.479306697845459, 6.854121208190918, 9.86506462097168, 16.18271255493164, 20.693172454833984]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('4f39d97f-c102-47a4-ba9d-b6358d90d4f1');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


For comparison, here is the portion of time series containing the data
which originates this point cloud. Notice the quasi-periodicity,
corresponding to the loop in the point cloud.

.. code:: ipython3

    embedded_begin, embedded_end = SW._slice_windows(X_embedded)[window_number]
    window_indices = np.arange(embedded_begin, embedded_end + time_delay_ * (embedding_dimension_ - 1))
    fig = px.line(title=f'Resampled Lorenz solution over sliding window {window_number}')
    fig.add_scatter(x=window_indices, y=X_sampled[window_indices], name='X_sampled')
    fig.show()



.. raw:: html

    <div>
    
    
                <div id="82b9f311-63cd-453e-9166-50542614b678" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("82b9f311-63cd-453e-9166-50542614b678")) {
                        Plotly.newPlot(
                            '82b9f311-63cd-453e-9166-50542614b678',
                            [{"name": "X_sampled", "type": "scatter", "x": [17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84], "y": [0.6162614226341248, 1.5636451244354248, 5.103882312774658, 14.98863410949707, 24.83124542236328, 19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045, 5.9185099601745605, 4.517035961151123, 3.447882652282715, 2.6329939365386963, 2.0123798847198486, 1.5405652523040771, 1.184604287147522, 0.9232151508331299, 0.7515450716018677, 0.702305257320404, 0.9235610365867615, 1.9513802528381348, 5.485874652862549, 14.582544326782227, 23.905990600585938, 21.142423629760742, 15.784836769104004, 12.039207458496094, 9.355100631713867, 7.48189115524292, 6.479306697845459, 6.854121208190918, 9.86506462097168, 16.18271255493164, 20.693172454833984, 18.73451805114746, 14.760367393493652, 11.364433288574219, 8.7335786819458, 6.728298664093018, 5.223234176635742, 4.110780715942383, 3.282271146774292, 2.7052900791168213, 2.4036595821380615, 2.5079102516174316, 3.202155113220215, 4.251739025115967, 5.609485149383545, 7.216982364654541, 8.871070861816406, 10.258978843688965, 11.169272422790527, 11.664118766784668, 12.023893356323242, 12.590555191040039]}],
                            {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Resampled Lorenz solution over sliding window 3"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('82b9f311-63cd-453e-9166-50542614b678');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Persistence diagram
-------------------

The topological information in the embedding is synthesised via the
persistence diagram. The horizontal axis corresponds to the moment in
which a homological generator is born, while the vertical axis
corresponds to the moments in which a homological generator dies. The
generators of the homology groups (at given rank) are colored
differently.

.. code:: ipython3

    homology_dimensions = (0, 1, 2)
    VR = VietorisRipsPersistence(
        metric='euclidean', max_edge_length=100, homology_dimensions=homology_dimensions)
    
    X_diagrams = VR.fit_transform(X_windows)

We can plot the persistence diagram for the embedding of the same
sliding window as before. One way is using the ``plot_diagram``
function.

.. code:: ipython3

    plot_diagram(X_diagrams[window_number])



.. raw:: html

    <div>
    
    
                <div id="1ed8471c-099b-4f73-a614-589ffc28b6f3" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("1ed8471c-099b-4f73-a614-589ffc28b6f3")) {
                        Plotly.newPlot(
                            '1ed8471c-099b-4f73-a614-589ffc28b6f3',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-2854.5333862304688, 2854.5333862304688], "y": [-2854.5333862304688, 2854.5333862304688]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [6.784940719604492, 7.3042192459106445, 7.32454252243042, 7.579392910003662, 7.879006385803223, 7.8999924659729, 7.901519775390625, 7.969804286956787, 8.063227653503418, 8.132235527038574, 8.344938278198242, 8.90837287902832, 9.037556648254395, 9.457598686218262, 10.516725540161133, 10.801090240478516, 10.829265594482422, 10.96535873413086, 11.142565727233887, 11.148630142211914, 11.49717903137207, 11.520899772644043, 11.59591293334961, 11.671819686889648, 11.684414863586426, 11.71546459197998, 11.7160005569458, 11.830119132995605, 11.847651481628418, 11.87600326538086, 12.00597095489502, 12.556045532226562, 12.568832397460938, 12.78563404083252, 12.793911933898926, 12.811745643615723, 12.856377601623535, 12.880829811096191, 13.35400104522705, 13.733892440795898]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [28.152729034423828, 27.526851654052734, 26.6622257232666, 24.603958129882812, 24.510522842407227, 24.284765243530273, 16.430830001831055, 14.200610160827637, 13.018623352050781, 12.890164375305176, 12.760909080505371, 12.20455265045166], "y": [28.545333862304688, 28.02376365661621, 26.664791107177734, 24.83266830444336, 26.282474517822266, 25.200891494750977, 17.091890335083008, 17.67685890197754, 28.035667419433594, 14.838135719299316, 13.396489143371582, 16.95931625366211]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [], "y": []}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 31.39986724853516], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 31.39986724853516], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('1ed8471c-099b-4f73-a614-589ffc28b6f3');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Alternatively, we could have used the ``plot`` method of
``VietorisRipsPersistence`` as follows:

::

   VR.plot(X_diagrams, sample=window_number)

Scikit-learn–style pipeline
---------------------------

One of the advantages of ``giotto-tda`` is the compatibility with
``scikit-learn``. It is possible to set up and run a full pipeline such
as the one above in a few lines:

.. code:: ipython3

    # Steps of the Pipeline
    steps = [
        ('sampling', periodicSampler),
        ('embedding', TE),
        ('window', SW),
        ('diagrams', VR)
    ]
    
    # Define the Pipeline
    pipeline = Pipeline(steps)
    
    # Run the pipeline
    X_diagrams = pipeline.fit_transform(X)

The final result is the same as before:

.. code:: ipython3

    plot_diagram(X_diagrams[window_number])



.. raw:: html

    <div>
    
    
                <div id="63d93236-64a8-4586-8c47-bf64b5f13cd9" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("63d93236-64a8-4586-8c47-bf64b5f13cd9")) {
                        Plotly.newPlot(
                            '63d93236-64a8-4586-8c47-bf64b5f13cd9',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-2854.5333862304688, 2854.5333862304688], "y": [-2854.5333862304688, 2854.5333862304688]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [6.784940719604492, 7.3042192459106445, 7.32454252243042, 7.579392910003662, 7.879006385803223, 7.8999924659729, 7.901519775390625, 7.969804286956787, 8.063227653503418, 8.132235527038574, 8.344938278198242, 8.90837287902832, 9.037556648254395, 9.457598686218262, 10.516725540161133, 10.801090240478516, 10.829265594482422, 10.96535873413086, 11.142565727233887, 11.148630142211914, 11.49717903137207, 11.520899772644043, 11.59591293334961, 11.671819686889648, 11.684414863586426, 11.71546459197998, 11.7160005569458, 11.830119132995605, 11.847651481628418, 11.87600326538086, 12.00597095489502, 12.556045532226562, 12.568832397460938, 12.78563404083252, 12.793911933898926, 12.811745643615723, 12.856377601623535, 12.880829811096191, 13.35400104522705, 13.733892440795898]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [28.152729034423828, 27.526851654052734, 26.6622257232666, 24.603958129882812, 24.510522842407227, 24.284765243530273, 16.430830001831055, 14.200610160827637, 13.018623352050781, 12.890164375305176, 12.760909080505371, 12.20455265045166], "y": [28.545333862304688, 28.02376365661621, 26.664791107177734, 24.83266830444336, 26.282474517822266, 25.200891494750977, 17.091890335083008, 17.67685890197754, 28.035667419433594, 14.838135719299316, 13.396489143371582, 16.95931625366211]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [], "y": []}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 31.39986724853516], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 31.39986724853516], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('63d93236-64a8-4586-8c47-bf64b5f13cd9');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Rescaling the diagram
---------------------

Rescaling a diagram means normalizing points such that the maximum
“bottleneck distance” from the *empty diagram* (by default, across all
homology dimensions) is equal to one. Notice that this means the birth
and death scales are modified. We can use ``Scaler`` as follows:

.. code:: ipython3

    diagramScaler = Scaler()
    
    X_scaled = diagramScaler.fit_transform(X_diagrams)
    
    diagramScaler.plot(X_scaled, sample=window_number)



.. raw:: html

    <div>
    
    
                <div id="d802df4b-41c0-489c-9904-77f27244b86a" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("d802df4b-41c0-489c-9904-77f27244b86a")) {
                        Plotly.newPlot(
                            'd802df4b-41c0-489c-9904-77f27244b86a',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-352.52613019331903, 352.52613019331903], "y": [-352.52613019331903, 352.52613019331903]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.8379193976188901, 0.9020487051457273, 0.9045585675487823, 0.9360318098456966, 0.9730331564359589, 0.975624873059709, 0.9758134910948791, 0.9842464191281183, 0.995783918754916, 1.004306179775777, 1.030574318067482, 1.1001567655546134, 1.116110565383591, 1.1679844705465843, 1.2987833930623778, 1.3339015625852955, 1.337381132507909, 1.354188218421687, 1.3760727393115613, 1.3768216759869574, 1.419866396245447, 1.4227958351394752, 1.432059730732591, 1.4414339823038242, 1.4429894480487455, 1.4468239944047045, 1.4468901844364033, 1.4609834790505312, 1.4631486704077383, 1.4666500288639182, 1.4827006404474445, 1.550633165952248, 1.5522123046444498, 1.578986643570036, 1.5800089380097966, 1.582211346537852, 1.5877232566508468, 1.5907430296272824, 1.6491782277901674, 1.6960936515927507]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [3.476775808179404, 3.399481868671793, 3.2927032144388018, 3.0385134708197654, 3.0269744989947536, 2.999094126994998, 2.0291571800667425, 1.7537318605305368, 1.6077601098942969, 1.5918958197167268, 1.5759331866984654, 1.5072248716228436], "y": [3.5252613019331904, 3.4608489790217054, 3.293020031494442, 3.06675847687315, 3.2458051036872146, 3.1122329130639277, 2.11079610649505, 2.1830379328358442, 3.4623190572702183, 1.8324643143569534, 1.6544253777763671, 2.0944236134940275]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [], "y": []}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 3.87778743212651], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 3.87778743212651], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('d802df4b-41c0-489c-9904-77f27244b86a');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Filtering diagrams
------------------

Filtering a diagram means eliminating the homology generators whose
lifespan is considererd too short to be significant. We can use
``Filtering`` as follows:

.. code:: ipython3

    diagramFiltering = Filtering(epsilon=0.1, homology_dimensions=(1, 2))
    
    X_filtered = diagramFiltering.fit_transform(X_scaled)
    
    diagramFiltering.plot(X_filtered, sample=window_number)



.. raw:: html

    <div>
    
    
                <div id="8c788b23-07fb-4d22-bcd0-e5c382040ab2" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("8c788b23-07fb-4d22-bcd0-e5c382040ab2")) {
                        Plotly.newPlot(
                            '8c788b23-07fb-4d22-bcd0-e5c382040ab2',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-346.23190572702185, 346.23190572702185], "y": [-346.23190572702185, 346.23190572702185]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.6077601098942969, 1.5072248716228436, 1.7537318605305368, 1.5918958197167268, 3.0269744989947536, 2.999094126994998], "y": [3.4623190572702183, 2.0944236134940275, 2.1830379328358442, 1.8324643143569534, 3.2458051036872146, 3.1122329130639277]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [], "y": []}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 3.8085509629972405], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 3.8085509629972405], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('8c788b23-07fb-4d22-bcd0-e5c382040ab2');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


We can add the steps above to our pipeline:

.. code:: ipython3

    steps_new = [
        ('scaler', diagramScaler),
        ('filtering', diagramFiltering)
    ]
    
    pipeline_filter = Pipeline(steps + steps_new)
    
    X_filtered = pipeline_filter.fit_transform(X)

.. code:: ipython3

    plot_diagram(X_filtered[window_number])



.. raw:: html

    <div>
    
    
                <div id="63c26006-5d17-4485-b792-1c4afa108746" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("63c26006-5d17-4485-b792-1c4afa108746")) {
                        Plotly.newPlot(
                            '63c26006-5d17-4485-b792-1c4afa108746',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-346.23190572702185, 346.23190572702185], "y": [-346.23190572702185, 346.23190572702185]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [1.6960936515927507, 1.6491782277901674, 1.5907430296272824, 1.5877232566508468, 1.582211346537852, 1.5800089380097966, 1.578986643570036, 1.5522123046444498, 1.550633165952248, 1.4827006404474445, 1.4666500288639182, 1.4631486704077383, 1.4609834790505312, 1.4468901844364033, 1.4468239944047045, 1.4429894480487455, 1.4414339823038242, 1.432059730732591, 1.4227958351394752, 1.419866396245447, 1.3768216759869574, 1.3760727393115613, 1.354188218421687, 1.337381132507909, 1.3339015625852955, 1.2987833930623778, 1.1679844705465843, 1.116110565383591, 1.1001567655546134, 1.030574318067482, 1.004306179775777, 0.995783918754916, 0.9842464191281183, 0.9758134910948791, 0.975624873059709, 0.9730331564359589, 0.9360318098456966, 0.9045585675487823, 0.9020487051457273, 0.8379193976188901]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.6077601098942969, 1.5072248716228436, 1.7537318605305368, 1.5918958197167268, 3.0269744989947536, 2.999094126994998], "y": [3.4623190572702183, 2.0944236134940275, 2.1830379328358442, 1.8324643143569534, 3.2458051036872146, 3.1122329130639277]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [], "y": []}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 3.8085509629972405], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 3.8085509629972405], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('63c26006-5d17-4485-b792-1c4afa108746');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Persistence entropy
-------------------

In this section we show how to compute the *entropy* of persistence
diagrams.

.. code:: ipython3

    PE = PersistenceEntropy()
    
    X_persistence_entropy = PE.fit_transform(X_scaled)

.. code:: ipython3

    fig = px.line(title='Persistence entropies, indexed by sliding window number')
    for dim in range(X_persistence_entropy.shape[1]):
        fig.add_scatter(y=X_persistence_entropy[:, dim], name=f'PE in homology dimension {dim}')
    fig.show()



.. raw:: html

    <div>
    
    
                <div id="b82397df-1a61-4687-92e6-9ad359f99309" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("b82397df-1a61-4687-92e6-9ad359f99309")) {
                        Plotly.newPlot(
                            'b82397df-1a61-4687-92e6-9ad359f99309',
                            [{"name": "PE in homology dimension 0", "type": "scatter", "y": [3.66903578036033, 3.6724983227617063, 3.6732765737322826, 3.6699598138552694, 3.66255023332702, 3.6401142225174805, 3.599527650076747, 3.5630085542267373, 3.5461916583187074, 3.5568260680711834, 3.5995543315892373, 3.6138145643989152, 3.5934876847277577, 3.574253523358373, 3.5809028856603256, 3.604719330309136, 3.631132541170124, 3.6519607462060892, 3.6629745091104287, 3.674253248792761, 3.673020071221911, 3.670361695359877, 3.6677986861800944, 3.642665728531589, 3.6128520207653247, 3.592554945456955, 3.59454034171659, 3.604623133299801, 3.6055415634573373, 3.5908327361257277, 3.5848564054013843, 3.6022891690669114, 3.626010517759121, 3.6522084637227787, 3.6472133941053357, 3.6470777872362543, 3.6470327596418066, 3.6516759364287585, 3.671521891128816, 3.6711260859719217, 3.6710437527038837, 3.669678190331888, 3.666430274725406, 3.666511674083876, 3.6632222613973617, 3.6628702458796165, 3.662835487801754, 3.657563954677559, 3.6489993826781504, 3.644564058583385, 3.644404945391103, 3.6404210418604483, 3.640018820183377, 3.6377903885764686, 3.6357589524418064, 3.635765321889216, 3.6391626291397685, 3.6418259737797807, 3.642348125870096, 3.6424257090765404, 3.6414952343251867, 3.6427269715464847, 3.6491701085628026, 3.658695264504683, 3.670916148930581, 3.668631951515758, 3.6680604505138605, 3.6620506267176682, 3.6609154414834144, 3.6658370351181655, 3.6682125302620854, 3.6739668554691285, 3.678121842114508, 3.6801161390830197, 3.6803759971297714, 3.679665884733756, 3.6779550236679457, 3.6774191532783536, 3.677644295056546, 3.674046075330847, 3.674472077821334, 3.6718063240336676, 3.6673275988109855, 3.6646626890271596, 3.6624271782179827, 3.6649302004355744]}, {"name": "PE in homology dimension 1", "type": "scatter", "y": [1.900626260463266, 1.9057658950599043, 1.8341327935843779, 1.6610582455346918, 1.6865610536304296, 1.5807181807570023, 1.479135950267511, 1.04593886245397, 1.2371932796268812, 0.8610686638457787, 0.3431371369481399, 0.27898839440616463, 0.7253315260663542, 1.3350959658037986, 1.8864561569511324, 2.0512532893049062, 2.148281759672294, 2.3588918737682447, 2.3076963825403283, 2.475886711200906, 2.2941920444405626, 1.9737446934180654, 2.1740094845995523, 2.0571360520382918, 1.8370602845078838, 1.8739793964890772, 1.9448058478400139, 1.6730584083030446, 1.5507531051028165, 2.055508171905324, 2.1538880227106043, 2.2007615862773244, 2.058732478109963, 2.0876076264320886, 1.893302848478982, 1.719872371362019, 1.8562824245848517, 2.0078549341857768, 2.0989309729852312, 1.9433445996486904, 2.0072725405051717, 1.946768214522129, 1.9496896743438172, 1.6806267006470144, 2.006544399911355, 2.4684189401151553, 2.1084420193878812, 2.248528413001962, 2.356432284938217, 2.4093665968209725, 2.4957785627593982, 2.4994588947146723, 2.188779343265123, 2.1065564244365227, 2.099831584308803, 1.7883489029658224, 1.8533098741055958, 1.933162745446707, 2.214828013401284, 2.367854751337631, 2.3449288820045413, 2.3037604180873967, 2.172280394204489, 1.945467949055598, 2.384374071309912, 2.3465998867938747, 2.191257628583195, 2.068274345109627, 2.144581733881055, 2.0260975681729922, 2.0245119325853906, 2.036785520457076, 2.1572208831373905, 2.1127574411436933, 2.095377273907014, 2.1770899252626537, 2.1189910258896183, 2.1359547175284055, 2.148991633987727, 2.100962514670665, 2.176409724309438, 2.1187691605955985, 2.2075467152277106, 1.7345333613959655, 1.7772544602551843, 1.5651333253137132]}, {"name": "PE in homology dimension 2", "type": "scatter", "y": [0.6874358346145794, 1.314789532293877, 1.468684734278415, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.3824111977995, 0.7241715526055503, 0.9663676262656808, 0.7241715526055503, 0.946208342051806, 1.0069713764443042, -0.0, -0.0, 1.0159914265914707, 1.2788595154529177, 1.4786420720019897, 1.7131682566355084, 1.3368683138335042, -0.0, 0.5918481847521279, 1.3516500295920149, 1.2894446467695284, 1.0054839865477765, 1.364361284336867, 0.7820657012032741, 0.1314963332534606, -0.0, -0.0, -0.0, -0.0, 0.6222274242754171, 1.131500432032599, 0.7521480230094779, 0.6398239530196023, 1.0553385285760033, 1.8140536185527563, 1.0013609161379837, 0.632835401933791, 1.0883054163118207, 0.9504474538345749, -0.0, -0.0, -0.0, -0.0, 0.9632530109873757, 1.5234257829765054, 1.4149347671319523, 1.3783658368327385, 1.1867649385970556, 0.8873656109226289, 0.6869617234343577, 0.4906017569756703, 0.9516012869946615, -0.0, 0.6656423563304544, 1.469348664526419, 1.4624446549398256, 1.4510911698610172, 0.39326140458816905, 1.1994480421471319, 0.8895200800821106, -0.0, -0.0, -0.0, -0.0, -0.0, 1.0849811929844702, 1.210000750891774, 1.5916849534952975, 1.3532926802297727, 0.7961931547423915, 0.9093265208225487, 1.2320948441681634, 1.3023551454142583, 1.8849288541929186, 1.5487376712431762, 1.5435991743183566, 0.8086291253165556, 1.227057318507594, 0.7289683096138603]}],
                            {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Persistence entropies, indexed by sliding window number"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('b82397df-1a61-4687-92e6-9ad359f99309');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Betti Curves
------------

In this section we show how to compute the Betti curves of a persistence
diagram. We also show the plot of the Betti surface, i.e. the time-stack
of the Betti curves.

.. code:: ipython3

    BC = BettiCurve()
    
    X_betti_curves = BC.fit_transform(X_scaled)

.. code:: ipython3

    BC.plot(X_betti_curves, sample=window_number)



.. raw:: html

    <div>
    
    
                <div id="1300dd22-313c-4e40-afc6-55cf5c6d6856" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("1300dd22-313c-4e40-afc6-55cf5c6d6856")) {
                        Plotly.newPlot(
                            '1300dd22-313c-4e40-afc6-55cf5c6d6856',
                            [{"mode": "lines", "name": "H0", "showlegend": true, "type": "scatter", "x": [0.0, 0.01893850058275048, 0.03787700116550096, 0.05681550174825144, 0.07575400233100192, 0.0946925029137524, 0.11363100349650287, 0.13256950407925336, 0.15150800466200384, 0.17044650524475433, 0.1893850058275048, 0.2083235064102553, 0.22726200699300575, 0.24620050757575623, 0.2651390081585067, 0.2840775087412572, 0.3030160093240077, 0.32195450990675817, 0.34089301048950865, 0.35983151107225914, 0.3787700116550096, 0.3977085122377601, 0.4166470128205106, 0.43558551340326107, 0.4545240139860115, 0.473462514568762, 0.49240101515151247, 0.511339515734263, 0.5302780163170134, 0.5492165168997639, 0.5681550174825144, 0.5870935180652649, 0.6060320186480154, 0.6249705192307659, 0.6439090198135163, 0.6628475203962668, 0.6817860209790173, 0.7007245215617678, 0.7196630221445183, 0.7386015227272688, 0.7575400233100192, 0.7764785238927697, 0.7954170244755202, 0.8143555250582707, 0.8332940256410212, 0.8522325262237717, 0.8711710268065221, 0.8901095273892726, 0.909048027972023, 0.9279865285547735, 0.946925029137524, 0.9658635297202744, 0.9848020303030249, 1.0037405308857754, 1.022679031468526, 1.0416175320512764, 1.0605560326340269, 1.0794945332167774, 1.0984330337995278, 1.1173715343822783, 1.1363100349650288, 1.1552485355477793, 1.1741870361305298, 1.1931255367132803, 1.2120640372960307, 1.2310025378787812, 1.2499410384615317, 1.2688795390442822, 1.2878180396270327, 1.3067565402097832, 1.3256950407925336, 1.3446335413752841, 1.3635720419580346, 1.382510542540785, 1.4014490431235356, 1.420387543706286, 1.4393260442890365, 1.458264544871787, 1.4772030454545375, 1.496141546037288, 1.5150800466200385, 1.534018547202789, 1.5529570477855394, 1.57189554836829, 1.5908340489510404, 1.609772549533791, 1.6287110501165414, 1.6476495506992919, 1.6665880512820423, 1.6855265518647928, 1.7044650524475433, 1.7234035530302938, 1.7423420536130443, 1.7612805541957948, 1.7802190547785453, 1.7991575553612957, 1.818096055944046, 1.8370345565267965, 1.855973057109547, 1.8749115576922974], "y": [40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 39, 39, 39, 37, 37, 36, 36, 32, 31, 30, 29, 29, 29, 29, 27, 27, 27, 26, 26, 26, 26, 26, 26, 26, 25, 25, 23, 22, 20, 20, 19, 17, 13, 10, 9, 9, 9, 7, 7, 2, 2, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]}, {"mode": "lines", "name": "H1", "showlegend": true, "type": "scatter", "x": [1.0975320128029422, 1.1240455424463947, 1.1505590720898473, 1.1770726017332998, 1.2035861313767522, 1.2300996610202046, 1.256613190663657, 1.2831267203071097, 1.3096402499505622, 1.3361537795940146, 1.3626673092374673, 1.3891808388809197, 1.4156943685243721, 1.4422078981678246, 1.468721427811277, 1.4952349574547297, 1.5217484870981821, 1.5482620167416346, 1.5747755463850872, 1.6012890760285396, 1.627802605671992, 1.6543161353154445, 1.680829664958897, 1.7073431946023496, 1.733856724245802, 1.7603702538892545, 1.7868837835327072, 1.8133973131761596, 1.839910842819612, 1.8664243724630645, 1.892937902106517, 1.9194514317499696, 1.945964961393422, 1.9724784910368744, 1.998992020680327, 2.0255055503237793, 2.052019079967232, 2.0785326096106846, 2.105046139254137, 2.1315596688975895, 2.158073198541042, 2.1845867281844944, 2.2111002578279466, 2.2376137874713997, 2.264127317114852, 2.290640846758304, 2.3171543764017573, 2.3436679060452095, 2.3701814356886617, 2.3966949653321143, 2.423208494975567, 2.4497220246190192, 2.476235554262472, 2.5027490839059245, 2.5292626135493768, 2.5557761431928294, 2.582289672836282, 2.6088032024797343, 2.6353167321231865, 2.6618302617666396, 2.688343791410092, 2.714857321053544, 2.741370850696997, 2.7678843803404494, 2.7943979099839016, 2.8209114396273542, 2.847424969270807, 2.873938498914259, 2.900452028557712, 2.9269655582011644, 2.9534790878446167, 2.9799926174880693, 3.006506147131522, 3.033019676774974, 3.0595332064184264, 3.0860467360618795, 3.1125602657053317, 3.139073795348784, 3.165587324992237, 3.1921008546356893, 3.2186143842791415, 3.2451279139225946, 3.271641443566047, 3.298154973209499, 3.3246685028529512, 3.3511820324964043, 3.3776955621398566, 3.4042090917833088, 3.430722621426762, 3.457236151070214, 3.4837496807136663, 3.5102632103571194, 3.5367767400005716, 3.563290269644024, 3.589803799287477, 3.616317328930929, 3.6428308585743814, 3.6693443882178345, 3.6958579178612867, 3.722371447504739], "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 4, 4, 3, 3, 3, 4, 4, 4, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 3, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 4, 3, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0]}, {"mode": "lines", "name": "H2", "showlegend": true, "type": "scatter", "x": [2.039923542269078, 2.05892417853887, 2.0779248148086626, 2.0969254510784547, 2.115926087348247, 2.134926723618039, 2.153927359887831, 2.1729279961576236, 2.1919286324274156, 2.2109292686972077, 2.2299299049670003, 2.2489305412367924, 2.2679311775065845, 2.2869318137763766, 2.3059324500461686, 2.324933086315961, 2.3439337225857533, 2.3629343588555454, 2.381934995125338, 2.40093563139513, 2.419936267664922, 2.438936903934714, 2.4579375402045063, 2.476938176474299, 2.495938812744091, 2.514939449013883, 2.5339400852836755, 2.5529407215534676, 2.5719413578232597, 2.590941994093052, 2.609942630362844, 2.6289432666326364, 2.6479439029024285, 2.6669445391722206, 2.685945175442013, 2.7049458117118053, 2.7239464479815974, 2.7429470842513894, 2.7619477205211815, 2.780948356790974, 2.799948993060766, 2.8189496293305583, 2.837950265600351, 2.856950901870143, 2.875951538139935, 2.894952174409727, 2.913952810679519, 2.9329534469493117, 2.951954083219104, 2.970954719488896, 2.9899553557586884, 3.0089559920284805, 3.0279566282982726, 3.0469572645680647, 3.065957900837857, 3.0849585371076493, 3.1039591733774414, 3.1229598096472335, 3.141960445917026, 3.160961082186818, 3.1799617184566102, 3.1989623547264023, 3.2179629909961944, 3.236963627265987, 3.255964263535779, 3.274964899805571, 3.2939655360753637, 3.312966172345156, 3.331966808614948, 3.35096744488474, 3.369968081154532, 3.3889687174243246, 3.4079693536941167, 3.426969989963909, 3.4459706262337013, 3.4649712625034934, 3.4839718987732855, 3.5029725350430776, 3.5219731713128697, 3.5409738075826622, 3.5599744438524543, 3.5789750801222464, 3.597975716392039, 3.616976352661831, 3.635976988931623, 3.6549776252014152, 3.6739782614712073, 3.692978897741, 3.711979534010792, 3.730980170280584, 3.7499808065503766, 3.7689814428201687, 3.7879820790899608, 3.806982715359753, 3.825983351629545, 3.8449839878993375, 3.8639846241691296, 3.8829852604389217, 3.901985896708714, 3.9209865329785063], "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Filtration parameter"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Betti number"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('1300dd22-313c-4e40-afc6-55cf5c6d6856');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Distances among diagrams
------------------------

In this section we show how to compute several notions of distances
among persistence diagrams.

In each case, we will obtain distance matrices whose i-th row encodes
the distance of the i-th diagram from all the others.

We start with the so-called “landscape :math:`L^2` distance”: when the
parameter ``order`` is ``None``, the output is one distance matrix per
sample and homology dimension.

.. code:: ipython3

    p_L = 2
    n_layers = 5
    PD = PairwiseDistance(
        metric='landscape', metric_params={'p': p_L, 'n_layers': n_layers, 'n_bins': 1000}, order=None)
    
    X_distance_L = PD.fit_transform(X_diagrams)
    print(X_distance_L.shape)


.. parsed-literal::

    (86, 86, 3)


This is what distances in homology dimension 0 look like:

.. code:: ipython3

    plot_heatmap(X_distance_L[:, :, 0], colorscale='blues')



.. raw:: html

    <div>
    
    
                <div id="ec983fbc-a435-4ae6-9be0-31556679d546" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("ec983fbc-a435-4ae6-9be0-31556679d546")) {
                        Plotly.newPlot(
                            'ec983fbc-a435-4ae6-9be0-31556679d546',
                            [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 0.13486358119867706, 0.18336327365032357, 0.1999680595895069, 0.27394731448388604, 0.2688286704308957, 0.2688286704308957, 0.2688286704308957, 0.31212090461405134, 0.5494022072820314, 1.0041723057901957, 1.0626240310955664, 0.9542164609219261, 0.8475039486646659, 0.7829612397852137, 0.7497997478368953, 0.7497997478368953, 0.5129750265598189, 0.41493018112381935, 0.11461990728685224, 0.0862198209050816, 0.0862198209050816, 0.0862198209050816, 0.0862198209050816, 0.0862198209050816, 0.2743645640072479, 0.3734121541143806, 0.528293114011629, 0.518731502197706, 0.32447702848457044, 0.2166741990590248, 0.21352626519986953, 0.4088416485734708, 0.5052567880028468, 0.3226874328744892, 0.3245187932591258, 0.3199942547445527, 0.1711136801674136, 0.21285059305160317, 0.23639185047206268, 0.33213998031702924, 0.31737711697874826, 0.3141926187152428, 0.267569652786383, 0.184660527995135, 0.27435277974179373, 0.32724638722935506, 0.2955116011738901, 0.26252204659090844, 0.25757473288615135, 0.25757473288615135, 0.2695558990944111, 0.2530549852275695, 0.26012734920263875, 0.26790611694910405, 0.33399608068081726, 0.36553748682559983, 0.3761232112128323, 0.3761232112128323, 0.416771539277644, 0.3650085712145839, 0.3355453867961476, 0.3923686028708134, 0.6263261493638077, 0.9359570670327465, 0.8382645368110675, 0.8321967914446133, 0.5792424834765785, 0.4385072696325149, 0.39582912757235583, 0.34693083450194295, 0.34693083450194295, 0.32009933504916677, 0.29999838819628777, 0.2974601042134225, 0.2631197678696113, 0.273168570252132, 0.2548315202171675, 0.2627722217650395, 0.28757496832349816, 0.3077641267516212, 0.35248720918345183, 0.45407008745392863, 0.8689907639766274, 0.8470447511186211, 0.8700318178733577], [0.13486358119867706, 0.0, 0.11879910045879276, 0.10688127819885372, 0.1861661780236365, 0.18224341554875856, 0.18224341554875856, 0.18224341554875856, 0.23616123746164785, 0.49142370597169766, 0.9293821714242645, 0.9911170561686404, 0.8796320702900419, 0.7723893685391614, 0.7037849337652188, 0.6697301406252237, 0.6697301406252237, 0.4417306503343459, 0.3663464147505487, 0.049842633561684224, 0.06630865692257876, 0.06630865692257876, 0.06630865692257876, 0.06630865692257876, 0.06630865692257876, 0.24874759134523142, 0.3126845369964456, 0.4456682291708678, 0.437349971924229, 0.287756202892911, 0.2759733272004097, 0.2727133913473454, 0.3088812154917832, 0.4208051703558853, 0.24805803740401156, 0.25037115930825793, 0.24450667735712503, 0.0644031550821463, 0.12328645490675297, 0.150361969174017, 0.250614976913167, 0.23236450443969078, 0.37379560508410864, 0.2675480982883503, 0.18769583737994705, 0.19630500261111228, 0.24037570757466353, 0.19978210748820813, 0.1767983348324541, 0.17147291776253376, 0.17147291776253376, 0.17672596620838843, 0.16488016727534532, 0.1750846698841576, 0.18611886089665106, 0.24338854199962676, 0.280882616783488, 0.2897817548187262, 0.2897817548187262, 0.33178389735002817, 0.2759376904739136, 0.253778313967589, 0.3241509234113869, 0.5707532976387303, 0.8602838556634066, 0.7612712554671459, 0.7546414158417676, 0.5001957388456969, 0.3624669925785399, 0.31068284277191416, 0.2603108783082699, 0.2603108783082699, 0.23336549679753127, 0.21373248799247674, 0.2103309354500172, 0.1742429799211421, 0.18549195697262127, 0.16469883778356464, 0.17597855816990846, 0.2054719069952409, 0.22154950851419594, 0.27497260779144084, 0.3925934228378513, 0.7903933335035818, 0.7691137372331055, 0.7915260909689966], [0.18336327365032357, 0.11879910045879276, 0.0, 0.06690986780705283, 0.09658115145863132, 0.09139111229663548, 0.09139111229663548, 0.09139111229663548, 0.14541119197396957, 0.4206972520428159, 0.8586692082049597, 0.9185426167129337, 0.8054228561945194, 0.6935125350204175, 0.6236651435112482, 0.5887538173864539, 0.5887538173864539, 0.39955068721854387, 0.29465351053750805, 0.1084617495836253, 0.14245723106124228, 0.14245723106124228, 0.14245723106124228, 0.14245723106124228, 0.14245723106124228, 0.19055164478319214, 0.24614205539478995, 0.3604212316468894, 0.3491293044676638, 0.2788713986153668, 0.27428869478546064, 0.2678870666258106, 0.29829030588760735, 0.3334724027503229, 0.19599901007296225, 0.1980910824684187, 0.1929103178522789, 0.07481942400820919, 0.043821673356364804, 0.06291591542360458, 0.1619866145305889, 0.216238708951951, 0.3705503716922459, 0.28013829892071307, 0.23624839882320323, 0.22553953846442767, 0.15725405290519442, 0.12078438009917483, 0.08975635645683906, 0.08395865526174516, 0.08395865526174516, 0.09420837095935657, 0.07467590202220602, 0.08256368426169396, 0.09247790175168857, 0.15817987683825677, 0.18864568330175088, 0.20009931946206355, 0.20009931946206355, 0.24560251765764407, 0.1902214437980329, 0.15974401215396639, 0.23171269228037975, 0.4960497202054333, 0.7870820318568448, 0.6848742110266767, 0.6781525614364564, 0.42222855095472056, 0.2727349114450049, 0.22051041389897638, 0.1697777731305928, 0.1697777731305928, 0.1418691380418182, 0.1208193229995328, 0.11849578685500664, 0.08480456236011862, 0.09458507421978161, 0.07766707236436926, 0.08466733702466883, 0.10826464947395933, 0.13114244406851128, 0.18629891260829756, 0.3156498529080735, 0.7137660972015376, 0.6913013879290757, 0.7153289804946056], [0.1999680595895069, 0.10688127819885372, 0.06690986780705283, 0.0, 0.10926412782267228, 0.10673705667854388, 0.10673705667854388, 0.10673705667854388, 0.1500887257896293, 0.4075705053513968, 0.8506679920639587, 0.9131147352219879, 0.7977567473752963, 0.6879653476606679, 0.6189581252748529, 0.5843213099969671, 0.5843213099969671, 0.3610966943292777, 0.279997233695138, 0.11833828791950438, 0.14021215563901157, 0.14021215563901157, 0.14021215563901157, 0.14021215563901157, 0.14021215563901157, 0.1889644088339501, 0.21759195463740158, 0.35433325274350636, 0.347356410673224, 0.23279794937543188, 0.27481416349159166, 0.2697752290719524, 0.2539595299954364, 0.3318498727670515, 0.16181838300235973, 0.16424508826939832, 0.15810689610438197, 0.044267540260225544, 0.06322304478606972, 0.06303952253665103, 0.15371924969995754, 0.17216584901243853, 0.36768243863215316, 0.25106198600481383, 0.2040362897454502, 0.1756084093034102, 0.147135785105473, 0.1123037407686384, 0.07786514630478582, 0.07423452514121259, 0.07423452514121259, 0.08565585845928429, 0.07973080577702953, 0.08606299237586704, 0.09472419248542009, 0.15331579092981104, 0.18982611104421626, 0.197079671472411, 0.197079671472411, 0.24081044658526704, 0.1821151433249623, 0.1586923489761342, 0.2289152770615725, 0.48288298375678357, 0.7787443548836326, 0.675973357041623, 0.6692307380961997, 0.4074585468740899, 0.269764345655456, 0.2187468437812116, 0.16854191340708705, 0.16854191340708705, 0.14327080610974977, 0.12618714587848132, 0.12429308491178494, 0.09090235157443874, 0.10518916715800855, 0.08667539406350676, 0.09152225343569322, 0.11603304663196577, 0.12602151620801633, 0.17676461160286452, 0.30273057726161673, 0.7079024750129322, 0.6849006653755787, 0.7089586970402242], [0.27394731448388604, 0.1861661780236365, 0.09658115145863132, 0.10926412782267228, 0.0, 0.006082557290477481, 0.006082557290477481, 0.006082557290477481, 0.10088382001566051, 0.3868813294469512, 0.7924212509296998, 0.8519811707696632, 0.7376396160798642, 0.6242718252226521, 0.5497157584518778, 0.5136354928925206, 0.5136354928925206, 0.3750375447205798, 0.2841564142342727, 0.18395182121156745, 0.22303818009531046, 0.22303818009531046, 0.22303818009531046, 0.22303818009531046, 0.22303818009531046, 0.22818814076142385, 0.23071045584672276, 0.2866626735542771, 0.2730748960089877, 0.3075395323667558, 0.3523574851428895, 0.3458952702398297, 0.27561508906228677, 0.25268333746705, 0.1900681525625506, 0.19208768216130254, 0.18718886913123825, 0.13439410690725898, 0.06631223702303944, 0.061100930948654486, 0.10642215599341871, 0.22016317719171608, 0.4416659134252791, 0.33791886747406547, 0.3062526765900968, 0.2566716891043819, 0.10357690557578106, 0.05392866046433646, 0.05567221130581488, 0.051785492234246375, 0.051785492234246375, 0.04201089145228046, 0.03994015265210411, 0.049566393661557476, 0.06160351698859578, 0.08421320173431933, 0.1084430156866233, 0.11934655026452007, 0.11934655026452007, 0.17348750365750049, 0.11365044003218587, 0.0914572613429676, 0.18528699396125292, 0.45928860277038347, 0.71985968432685, 0.6161626739689074, 0.6088021998073989, 0.3596777109748693, 0.2101075083459792, 0.14107007300192576, 0.0899419742493556, 0.0899419742493556, 0.06425333659336999, 0.03754409704578184, 0.03162703834139592, 0.02350987316660267, 0.013263047156421515, 0.024057823704210408, 0.035812526299329066, 0.04538466655895157, 0.06228658243244556, 0.13529677357486758, 0.28331711789317765, 0.6413411109010562, 0.6193208143411424, 0.6436222960914766], [0.2688286704308957, 0.18224341554875856, 0.09139111229663548, 0.10673705667854388, 0.006082557290477481, 0.0, 5.575413950931817e-18, 6.558452425035609e-18, 0.10203649861210301, 0.38942157691526214, 0.7967162005668945, 0.8561639894191349, 0.7420118251287011, 0.6286330353713878, 0.5542993312365503, 0.5182734385734156, 0.5182734385734156, 0.3782419605673622, 0.28572474949294957, 0.17916259222892747, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.22651724456589578, 0.23283990316328293, 0.29139114466174565, 0.27764889991404934, 0.3076970586364399, 0.34885817328384056, 0.34236677267149174, 0.27844921446341087, 0.25754784120378343, 0.19162217315670543, 0.193641472610329, 0.18869158714770876, 0.13096541915205748, 0.06170057520896551, 0.058451554051425464, 0.10960608468633501, 0.22109908533050943, 0.4386805220936739, 0.3358459446478011, 0.30345785187388696, 0.25622102309319084, 0.10697212107314376, 0.05766342857136005, 0.05626021554182679, 0.051836696035757045, 0.051836696035757045, 0.04363112907204429, 0.03836743401849963, 0.048890651025179394, 0.06160756649316365, 0.0887217972311861, 0.11317539520146777, 0.12439027528991568, 0.12439027528991568, 0.17786245109350485, 0.11870020471662299, 0.09543280464188485, 0.1882643994059624, 0.46237354006786513, 0.7242527432596696, 0.6206753859781544, 0.6133551010095947, 0.36417411475744116, 0.21385280766399775, 0.14587978164063792, 0.09473031698976661, 0.09473031698976661, 0.06870760255998572, 0.04199584786553895, 0.036529283256950644, 0.022833961695754933, 0.014492432172407971, 0.02139390352633365, 0.03481714523002611, 0.047385062241303816, 0.06632560403398288, 0.1384896604791602, 0.2857880261095273, 0.6458793358897882, 0.6238722574967014, 0.648151915563546], [0.2688286704308957, 0.18224341554875856, 0.09139111229663548, 0.10673705667854388, 0.006082557290477481, 5.575413950931817e-18, 0.0, 3.4537019974529274e-18, 0.10203649861210301, 0.38942157691526214, 0.7967162005668945, 0.8561639894191349, 0.7420118251287011, 0.6286330353713878, 0.5542993312365503, 0.5182734385734156, 0.5182734385734156, 0.3782419605673622, 0.28572474949294957, 0.17916259222892747, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.22651724456589578, 0.23283990316328293, 0.29139114466174565, 0.27764889991404934, 0.3076970586364399, 0.34885817328384056, 0.34236677267149174, 0.27844921446341087, 0.25754784120378343, 0.19162217315670543, 0.193641472610329, 0.18869158714770876, 0.13096541915205748, 0.06170057520896551, 0.058451554051425464, 0.10960608468633501, 0.22109908533050943, 0.4386805220936739, 0.3358459446478011, 0.30345785187388696, 0.25622102309319084, 0.10697212107314376, 0.05766342857136005, 0.05626021554182679, 0.051836696035757045, 0.051836696035757045, 0.04363112907204429, 0.03836743401849963, 0.048890651025179394, 0.06160756649316365, 0.0887217972311861, 0.11317539520146777, 0.12439027528991568, 0.12439027528991568, 0.17786245109350485, 0.11870020471662299, 0.09543280464188485, 0.1882643994059624, 0.46237354006786513, 0.7242527432596696, 0.6206753859781544, 0.6133551010095947, 0.36417411475744116, 0.21385280766399775, 0.14587978164063792, 0.09473031698976661, 0.09473031698976661, 0.06870760255998572, 0.04199584786553895, 0.036529283256950644, 0.022833961695754933, 0.014492432172407971, 0.02139390352633365, 0.03481714523002611, 0.047385062241303816, 0.06632560403398288, 0.1384896604791602, 0.2857880261095273, 0.6458793358897882, 0.6238722574967014, 0.648151915563546], [0.2688286704308957, 0.18224341554875856, 0.09139111229663548, 0.10673705667854388, 0.006082557290477481, 6.558452425035609e-18, 3.4537019974529274e-18, 0.0, 0.10203649861210301, 0.38942157691526214, 0.7967162005668945, 0.8561639894191349, 0.7420118251287011, 0.6286330353713878, 0.5542993312365503, 0.5182734385734156, 0.5182734385734156, 0.3782419605673622, 0.28572474949294957, 0.17916259222892747, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.22651724456589578, 0.23283990316328293, 0.29139114466174565, 0.27764889991404934, 0.3076970586364399, 0.34885817328384056, 0.34236677267149174, 0.27844921446341087, 0.25754784120378343, 0.19162217315670543, 0.193641472610329, 0.18869158714770876, 0.13096541915205748, 0.06170057520896551, 0.058451554051425464, 0.10960608468633501, 0.22109908533050943, 0.4386805220936739, 0.3358459446478011, 0.30345785187388696, 0.25622102309319084, 0.10697212107314376, 0.05766342857136005, 0.05626021554182679, 0.051836696035757045, 0.051836696035757045, 0.04363112907204429, 0.03836743401849963, 0.048890651025179394, 0.06160756649316365, 0.0887217972311861, 0.11317539520146777, 0.12439027528991568, 0.12439027528991568, 0.17786245109350485, 0.11870020471662299, 0.09543280464188485, 0.1882643994059624, 0.46237354006786513, 0.7242527432596696, 0.6206753859781544, 0.6133551010095947, 0.36417411475744116, 0.21385280766399775, 0.14587978164063792, 0.09473031698976661, 0.09473031698976661, 0.06870760255998572, 0.04199584786553895, 0.036529283256950644, 0.022833961695754933, 0.014492432172407971, 0.02139390352633365, 0.03481714523002611, 0.047385062241303816, 0.06632560403398288, 0.1384896604791602, 0.2857880261095273, 0.6458793358897882, 0.6238722574967014, 0.648151915563546], [0.31212090461405134, 0.23616123746164785, 0.14541119197396957, 0.1500887257896293, 0.10088382001566051, 0.10203649861210301, 0.10203649861210301, 0.10203649861210301, 0.0, 0.3075559565213817, 0.7522420502223164, 0.8147523127397128, 0.6967259609515362, 0.5791646109152229, 0.5112710937902902, 0.47643555012243655, 0.47643555012243655, 0.32830059687045354, 0.2245041030385045, 0.2340437509756612, 0.2657454722694084, 0.2657454722694084, 0.2657454722694084, 0.2657454722694084, 0.2657454722694084, 0.1806406327450757, 0.18218600052077602, 0.24494297559728417, 0.22920673425508198, 0.28892757853644746, 0.34152795091667276, 0.3348806543486815, 0.25460314798896383, 0.2228761717498293, 0.1585140323632177, 0.15859701067553522, 0.15267960004038791, 0.17893237666628456, 0.13394573178916863, 0.09455903816704155, 0.052209325332481765, 0.18312070619156393, 0.4195667963710598, 0.30796640115944823, 0.31527719121647996, 0.25014317238342637, 0.08482212469357003, 0.08559642791037542, 0.09399734215140422, 0.09741500709953861, 0.09741500709953861, 0.09258974782812146, 0.09578894891968386, 0.08293913026439378, 0.0772933133727927, 0.07571581832603187, 0.09610796875074513, 0.10735087890069814, 0.10735087890069814, 0.11978535379590471, 0.10074598341358335, 0.07640221393463668, 0.1348675680112008, 0.3995506911876443, 0.679010957879073, 0.5728762478731596, 0.566837211824446, 0.3076400208334631, 0.14291370292426023, 0.1136111418357298, 0.07965544122164071, 0.07965544122164071, 0.07709018173613712, 0.07912490118020879, 0.08585457662913179, 0.0913626234957317, 0.08942482702566813, 0.10513343038625851, 0.07871634500996146, 0.07141329934503175, 0.07616684436963873, 0.07583091542543437, 0.20371530334259688, 0.6039998026215969, 0.5802316048858746, 0.6052876777744778], [0.5494022072820314, 0.49142370597169766, 0.4206972520428159, 0.4075705053513968, 0.3868813294469512, 0.38942157691526214, 0.38942157691526214, 0.38942157691526214, 0.3075559565213817, 0.0, 0.5905174410069893, 0.6630729769663496, 0.536884887827559, 0.4247731091204771, 0.40899286214960784, 0.38997089678529284, 0.38997089678529284, 0.24952896018781615, 0.21590015440331953, 0.49721280488989356, 0.5128983837052054, 0.5128983837052054, 0.5128983837052054, 0.5128983837052054, 0.5128983837052054, 0.3179096460209036, 0.24751699617429665, 0.2596032463150941, 0.26378552141852446, 0.37524940442829563, 0.4811281037096846, 0.4764325383293388, 0.34623110528875584, 0.2962297254176412, 0.29891613886579943, 0.2959252828148301, 0.2964753582809054, 0.4381885949716445, 0.417154887643741, 0.37737106084056643, 0.293886910976059, 0.32014550481459225, 0.5041419672144238, 0.41596673857883515, 0.49088362533337426, 0.40826653891940534, 0.3143370902503948, 0.35565117965226906, 0.364105755442281, 0.37005166133348544, 0.37005166133348544, 0.368810804953359, 0.37856132812285526, 0.36449883669851557, 0.3528911215289254, 0.32574351700904064, 0.31781303194405963, 0.3134769511031356, 0.3134769511031356, 0.26253036158897136, 0.3112769519995582, 0.31651985700200014, 0.2538655003423789, 0.19813013529795226, 0.521338423918498, 0.42059322112070774, 0.42234390192708804, 0.2127962159559693, 0.2219994156898401, 0.2983361945984301, 0.32197404076316544, 0.32197404076316544, 0.3397520329018284, 0.35725255269264716, 0.3636857232802849, 0.37850874405868334, 0.3780456851300246, 0.39099115543644936, 0.36946559552073516, 0.3521050931715724, 0.338511851083954, 0.27023166690382094, 0.12855608082815365, 0.483890204532685, 0.45378670562567963, 0.4791052330279948], [1.0041723057901957, 0.9293821714242645, 0.8586692082049597, 0.8506679920639587, 0.7924212509296998, 0.7967162005668945, 0.7967162005668945, 0.7967162005668945, 0.7522420502223164, 0.5905174410069893, 0.0, 0.12268824789717098, 0.09585317650621869, 0.21709212534491565, 0.2947796866757519, 0.3320053659116309, 0.3320053659116309, 0.6391627100145916, 0.6865396233716378, 0.9387848175666308, 0.9651107712714172, 0.9651107712714172, 0.9651107712714172, 0.9651107712714172, 0.9651107712714172, 0.8096195657849562, 0.7168397919250243, 0.544122358776539, 0.5582221468371077, 0.8430067133832906, 0.9629835453642696, 0.9583596326849363, 0.729487499798474, 0.5757593476679541, 0.7521914057822506, 0.7508293422841471, 0.7541449839512037, 0.8804056488630235, 0.8418738187198711, 0.8148269054580841, 0.7285595275836858, 0.785181186055586, 0.982105294180489, 0.9222330211779862, 0.9679452097442177, 0.8628615454117606, 0.7302068014243285, 0.7657067209217794, 0.7933641302352435, 0.7981890686915384, 0.7981890686915384, 0.7883807028015676, 0.801126785056137, 0.7920955875553916, 0.7830807442755555, 0.7287502650124562, 0.7022537127152841, 0.6931353226390446, 0.6931353226390446, 0.652560989499606, 0.7009844825829737, 0.7250616701832315, 0.6715157113489343, 0.5102528434683713, 0.09714654663983269, 0.21826701180776506, 0.22597715500330098, 0.4971785055325773, 0.6319708230201007, 0.6741215622267207, 0.7191236162851731, 0.7191236162851731, 0.7423080141775089, 0.7637343646737712, 0.7675022831141857, 0.7966767111042073, 0.7900032649370452, 0.8057968688989525, 0.7945802202994252, 0.769500178115683, 0.752534079304063, 0.708659728531768, 0.6405040304214096, 0.2012118599876756, 0.22087242664495482, 0.19194330451954647], [1.0626240310955664, 0.9911170561686404, 0.9185426167129337, 0.9131147352219879, 0.8519811707696632, 0.8561639894191349, 0.8561639894191349, 0.8561639894191349, 0.8147523127397128, 0.6630729769663496, 0.12268824789717098, 0.0, 0.1560919854051772, 0.2810286770836001, 0.35259725710993167, 0.3896636602239364, 0.3896636602239364, 0.7142207777174874, 0.7553725668381087, 0.998503302361412, 1.0251214750638753, 1.0251214750638753, 1.0251214750638753, 1.0251214750638753, 1.0251214750638753, 0.8754883112220042, 0.7838802338683647, 0.6097144366797664, 0.6210214802013847, 0.909456453320015, 1.0249198551772267, 1.0201515850208351, 0.8044866796042386, 0.6366360814573029, 0.8207280361328345, 0.8194785869611734, 0.8227345326544887, 0.9428386659050113, 0.9022522023813063, 0.8766494651359897, 0.7921280121954469, 0.8561230652884805, 1.0440819200852227, 0.9881116559932039, 1.0312739788634562, 0.9320036394636124, 0.7950776388904655, 0.8287240039127541, 0.8548955619210084, 0.8594958536268419, 0.8594958536268419, 0.8503948880214184, 0.8626309780618764, 0.8541204886847985, 0.8455435175191925, 0.7920440202474941, 0.7634687326782181, 0.7546338056223411, 0.7546338056223411, 0.7173841944401935, 0.7640358861993095, 0.7870689834658368, 0.7362343624556329, 0.582442117669181, 0.1831825078230035, 0.29239527599672444, 0.29822237075933455, 0.5697858192909457, 0.6971127842218687, 0.7360246787358095, 0.7807602096596103, 0.7807602096596103, 0.8038999431470736, 0.8241963484242173, 0.8277209012061204, 0.8573909592598195, 0.8501832588444996, 0.8662235892109618, 0.8557921460157285, 0.8306630525565555, 0.8143038943290134, 0.7730960238379136, 0.7105707832197001, 0.2572139888604557, 0.27870193963771067, 0.25459362861251944], [0.9542164609219261, 0.8796320702900419, 0.8054228561945194, 0.7977567473752963, 0.7376396160798642, 0.7420118251287011, 0.7420118251287011, 0.7420118251287011, 0.6967259609515362, 0.536884887827559, 0.09585317650621869, 0.1560919854051772, 0.0, 0.14628257754710322, 0.22840135790963667, 0.2661297708396389, 0.2661297708396389, 0.5878041629754727, 0.6326191540970593, 0.8879443187145358, 0.9144583241286482, 0.9144583241286482, 0.9144583241286482, 0.9144583241286482, 0.9144583241286482, 0.7581533779822207, 0.660245028909746, 0.48428564198999613, 0.49795928671035955, 0.7910545504126938, 0.9142362704231443, 0.9093639947846138, 0.684619932507062, 0.5158450813578567, 0.6995376639492035, 0.6981743588400603, 0.7014504169570661, 0.8289686403968233, 0.7887630275788624, 0.7609794394509743, 0.6721669590595991, 0.7357938373460701, 0.9355546847145849, 0.8728564286280491, 0.918143195958383, 0.8153299306213326, 0.675836060272419, 0.7117979865679246, 0.738190818366223, 0.7431622678135191, 0.7431622678135191, 0.734082968840873, 0.7472368982241226, 0.7380365940610761, 0.7288859110699195, 0.6737835753964192, 0.6452966369822069, 0.6356990813664068, 0.6356990813664068, 0.5956027734309787, 0.6444709210373776, 0.6685662080299181, 0.6145492601432808, 0.45732388214350006, 0.0532885043517921, 0.14683425305797287, 0.15470730101105182, 0.4368328631831228, 0.573710909009489, 0.6164252250472255, 0.662589485189125, 0.662589485189125, 0.686773028412545, 0.7081591711081489, 0.7120199627279762, 0.742162295734766, 0.7352682969290222, 0.7516482454903787, 0.7401684844686822, 0.7143689815410129, 0.6966242733373128, 0.6517858504721005, 0.5843646624159514, 0.14004690239943252, 0.14863981456088043, 0.1317412546744354], [0.8475039486646659, 0.7723893685391614, 0.6935125350204175, 0.6879653476606679, 0.6242718252226521, 0.6286330353713878, 0.6286330353713878, 0.6286330353713878, 0.5791646109152229, 0.4247731091204771, 0.21709212534491565, 0.2810286770836001, 0.14628257754710322, 0.0, 0.11071771285558123, 0.1463271190997712, 0.1463271190997712, 0.49446576457991487, 0.5220781529298112, 0.7795110095805948, 0.8074884147669753, 0.8074884147669753, 0.8074884147669753, 0.8074884147669753, 0.8074884147669753, 0.6457986410825909, 0.5508321733565446, 0.36262797730398255, 0.3739922208813103, 0.6915227623318636, 0.8098223849831767, 0.804553357653844, 0.5830261032433154, 0.3952346076525585, 0.5898479215572443, 0.5883782385074915, 0.5913658861041463, 0.7198864370091831, 0.6771210944266814, 0.6479341195469774, 0.5558444851213222, 0.6275835036081523, 0.8357058983312634, 0.768900122800852, 0.8152167199828293, 0.7115878551061683, 0.5610375291227417, 0.5983322365823176, 0.6256825102190525, 0.6307553236788289, 0.6307553236788289, 0.6213453589388892, 0.634149197544506, 0.624301393065871, 0.6147549867457535, 0.558327014316145, 0.5284842764447992, 0.5194521156536853, 0.5194521156536853, 0.4757032749562426, 0.5290957617417583, 0.5526255945802544, 0.496945990267528, 0.36120950103936467, 0.13822004490722142, 0.06652256197332304, 0.07463751103619666, 0.3206689217225686, 0.4515566276064994, 0.4985252820005102, 0.5464734136337324, 0.5464734136337324, 0.5715844760698969, 0.5936138686566348, 0.597843770158413, 0.6288341548764054, 0.6214866577176644, 0.6389062504426248, 0.626194523213411, 0.599538229207583, 0.582350993490862, 0.5349894745307529, 0.4671162227111179, 0.09141106378658267, 0.06850374520878497, 0.0843613309038195], [0.7829612397852137, 0.7037849337652188, 0.6236651435112482, 0.6189581252748529, 0.5497157584518778, 0.5542993312365503, 0.5542993312365503, 0.5542993312365503, 0.5112710937902902, 0.40899286214960784, 0.2947796866757519, 0.35259725710993167, 0.22840135790963667, 0.11071771285558123, 0.0, 0.041589955221029186, 0.041589955221029186, 0.4545928344086731, 0.4746678174127391, 0.7109678578361589, 0.7410872854611393, 0.7410872854611393, 0.7410872854611393, 0.7410872854611393, 0.7410872854611393, 0.5912925326219424, 0.494525121671374, 0.2861336553398374, 0.2968609981614976, 0.6390529694830516, 0.7578689232527478, 0.7523159390586268, 0.5216397659965732, 0.312914993899614, 0.5280368282934703, 0.5269196709638669, 0.5297362130918739, 0.6510427235172279, 0.6051142826562989, 0.5776382672458245, 0.4864575529855135, 0.5688941617404705, 0.7920917619612245, 0.7202740697038742, 0.7571461664835103, 0.6520474033772012, 0.4895716165870777, 0.5247926177395189, 0.5543369878520937, 0.5591978080489667, 0.5591978080489667, 0.5486970104251443, 0.5618892932141409, 0.5528518755548669, 0.5439099625230008, 0.4844326064215523, 0.45274981993465047, 0.443342828781042, 0.443342828781042, 0.403601476950821, 0.45416297612559675, 0.47960177859861536, 0.43060671289127406, 0.35377726544655974, 0.21462405525313746, 0.1180712292726673, 0.10811570417577437, 0.2647041868658847, 0.3852225937343539, 0.4226859533719543, 0.4718248941211828, 0.4718248941211828, 0.4972293049680122, 0.5193599430380352, 0.5232062169780622, 0.5558391250953713, 0.5477382337218446, 0.5654825570158404, 0.5541946996287537, 0.5268286838957015, 0.5093133480065155, 0.4672528587797978, 0.42282896505415557, 0.10714471197929555, 0.08476438114229548, 0.11168317695905554], [0.7497997478368953, 0.6697301406252237, 0.5887538173864539, 0.5843213099969671, 0.5136354928925206, 0.5182734385734156, 0.5182734385734156, 0.5182734385734156, 0.47643555012243655, 0.38997089678529284, 0.3320053659116309, 0.3896636602239364, 0.2661297708396389, 0.1463271190997712, 0.041589955221029186, 0.0, 6.933519036992152e-18, 0.4315809468830394, 0.4467846775917965, 0.6767230227866247, 0.7073561796850745, 0.7073561796850745, 0.7073561796850745, 0.7073561796850745, 0.7073561796850745, 0.5606213384206061, 0.4634126486648276, 0.24949406945044056, 0.259767326102597, 0.6097781634642947, 0.7283551989662271, 0.7226879378567466, 0.4919290449271899, 0.2746717664479622, 0.49568119201508076, 0.49465221012831667, 0.4973494083343759, 0.6166377405814241, 0.5697694420124821, 0.5424843601479686, 0.45119149070990816, 0.5377517846079133, 0.7654473605943657, 0.6914325380061779, 0.7257931280721092, 0.6210232365499586, 0.4542024964603386, 0.4889990283982263, 0.5188484669023904, 0.5236826156199896, 0.5236826156199896, 0.51303417330693, 0.5263434822945819, 0.5174323079690372, 0.5086051677485505, 0.44838848787978924, 0.4160694422503192, 0.4065526402967976, 0.4065526402967976, 0.3677632589185921, 0.4177529099828454, 0.4435462603017478, 0.3964624183752836, 0.3416538727994357, 0.2516709502738731, 0.14902309734185723, 0.13846992537760228, 0.23619280869155257, 0.35075758163324167, 0.3858834116357694, 0.435408961797045, 0.435408961797045, 0.4610162734918413, 0.48318015728857777, 0.48698009382656443, 0.5200627179634545, 0.511788106195932, 0.5296951338093021, 0.5186059507987303, 0.49100213797157344, 0.4733424513716142, 0.43238357444457315, 0.39520411607166556, 0.14613280365144735, 0.12371378962646112, 0.15090320549929917], [0.7497997478368953, 0.6697301406252237, 0.5887538173864539, 0.5843213099969671, 0.5136354928925206, 0.5182734385734156, 0.5182734385734156, 0.5182734385734156, 0.47643555012243655, 0.38997089678529284, 0.3320053659116309, 0.3896636602239364, 0.2661297708396389, 0.1463271190997712, 0.041589955221029186, 6.933519036992152e-18, 0.0, 0.4315809468830394, 0.4467846775917965, 0.6767230227866247, 0.7073561796850745, 0.7073561796850745, 0.7073561796850745, 0.7073561796850745, 0.7073561796850745, 0.5606213384206061, 0.4634126486648276, 0.24949406945044056, 0.259767326102597, 0.6097781634642947, 0.7283551989662271, 0.7226879378567466, 0.4919290449271899, 0.2746717664479622, 0.49568119201508076, 0.49465221012831667, 0.4973494083343759, 0.6166377405814241, 0.5697694420124821, 0.5424843601479686, 0.45119149070990816, 0.5377517846079133, 0.7654473605943657, 0.6914325380061779, 0.7257931280721092, 0.6210232365499586, 0.4542024964603386, 0.4889990283982263, 0.5188484669023904, 0.5236826156199896, 0.5236826156199896, 0.51303417330693, 0.5263434822945819, 0.5174323079690372, 0.5086051677485505, 0.44838848787978924, 0.4160694422503192, 0.4065526402967976, 0.4065526402967976, 0.3677632589185921, 0.4177529099828454, 0.4435462603017478, 0.3964624183752836, 0.3416538727994357, 0.2516709502738731, 0.14902309734185723, 0.13846992537760228, 0.23619280869155257, 0.35075758163324167, 0.3858834116357694, 0.435408961797045, 0.435408961797045, 0.4610162734918413, 0.48318015728857777, 0.48698009382656443, 0.5200627179634545, 0.511788106195932, 0.5296951338093021, 0.5186059507987303, 0.49100213797157344, 0.4733424513716142, 0.43238357444457315, 0.39520411607166556, 0.14613280365144735, 0.12371378962646112, 0.15090320549929917], [0.5129750265598189, 0.4417306503343459, 0.39955068721854387, 0.3610966943292777, 0.3750375447205798, 0.3782419605673622, 0.3782419605673622, 0.3782419605673622, 0.32830059687045354, 0.24952896018781615, 0.6391627100145916, 0.7142207777174874, 0.5878041629754727, 0.49446576457991487, 0.4545928344086731, 0.4315809468830394, 0.4315809468830394, 0.0, 0.18033335293053787, 0.4646125787191688, 0.4700762162005614, 0.4700762162005614, 0.4700762162005614, 0.4700762162005614, 0.4700762162005614, 0.3004587734729044, 0.18074211871586585, 0.27949875507324035, 0.3061733519754215, 0.2517367694844365, 0.4315128838686032, 0.4292527871875221, 0.2226302284090044, 0.31846590653298307, 0.21713480337461427, 0.21519739328599172, 0.22002475895116197, 0.39200332988692604, 0.3933044311180692, 0.35751660489116105, 0.29125051269866425, 0.24477494013676665, 0.45143675037721115, 0.3590557571136323, 0.4129511596337269, 0.30895842550259167, 0.28789691079966323, 0.33126893109775535, 0.3362039343238317, 0.3425948418497566, 0.3425948418497566, 0.3421109715035664, 0.3566923281820929, 0.3449139372725108, 0.33320993507143304, 0.31348103217918466, 0.31784398086720816, 0.3081331909474759, 0.3081331909474759, 0.2851749686294161, 0.29538453978351376, 0.30740982716557685, 0.24980827186439156, 0.23334786355730933, 0.5647167858542245, 0.4653893050775652, 0.46124126536112753, 0.2206627323477476, 0.26936636399003044, 0.3049649576853326, 0.3185178034561635, 0.3185178034561635, 0.3290430824300902, 0.3478767026320287, 0.3525617842828327, 0.36277063695596373, 0.36747035917537757, 0.3721515704535266, 0.35781685080070913, 0.34152197225840514, 0.32038389419539764, 0.26727375442255796, 0.20350230025358512, 0.5261080942977787, 0.4979354095242166, 0.5215778258986571], [0.41493018112381935, 0.3663464147505487, 0.29465351053750805, 0.279997233695138, 0.2841564142342727, 0.28572474949294957, 0.28572474949294957, 0.28572474949294957, 0.2245041030385045, 0.21590015440331953, 0.6865396233716378, 0.7553725668381087, 0.6326191540970593, 0.5220781529298112, 0.4746678174127391, 0.4467846775917965, 0.4467846775917965, 0.18033335293053787, 0.0, 0.3768884932487935, 0.3873191509903276, 0.3873191509903276, 0.3873191509903276, 0.3873191509903276, 0.3873191509903276, 0.1654357583328347, 0.10542342962227902, 0.2464449098745023, 0.2584407848452562, 0.23165659343367648, 0.32709460603877877, 0.3221297628393579, 0.2483272232871545, 0.27284912855806753, 0.14294249992578376, 0.14024126217669686, 0.14590751502655852, 0.3127421203151147, 0.3008014657922815, 0.2628352890530476, 0.19957561722583064, 0.20510713374594117, 0.3570236817973315, 0.2963625784214681, 0.35503603020639335, 0.2796802348976922, 0.19977403472023347, 0.24971851372509693, 0.2478699322365469, 0.253804927152733, 0.253804927152733, 0.2567137164958014, 0.26308194653883754, 0.24805334552155697, 0.2330817159769418, 0.23048930122061842, 0.23334927334522151, 0.23185807582049042, 0.23185807582049042, 0.21228858275470985, 0.2218564266990929, 0.21453321690607483, 0.13693190040385148, 0.23676787272723146, 0.610697070873451, 0.5069077287011479, 0.502800270709963, 0.23518626632713308, 0.18579701909781368, 0.2287360773324301, 0.23439963026170058, 0.23439963026170058, 0.23956919825046138, 0.25705157385391586, 0.26297656578689094, 0.2716427711094318, 0.27541336646272435, 0.2817424332501796, 0.2634042519554442, 0.24305084815085373, 0.2328442170756956, 0.17238720888421763, 0.11525809776997382, 0.559151092596409, 0.5312755049750321, 0.556394376888385], [0.11461990728685224, 0.049842633561684224, 0.1084617495836253, 0.11833828791950438, 0.18395182121156745, 0.17916259222892747, 0.17916259222892747, 0.17916259222892747, 0.2340437509756612, 0.49721280488989356, 0.9387848175666308, 0.998503302361412, 0.8879443187145358, 0.7795110095805948, 0.7109678578361589, 0.6767230227866247, 0.6767230227866247, 0.4646125787191688, 0.3768884932487935, 0.0, 0.05245444899402821, 0.05245444899402821, 0.05245444899402821, 0.05245444899402821, 0.05245444899402821, 0.2542409195133522, 0.3240298783452608, 0.4532763798005097, 0.44213482716874725, 0.3090005952055624, 0.2777599788834521, 0.273502593135895, 0.34388571083051955, 0.4258554747142684, 0.2682094964386743, 0.2703280163007601, 0.264311645740381, 0.08222076622746276, 0.1206622873580031, 0.1511835568199807, 0.2545321399138686, 0.26002775420661944, 0.3778006821003442, 0.28030606111787076, 0.20426698442160413, 0.2337555269767533, 0.25032072825345847, 0.20765459193464064, 0.18001514681121975, 0.17408679948998748, 0.17408679948998748, 0.18216040335575914, 0.1674133706876085, 0.17804945392919475, 0.18996084876364072, 0.24979126825911913, 0.2838997614403936, 0.2940443581491315, 0.2940443581491315, 0.33713552965096544, 0.2828094887738636, 0.25733707489991003, 0.33017346159354194, 0.5807887167711393, 0.8697407583620925, 0.7702831561443229, 0.763752469868356, 0.5112074899033002, 0.36630741157792934, 0.3145749935261555, 0.2634432397216189, 0.2634432397216189, 0.2366966656774588, 0.21409425818226213, 0.2106222577649907, 0.1740003750099169, 0.18385306301095708, 0.16441986603750358, 0.17543449886732623, 0.2062356915216831, 0.22536352539650648, 0.28017211246237256, 0.3993930715943975, 0.798429820216637, 0.7769241126558657, 0.7999378910571688], [0.0862198209050816, 0.06630865692257876, 0.14245723106124228, 0.14021215563901157, 0.22303818009531046, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2657454722694084, 0.5128983837052054, 0.9651107712714172, 1.0251214750638753, 0.9144583241286482, 0.8074884147669753, 0.7410872854611393, 0.7073561796850745, 0.7073561796850745, 0.4700762162005614, 0.3873191509903276, 0.05245444899402821, 0.0, 5.8906539194861334e-18, 6.801941252236487e-18, 8.937664098385e-18, 1.2232861603948852e-17, 0.2599043784618197, 0.33288330549552003, 0.48377301867159594, 0.4744829672200483, 0.29100494254206566, 0.2510153137100009, 0.24789310722780658, 0.3562187259523368, 0.45952827375182315, 0.2798176559170036, 0.281848936453737, 0.2760837421091422, 0.10627582490153101, 0.16003714625174456, 0.1841438797317914, 0.2833578288815231, 0.26718795908582244, 0.3495393300606941, 0.2525138467260635, 0.16406326771606008, 0.2264810449830483, 0.28014020285935715, 0.24228547992919774, 0.20967466243833272, 0.20460748946173032, 0.20460748946173032, 0.21577314746397766, 0.20283598973519468, 0.21169981126905632, 0.22181146523539558, 0.2837885653334742, 0.31831248265658885, 0.32739249629218253, 0.32739249629218253, 0.3691298554200269, 0.31492031351999344, 0.28920836558627344, 0.3555750600755078, 0.595596039388869, 0.8962291184563188, 0.7970012445598589, 0.7906912661844171, 0.535314017079376, 0.395461741328565, 0.3480894937076913, 0.29756297023838746, 0.29756297023838746, 0.2715628059825114, 0.25021834134553916, 0.24725412519333406, 0.21082280063079764, 0.22204521824504808, 0.20248593790489583, 0.2115276012587123, 0.24090514860502255, 0.25747009291589656, 0.30659181784354056, 0.4167552619941723, 0.8276399739813997, 0.8055588730821418, 0.8287958566963831], [0.0862198209050816, 0.06630865692257876, 0.14245723106124228, 0.14021215563901157, 0.22303818009531046, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2657454722694084, 0.5128983837052054, 0.9651107712714172, 1.0251214750638753, 0.9144583241286482, 0.8074884147669753, 0.7410872854611393, 0.7073561796850745, 0.7073561796850745, 0.4700762162005614, 0.3873191509903276, 0.05245444899402821, 5.8906539194861334e-18, 0.0, 3.4009706261182436e-18, 6.721758396164117e-18, 1.0721151963395011e-17, 0.2599043784618197, 0.33288330549552003, 0.48377301867159594, 0.4744829672200483, 0.29100494254206566, 0.2510153137100009, 0.24789310722780658, 0.3562187259523368, 0.45952827375182315, 0.2798176559170036, 0.281848936453737, 0.2760837421091422, 0.10627582490153101, 0.16003714625174456, 0.1841438797317914, 0.2833578288815231, 0.26718795908582244, 0.3495393300606941, 0.2525138467260635, 0.16406326771606008, 0.2264810449830483, 0.28014020285935715, 0.24228547992919774, 0.20967466243833272, 0.20460748946173032, 0.20460748946173032, 0.21577314746397766, 0.20283598973519468, 0.21169981126905632, 0.22181146523539558, 0.2837885653334742, 0.31831248265658885, 0.32739249629218253, 0.32739249629218253, 0.3691298554200269, 0.31492031351999344, 0.28920836558627344, 0.3555750600755078, 0.595596039388869, 0.8962291184563188, 0.7970012445598589, 0.7906912661844171, 0.535314017079376, 0.395461741328565, 0.3480894937076913, 0.29756297023838746, 0.29756297023838746, 0.2715628059825114, 0.25021834134553916, 0.24725412519333406, 0.21082280063079764, 0.22204521824504808, 0.20248593790489583, 0.2115276012587123, 0.24090514860502255, 0.25747009291589656, 0.30659181784354056, 0.4167552619941723, 0.8276399739813997, 0.8055588730821418, 0.8287958566963831], [0.0862198209050816, 0.06630865692257876, 0.14245723106124228, 0.14021215563901157, 0.22303818009531046, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2657454722694084, 0.5128983837052054, 0.9651107712714172, 1.0251214750638753, 0.9144583241286482, 0.8074884147669753, 0.7410872854611393, 0.7073561796850745, 0.7073561796850745, 0.4700762162005614, 0.3873191509903276, 0.05245444899402821, 6.801941252236487e-18, 3.4009706261182436e-18, 0.0, 5.797881918139044e-18, 1.0167423381687694e-17, 0.2599043784618197, 0.33288330549552003, 0.48377301867159594, 0.4744829672200483, 0.29100494254206566, 0.2510153137100009, 0.24789310722780658, 0.3562187259523368, 0.45952827375182315, 0.2798176559170036, 0.281848936453737, 0.2760837421091422, 0.10627582490153101, 0.16003714625174456, 0.1841438797317914, 0.2833578288815231, 0.26718795908582244, 0.3495393300606941, 0.2525138467260635, 0.16406326771606008, 0.2264810449830483, 0.28014020285935715, 0.24228547992919774, 0.20967466243833272, 0.20460748946173032, 0.20460748946173032, 0.21577314746397766, 0.20283598973519468, 0.21169981126905632, 0.22181146523539558, 0.2837885653334742, 0.31831248265658885, 0.32739249629218253, 0.32739249629218253, 0.3691298554200269, 0.31492031351999344, 0.28920836558627344, 0.3555750600755078, 0.595596039388869, 0.8962291184563188, 0.7970012445598589, 0.7906912661844171, 0.535314017079376, 0.395461741328565, 0.3480894937076913, 0.29756297023838746, 0.29756297023838746, 0.2715628059825114, 0.25021834134553916, 0.24725412519333406, 0.21082280063079764, 0.22204521824504808, 0.20248593790489583, 0.2115276012587123, 0.24090514860502255, 0.25747009291589656, 0.30659181784354056, 0.4167552619941723, 0.8276399739813997, 0.8055588730821418, 0.8287958566963831], [0.0862198209050816, 0.06630865692257876, 0.14245723106124228, 0.14021215563901157, 0.22303818009531046, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2657454722694084, 0.5128983837052054, 0.9651107712714172, 1.0251214750638753, 0.9144583241286482, 0.8074884147669753, 0.7410872854611393, 0.7073561796850745, 0.7073561796850745, 0.4700762162005614, 0.3873191509903276, 0.05245444899402821, 8.937664098385e-18, 6.721758396164117e-18, 5.797881918139044e-18, 0.0, 8.308919960549835e-18, 0.2599043784618197, 0.33288330549552003, 0.48377301867159594, 0.4744829672200483, 0.29100494254206566, 0.2510153137100009, 0.24789310722780658, 0.3562187259523368, 0.45952827375182315, 0.2798176559170036, 0.281848936453737, 0.2760837421091422, 0.10627582490153101, 0.16003714625174456, 0.1841438797317914, 0.2833578288815231, 0.26718795908582244, 0.3495393300606941, 0.2525138467260635, 0.16406326771606008, 0.2264810449830483, 0.28014020285935715, 0.24228547992919774, 0.20967466243833272, 0.20460748946173032, 0.20460748946173032, 0.21577314746397766, 0.20283598973519468, 0.21169981126905632, 0.22181146523539558, 0.2837885653334742, 0.31831248265658885, 0.32739249629218253, 0.32739249629218253, 0.3691298554200269, 0.31492031351999344, 0.28920836558627344, 0.3555750600755078, 0.595596039388869, 0.8962291184563188, 0.7970012445598589, 0.7906912661844171, 0.535314017079376, 0.395461741328565, 0.3480894937076913, 0.29756297023838746, 0.29756297023838746, 0.2715628059825114, 0.25021834134553916, 0.24725412519333406, 0.21082280063079764, 0.22204521824504808, 0.20248593790489583, 0.2115276012587123, 0.24090514860502255, 0.25747009291589656, 0.30659181784354056, 0.4167552619941723, 0.8276399739813997, 0.8055588730821418, 0.8287958566963831], [0.0862198209050816, 0.06630865692257876, 0.14245723106124228, 0.14021215563901157, 0.22303818009531046, 0.2185250505049717, 0.2185250505049717, 0.2185250505049717, 0.2657454722694084, 0.5128983837052054, 0.9651107712714172, 1.0251214750638753, 0.9144583241286482, 0.8074884147669753, 0.7410872854611393, 0.7073561796850745, 0.7073561796850745, 0.4700762162005614, 0.3873191509903276, 0.05245444899402821, 1.2232861603948852e-17, 1.0721151963395011e-17, 1.0167423381687694e-17, 8.308919960549835e-18, 0.0, 0.2599043784618197, 0.33288330549552003, 0.48377301867159594, 0.4744829672200483, 0.29100494254206566, 0.2510153137100009, 0.24789310722780658, 0.3562187259523368, 0.45952827375182315, 0.2798176559170036, 0.281848936453737, 0.2760837421091422, 0.10627582490153101, 0.16003714625174456, 0.1841438797317914, 0.2833578288815231, 0.26718795908582244, 0.3495393300606941, 0.2525138467260635, 0.16406326771606008, 0.2264810449830483, 0.28014020285935715, 0.24228547992919774, 0.20967466243833272, 0.20460748946173032, 0.20460748946173032, 0.21577314746397766, 0.20283598973519468, 0.21169981126905632, 0.22181146523539558, 0.2837885653334742, 0.31831248265658885, 0.32739249629218253, 0.32739249629218253, 0.3691298554200269, 0.31492031351999344, 0.28920836558627344, 0.3555750600755078, 0.595596039388869, 0.8962291184563188, 0.7970012445598589, 0.7906912661844171, 0.535314017079376, 0.395461741328565, 0.3480894937076913, 0.29756297023838746, 0.29756297023838746, 0.2715628059825114, 0.25021834134553916, 0.24725412519333406, 0.21082280063079764, 0.22204521824504808, 0.20248593790489583, 0.2115276012587123, 0.24090514860502255, 0.25747009291589656, 0.30659181784354056, 0.4167552619941723, 0.8276399739813997, 0.8055588730821418, 0.8287958566963831], [0.2743645640072479, 0.24874759134523142, 0.19055164478319214, 0.1889644088339501, 0.22818814076142385, 0.22651724456589578, 0.22651724456589578, 0.22651724456589578, 0.1806406327450757, 0.3179096460209036, 0.8096195657849562, 0.8754883112220042, 0.7581533779822207, 0.6457986410825909, 0.5912925326219424, 0.5606213384206061, 0.5606213384206061, 0.3004587734729044, 0.1654357583328347, 0.2542409195133522, 0.2599043784618197, 0.2599043784618197, 0.2599043784618197, 0.2599043784618197, 0.2599043784618197, 0.0, 0.1675880133958539, 0.33901015320593014, 0.3365135619967006, 0.207452830318137, 0.19764746835618022, 0.19159775450482072, 0.25903968457738275, 0.34067923264642536, 0.1344402688402403, 0.1331557802751685, 0.13182135370665174, 0.20684738967310218, 0.21328431435675846, 0.1829803654300809, 0.1856572453990809, 0.1590722288023385, 0.25875729436680944, 0.1947792913619238, 0.24121251807094404, 0.20115678950370036, 0.1843641277663929, 0.2076918388682788, 0.19195581044010315, 0.19466673113133812, 0.19466673113133812, 0.20167248062079818, 0.19527790557225216, 0.18254376127863836, 0.1717303838099934, 0.21310579046127426, 0.2367985242261369, 0.2447123464718776, 0.2447123464718776, 0.2469437487719252, 0.23110500569118944, 0.20449589403382687, 0.19115008885582588, 0.3886790176216151, 0.7374424428480649, 0.6357445451507577, 0.6312319120314147, 0.36486450529719866, 0.24305359191182976, 0.251124565827407, 0.22622840147849926, 0.22622840147849926, 0.21408015500501237, 0.21781550270012517, 0.22243145657754462, 0.20998392537689972, 0.21815328020782415, 0.21614662375993013, 0.1986135935906197, 0.19553019044165004, 0.20409013645505397, 0.1808595359844117, 0.21555524689597086, 0.6782944955774469, 0.6532484903689042, 0.6770652417870567], [0.3734121541143806, 0.3126845369964456, 0.24614205539478995, 0.21759195463740158, 0.23071045584672276, 0.23283990316328293, 0.23283990316328293, 0.23283990316328293, 0.18218600052077602, 0.24751699617429665, 0.7168397919250243, 0.7838802338683647, 0.660245028909746, 0.5508321733565446, 0.494525121671374, 0.4634126486648276, 0.4634126486648276, 0.18074211871586585, 0.10542342962227902, 0.3240298783452608, 0.33288330549552003, 0.33288330549552003, 0.33288330549552003, 0.33288330549552003, 0.33288330549552003, 0.1675880133958539, 0.0, 0.2451596363291805, 0.25369806157084285, 0.1740480185689992, 0.3179841197359866, 0.3131169507019638, 0.21817497529612845, 0.2574566672033992, 0.09502423388093353, 0.09319807379721819, 0.09563208298613012, 0.2553141350269062, 0.24687978223977436, 0.20795337438420455, 0.1477270986506222, 0.16238635595085377, 0.3658127919048916, 0.2642283525760731, 0.30311732414121156, 0.2339232177129405, 0.1566652908448904, 0.19672653863333547, 0.18549528677717153, 0.1921675512816716, 0.1921675512816716, 0.19912107343885146, 0.21079645357077942, 0.1976717687837358, 0.1852053463944188, 0.18381025997764028, 0.19156749750460167, 0.18663727445993308, 0.18663727445993308, 0.18451954966775486, 0.17341937215037162, 0.1683428660869815, 0.13081976545069876, 0.29704160076375524, 0.6406523161028983, 0.533545563425156, 0.5281604569906375, 0.25089021230127867, 0.17560894451966924, 0.19075360439718464, 0.18639768010773683, 0.18639768010773683, 0.19157258830769527, 0.2048571239293346, 0.21005716371690747, 0.21655327040318298, 0.22224068616834836, 0.2270004198780476, 0.21037392238814429, 0.1947245041567413, 0.17693798963219828, 0.12605960536744737, 0.14062416515178727, 0.5815619546251679, 0.5536211279664602, 0.5802997028153127], [0.528293114011629, 0.4456682291708678, 0.3604212316468894, 0.35433325274350636, 0.2866626735542771, 0.29139114466174565, 0.29139114466174565, 0.29139114466174565, 0.24494297559728417, 0.2596032463150941, 0.544122358776539, 0.6097144366797664, 0.48428564198999613, 0.36262797730398255, 0.2861336553398374, 0.24949406945044056, 0.24949406945044056, 0.27949875507324035, 0.2464449098745023, 0.4532763798005097, 0.48377301867159594, 0.48377301867159594, 0.48377301867159594, 0.48377301867159594, 0.48377301867159594, 0.33901015320593014, 0.2451596363291805, 0.0, 0.04058473307130078, 0.40215588188822, 0.5150825515159434, 0.5090361176318523, 0.29448614089150554, 0.06052676690009366, 0.26723978517953023, 0.26642397043024535, 0.2683520882255323, 0.3887607191347732, 0.3421604450874141, 0.3110555169930004, 0.21438135672080233, 0.3169402649349727, 0.5661432732530183, 0.47933558487093486, 0.5060112708930062, 0.4032925096317715, 0.21657777282223764, 0.2566663317669834, 0.2866278162979917, 0.2919912125002074, 0.2919912125002074, 0.2813199908816717, 0.29521589739016985, 0.2847321947617418, 0.2745995526765137, 0.2134517972704781, 0.18233705062627517, 0.17237077211295368, 0.17237077211295368, 0.1301483799120235, 0.1814228140231262, 0.2072777442240589, 0.16093242652731274, 0.2718474247685319, 0.46457982167769524, 0.35268715356094127, 0.3449460314900439, 0.11043590924212017, 0.11756537445993705, 0.1504381646202982, 0.2015587302248665, 0.2015587302248665, 0.2278496301145287, 0.2527042450047455, 0.2574239526001674, 0.29037864222115467, 0.2832020143226875, 0.3011837358127735, 0.2878270072089794, 0.2583704946518138, 0.2393771961319682, 0.19406759153828468, 0.1997652772318075, 0.3835374406548736, 0.3583285582610495, 0.3846654876849341], [0.518731502197706, 0.437349971924229, 0.3491293044676638, 0.347356410673224, 0.2730748960089877, 0.27764889991404934, 0.27764889991404934, 0.27764889991404934, 0.22920673425508198, 0.26378552141852446, 0.5582221468371077, 0.6210214802013847, 0.49795928671035955, 0.3739922208813103, 0.2968609981614976, 0.259767326102597, 0.259767326102597, 0.3061733519754215, 0.2584407848452562, 0.44213482716874725, 0.4744829672200483, 0.4744829672200483, 0.4744829672200483, 0.4744829672200483, 0.4744829672200483, 0.3365135619967006, 0.25369806157084285, 0.04058473307130078, 0.0, 0.41104568144646736, 0.5136562834469862, 0.5073172877150872, 0.3070778371059668, 0.04289580052245907, 0.27328452990993113, 0.2724868134884821, 0.273328882231385, 0.3808497729983596, 0.33059410331100764, 0.3000920777831351, 0.2043628509845585, 0.31954249787848177, 0.5681898435134095, 0.47889951261090513, 0.5043514833907786, 0.40608334740835406, 0.21131932770480755, 0.24723063091562686, 0.27769719451499086, 0.2827007062313379, 0.2827007062313379, 0.2717502662513318, 0.28453896632736353, 0.2743417918228927, 0.2650456720677739, 0.20313605745755778, 0.16932164991614443, 0.16127622319482915, 0.16127622319482915, 0.11627601214225192, 0.17356275749850852, 0.19733362004152452, 0.16150545699058977, 0.2957188526783399, 0.48017140043398315, 0.3691154637118761, 0.3617260868461709, 0.14156792375771055, 0.1049846452271476, 0.13692010313026418, 0.1889851114919352, 0.1889851114919352, 0.21631540543483177, 0.23975895055393392, 0.24455076776352366, 0.2780878407729934, 0.2697184469440014, 0.28912164933702267, 0.2751800710009718, 0.24650616753838417, 0.2296290278443057, 0.1871171572916908, 0.20329041498679287, 0.395401949645658, 0.370997968459855, 0.3974306888320142], [0.32447702848457044, 0.287756202892911, 0.2788713986153668, 0.23279794937543188, 0.3075395323667558, 0.3076970586364399, 0.3076970586364399, 0.3076970586364399, 0.28892757853644746, 0.37524940442829563, 0.8430067133832906, 0.909456453320015, 0.7910545504126938, 0.6915227623318636, 0.6390529694830516, 0.6097781634642947, 0.6097781634642947, 0.2517367694844365, 0.23165659343367648, 0.3090005952055624, 0.29100494254206566, 0.29100494254206566, 0.29100494254206566, 0.29100494254206566, 0.29100494254206566, 0.207452830318137, 0.1740480185689992, 0.40215588188822, 0.41104568144646736, 0.0, 0.23969696645764768, 0.23949354393208347, 0.24959139574262837, 0.40894349879367087, 0.17055546271570385, 0.17062356305642262, 0.1708051304161267, 0.2535297110150881, 0.28925197829036414, 0.26486402158872324, 0.26780645688334925, 0.1797626418229937, 0.27808558557663415, 0.15799296172563104, 0.18535192032215278, 0.17080873691630566, 0.2668362595587059, 0.2822285940803481, 0.25492041488519496, 0.2585951029036466, 0.2585951029036466, 0.2713595746531497, 0.27766447402767547, 0.27085368772013946, 0.26460040360632003, 0.29434984165549544, 0.3178554968970118, 0.3157499561560615, 0.3157499561560615, 0.33083615317937637, 0.29835219414489506, 0.2869670247151001, 0.28380912667458696, 0.421780881367081, 0.7710500480143677, 0.670810916692576, 0.6656677771169376, 0.40286341294340977, 0.3338408110956527, 0.3283173426348026, 0.3049221809886045, 0.3049221809886045, 0.29688494916514235, 0.29866191299868144, 0.30106440860171463, 0.2886099849338887, 0.3003511955175104, 0.2929744093492505, 0.28452924343467817, 0.28602246466856385, 0.27639079975585745, 0.262457902136336, 0.2902977512146829, 0.7194324719014535, 0.6929537727228398, 0.7176877965202969], [0.2166741990590248, 0.2759733272004097, 0.27428869478546064, 0.27481416349159166, 0.3523574851428895, 0.34885817328384056, 0.34885817328384056, 0.34885817328384056, 0.34152795091667276, 0.4811281037096846, 0.9629835453642696, 1.0249198551772267, 0.9142362704231443, 0.8098223849831767, 0.7578689232527478, 0.7283551989662271, 0.7283551989662271, 0.4315128838686032, 0.32709460603877877, 0.2777599788834521, 0.2510153137100009, 0.2510153137100009, 0.2510153137100009, 0.2510153137100009, 0.2510153137100009, 0.19764746835618022, 0.3179841197359866, 0.5150825515159434, 0.5136562834469862, 0.23969696645764768, 0.0, 0.009919072810184244, 0.38534680199961724, 0.512284703570062, 0.28571731114480886, 0.28594004234914977, 0.28506526130758103, 0.27162918552385434, 0.3102243531856726, 0.3024404143812012, 0.3496808849245502, 0.28932740063974904, 0.10611924461602663, 0.16375104824795922, 0.1776855764875941, 0.2575717557694578, 0.34492453816330776, 0.34844626159153286, 0.31742880375599686, 0.3171339757346163, 0.3171339757346163, 0.3306316760504388, 0.319312205373244, 0.3146546637751014, 0.3108126423232883, 0.36977142208106845, 0.3965632778512234, 0.4046367355669802, 0.4046367355669802, 0.4241062206914156, 0.39105390938084506, 0.3619673179550222, 0.36767830304403903, 0.538158944104063, 0.8941719673782298, 0.7980335936918307, 0.7935225900192762, 0.5376475475067437, 0.4259368671579878, 0.4175388593865272, 0.3829514136415678, 0.3829514136415678, 0.3635542524468611, 0.35729369222823565, 0.3589152733475035, 0.33502124354880575, 0.3459974419673108, 0.33461977603452586, 0.3283161653025917, 0.3367454992439606, 0.349465581444233, 0.35256138119667246, 0.39409789374097143, 0.8402378543308249, 0.8159989641952763, 0.8390252191330441], [0.21352626519986953, 0.2727133913473454, 0.2678870666258106, 0.2697752290719524, 0.3458952702398297, 0.34236677267149174, 0.34236677267149174, 0.34236677267149174, 0.3348806543486815, 0.4764325383293388, 0.9583596326849363, 1.0201515850208351, 0.9093639947846138, 0.804553357653844, 0.7523159390586268, 0.7226879378567466, 0.7226879378567466, 0.4292527871875221, 0.3221297628393579, 0.273502593135895, 0.24789310722780658, 0.24789310722780658, 0.24789310722780658, 0.24789310722780658, 0.24789310722780658, 0.19159775450482072, 0.3131169507019638, 0.5090361176318523, 0.5073172877150872, 0.23949354393208347, 0.009919072810184244, 0.0, 0.3837150989612941, 0.505901670156117, 0.2813678608105166, 0.2815940323016457, 0.2807057078394135, 0.2672178190478183, 0.30425601835653626, 0.29631533819189326, 0.3433207876158597, 0.28690429424566377, 0.11168224936047091, 0.16595790979667077, 0.1797214125069773, 0.25783333083832527, 0.33885950247577346, 0.3424603599859089, 0.3112748189848294, 0.3109741565553631, 0.3109741565553631, 0.32459127198543625, 0.3130737553366166, 0.30832198951042883, 0.3044000499478133, 0.3635223819396677, 0.38994276917852183, 0.3981504962508651, 0.3981504962508651, 0.41781388280497084, 0.3848068848612474, 0.3553735569235027, 0.3611888151953962, 0.5337462644479206, 0.8893851418370446, 0.7929900326316843, 0.7884501734817502, 0.5324200429412139, 0.419541349419841, 0.4110126861381068, 0.3764370268469523, 0.3764370268469523, 0.35704853214321225, 0.35073759884262706, 0.3523893502617745, 0.3287039308734622, 0.3395448507492209, 0.32837271202748775, 0.3219468091003387, 0.3301121129002272, 0.34307822495247287, 0.34623114148455586, 0.3887418042785566, 0.8349907542640244, 0.8107147216436799, 0.8338414755907902], [0.4088416485734708, 0.3088812154917832, 0.29829030588760735, 0.2539595299954364, 0.27561508906228677, 0.27844921446341087, 0.27844921446341087, 0.27844921446341087, 0.25460314798896383, 0.34623110528875584, 0.729487499798474, 0.8044866796042386, 0.684619932507062, 0.5830261032433154, 0.5216397659965732, 0.4919290449271899, 0.4919290449271899, 0.2226302284090044, 0.2483272232871545, 0.34388571083051955, 0.3562187259523368, 0.3562187259523368, 0.3562187259523368, 0.3562187259523368, 0.3562187259523368, 0.25903968457738275, 0.21817497529612845, 0.29448614089150554, 0.3070778371059668, 0.24959139574262837, 0.38534680199961724, 0.3837150989612941, 0.0, 0.3030762671989662, 0.15873008470454647, 0.1588032562582193, 0.15849380912669636, 0.2700031770420496, 0.2817338565733681, 0.25588885888507323, 0.22868138764251852, 0.12872251262519852, 0.4375650801992097, 0.3165357707456513, 0.33050215808159134, 0.17569391146251673, 0.2037458643002916, 0.2261737657387793, 0.24841062248846432, 0.25237091022472424, 0.25237091022472424, 0.24127522951801983, 0.2534280667154001, 0.2461661379376744, 0.23965432641895182, 0.22508129703764923, 0.2516401361117251, 0.24781266084535852, 0.24781266084535852, 0.2400903199036607, 0.22795977312654114, 0.240310075102034, 0.23897743453730802, 0.3910221980445204, 0.659230889902725, 0.562477557441766, 0.5563338082154686, 0.30848943408641694, 0.2592971592706975, 0.2515387659027275, 0.245193291311951, 0.245193291311951, 0.24414734093064605, 0.2592561551109468, 0.26197327903019635, 0.2626903673882835, 0.2686167955658517, 0.26790604381346955, 0.2586436431613056, 0.2533134126421195, 0.2403333965811095, 0.22388558155200464, 0.2630827211469139, 0.6006577768090422, 0.5797681712931615, 0.5987547381419839], [0.5052567880028468, 0.4208051703558853, 0.3334724027503229, 0.3318498727670515, 0.25268333746705, 0.25754784120378343, 0.25754784120378343, 0.25754784120378343, 0.2228761717498293, 0.2962297254176412, 0.5757593476679541, 0.6366360814573029, 0.5158450813578567, 0.3952346076525585, 0.312914993899614, 0.2746717664479622, 0.2746717664479622, 0.31846590653298307, 0.27284912855806753, 0.4258554747142684, 0.45952827375182315, 0.45952827375182315, 0.45952827375182315, 0.45952827375182315, 0.45952827375182315, 0.34067923264642536, 0.2574566672033992, 0.06052676690009366, 0.04289580052245907, 0.40894349879367087, 0.512284703570062, 0.505901670156117, 0.3030762671989662, 0.0, 0.2699133804279424, 0.2696931297539279, 0.2704011714548991, 0.3651666427201558, 0.3124342614356239, 0.28532731653675786, 0.19544350854806442, 0.318769662681539, 0.5719634435802906, 0.48137008623760014, 0.4963424206595029, 0.3998228620025117, 0.1983681345900806, 0.22923464913265154, 0.2610639328574497, 0.26565204263294495, 0.26565204263294495, 0.2538761053100097, 0.26730075103468587, 0.2587895245718847, 0.2507596013669296, 0.18656102456761628, 0.1502486312059429, 0.14100666568454795, 0.14100666568454795, 0.11277542067135267, 0.15517191217015866, 0.18185640420512586, 0.1625293836737564, 0.3235860451621971, 0.49819104902950534, 0.3888673523495317, 0.38048926058058424, 0.16729436107217993, 0.11876199697196464, 0.11942300037823629, 0.17114311694744994, 0.17114311694744994, 0.1979860024198855, 0.22070596685750518, 0.2246229068288833, 0.2599091880786339, 0.250825150916334, 0.2699270466161176, 0.2589477273764769, 0.22998251246892001, 0.21233372681139479, 0.18227301039011728, 0.22795682852362747, 0.4105839160686198, 0.38748573377070816, 0.4134256328996526], [0.3226874328744892, 0.24805803740401156, 0.19599901007296225, 0.16181838300235973, 0.1900681525625506, 0.19162217315670543, 0.19162217315670543, 0.19162217315670543, 0.1585140323632177, 0.29891613886579943, 0.7521914057822506, 0.8207280361328345, 0.6995376639492035, 0.5898479215572443, 0.5280368282934703, 0.49568119201508076, 0.49568119201508076, 0.21713480337461427, 0.14294249992578376, 0.2682094964386743, 0.2798176559170036, 0.2798176559170036, 0.2798176559170036, 0.2798176559170036, 0.2798176559170036, 0.1344402688402403, 0.09502423388093353, 0.26723978517953023, 0.27328452990993113, 0.17055546271570385, 0.28571731114480886, 0.2813678608105166, 0.15873008470454647, 0.2699133804279424, 0.0, 0.0038647831670838087, 0.01063593981048196, 0.19341445340195337, 0.19441510011651228, 0.15894827568128445, 0.1294358932275635, 0.09572403339456224, 0.34721337254258594, 0.24197390138770616, 0.2613228083214954, 0.16313181619883357, 0.11405796818515128, 0.1487541668832852, 0.14553188755244567, 0.1509923111630462, 0.1509923111630462, 0.15208916273664777, 0.16088864191575444, 0.1486408251448006, 0.13668261028004283, 0.14909994311742902, 0.17426589451628222, 0.1741306160858258, 0.1741306160858258, 0.18372243451185435, 0.15439560795173426, 0.1451386303266236, 0.1373074289346463, 0.3506327537398841, 0.6775852040561912, 0.5733260287492749, 0.5673213595319793, 0.29205232849156215, 0.1928955981249236, 0.18386243975970076, 0.1644559935493457, 0.1644559935493457, 0.15824002763169495, 0.17037383476932078, 0.17460975360056055, 0.17303121617902778, 0.18121359602198145, 0.18076498526256582, 0.1665660741331303, 0.15587326017197475, 0.14513976714607743, 0.11993608988396035, 0.18713424143628393, 0.6154218553142379, 0.5903306943280335, 0.6144148870993619], [0.3245187932591258, 0.25037115930825793, 0.1980910824684187, 0.16424508826939832, 0.19208768216130254, 0.193641472610329, 0.193641472610329, 0.193641472610329, 0.15859701067553522, 0.2959252828148301, 0.7508293422841471, 0.8194785869611734, 0.6981743588400603, 0.5883782385074915, 0.5269196709638669, 0.49465221012831667, 0.49465221012831667, 0.21519739328599172, 0.14024126217669686, 0.2703280163007601, 0.281848936453737, 0.281848936453737, 0.281848936453737, 0.281848936453737, 0.281848936453737, 0.1331557802751685, 0.09319807379721819, 0.26642397043024535, 0.2724868134884821, 0.17062356305642262, 0.28594004234914977, 0.2815940323016457, 0.1588032562582193, 0.2696931297539279, 0.0038647831670838087, 0.0, 0.00990891854460517, 0.19574269506015915, 0.1966854179706111, 0.16081766235521203, 0.12980932240547746, 0.09497319575026777, 0.3467390014206518, 0.24129272261421653, 0.2625086807297105, 0.16407925667682816, 0.11532570898125383, 0.15067440148559696, 0.14765069455982968, 0.1531565902422015, 0.1531565902422015, 0.154238051485987, 0.16299466774638385, 0.15054934829980746, 0.13847016729353254, 0.1503301039495435, 0.17519662327037788, 0.17504912008160872, 0.17504912008160872, 0.18321464189733896, 0.15543077796145152, 0.14625483522561178, 0.1365735113407002, 0.3483334448713439, 0.6762264009186753, 0.5719227186098964, 0.565981260892933, 0.2904550875958129, 0.19157569933527138, 0.18429705173303412, 0.1655278773980927, 0.1655278773980927, 0.15975239557633678, 0.17208785187084996, 0.17643460520556692, 0.1750116246124101, 0.18310552793484866, 0.1829173583769211, 0.16831887071758542, 0.15753832911025817, 0.14680649747129604, 0.11969497454585884, 0.18414460023399395, 0.614278243849, 0.5891249856793876, 0.6132240873662294], [0.3199942547445527, 0.24450667735712503, 0.1929103178522789, 0.15810689610438197, 0.18718886913123825, 0.18869158714770876, 0.18869158714770876, 0.18869158714770876, 0.15267960004038791, 0.2964753582809054, 0.7541449839512037, 0.8227345326544887, 0.7014504169570661, 0.5913658861041463, 0.5297362130918739, 0.4973494083343759, 0.4973494083343759, 0.22002475895116197, 0.14590751502655852, 0.264311645740381, 0.2760837421091422, 0.2760837421091422, 0.2760837421091422, 0.2760837421091422, 0.2760837421091422, 0.13182135370665174, 0.09563208298613012, 0.2683520882255323, 0.273328882231385, 0.1708051304161267, 0.28506526130758103, 0.2807057078394135, 0.15849380912669636, 0.2704011714548991, 0.01063593981048196, 0.00990891854460517, 0.0, 0.18948705003787214, 0.1910360921518687, 0.1545573579662052, 0.12525949102544054, 0.08865318843449539, 0.34749014554095137, 0.2376315880681376, 0.2583030048621891, 0.1595953223152585, 0.11249727639494407, 0.14577873540518263, 0.14231390638559407, 0.1478093752394434, 0.1478093752394434, 0.1489296706511197, 0.1577584350537785, 0.1453190511262181, 0.1336144396697009, 0.14657171334000924, 0.17291105604189777, 0.173084651324921, 0.173084651324921, 0.18137104623807934, 0.1532149758366526, 0.14350907052536035, 0.13886486554746144, 0.3536331281916721, 0.6797250341572427, 0.5752846866950418, 0.5693783121665524, 0.2937678338437757, 0.19090763958216492, 0.1825794277197799, 0.16220958316547526, 0.16220958316547526, 0.15610370803810802, 0.16766799281503816, 0.17203887231350953, 0.1695835046610042, 0.17792450832848436, 0.1776406115650075, 0.16256896727617517, 0.1531526238740693, 0.1426831221576713, 0.1168031980195455, 0.1849692176347529, 0.6172848269755398, 0.5921858654093372, 0.6163155169550856], [0.1711136801674136, 0.0644031550821463, 0.07481942400820919, 0.044267540260225544, 0.13439410690725898, 0.13096541915205748, 0.13096541915205748, 0.13096541915205748, 0.17893237666628456, 0.4381885949716445, 0.8804056488630235, 0.9428386659050113, 0.8289686403968233, 0.7198864370091831, 0.6510427235172279, 0.6166377405814241, 0.6166377405814241, 0.39200332988692604, 0.3127421203151147, 0.08222076622746276, 0.10627582490153101, 0.10627582490153101, 0.10627582490153101, 0.10627582490153101, 0.10627582490153101, 0.20684738967310218, 0.2553141350269062, 0.3887607191347732, 0.3808497729983596, 0.2535297110150881, 0.27162918552385434, 0.2672178190478183, 0.2700031770420496, 0.3651666427201558, 0.19341445340195337, 0.19574269506015915, 0.18948705003787214, 0.0, 0.07467994928311615, 0.09117145667596982, 0.18968807226699308, 0.18862547457207604, 0.3677361424495609, 0.2524866357192417, 0.19290708464119244, 0.17511484125707083, 0.18118407725467547, 0.14251152220579563, 0.11597434730497068, 0.11126590734506557, 0.11126590734506557, 0.1180744566690532, 0.10799139433701617, 0.1165852446892889, 0.12694588356532446, 0.18552382224334021, 0.22354106501753407, 0.23195022259965614, 0.23195022259965614, 0.27379923305303716, 0.2173473069531813, 0.19445073884984462, 0.265191230378385, 0.5168969986984602, 0.8097116719784186, 0.7084898491164374, 0.701835037039344, 0.4429301448537014, 0.3038575689498535, 0.2529305439593062, 0.202320203677174, 0.202320203677174, 0.17595116547684103, 0.15744434157205625, 0.15486123667629315, 0.11864198661812142, 0.13161709573147148, 0.11138822637071738, 0.11922429573477422, 0.1479004239308375, 0.16199083052124472, 0.21384729478669418, 0.33591289411720643, 0.7391233638792718, 0.716933114647632, 0.7401905565374338], [0.21285059305160317, 0.12328645490675297, 0.043821673356364804, 0.06322304478606972, 0.06631223702303944, 0.06170057520896551, 0.06170057520896551, 0.06170057520896551, 0.13394573178916863, 0.417154887643741, 0.8418738187198711, 0.9022522023813063, 0.7887630275788624, 0.6771210944266814, 0.6051142826562989, 0.5697694420124821, 0.5697694420124821, 0.3933044311180692, 0.3008014657922815, 0.1206622873580031, 0.16003714625174456, 0.16003714625174456, 0.16003714625174456, 0.16003714625174456, 0.16003714625174456, 0.21328431435675846, 0.24687978223977436, 0.3421604450874141, 0.33059410331100764, 0.28925197829036414, 0.3102243531856726, 0.30425601835653626, 0.2817338565733681, 0.3124342614356239, 0.19441510011651228, 0.1966854179706111, 0.1910360921518687, 0.07467994928311615, 0.0, 0.046532596908955684, 0.14730257883156592, 0.21104701660101186, 0.4049657820101514, 0.3016156487352576, 0.25628054418330065, 0.22580189433414144, 0.1406862144366109, 0.09308905278575465, 0.0713427120682445, 0.06433713620866412, 0.06433713620866412, 0.06723323201134543, 0.050669304342362324, 0.06506501963935557, 0.07997680780669762, 0.1349751111402568, 0.16757174348107298, 0.1781583451975708, 0.1781583451975708, 0.2265860396121409, 0.16797470757787428, 0.1426666023525404, 0.2256230785895363, 0.4933761170446024, 0.7703638260561739, 0.6680775358436434, 0.6610534613819582, 0.4075456080720468, 0.25954231913655107, 0.19963298981578206, 0.14755438533099113, 0.14755438533099113, 0.11950254003288108, 0.0963260757315163, 0.09248050515288957, 0.056214329210699604, 0.06608380900043803, 0.04520924350093659, 0.06084280664887877, 0.08998924707770094, 0.11028057551300902, 0.1750151188444322, 0.3130128841995005, 0.6952244669662615, 0.6732869996419317, 0.6970267589954601], [0.23639185047206268, 0.150361969174017, 0.06291591542360458, 0.06303952253665103, 0.061100930948654486, 0.058451554051425464, 0.058451554051425464, 0.058451554051425464, 0.09455903816704155, 0.37737106084056643, 0.8148269054580841, 0.8766494651359897, 0.7609794394509743, 0.6479341195469774, 0.5776382672458245, 0.5424843601479686, 0.5424843601479686, 0.35751660489116105, 0.2628352890530476, 0.1511835568199807, 0.1841438797317914, 0.1841438797317914, 0.1841438797317914, 0.1841438797317914, 0.1841438797317914, 0.1829803654300809, 0.20795337438420455, 0.3110555169930004, 0.3000920777831351, 0.26486402158872324, 0.3024404143812012, 0.29631533819189326, 0.25588885888507323, 0.28532731653675786, 0.15894827568128445, 0.16081766235521203, 0.1545573579662052, 0.09117145667596982, 0.046532596908955684, 0.0, 0.10701646133669265, 0.17875890364317926, 0.3926804131669406, 0.28209058355163785, 0.25448838220792935, 0.20963488270074998, 0.10618763640243395, 0.06705970976429372, 0.041196704687562355, 0.03728633289838967, 0.03728633289838967, 0.04208694586411207, 0.02981133033858233, 0.03245924979463705, 0.0447664553614801, 0.10443994208421507, 0.13992906662381285, 0.15022397735345316, 0.15022397735345316, 0.19210352813622494, 0.1379940208640436, 0.11057955753221818, 0.18946610233802305, 0.4571581596714418, 0.7424348245481727, 0.6385970025349198, 0.6318825120444388, 0.37249584995274293, 0.2223916021861912, 0.1699184795777641, 0.11831587700696786, 0.11831587700696786, 0.09254600875365841, 0.07383222884047928, 0.07349526139860767, 0.03901841221639531, 0.05224419101953754, 0.04189411670057359, 0.03235229980529138, 0.06160642046206814, 0.0796038634407656, 0.1344804059120147, 0.2713342420941985, 0.6684610563266234, 0.6456148251110283, 0.6698776493121726], [0.33213998031702924, 0.250614976913167, 0.1619866145305889, 0.15371924969995754, 0.10642215599341871, 0.10960608468633501, 0.10960608468633501, 0.10960608468633501, 0.052209325332481765, 0.293886910976059, 0.7285595275836858, 0.7921280121954469, 0.6721669590595991, 0.5558444851213222, 0.4864575529855135, 0.45119149070990816, 0.45119149070990816, 0.29125051269866425, 0.19957561722583064, 0.2545321399138686, 0.2833578288815231, 0.2833578288815231, 0.2833578288815231, 0.2833578288815231, 0.2833578288815231, 0.1856572453990809, 0.1477270986506222, 0.21438135672080233, 0.2043628509845585, 0.26780645688334925, 0.3496808849245502, 0.3433207876158597, 0.22868138764251852, 0.19544350854806442, 0.1294358932275635, 0.12980932240547746, 0.12525949102544054, 0.18968807226699308, 0.14730257883156592, 0.10701646133669265, 0.0, 0.1719160317993709, 0.4241771319148392, 0.31319510204926687, 0.3197034654739908, 0.24387131294896303, 0.050895484086224976, 0.07475970881008849, 0.0871014667377485, 0.09316474825666841, 0.09316474825666841, 0.08803792816204019, 0.10070569759878108, 0.08696587822348004, 0.07693146632991948, 0.05049605785349837, 0.06784042731637735, 0.07296334532938224, 0.07296334532938224, 0.09437611088973245, 0.06072123026172012, 0.04248146045203887, 0.1016838443324796, 0.371333484986718, 0.6537632845590428, 0.5463140693822809, 0.5397860238573154, 0.2741189406734176, 0.12081331278215934, 0.08288642639280439, 0.052425605719962104, 0.052425605719962104, 0.0586818119565255, 0.07361980145819175, 0.08078282947011853, 0.09786593849494726, 0.09681032732072918, 0.11187097036918622, 0.0901610896056408, 0.06906201964453744, 0.05283063441503774, 0.03302115017945351, 0.18481515529306122, 0.5793814143327465, 0.554896528782053, 0.5804706652999057], [0.31737711697874826, 0.23236450443969078, 0.216238708951951, 0.17216584901243853, 0.22016317719171608, 0.22109908533050943, 0.22109908533050943, 0.22109908533050943, 0.18312070619156393, 0.32014550481459225, 0.785181186055586, 0.8561230652884805, 0.7357938373460701, 0.6275835036081523, 0.5688941617404705, 0.5377517846079133, 0.5377517846079133, 0.24477494013676665, 0.20510713374594117, 0.26002775420661944, 0.26718795908582244, 0.26718795908582244, 0.26718795908582244, 0.26718795908582244, 0.26718795908582244, 0.1590722288023385, 0.16238635595085377, 0.3169402649349727, 0.31954249787848177, 0.1797626418229937, 0.28932740063974904, 0.28690429424566377, 0.12872251262519852, 0.318769662681539, 0.09572403339456224, 0.09497319575026777, 0.08865318843449539, 0.18862547457207604, 0.21104701660101186, 0.17875890364317926, 0.1719160317993709, 0.0, 0.35091902573733874, 0.20982031596527223, 0.23627554880063217, 0.10285134348382287, 0.16366536177426508, 0.17910273219748446, 0.1807909130208728, 0.18460058026200798, 0.18460058026200798, 0.18206696765313296, 0.18902826987059299, 0.17960201463974707, 0.17312893712937355, 0.188343709307561, 0.2231599325877271, 0.22468893066076898, 0.22468893066076898, 0.22354402657109246, 0.20398022473053953, 0.19745260557216773, 0.20801477567443769, 0.39922048668035964, 0.7137311515108485, 0.612086593267767, 0.6068607044388435, 0.33830627100560345, 0.2372882091353597, 0.23236026218788447, 0.2086404305671474, 0.2086404305671474, 0.2011281459503591, 0.20804937095836037, 0.21171463970006432, 0.20037243180419181, 0.21003221392173152, 0.20689040270615044, 0.19193250735812872, 0.1953465158725767, 0.1894659141144361, 0.1726444943344515, 0.22392953971302992, 0.6535387492394813, 0.6297800651501979, 0.6521770830317652], [0.3141926187152428, 0.37379560508410864, 0.3705503716922459, 0.36768243863215316, 0.4416659134252791, 0.4386805220936739, 0.4386805220936739, 0.4386805220936739, 0.4195667963710598, 0.5041419672144238, 0.982105294180489, 1.0440819200852227, 0.9355546847145849, 0.8357058983312634, 0.7920917619612245, 0.7654473605943657, 0.7654473605943657, 0.45143675037721115, 0.3570236817973315, 0.3778006821003442, 0.3495393300606941, 0.3495393300606941, 0.3495393300606941, 0.3495393300606941, 0.3495393300606941, 0.25875729436680944, 0.3658127919048916, 0.5661432732530183, 0.5681898435134095, 0.27808558557663415, 0.10611924461602663, 0.11168224936047091, 0.4375650801992097, 0.5719634435802906, 0.34721337254258594, 0.3467390014206518, 0.34749014554095137, 0.3677361424495609, 0.4049657820101514, 0.3926804131669406, 0.4241771319148392, 0.35091902573733874, 0.0, 0.20342106386752654, 0.2512177328976485, 0.3227440480418661, 0.4202780150104775, 0.43271487301053246, 0.40410896696741255, 0.4048180907327032, 0.4048180907327032, 0.4178321984422154, 0.40853762462639426, 0.4019382038010009, 0.39591497100548784, 0.44833400675174806, 0.47185965751716175, 0.47855089407142654, 0.47855089407142654, 0.4893449866428441, 0.4651640359902191, 0.4384526819875305, 0.4252279375280256, 0.5475057697246486, 0.9152068242359722, 0.8231244993647127, 0.819614184030965, 0.5738008845802098, 0.4829941022404336, 0.48847261525238317, 0.4605797350675244, 0.4605797350675244, 0.44459868619141163, 0.4419980837921796, 0.4444135490673866, 0.424158528400227, 0.4346589502052297, 0.42522315600206, 0.416698007945875, 0.42116162601371415, 0.4309208252572633, 0.4210750085823413, 0.43084741898567, 0.8698255373328467, 0.8452245923573063, 0.867523941359117], [0.267569652786383, 0.2675480982883503, 0.28013829892071307, 0.25106198600481383, 0.33791886747406547, 0.3358459446478011, 0.3358459446478011, 0.3358459446478011, 0.30796640115944823, 0.41596673857883515, 0.9222330211779862, 0.9881116559932039, 0.8728564286280491, 0.768900122800852, 0.7202740697038742, 0.6914325380061779, 0.6914325380061779, 0.3590557571136323, 0.2963625784214681, 0.28030606111787076, 0.2525138467260635, 0.2525138467260635, 0.2525138467260635, 0.2525138467260635, 0.2525138467260635, 0.1947792913619238, 0.2642283525760731, 0.47933558487093486, 0.47889951261090513, 0.15799296172563104, 0.16375104824795922, 0.16595790979667077, 0.3165357707456513, 0.48137008623760014, 0.24197390138770616, 0.24129272261421653, 0.2376315880681376, 0.2524866357192417, 0.3016156487352576, 0.28209058355163785, 0.31319510204926687, 0.20982031596527223, 0.20342106386752654, 0.0, 0.12736563437464482, 0.17884606374790096, 0.3191434004526321, 0.32290422706243715, 0.29371917837280337, 0.2951463354023919, 0.2951463354023919, 0.3078424822757657, 0.3045936076169733, 0.29848073093727445, 0.2951699387234587, 0.3420103308829548, 0.372749245399119, 0.3772530057760489, 0.3772530057760489, 0.38513499195491874, 0.36082464982171775, 0.3392748447186612, 0.3471175061570188, 0.49991902679204786, 0.8536168110741431, 0.7551831573391182, 0.7513554886596723, 0.4896942275460156, 0.3868775285394196, 0.3879575257765412, 0.35588990581809027, 0.35588990581809027, 0.34260748230798027, 0.3378559613055204, 0.34045418068479105, 0.3166406250957033, 0.32898654373814634, 0.31974556455174824, 0.30831756919809156, 0.3210456882196084, 0.3247619244799552, 0.3157552363987903, 0.33925102212093966, 0.8016504439738795, 0.7762724862578472, 0.7999198994294822], [0.184660527995135, 0.18769583737994705, 0.23624839882320323, 0.2040362897454502, 0.3062526765900968, 0.30345785187388696, 0.30345785187388696, 0.30345785187388696, 0.31527719121647996, 0.49088362533337426, 0.9679452097442177, 1.0312739788634562, 0.918143195958383, 0.8152167199828293, 0.7571461664835103, 0.7257931280721092, 0.7257931280721092, 0.4129511596337269, 0.35503603020639335, 0.20426698442160413, 0.16406326771606008, 0.16406326771606008, 0.16406326771606008, 0.16406326771606008, 0.16406326771606008, 0.24121251807094404, 0.30311732414121156, 0.5060112708930062, 0.5043514833907786, 0.18535192032215278, 0.1776855764875941, 0.1797214125069773, 0.33050215808159134, 0.4963424206595029, 0.2613228083214954, 0.2625086807297105, 0.2583030048621891, 0.19290708464119244, 0.25628054418330065, 0.25448838220792935, 0.3197034654739908, 0.23627554880063217, 0.2512177328976485, 0.12736563437464482, 0.0, 0.16831244824201816, 0.3176174944762435, 0.3027731952841717, 0.268042397868726, 0.2669450031739778, 0.2669450031739778, 0.2809186168836073, 0.27554156814146824, 0.27635450917270205, 0.2787361645338273, 0.33501806068136625, 0.36939588447679833, 0.37450590704501663, 0.37450590704501663, 0.40340524728328025, 0.357951493869648, 0.3355871567590976, 0.3719164041742124, 0.5654421465781146, 0.8988850708374685, 0.8002462370864194, 0.7948569350977522, 0.5329537615658164, 0.41885102058239004, 0.39229024826399245, 0.34998169328191814, 0.34998169328191814, 0.3297820676427017, 0.31781816062192025, 0.31759644735182607, 0.2874599658625201, 0.30100513695525993, 0.2852002909578319, 0.2842849924055554, 0.3041597603492741, 0.31072245178248087, 0.33159303202720825, 0.401913089611859, 0.8402248949250051, 0.8162454389477151, 0.8397588559816291], [0.27435277974179373, 0.19630500261111228, 0.22553953846442767, 0.1756084093034102, 0.2566716891043819, 0.25622102309319084, 0.25622102309319084, 0.25622102309319084, 0.25014317238342637, 0.40826653891940534, 0.8628615454117606, 0.9320036394636124, 0.8153299306213326, 0.7115878551061683, 0.6520474033772012, 0.6210232365499586, 0.6210232365499586, 0.30895842550259167, 0.2796802348976922, 0.2337555269767533, 0.2264810449830483, 0.2264810449830483, 0.2264810449830483, 0.2264810449830483, 0.2264810449830483, 0.20115678950370036, 0.2339232177129405, 0.4032925096317715, 0.40608334740835406, 0.17080873691630566, 0.2575717557694578, 0.25783333083832527, 0.17569391146251673, 0.3998228620025117, 0.16313181619883357, 0.16407925667682816, 0.1595953223152585, 0.17511484125707083, 0.22580189433414144, 0.20963488270074998, 0.24387131294896303, 0.10285134348382287, 0.3227440480418661, 0.17884606374790096, 0.16831244824201816, 0.0, 0.2299482010672282, 0.22788273311825022, 0.21830055918591507, 0.2195359845014968, 0.2195359845014968, 0.22096881997881285, 0.22307831307350515, 0.21968411838275878, 0.21820183825874034, 0.2521124649191306, 0.29048631814854203, 0.2932853095386101, 0.2932853095386101, 0.3085549317915861, 0.2726396997981123, 0.26176950394003057, 0.2882228373770326, 0.47867078314123257, 0.7931643083302397, 0.6947074098876542, 0.6891356536437785, 0.4268910398157767, 0.32748728413491457, 0.3068516824568259, 0.27345321418439145, 0.27345321418439145, 0.2580346171288084, 0.25696116257219087, 0.2582137338058996, 0.2368135998004241, 0.24912150340156947, 0.23792466695915568, 0.23176219259803305, 0.24416571340013954, 0.2438113011582968, 0.2514628437823818, 0.31621224460748504, 0.7343745529546809, 0.7116213537682862, 0.7332202831778052], [0.32724638722935506, 0.24037570757466353, 0.15725405290519442, 0.147135785105473, 0.10357690557578106, 0.10697212107314376, 0.10697212107314376, 0.10697212107314376, 0.08482212469357003, 0.3143370902503948, 0.7302068014243285, 0.7950776388904655, 0.675836060272419, 0.5610375291227417, 0.4895716165870777, 0.4542024964603386, 0.4542024964603386, 0.28789691079966323, 0.19977403472023347, 0.25032072825345847, 0.28014020285935715, 0.28014020285935715, 0.28014020285935715, 0.28014020285935715, 0.28014020285935715, 0.1843641277663929, 0.1566652908448904, 0.21657777282223764, 0.21131932770480755, 0.2668362595587059, 0.34492453816330776, 0.33885950247577346, 0.2037458643002916, 0.1983681345900806, 0.11405796818515128, 0.11532570898125383, 0.11249727639494407, 0.18118407725467547, 0.1406862144366109, 0.10618763640243395, 0.050895484086224976, 0.16366536177426508, 0.4202780150104775, 0.3191434004526321, 0.3176174944762435, 0.2299482010672282, 0.0, 0.05847831243066819, 0.08664134157991898, 0.09182106054124455, 0.09182106054124455, 0.07955106127849235, 0.09163742351616337, 0.0787327688163358, 0.06661281499610121, 0.03913622000434483, 0.06951684665035215, 0.07532010167012536, 0.07532010167012536, 0.10693685208718899, 0.05607486896329569, 0.043007281673920525, 0.10023333909629795, 0.3755344611590245, 0.6554867384722122, 0.5498022160392539, 0.5427960173410674, 0.2781359604737536, 0.1382248391098749, 0.08981538669333851, 0.05854533162527837, 0.05854533162527837, 0.05158521187969355, 0.07355939360483052, 0.07896178077647344, 0.09576359299887831, 0.09580739581520031, 0.10627643062011376, 0.09089273383144895, 0.06513579912775823, 0.05230014270930363, 0.059871897774798594, 0.2027297372823089, 0.5816099968023904, 0.558262967548841, 0.5824756003169207], [0.2955116011738901, 0.19978210748820813, 0.12078438009917483, 0.1123037407686384, 0.05392866046433646, 0.05766342857136005, 0.05766342857136005, 0.05766342857136005, 0.08559642791037542, 0.35565117965226906, 0.7657067209217794, 0.8287240039127541, 0.7117979865679246, 0.5983322365823176, 0.5247926177395189, 0.4889990283982263, 0.4889990283982263, 0.33126893109775535, 0.24971851372509693, 0.20765459193464064, 0.24228547992919774, 0.24228547992919774, 0.24228547992919774, 0.24228547992919774, 0.24228547992919774, 0.2076918388682788, 0.19672653863333547, 0.2566663317669834, 0.24723063091562686, 0.2822285940803481, 0.34844626159153286, 0.3424603599859089, 0.2261737657387793, 0.22923464913265154, 0.1487541668832852, 0.15067440148559696, 0.14577873540518263, 0.14251152220579563, 0.09308905278575465, 0.06705970976429372, 0.07475970881008849, 0.17910273219748446, 0.43271487301053246, 0.32290422706243715, 0.3027731952841717, 0.22788273311825022, 0.05847831243066819, 0.0, 0.052437946096419316, 0.05420439028547989, 0.05420439028547989, 0.03164602305000263, 0.04713074172037539, 0.04307567861194091, 0.044884298018585365, 0.046279292165137605, 0.08655529512009312, 0.09516818485944094, 0.09516818485944094, 0.14176170737616867, 0.08072658396976529, 0.06481663298669417, 0.1535080787477007, 0.4257007829971904, 0.6924647503994389, 0.5881078794566774, 0.5808652767420688, 0.3240789430568986, 0.1801904915963179, 0.11594893758685478, 0.06606336486439272, 0.06606336486439272, 0.04097915907227959, 0.03843666982507565, 0.03967345156497911, 0.046212679798039814, 0.04682440140548171, 0.0550512578205605, 0.04627538872706805, 0.03821828217751049, 0.037964360735848454, 0.10149357671838853, 0.24915296770621478, 0.6162037768803502, 0.5938786654926095, 0.6177534560287548], [0.26252204659090844, 0.1767983348324541, 0.08975635645683906, 0.07786514630478582, 0.05567221130581488, 0.05626021554182679, 0.05626021554182679, 0.05626021554182679, 0.09399734215140422, 0.364105755442281, 0.7933641302352435, 0.8548955619210084, 0.738190818366223, 0.6256825102190525, 0.5543369878520937, 0.5188484669023904, 0.5188484669023904, 0.3362039343238317, 0.2478699322365469, 0.18001514681121975, 0.20967466243833272, 0.20967466243833272, 0.20967466243833272, 0.20967466243833272, 0.20967466243833272, 0.19195581044010315, 0.18549528677717153, 0.2866278162979917, 0.27769719451499086, 0.25492041488519496, 0.31742880375599686, 0.3112748189848294, 0.24841062248846432, 0.2610639328574497, 0.14553188755244567, 0.14765069455982968, 0.14231390638559407, 0.11597434730497068, 0.0713427120682445, 0.041196704687562355, 0.0871014667377485, 0.1807909130208728, 0.40410896696741255, 0.29371917837280337, 0.268042397868726, 0.21830055918591507, 0.08664134157991898, 0.052437946096419316, 0.0, 0.007445221529670952, 0.007445221529670952, 0.026203095912784677, 0.03595808071581508, 0.03483399936091763, 0.04061973616974391, 0.08504013392864429, 0.11616734409560546, 0.12345400514356747, 0.12345400514356747, 0.17287838395764657, 0.11086995991490188, 0.08547599347854538, 0.16800347646128677, 0.43606032178541043, 0.7198834630171942, 0.6149316698177395, 0.6079016909392939, 0.3474153685037894, 0.2038262851021174, 0.14592131750539047, 0.09487656048128838, 0.09487656048128838, 0.07113889821541734, 0.05503605099244634, 0.054838292893206395, 0.037920464658348016, 0.04874096282834938, 0.04547915117482287, 0.039333244668876964, 0.047486486016874774, 0.05101152316307815, 0.11287495614503706, 0.2566849181642955, 0.6455167876680402, 0.6220520594273301, 0.6470269835554707], [0.25757473288615135, 0.17147291776253376, 0.08395865526174516, 0.07423452514121259, 0.051785492234246375, 0.051836696035757045, 0.051836696035757045, 0.051836696035757045, 0.09741500709953861, 0.37005166133348544, 0.7981890686915384, 0.8594958536268419, 0.7431622678135191, 0.6307553236788289, 0.5591978080489667, 0.5236826156199896, 0.5236826156199896, 0.3425948418497566, 0.253804927152733, 0.17408679948998748, 0.20460748946173032, 0.20460748946173032, 0.20460748946173032, 0.20460748946173032, 0.20460748946173032, 0.19466673113133812, 0.1921675512816716, 0.2919912125002074, 0.2827007062313379, 0.2585951029036466, 0.3171339757346163, 0.3109741565553631, 0.25237091022472424, 0.26565204263294495, 0.1509923111630462, 0.1531565902422015, 0.1478093752394434, 0.11126590734506557, 0.06433713620866412, 0.03728633289838967, 0.09316474825666841, 0.18460058026200798, 0.4048180907327032, 0.2951463354023919, 0.2669450031739778, 0.2195359845014968, 0.09182106054124455, 0.05420439028547989, 0.007445221529670952, 0.0, 1.1657939959388178e-17, 0.02512311508926986, 0.031606422699563666, 0.03374018875433281, 0.042150647206847934, 0.08910196891509009, 0.1202519645868659, 0.12798411864927273, 0.12798411864927273, 0.17810956660000324, 0.11589301640726536, 0.09040770578838085, 0.17385770148262478, 0.44221378941140005, 0.7248882274096066, 0.6201910626488815, 0.6131366587414147, 0.35360400720259305, 0.20949088822240872, 0.15060105124149348, 0.0990441456453902, 0.0990441456453902, 0.07428206308760685, 0.05608336315535031, 0.055054508662036365, 0.03372381226013413, 0.04555233617375038, 0.0396468988846519, 0.03673131994812864, 0.04898864316469793, 0.055635891725087996, 0.11936141861409075, 0.2629973437094708, 0.6503055788317457, 0.6270022828431949, 0.6518779086137505], [0.25757473288615135, 0.17147291776253376, 0.08395865526174516, 0.07423452514121259, 0.051785492234246375, 0.051836696035757045, 0.051836696035757045, 0.051836696035757045, 0.09741500709953861, 0.37005166133348544, 0.7981890686915384, 0.8594958536268419, 0.7431622678135191, 0.6307553236788289, 0.5591978080489667, 0.5236826156199896, 0.5236826156199896, 0.3425948418497566, 0.253804927152733, 0.17408679948998748, 0.20460748946173032, 0.20460748946173032, 0.20460748946173032, 0.20460748946173032, 0.20460748946173032, 0.19466673113133812, 0.1921675512816716, 0.2919912125002074, 0.2827007062313379, 0.2585951029036466, 0.3171339757346163, 0.3109741565553631, 0.25237091022472424, 0.26565204263294495, 0.1509923111630462, 0.1531565902422015, 0.1478093752394434, 0.11126590734506557, 0.06433713620866412, 0.03728633289838967, 0.09316474825666841, 0.18460058026200798, 0.4048180907327032, 0.2951463354023919, 0.2669450031739778, 0.2195359845014968, 0.09182106054124455, 0.05420439028547989, 0.007445221529670952, 1.1657939959388178e-17, 0.0, 0.02512311508926986, 0.031606422699563666, 0.03374018875433281, 0.042150647206847934, 0.08910196891509009, 0.1202519645868659, 0.12798411864927273, 0.12798411864927273, 0.17810956660000324, 0.11589301640726536, 0.09040770578838085, 0.17385770148262478, 0.44221378941140005, 0.7248882274096066, 0.6201910626488815, 0.6131366587414147, 0.35360400720259305, 0.20949088822240872, 0.15060105124149348, 0.0990441456453902, 0.0990441456453902, 0.07428206308760685, 0.05608336315535031, 0.055054508662036365, 0.03372381226013413, 0.04555233617375038, 0.0396468988846519, 0.03673131994812864, 0.04898864316469793, 0.055635891725087996, 0.11936141861409075, 0.2629973437094708, 0.6503055788317457, 0.6270022828431949, 0.6518779086137505], [0.2695558990944111, 0.17672596620838843, 0.09420837095935657, 0.08565585845928429, 0.04201089145228046, 0.04363112907204429, 0.04363112907204429, 0.04363112907204429, 0.09258974782812146, 0.368810804953359, 0.7883807028015676, 0.8503948880214184, 0.734082968840873, 0.6213453589388892, 0.5486970104251443, 0.51303417330693, 0.51303417330693, 0.3421109715035664, 0.2567137164958014, 0.18216040335575914, 0.21577314746397766, 0.21577314746397766, 0.21577314746397766, 0.21577314746397766, 0.21577314746397766, 0.20167248062079818, 0.19912107343885146, 0.2813199908816717, 0.2717502662513318, 0.2713595746531497, 0.3306316760504388, 0.32459127198543625, 0.24127522951801983, 0.2538761053100097, 0.15208916273664777, 0.154238051485987, 0.1489296706511197, 0.1180744566690532, 0.06723323201134543, 0.04208694586411207, 0.08803792816204019, 0.18206696765313296, 0.4178321984422154, 0.3078424822757657, 0.2809186168836073, 0.22096881997881285, 0.07955106127849235, 0.03164602305000263, 0.026203095912784677, 0.02512311508926986, 0.02512311508926986, 0.0, 0.02346034051891631, 0.026264461893934426, 0.03644308825217868, 0.07294020714922497, 0.10844895692368825, 0.11696399402066254, 0.11696399402066254, 0.16644369086301553, 0.10398223024344629, 0.08182753904458732, 0.16955439612406503, 0.44053970130484843, 0.7152950570203208, 0.6110081700373348, 0.6038464970134462, 0.3460481154877442, 0.20146745628846044, 0.13922420885094924, 0.08709077822268552, 0.08709077822268552, 0.06026001291151335, 0.04387303918353677, 0.04254995732551997, 0.0250470839944155, 0.034696613765572426, 0.03258738244223221, 0.028969825135790876, 0.03909893649485961, 0.0471613414138834, 0.11565460617493442, 0.2620260744687521, 0.6398328859925394, 0.6171413123389969, 0.6414308878409952], [0.2530549852275695, 0.16488016727534532, 0.07467590202220602, 0.07973080577702953, 0.03994015265210411, 0.03836743401849963, 0.03836743401849963, 0.03836743401849963, 0.09578894891968386, 0.37856132812285526, 0.801126785056137, 0.8626309780618764, 0.7472368982241226, 0.634149197544506, 0.5618892932141409, 0.5263434822945819, 0.5263434822945819, 0.3566923281820929, 0.26308194653883754, 0.1674133706876085, 0.20283598973519468, 0.20283598973519468, 0.20283598973519468, 0.20283598973519468, 0.20283598973519468, 0.19527790557225216, 0.21079645357077942, 0.29521589739016985, 0.28453896632736353, 0.27766447402767547, 0.319312205373244, 0.3130737553366166, 0.2534280667154001, 0.26730075103468587, 0.16088864191575444, 0.16299466774638385, 0.1577584350537785, 0.10799139433701617, 0.050669304342362324, 0.02981133033858233, 0.10070569759878108, 0.18902826987059299, 0.40853762462639426, 0.3045936076169733, 0.27554156814146824, 0.22307831307350515, 0.09163742351616337, 0.04713074172037539, 0.03595808071581508, 0.031606422699563666, 0.031606422699563666, 0.02346034051891631, 0.0, 0.017485047479266238, 0.03340154194000497, 0.08673580159389573, 0.12094822654873166, 0.13163653675342157, 0.13163653675342157, 0.17948777452849143, 0.12020023064071789, 0.09393627921402074, 0.1784174602968014, 0.4512172533864492, 0.7284259006746686, 0.6247413812880475, 0.6176849930900034, 0.3610150118608595, 0.21270464942748768, 0.1528496174863954, 0.10076947496520944, 0.10076947496520944, 0.0719094493409252, 0.05298208515008169, 0.05125930575549405, 0.021182545104604444, 0.03283562631102829, 0.023228652365716588, 0.02258822610397407, 0.04226281933495696, 0.06269406020872771, 0.12794530780883673, 0.2715489086529615, 0.6530212865883275, 0.6305783360841242, 0.6546449814981816], [0.26012734920263875, 0.1750846698841576, 0.08256368426169396, 0.08606299237586704, 0.049566393661557476, 0.048890651025179394, 0.048890651025179394, 0.048890651025179394, 0.08293913026439378, 0.36449883669851557, 0.7920955875553916, 0.8541204886847985, 0.7380365940610761, 0.624301393065871, 0.5528518755548669, 0.5174323079690372, 0.5174323079690372, 0.3449139372725108, 0.24805334552155697, 0.17804945392919475, 0.21169981126905632, 0.21169981126905632, 0.21169981126905632, 0.21169981126905632, 0.21169981126905632, 0.18254376127863836, 0.1976717687837358, 0.2847321947617418, 0.2743417918228927, 0.27085368772013946, 0.3146546637751014, 0.30832198951042883, 0.2461661379376744, 0.2587895245718847, 0.1486408251448006, 0.15054934829980746, 0.1453190511262181, 0.1165852446892889, 0.06506501963935557, 0.03245924979463705, 0.08696587822348004, 0.17960201463974707, 0.4019382038010009, 0.29848073093727445, 0.27635450917270205, 0.21968411838275878, 0.0787327688163358, 0.04307567861194091, 0.03483399936091763, 0.03374018875433281, 0.03374018875433281, 0.026264461893934426, 0.017485047479266238, 0.0, 0.016693926877969927, 0.07744732166391595, 0.11261578150183583, 0.12361707590677498, 0.12361707590677498, 0.1679704958353363, 0.11136022222225035, 0.08293289631117864, 0.16396576858100168, 0.4376222657850578, 0.7190726377994601, 0.6149230832625615, 0.6080091803323986, 0.3490546197682234, 0.1993999863454002, 0.1436363945546841, 0.09244721513597884, 0.09244721513597884, 0.06445425602664664, 0.0503572852155663, 0.05121809102014934, 0.030724406943592818, 0.0396669550150291, 0.03857578384132111, 0.023823647076718753, 0.033368862552656475, 0.054503497844048156, 0.11337177674846924, 0.25627874946691775, 0.6442634616519807, 0.6215040944256052, 0.6457072541137894], [0.26790611694910405, 0.18611886089665106, 0.09247790175168857, 0.09472419248542009, 0.06160351698859578, 0.06160756649316365, 0.06160756649316365, 0.06160756649316365, 0.0772933133727927, 0.3528911215289254, 0.7830807442755555, 0.8455435175191925, 0.7288859110699195, 0.6147549867457535, 0.5439099625230008, 0.5086051677485505, 0.5086051677485505, 0.33320993507143304, 0.2330817159769418, 0.18996084876364072, 0.22181146523539558, 0.22181146523539558, 0.22181146523539558, 0.22181146523539558, 0.22181146523539558, 0.1717303838099934, 0.1852053463944188, 0.2745995526765137, 0.2650456720677739, 0.26460040360632003, 0.3108126423232883, 0.3044000499478133, 0.23965432641895182, 0.2507596013669296, 0.13668261028004283, 0.13847016729353254, 0.1336144396697009, 0.12694588356532446, 0.07997680780669762, 0.0447664553614801, 0.07693146632991948, 0.17312893712937355, 0.39591497100548784, 0.2951699387234587, 0.2787361645338273, 0.21820183825874034, 0.06661281499610121, 0.044884298018585365, 0.04061973616974391, 0.042150647206847934, 0.042150647206847934, 0.03644308825217868, 0.03340154194000497, 0.016693926877969927, 0.0, 0.0711985156383115, 0.10588428647632306, 0.11686030826176298, 0.11686030826176298, 0.15870739540485712, 0.10380871487828827, 0.07353253137143587, 0.149303432413877, 0.4240061439212747, 0.7096717238004777, 0.6051837556760493, 0.5983446134245972, 0.33741394264111546, 0.1881010415351263, 0.13594083843079238, 0.08681424569754825, 0.08681424569754825, 0.060130422490836784, 0.05293216948617681, 0.05567189019398338, 0.045159345522097515, 0.05166086164702453, 0.05405874970601, 0.03721829545476242, 0.03137776852077412, 0.05004331215145584, 0.10090255742195314, 0.24306669111008875, 0.6355104195484622, 0.6124715383109021, 0.6367773577179682], [0.33399608068081726, 0.24338854199962676, 0.15817987683825677, 0.15331579092981104, 0.08421320173431933, 0.0887217972311861, 0.0887217972311861, 0.0887217972311861, 0.07571581832603187, 0.32574351700904064, 0.7287502650124562, 0.7920440202474941, 0.6737835753964192, 0.558327014316145, 0.4844326064215523, 0.44838848787978924, 0.44838848787978924, 0.31348103217918466, 0.23048930122061842, 0.24979126825911913, 0.2837885653334742, 0.2837885653334742, 0.2837885653334742, 0.2837885653334742, 0.2837885653334742, 0.21310579046127426, 0.18381025997764028, 0.2134517972704781, 0.20313605745755778, 0.29434984165549544, 0.36977142208106845, 0.3635223819396677, 0.22508129703764923, 0.18656102456761628, 0.14909994311742902, 0.1503301039495435, 0.14657171334000924, 0.18552382224334021, 0.1349751111402568, 0.10443994208421507, 0.05049605785349837, 0.188343709307561, 0.44833400675174806, 0.3420103308829548, 0.33501806068136625, 0.2521124649191306, 0.03913622000434483, 0.046279292165137605, 0.08504013392864429, 0.08910196891509009, 0.08910196891509009, 0.07294020714922497, 0.08673580159389573, 0.07744732166391595, 0.0711985156383115, 0.0, 0.04575276767126872, 0.05478018772470753, 0.05478018772470753, 0.09734339937852338, 0.040613482986070114, 0.03312044861927926, 0.11920561965158133, 0.3933440839230091, 0.6545469149575177, 0.5488139283983519, 0.5415887721519277, 0.2844880676588824, 0.13746319368258703, 0.07192134358039443, 0.02837619427843278, 0.02837619427843278, 0.02600548701604635, 0.05075533897540298, 0.056257109086599075, 0.08272443505962042, 0.07777040801100539, 0.09404830886482105, 0.0798580334144699, 0.0543348290465674, 0.03966065543558874, 0.07123603593740246, 0.21961192704787716, 0.5771498009972762, 0.5543920702152342, 0.5787088521058268], [0.36553748682559983, 0.280882616783488, 0.18864568330175088, 0.18982611104421626, 0.1084430156866233, 0.11317539520146777, 0.11317539520146777, 0.11317539520146777, 0.09610796875074513, 0.31781303194405963, 0.7022537127152841, 0.7634687326782181, 0.6452966369822069, 0.5284842764447992, 0.45274981993465047, 0.4160694422503192, 0.4160694422503192, 0.31784398086720816, 0.23334927334522151, 0.2838997614403936, 0.31831248265658885, 0.31831248265658885, 0.31831248265658885, 0.31831248265658885, 0.31831248265658885, 0.2367985242261369, 0.19156749750460167, 0.18233705062627517, 0.16932164991614443, 0.3178554968970118, 0.3965632778512234, 0.38994276917852183, 0.2516401361117251, 0.1502486312059429, 0.17426589451628222, 0.17519662327037788, 0.17291105604189777, 0.22354106501753407, 0.16757174348107298, 0.13992906662381285, 0.06784042731637735, 0.2231599325877271, 0.47185965751716175, 0.372749245399119, 0.36939588447679833, 0.29048631814854203, 0.06951684665035215, 0.08655529512009312, 0.11616734409560546, 0.1202519645868659, 0.1202519645868659, 0.10844895692368825, 0.12094822654873166, 0.11261578150183583, 0.10588428647632306, 0.04575276767126872, 0.0, 0.01805030428944688, 0.01805030428944688, 0.0761825707884185, 0.02972139099647658, 0.03844186894986691, 0.10688981639587868, 0.37786388824522243, 0.6270881464988513, 0.5202164185271837, 0.512709223564739, 0.26163239536296495, 0.11541080027271605, 0.03470808740537521, 0.02428877122651829, 0.02428877122651829, 0.049787516302671864, 0.0733963384003918, 0.07821398458935377, 0.1136184119527406, 0.10516587300436606, 0.1244381190099164, 0.11269920769964592, 0.08223926214717668, 0.06604866998501698, 0.0760948167058492, 0.21529707352085597, 0.5469582104353012, 0.523815978893307, 0.5490463282839312], [0.3761232112128323, 0.2897817548187262, 0.20009931946206355, 0.197079671472411, 0.11934655026452007, 0.12439027528991568, 0.12439027528991568, 0.12439027528991568, 0.10735087890069814, 0.3134769511031356, 0.6931353226390446, 0.7546338056223411, 0.6356990813664068, 0.5194521156536853, 0.443342828781042, 0.4065526402967976, 0.4065526402967976, 0.3081331909474759, 0.23185807582049042, 0.2940443581491315, 0.32739249629218253, 0.32739249629218253, 0.32739249629218253, 0.32739249629218253, 0.32739249629218253, 0.2447123464718776, 0.18663727445993308, 0.17237077211295368, 0.16127622319482915, 0.3157499561560615, 0.4046367355669802, 0.3981504962508651, 0.24781266084535852, 0.14100666568454795, 0.1741306160858258, 0.17504912008160872, 0.173084651324921, 0.23195022259965614, 0.1781583451975708, 0.15022397735345316, 0.07296334532938224, 0.22468893066076898, 0.47855089407142654, 0.3772530057760489, 0.37450590704501663, 0.2932853095386101, 0.07532010167012536, 0.09516818485944094, 0.12345400514356747, 0.12798411864927273, 0.12798411864927273, 0.11696399402066254, 0.13163653675342157, 0.12361707590677498, 0.11686030826176298, 0.05478018772470753, 0.01805030428944688, 0.0, 5.3774067169312934e-18, 0.07205914758541847, 0.023612445824688192, 0.04728419768180008, 0.10616100255785148, 0.37051657301296936, 0.6175445954538185, 0.5101160840082875, 0.5024709982935752, 0.2504664372095072, 0.11198621055909645, 0.02741640591149708, 0.034186506424308996, 0.034186506424308996, 0.06130648024007961, 0.08445621186629537, 0.08883135453457565, 0.12411773018210913, 0.11642992852212355, 0.13485455168275987, 0.1239720297332907, 0.09442060720866255, 0.07358001751076067, 0.07721054140125866, 0.21220973371093466, 0.5374994511814326, 0.5140433814446558, 0.5395658813032329], [0.3761232112128323, 0.2897817548187262, 0.20009931946206355, 0.197079671472411, 0.11934655026452007, 0.12439027528991568, 0.12439027528991568, 0.12439027528991568, 0.10735087890069814, 0.3134769511031356, 0.6931353226390446, 0.7546338056223411, 0.6356990813664068, 0.5194521156536853, 0.443342828781042, 0.4065526402967976, 0.4065526402967976, 0.3081331909474759, 0.23185807582049042, 0.2940443581491315, 0.32739249629218253, 0.32739249629218253, 0.32739249629218253, 0.32739249629218253, 0.32739249629218253, 0.2447123464718776, 0.18663727445993308, 0.17237077211295368, 0.16127622319482915, 0.3157499561560615, 0.4046367355669802, 0.3981504962508651, 0.24781266084535852, 0.14100666568454795, 0.1741306160858258, 0.17504912008160872, 0.173084651324921, 0.23195022259965614, 0.1781583451975708, 0.15022397735345316, 0.07296334532938224, 0.22468893066076898, 0.47855089407142654, 0.3772530057760489, 0.37450590704501663, 0.2932853095386101, 0.07532010167012536, 0.09516818485944094, 0.12345400514356747, 0.12798411864927273, 0.12798411864927273, 0.11696399402066254, 0.13163653675342157, 0.12361707590677498, 0.11686030826176298, 0.05478018772470753, 0.01805030428944688, 5.3774067169312934e-18, 0.0, 0.07205914758541847, 0.023612445824688192, 0.04728419768180008, 0.10616100255785148, 0.37051657301296936, 0.6175445954538185, 0.5101160840082875, 0.5024709982935752, 0.2504664372095072, 0.11198621055909645, 0.02741640591149708, 0.034186506424308996, 0.034186506424308996, 0.06130648024007961, 0.08445621186629537, 0.08883135453457565, 0.12411773018210913, 0.11642992852212355, 0.13485455168275987, 0.1239720297332907, 0.09442060720866255, 0.07358001751076067, 0.07721054140125866, 0.21220973371093466, 0.5374994511814326, 0.5140433814446558, 0.5395658813032329], [0.416771539277644, 0.33178389735002817, 0.24560251765764407, 0.24081044658526704, 0.17348750365750049, 0.17786245109350485, 0.17786245109350485, 0.17786245109350485, 0.11978535379590471, 0.26253036158897136, 0.652560989499606, 0.7173841944401935, 0.5956027734309787, 0.4757032749562426, 0.403601476950821, 0.3677632589185921, 0.3677632589185921, 0.2851749686294161, 0.21228858275470985, 0.33713552965096544, 0.3691298554200269, 0.3691298554200269, 0.3691298554200269, 0.3691298554200269, 0.3691298554200269, 0.2469437487719252, 0.18451954966775486, 0.1301483799120235, 0.11627601214225192, 0.33083615317937637, 0.4241062206914156, 0.41781388280497084, 0.2400903199036607, 0.11277542067135267, 0.18372243451185435, 0.18321464189733896, 0.18137104623807934, 0.27379923305303716, 0.2265860396121409, 0.19210352813622494, 0.09437611088973245, 0.22354402657109246, 0.4893449866428441, 0.38513499195491874, 0.40340524728328025, 0.3085549317915861, 0.10693685208718899, 0.14176170737616867, 0.17287838395764657, 0.17810956660000324, 0.17810956660000324, 0.16644369086301553, 0.17948777452849143, 0.1679704958353363, 0.15870739540485712, 0.09734339937852338, 0.0761825707884185, 0.07205914758541847, 0.07205914758541847, 0.0, 0.07644673323587692, 0.09618133938403395, 0.09556541075907972, 0.3312782504797676, 0.57686013818504, 0.46808306156619583, 0.46137579691925407, 0.20466688880633976, 0.052346083586592464, 0.049011734195510186, 0.08795403471558516, 0.08795403471558516, 0.11471378717876751, 0.13867937177559764, 0.14467677523419675, 0.1739422573269427, 0.16739410361199503, 0.18637183042078964, 0.168782115350063, 0.1428790556558436, 0.12628864689222183, 0.08282876539120372, 0.16731292736723258, 0.4984812850761988, 0.47448321822967326, 0.49975517602957625], [0.3650085712145839, 0.2759376904739136, 0.1902214437980329, 0.1821151433249623, 0.11365044003218587, 0.11870020471662299, 0.11870020471662299, 0.11870020471662299, 0.10074598341358335, 0.3112769519995582, 0.7009844825829737, 0.7640358861993095, 0.6444709210373776, 0.5290957617417583, 0.45416297612559675, 0.4177529099828454, 0.4177529099828454, 0.29538453978351376, 0.2218564266990929, 0.2828094887738636, 0.31492031351999344, 0.31492031351999344, 0.31492031351999344, 0.31492031351999344, 0.31492031351999344, 0.23110500569118944, 0.17341937215037162, 0.1814228140231262, 0.17356275749850852, 0.29835219414489506, 0.39105390938084506, 0.3848068848612474, 0.22795977312654114, 0.15517191217015866, 0.15439560795173426, 0.15543077796145152, 0.1532149758366526, 0.2173473069531813, 0.16797470757787428, 0.1379940208640436, 0.06072123026172012, 0.20398022473053953, 0.4651640359902191, 0.36082464982171775, 0.357951493869648, 0.2726396997981123, 0.05607486896329569, 0.08072658396976529, 0.11086995991490188, 0.11589301640726536, 0.11589301640726536, 0.10398223024344629, 0.12020023064071789, 0.11136022222225035, 0.10380871487828827, 0.040613482986070114, 0.02972139099647658, 0.023612445824688192, 0.023612445824688192, 0.07644673323587692, 0.0, 0.03851136520549291, 0.10255480663366043, 0.36949947331065913, 0.625535863343392, 0.5183884556712551, 0.5108671803271578, 0.2532613063929891, 0.11681391980445568, 0.043084101682633054, 0.031258443898639715, 0.031258443898639715, 0.05311198205610141, 0.0784232201743159, 0.08311654040052521, 0.11492597216314676, 0.10942533666320352, 0.12587224998638688, 0.11413648567951014, 0.08563426366730495, 0.06190310997900079, 0.06617736585619015, 0.20696796663675043, 0.5475194139251905, 0.5240214166926696, 0.5491630857164591], [0.3355453867961476, 0.253778313967589, 0.15974401215396639, 0.1586923489761342, 0.0914572613429676, 0.09543280464188485, 0.09543280464188485, 0.09543280464188485, 0.07640221393463668, 0.31651985700200014, 0.7250616701832315, 0.7870689834658368, 0.6685662080299181, 0.5526255945802544, 0.47960177859861536, 0.4435462603017478, 0.4435462603017478, 0.30740982716557685, 0.21453321690607483, 0.25733707489991003, 0.28920836558627344, 0.28920836558627344, 0.28920836558627344, 0.28920836558627344, 0.28920836558627344, 0.20449589403382687, 0.1683428660869815, 0.2072777442240589, 0.19733362004152452, 0.2869670247151001, 0.3619673179550222, 0.3553735569235027, 0.240310075102034, 0.18185640420512586, 0.1451386303266236, 0.14625483522561178, 0.14350907052536035, 0.19445073884984462, 0.1426666023525404, 0.11057955753221818, 0.04248146045203887, 0.19745260557216773, 0.4384526819875305, 0.3392748447186612, 0.3355871567590976, 0.26176950394003057, 0.043007281673920525, 0.06481663298669417, 0.08547599347854538, 0.09040770578838085, 0.09040770578838085, 0.08182753904458732, 0.09393627921402074, 0.08293289631117864, 0.07353253137143587, 0.03312044861927926, 0.03844186894986691, 0.04728419768180008, 0.04728419768180008, 0.09618133938403395, 0.03851136520549291, 0.0, 0.09973793441206763, 0.37923779085160253, 0.6499431575127337, 0.5431867269898291, 0.5360013490664304, 0.27668194362150966, 0.12832000653055053, 0.0659622815535597, 0.026990805087994545, 0.026990805087994545, 0.03126999178421873, 0.05501157225444239, 0.06129174476766314, 0.09035253651152633, 0.08559255109804693, 0.10222472220961659, 0.08755660902658943, 0.0550410773623965, 0.03720841221029074, 0.056341580397228065, 0.20805103364064487, 0.5730296861753241, 0.5492984570825594, 0.5746171239019165], [0.3923686028708134, 0.3241509234113869, 0.23171269228037975, 0.2289152770615725, 0.18528699396125292, 0.1882643994059624, 0.1882643994059624, 0.1882643994059624, 0.1348675680112008, 0.2538655003423789, 0.6715157113489343, 0.7362343624556329, 0.6145492601432808, 0.496945990267528, 0.43060671289127406, 0.3964624183752836, 0.3964624183752836, 0.24980827186439156, 0.13693190040385148, 0.33017346159354194, 0.3555750600755078, 0.3555750600755078, 0.3555750600755078, 0.3555750600755078, 0.3555750600755078, 0.19115008885582588, 0.13081976545069876, 0.16093242652731274, 0.16150545699058977, 0.28380912667458696, 0.36767830304403903, 0.3611888151953962, 0.23897743453730802, 0.1625293836737564, 0.1373074289346463, 0.1365735113407002, 0.13886486554746144, 0.265191230378385, 0.2256230785895363, 0.18946610233802305, 0.1016838443324796, 0.20801477567443769, 0.4252279375280256, 0.3471175061570188, 0.3719164041742124, 0.2882228373770326, 0.10023333909629795, 0.1535080787477007, 0.16800347646128677, 0.17385770148262478, 0.17385770148262478, 0.16955439612406503, 0.1784174602968014, 0.16396576858100168, 0.149303432413877, 0.11920561965158133, 0.10688981639587868, 0.10616100255785148, 0.10616100255785148, 0.09556541075907972, 0.10255480663366043, 0.09973793441206763, 0.0, 0.29351064194058857, 0.594235816215243, 0.4861832736457266, 0.47977789559816475, 0.20982249052436136, 0.08689168506364227, 0.10037461873284247, 0.11560544398745508, 0.11560544398745508, 0.12809560526396171, 0.15160032684130081, 0.15783451293325013, 0.18089647510834, 0.1785666224579143, 0.1922198334264827, 0.17494482823585347, 0.1441090870909236, 0.13124357294849542, 0.07366740693106674, 0.13990245436763085, 0.5238125027944578, 0.49810104516508047, 0.523920993264178], [0.6263261493638077, 0.5707532976387303, 0.4960497202054333, 0.48288298375678357, 0.45928860277038347, 0.46237354006786513, 0.46237354006786513, 0.46237354006786513, 0.3995506911876443, 0.19813013529795226, 0.5102528434683713, 0.582442117669181, 0.45732388214350006, 0.36120950103936467, 0.35377726544655974, 0.3416538727994357, 0.3416538727994357, 0.23334786355730933, 0.23676787272723146, 0.5807887167711393, 0.595596039388869, 0.595596039388869, 0.595596039388869, 0.595596039388869, 0.595596039388869, 0.3886790176216151, 0.29704160076375524, 0.2718474247685319, 0.2957188526783399, 0.421780881367081, 0.538158944104063, 0.5337462644479206, 0.3910221980445204, 0.3235860451621971, 0.3506327537398841, 0.3483334448713439, 0.3536331281916721, 0.5168969986984602, 0.4933761170446024, 0.4571581596714418, 0.371333484986718, 0.39922048668035964, 0.5475057697246486, 0.49991902679204786, 0.5654421465781146, 0.47867078314123257, 0.3755344611590245, 0.4257007829971904, 0.43606032178541043, 0.44221378941140005, 0.44221378941140005, 0.44053970130484843, 0.4512172533864492, 0.4376222657850578, 0.4240061439212747, 0.3933440839230091, 0.37786388824522243, 0.37051657301296936, 0.37051657301296936, 0.3312782504797676, 0.36949947331065913, 0.37923779085160253, 0.29351064194058857, 0.0, 0.4347474395898628, 0.34141022099803703, 0.34184062322199726, 0.18803479380824306, 0.2921926862613059, 0.35687314177824553, 0.38853216897617804, 0.38853216897617804, 0.4057387326051079, 0.42758109296404473, 0.43322489416117266, 0.4537195915978557, 0.4527957285014182, 0.4645863097650133, 0.44779528975395694, 0.42237136544132936, 0.4060242480538711, 0.34198722798961306, 0.22502380454566487, 0.4158606048347254, 0.3846737554744488, 0.40840275752732824], [0.9359570670327465, 0.8602838556634066, 0.7870820318568448, 0.7787443548836326, 0.71985968432685, 0.7242527432596696, 0.7242527432596696, 0.7242527432596696, 0.679010957879073, 0.521338423918498, 0.09714654663983269, 0.1831825078230035, 0.0532885043517921, 0.13822004490722142, 0.21462405525313746, 0.2516709502738731, 0.2516709502738731, 0.5647167858542245, 0.610697070873451, 0.8697407583620925, 0.8962291184563188, 0.8962291184563188, 0.8962291184563188, 0.8962291184563188, 0.8962291184563188, 0.7374424428480649, 0.6406523161028983, 0.46457982167769524, 0.48017140043398315, 0.7710500480143677, 0.8941719673782298, 0.8893851418370446, 0.659230889902725, 0.49819104902950534, 0.6775852040561912, 0.6762264009186753, 0.6797250341572427, 0.8097116719784186, 0.7703638260561739, 0.7424348245481727, 0.6537632845590428, 0.7137311515108485, 0.9152068242359722, 0.8536168110741431, 0.8988850708374685, 0.7931643083302397, 0.6554867384722122, 0.6924647503994389, 0.7198834630171942, 0.7248882274096066, 0.7248882274096066, 0.7152950570203208, 0.7284259006746686, 0.7190726377994601, 0.7096717238004777, 0.6545469149575177, 0.6270881464988513, 0.6175445954538185, 0.6175445954538185, 0.57686013818504, 0.625535863343392, 0.6499431575127337, 0.594235816215243, 0.4347474395898628, 0.0, 0.12810647986485507, 0.13532552300234252, 0.41543577440520163, 0.5553923614825902, 0.5983214527713345, 0.6444214858418928, 0.6444214858418928, 0.6681567008305664, 0.6901835496923229, 0.6940822705566796, 0.7240161245639618, 0.7173453328316636, 0.7334187422693828, 0.7219210549604407, 0.6958794783839078, 0.678206552087465, 0.632989324163947, 0.5654261040008166, 0.12945158735551282, 0.13918586299818725, 0.11654484567860102], [0.8382645368110675, 0.7612712554671459, 0.6848742110266767, 0.675973357041623, 0.6161626739689074, 0.6206753859781544, 0.6206753859781544, 0.6206753859781544, 0.5728762478731596, 0.42059322112070774, 0.21826701180776506, 0.29239527599672444, 0.14683425305797287, 0.06652256197332304, 0.1180712292726673, 0.14902309734185723, 0.14902309734185723, 0.4653893050775652, 0.5069077287011479, 0.7702831561443229, 0.7970012445598589, 0.7970012445598589, 0.7970012445598589, 0.7970012445598589, 0.7970012445598589, 0.6357445451507577, 0.533545563425156, 0.35268715356094127, 0.3691154637118761, 0.670810916692576, 0.7980335936918307, 0.7929900326316843, 0.562477557441766, 0.3888673523495317, 0.5733260287492749, 0.5719227186098964, 0.5752846866950418, 0.7084898491164374, 0.6680775358436434, 0.6385970025349198, 0.5463140693822809, 0.612086593267767, 0.8231244993647127, 0.7551831573391182, 0.8002462370864194, 0.6947074098876542, 0.5498022160392539, 0.5881078794566774, 0.6149316698177395, 0.6201910626488815, 0.6201910626488815, 0.6110081700373348, 0.6247413812880475, 0.6149230832625615, 0.6051837556760493, 0.5488139283983519, 0.5202164185271837, 0.5101160840082875, 0.5101160840082875, 0.46808306156619583, 0.5183884556712551, 0.5431867269898291, 0.4861832736457266, 0.34141022099803703, 0.12810647986485507, 0.0, 0.017148547544152206, 0.301009216384318, 0.4451411811001587, 0.49029524749424214, 0.5377704276166749, 0.5377704276166749, 0.5626338494859298, 0.5851549826381897, 0.5893085887761446, 0.6200083775835166, 0.6133371630664461, 0.6299896976326674, 0.6177112605643973, 0.5909476226466541, 0.5722621379683587, 0.5247123741230502, 0.4575927402930008, 0.10023005985736676, 0.06978243329969566, 0.08872475182105477], [0.8321967914446133, 0.7546414158417676, 0.6781525614364564, 0.6692307380961997, 0.6088021998073989, 0.6133551010095947, 0.6133551010095947, 0.6133551010095947, 0.566837211824446, 0.42234390192708804, 0.22597715500330098, 0.29822237075933455, 0.15470730101105182, 0.07463751103619666, 0.10811570417577437, 0.13846992537760228, 0.13846992537760228, 0.46124126536112753, 0.502800270709963, 0.763752469868356, 0.7906912661844171, 0.7906912661844171, 0.7906912661844171, 0.7906912661844171, 0.7906912661844171, 0.6312319120314147, 0.5281604569906375, 0.3449460314900439, 0.3617260868461709, 0.6656677771169376, 0.7935225900192762, 0.7884501734817502, 0.5563338082154686, 0.38048926058058424, 0.5673213595319793, 0.565981260892933, 0.5693783121665524, 0.701835037039344, 0.6610534613819582, 0.6318825120444388, 0.5397860238573154, 0.6068607044388435, 0.819614184030965, 0.7513554886596723, 0.7948569350977522, 0.6891356536437785, 0.5427960173410674, 0.5808652767420688, 0.6079016909392939, 0.6131366587414147, 0.6131366587414147, 0.6038464970134462, 0.6176849930900034, 0.6080091803323986, 0.5983446134245972, 0.5415887721519277, 0.512709223564739, 0.5024709982935752, 0.5024709982935752, 0.46137579691925407, 0.5108671803271578, 0.5360013490664304, 0.47977789559816475, 0.34184062322199726, 0.13532552300234252, 0.017148547544152206, 0.0, 0.2952410592978793, 0.43932732606615355, 0.4828192060743682, 0.5304345125945644, 0.5304345125945644, 0.5552988411756653, 0.5778460853018675, 0.581922392157734, 0.6128811867590442, 0.6061315339163822, 0.6227682125189754, 0.6107920644707574, 0.5838688714311825, 0.5650378626671997, 0.5183537537138561, 0.4547463496689666, 0.09514855962420415, 0.06301897269441034, 0.08495491998611111], [0.5792424834765785, 0.5001957388456969, 0.42222855095472056, 0.4074585468740899, 0.3596777109748693, 0.36417411475744116, 0.36417411475744116, 0.36417411475744116, 0.3076400208334631, 0.2127962159559693, 0.4971785055325773, 0.5697858192909457, 0.4368328631831228, 0.3206689217225686, 0.2647041868658847, 0.23619280869155257, 0.23619280869155257, 0.2206627323477476, 0.23518626632713308, 0.5112074899033002, 0.535314017079376, 0.535314017079376, 0.535314017079376, 0.535314017079376, 0.535314017079376, 0.36486450529719866, 0.25089021230127867, 0.11043590924212017, 0.14156792375771055, 0.40286341294340977, 0.5376475475067437, 0.5324200429412139, 0.30848943408641694, 0.16729436107217993, 0.29205232849156215, 0.2904550875958129, 0.2937678338437757, 0.4429301448537014, 0.4075456080720468, 0.37249584995274293, 0.2741189406734176, 0.33830627100560345, 0.5738008845802098, 0.4896942275460156, 0.5329537615658164, 0.4268910398157767, 0.2781359604737536, 0.3240789430568986, 0.3474153685037894, 0.35360400720259305, 0.35360400720259305, 0.3460481154877442, 0.3610150118608595, 0.3490546197682234, 0.33741394264111546, 0.2844880676588824, 0.26163239536296495, 0.2504664372095072, 0.2504664372095072, 0.20466688880633976, 0.2532613063929891, 0.27668194362150966, 0.20982249052436136, 0.18803479380824306, 0.41543577440520163, 0.301009216384318, 0.2952410592978793, 0.0, 0.1774318545750162, 0.2320231145075953, 0.2762968978940411, 0.2762968978940411, 0.3006472675078759, 0.3252962693758655, 0.3305111327073471, 0.3587419072373216, 0.35459602984178795, 0.3701209535277726, 0.35486744111134966, 0.32749231744123847, 0.3062096303403388, 0.24804598714695927, 0.18715469594534398, 0.35301604189707025, 0.3231882772593524, 0.3506485698871953], [0.4385072696325149, 0.3624669925785399, 0.2727349114450049, 0.269764345655456, 0.2101075083459792, 0.21385280766399775, 0.21385280766399775, 0.21385280766399775, 0.14291370292426023, 0.2219994156898401, 0.6319708230201007, 0.6971127842218687, 0.573710909009489, 0.4515566276064994, 0.3852225937343539, 0.35075758163324167, 0.35075758163324167, 0.26936636399003044, 0.18579701909781368, 0.36630741157792934, 0.395461741328565, 0.395461741328565, 0.395461741328565, 0.395461741328565, 0.395461741328565, 0.24305359191182976, 0.17560894451966924, 0.11756537445993705, 0.1049846452271476, 0.3338408110956527, 0.4259368671579878, 0.419541349419841, 0.2592971592706975, 0.11876199697196464, 0.1928955981249236, 0.19157569933527138, 0.19090763958216492, 0.3038575689498535, 0.25954231913655107, 0.2223916021861912, 0.12081331278215934, 0.2372882091353597, 0.4829941022404336, 0.3868775285394196, 0.41885102058239004, 0.32748728413491457, 0.1382248391098749, 0.1801904915963179, 0.2038262851021174, 0.20949088822240872, 0.20949088822240872, 0.20146745628846044, 0.21270464942748768, 0.1993999863454002, 0.1881010415351263, 0.13746319368258703, 0.11541080027271605, 0.11198621055909645, 0.11198621055909645, 0.052346083586592464, 0.11681391980445568, 0.12832000653055053, 0.08689168506364227, 0.2921926862613059, 0.5553923614825902, 0.4451411811001587, 0.43932732606615355, 0.1774318545750162, 0.0, 0.08987929696230759, 0.12736030626789407, 0.12736030626789407, 0.15205919574887855, 0.17508028041108414, 0.18163732931733254, 0.2087817571378891, 0.2032221619028066, 0.22172984347969937, 0.20206306134650373, 0.17540906781595786, 0.1605275331036188, 0.09904331244126242, 0.12830050475969876, 0.48043415195505373, 0.4547227032892619, 0.48103978316285845], [0.39582912757235583, 0.31068284277191416, 0.22051041389897638, 0.2187468437812116, 0.14107007300192576, 0.14587978164063792, 0.14587978164063792, 0.14587978164063792, 0.1136111418357298, 0.2983361945984301, 0.6741215622267207, 0.7360246787358095, 0.6164252250472255, 0.4985252820005102, 0.4226859533719543, 0.3858834116357694, 0.3858834116357694, 0.3049649576853326, 0.2287360773324301, 0.3145749935261555, 0.3480894937076913, 0.3480894937076913, 0.3480894937076913, 0.3480894937076913, 0.3480894937076913, 0.251124565827407, 0.19075360439718464, 0.1504381646202982, 0.13692010313026418, 0.3283173426348026, 0.4175388593865272, 0.4110126861381068, 0.2515387659027275, 0.11942300037823629, 0.18386243975970076, 0.18429705173303412, 0.1825794277197799, 0.2529305439593062, 0.19963298981578206, 0.1699184795777641, 0.08288642639280439, 0.23236026218788447, 0.48847261525238317, 0.3879575257765412, 0.39229024826399245, 0.3068516824568259, 0.08981538669333851, 0.11594893758685478, 0.14592131750539047, 0.15060105124149348, 0.15060105124149348, 0.13922420885094924, 0.1528496174863954, 0.1436363945546841, 0.13594083843079238, 0.07192134358039443, 0.03470808740537521, 0.02741640591149708, 0.02741640591149708, 0.049011734195510186, 0.043084101682633054, 0.0659622815535597, 0.10037461873284247, 0.35687314177824553, 0.5983214527713345, 0.49029524749424214, 0.4828192060743682, 0.2320231145075953, 0.08987929696230759, 0.0, 0.053686117678287494, 0.053686117678287494, 0.0824830147311849, 0.10610687563044587, 0.11107320628340052, 0.1454838066424886, 0.13738618187450746, 0.1567930540973449, 0.14362916858105884, 0.11450458645138235, 0.09612867922839906, 0.08064657416666561, 0.20005726245395036, 0.5176148972681255, 0.494061932994163, 0.5196441363806515], [0.34693083450194295, 0.2603108783082699, 0.1697777731305928, 0.16854191340708705, 0.0899419742493556, 0.09473031698976661, 0.09473031698976661, 0.09473031698976661, 0.07965544122164071, 0.32197404076316544, 0.7191236162851731, 0.7807602096596103, 0.662589485189125, 0.5464734136337324, 0.4718248941211828, 0.435408961797045, 0.435408961797045, 0.3185178034561635, 0.23439963026170058, 0.2634432397216189, 0.29756297023838746, 0.29756297023838746, 0.29756297023838746, 0.29756297023838746, 0.29756297023838746, 0.22622840147849926, 0.18639768010773683, 0.2015587302248665, 0.1889851114919352, 0.3049221809886045, 0.3829514136415678, 0.3764370268469523, 0.245193291311951, 0.17114311694744994, 0.1644559935493457, 0.1655278773980927, 0.16220958316547526, 0.202320203677174, 0.14755438533099113, 0.11831587700696786, 0.052425605719962104, 0.2086404305671474, 0.4605797350675244, 0.35588990581809027, 0.34998169328191814, 0.27345321418439145, 0.05854533162527837, 0.06606336486439272, 0.09487656048128838, 0.0990441456453902, 0.0990441456453902, 0.08709077822268552, 0.10076947496520944, 0.09244721513597884, 0.08681424569754825, 0.02837619427843278, 0.02428877122651829, 0.034186506424308996, 0.034186506424308996, 0.08795403471558516, 0.031258443898639715, 0.026990805087994545, 0.11560544398745508, 0.38853216897617804, 0.6444214858418928, 0.5377704276166749, 0.5304345125945644, 0.2762968978940411, 0.12736030626789407, 0.053686117678287494, 0.0, 5.241247737832367e-18, 0.03113077549719431, 0.05376463502810741, 0.05927805096754054, 0.09276780350302856, 0.0852932993074948, 0.10447964766475709, 0.09132556910152824, 0.0632684709607758, 0.04512551856815135, 0.07008836823900255, 0.21804791674068646, 0.5654114720168901, 0.5422048865653153, 0.5673604541197139], [0.34693083450194295, 0.2603108783082699, 0.1697777731305928, 0.16854191340708705, 0.0899419742493556, 0.09473031698976661, 0.09473031698976661, 0.09473031698976661, 0.07965544122164071, 0.32197404076316544, 0.7191236162851731, 0.7807602096596103, 0.662589485189125, 0.5464734136337324, 0.4718248941211828, 0.435408961797045, 0.435408961797045, 0.3185178034561635, 0.23439963026170058, 0.2634432397216189, 0.29756297023838746, 0.29756297023838746, 0.29756297023838746, 0.29756297023838746, 0.29756297023838746, 0.22622840147849926, 0.18639768010773683, 0.2015587302248665, 0.1889851114919352, 0.3049221809886045, 0.3829514136415678, 0.3764370268469523, 0.245193291311951, 0.17114311694744994, 0.1644559935493457, 0.1655278773980927, 0.16220958316547526, 0.202320203677174, 0.14755438533099113, 0.11831587700696786, 0.052425605719962104, 0.2086404305671474, 0.4605797350675244, 0.35588990581809027, 0.34998169328191814, 0.27345321418439145, 0.05854533162527837, 0.06606336486439272, 0.09487656048128838, 0.0990441456453902, 0.0990441456453902, 0.08709077822268552, 0.10076947496520944, 0.09244721513597884, 0.08681424569754825, 0.02837619427843278, 0.02428877122651829, 0.034186506424308996, 0.034186506424308996, 0.08795403471558516, 0.031258443898639715, 0.026990805087994545, 0.11560544398745508, 0.38853216897617804, 0.6444214858418928, 0.5377704276166749, 0.5304345125945644, 0.2762968978940411, 0.12736030626789407, 0.053686117678287494, 5.241247737832367e-18, 0.0, 0.03113077549719431, 0.05376463502810741, 0.05927805096754054, 0.09276780350302856, 0.0852932993074948, 0.10447964766475709, 0.09132556910152824, 0.0632684709607758, 0.04512551856815135, 0.07008836823900255, 0.21804791674068646, 0.5654114720168901, 0.5422048865653153, 0.5673604541197139], [0.32009933504916677, 0.23336549679753127, 0.1418691380418182, 0.14327080610974977, 0.06425333659336999, 0.06870760255998572, 0.06870760255998572, 0.06870760255998572, 0.07709018173613712, 0.3397520329018284, 0.7423080141775089, 0.8038999431470736, 0.686773028412545, 0.5715844760698969, 0.4972293049680122, 0.4610162734918413, 0.4610162734918413, 0.3290430824300902, 0.23956919825046138, 0.2366966656774588, 0.2715628059825114, 0.2715628059825114, 0.2715628059825114, 0.2715628059825114, 0.2715628059825114, 0.21408015500501237, 0.19157258830769527, 0.2278496301145287, 0.21631540543483177, 0.29688494916514235, 0.3635542524468611, 0.35704853214321225, 0.24414734093064605, 0.1979860024198855, 0.15824002763169495, 0.15975239557633678, 0.15610370803810802, 0.17595116547684103, 0.11950254003288108, 0.09254600875365841, 0.0586818119565255, 0.2011281459503591, 0.44459868619141163, 0.34260748230798027, 0.3297820676427017, 0.2580346171288084, 0.05158521187969355, 0.04097915907227959, 0.07113889821541734, 0.07428206308760685, 0.07428206308760685, 0.06026001291151335, 0.0719094493409252, 0.06445425602664664, 0.060130422490836784, 0.02600548701604635, 0.049787516302671864, 0.06130648024007961, 0.06130648024007961, 0.11471378717876751, 0.05311198205610141, 0.03126999178421873, 0.12809560526396171, 0.4057387326051079, 0.6681567008305664, 0.5626338494859298, 0.5552988411756653, 0.3006472675078759, 0.15205919574887855, 0.0824830147311849, 0.03113077549719431, 0.03113077549719431, 0.0, 0.028624088533320217, 0.03420464697311381, 0.06596469355039793, 0.05925468427642509, 0.07683721121509048, 0.0654437403612709, 0.03531627054416729, 0.025427922216425432, 0.0820265392215503, 0.23339670431898765, 0.5900912091105669, 0.5672962669023149, 0.5919499674794063], [0.29999838819628777, 0.21373248799247674, 0.1208193229995328, 0.12618714587848132, 0.03754409704578184, 0.04199584786553895, 0.04199584786553895, 0.04199584786553895, 0.07912490118020879, 0.35725255269264716, 0.7637343646737712, 0.8241963484242173, 0.7081591711081489, 0.5936138686566348, 0.5193599430380352, 0.48318015728857777, 0.48318015728857777, 0.3478767026320287, 0.25705157385391586, 0.21409425818226213, 0.25021834134553916, 0.25021834134553916, 0.25021834134553916, 0.25021834134553916, 0.25021834134553916, 0.21781550270012517, 0.2048571239293346, 0.2527042450047455, 0.23975895055393392, 0.29866191299868144, 0.35729369222823565, 0.35073759884262706, 0.2592561551109468, 0.22070596685750518, 0.17037383476932078, 0.17208785187084996, 0.16766799281503816, 0.15744434157205625, 0.0963260757315163, 0.07383222884047928, 0.07361980145819175, 0.20804937095836037, 0.4419980837921796, 0.3378559613055204, 0.31781816062192025, 0.25696116257219087, 0.07355939360483052, 0.03843666982507565, 0.05503605099244634, 0.05608336315535031, 0.05608336315535031, 0.04387303918353677, 0.05298208515008169, 0.0503572852155663, 0.05293216948617681, 0.05075533897540298, 0.0733963384003918, 0.08445621186629537, 0.08445621186629537, 0.13867937177559764, 0.0784232201743159, 0.05501157225444239, 0.15160032684130081, 0.42758109296404473, 0.6901835496923229, 0.5851549826381897, 0.5778460853018675, 0.3252962693758655, 0.17508028041108414, 0.10610687563044587, 0.05376463502810741, 0.05376463502810741, 0.028624088533320217, 0.0, 0.007830421382629967, 0.04156586823965041, 0.03289454574657036, 0.05240049454146762, 0.04417841315492551, 0.024230447198773337, 0.03004383614240661, 0.10132925073876488, 0.25222071896307807, 0.6118408109652602, 0.5891839054982083, 0.6139255183717205], [0.2974601042134225, 0.2103309354500172, 0.11849578685500664, 0.12429308491178494, 0.03162703834139592, 0.036529283256950644, 0.036529283256950644, 0.036529283256950644, 0.08585457662913179, 0.3636857232802849, 0.7675022831141857, 0.8277209012061204, 0.7120199627279762, 0.597843770158413, 0.5232062169780622, 0.48698009382656443, 0.48698009382656443, 0.3525617842828327, 0.26297656578689094, 0.2106222577649907, 0.24725412519333406, 0.24725412519333406, 0.24725412519333406, 0.24725412519333406, 0.24725412519333406, 0.22243145657754462, 0.21005716371690747, 0.2574239526001674, 0.24455076776352366, 0.30106440860171463, 0.3589152733475035, 0.3523893502617745, 0.26197327903019635, 0.2246229068288833, 0.17460975360056055, 0.17643460520556692, 0.17203887231350953, 0.15486123667629315, 0.09248050515288957, 0.07349526139860767, 0.08078282947011853, 0.21171463970006432, 0.4444135490673866, 0.34045418068479105, 0.31759644735182607, 0.2582137338058996, 0.07896178077647344, 0.03967345156497911, 0.054838292893206395, 0.055054508662036365, 0.055054508662036365, 0.04254995732551997, 0.05125930575549405, 0.05121809102014934, 0.05567189019398338, 0.056257109086599075, 0.07821398458935377, 0.08883135453457565, 0.08883135453457565, 0.14467677523419675, 0.08311654040052521, 0.06129174476766314, 0.15783451293325013, 0.43322489416117266, 0.6940822705566796, 0.5893085887761446, 0.581922392157734, 0.3305111327073471, 0.18163732931733254, 0.11107320628340052, 0.05927805096754054, 0.05927805096754054, 0.03420464697311381, 0.007830421382629967, 0.0, 0.03869199480210902, 0.02917876281002539, 0.04800113293389339, 0.044032015379508946, 0.028526107724441908, 0.035128833033515015, 0.10832886359991814, 0.25904132311667394, 0.6155170014121948, 0.5930126927767608, 0.6176783207039712], [0.2631197678696113, 0.1742429799211421, 0.08480456236011862, 0.09090235157443874, 0.02350987316660267, 0.022833961695754933, 0.022833961695754933, 0.022833961695754933, 0.0913626234957317, 0.37850874405868334, 0.7966767111042073, 0.8573909592598195, 0.742162295734766, 0.6288341548764054, 0.5558391250953713, 0.5200627179634545, 0.5200627179634545, 0.36277063695596373, 0.2716427711094318, 0.1740003750099169, 0.21082280063079764, 0.21082280063079764, 0.21082280063079764, 0.21082280063079764, 0.21082280063079764, 0.20998392537689972, 0.21655327040318298, 0.29037864222115467, 0.2780878407729934, 0.2886099849338887, 0.33502124354880575, 0.3287039308734622, 0.2626903673882835, 0.2599091880786339, 0.17303121617902778, 0.1750116246124101, 0.1695835046610042, 0.11864198661812142, 0.056214329210699604, 0.03901841221639531, 0.09786593849494726, 0.20037243180419181, 0.424158528400227, 0.3166406250957033, 0.2874599658625201, 0.2368135998004241, 0.09576359299887831, 0.046212679798039814, 0.037920464658348016, 0.03372381226013413, 0.03372381226013413, 0.0250470839944155, 0.021182545104604444, 0.030724406943592818, 0.045159345522097515, 0.08272443505962042, 0.1136184119527406, 0.12411773018210913, 0.12411773018210913, 0.1739422573269427, 0.11492597216314676, 0.09035253651152633, 0.18089647510834, 0.4537195915978557, 0.7240161245639618, 0.6200083775835166, 0.6128811867590442, 0.3587419072373216, 0.2087817571378891, 0.1454838066424886, 0.09276780350302856, 0.09276780350302856, 0.06596469355039793, 0.04156586823965041, 0.03869199480210902, 0.0, 0.014889456538911616, 0.015053209700195693, 0.015983044366562615, 0.03976828435756631, 0.057733372220821276, 0.127264466245223, 0.2734750163535671, 0.6472680371592914, 0.6248363687002283, 0.6491789901455025], [0.273168570252132, 0.18549195697262127, 0.09458507421978161, 0.10518916715800855, 0.013263047156421515, 0.014492432172407971, 0.014492432172407971, 0.014492432172407971, 0.08942482702566813, 0.3780456851300246, 0.7900032649370452, 0.8501832588444996, 0.7352682969290222, 0.6214866577176644, 0.5477382337218446, 0.511788106195932, 0.511788106195932, 0.36747035917537757, 0.27541336646272435, 0.18385306301095708, 0.22204521824504808, 0.22204521824504808, 0.22204521824504808, 0.22204521824504808, 0.22204521824504808, 0.21815328020782415, 0.22224068616834836, 0.2832020143226875, 0.2697184469440014, 0.3003511955175104, 0.3459974419673108, 0.3395448507492209, 0.2686167955658517, 0.250825150916334, 0.18121359602198145, 0.18310552793484866, 0.17792450832848436, 0.13161709573147148, 0.06608380900043803, 0.05224419101953754, 0.09681032732072918, 0.21003221392173152, 0.4346589502052297, 0.32898654373814634, 0.30100513695525993, 0.24912150340156947, 0.09580739581520031, 0.04682440140548171, 0.04874096282834938, 0.04555233617375038, 0.04555233617375038, 0.034696613765572426, 0.03283562631102829, 0.0396669550150291, 0.05166086164702453, 0.07777040801100539, 0.10516587300436606, 0.11642992852212355, 0.11642992852212355, 0.16739410361199503, 0.10942533666320352, 0.08559255109804693, 0.1785666224579143, 0.4527957285014182, 0.7173453328316636, 0.6133371630664461, 0.6061315339163822, 0.35459602984178795, 0.2032221619028066, 0.13738618187450746, 0.0852932993074948, 0.0852932993074948, 0.05925468427642509, 0.03289454574657036, 0.02917876281002539, 0.014889456538911616, 0.0, 0.023052138320840226, 0.02366980494445599, 0.03687574439547101, 0.0557803401922554, 0.1263904602913422, 0.2738800476223267, 0.6394769899927297, 0.6172367340972313, 0.6415826323343701], [0.2548315202171675, 0.16469883778356464, 0.07766707236436926, 0.08667539406350676, 0.024057823704210408, 0.02139390352633365, 0.02139390352633365, 0.02139390352633365, 0.10513343038625851, 0.39099115543644936, 0.8057968688989525, 0.8662235892109618, 0.7516482454903787, 0.6389062504426248, 0.5654825570158404, 0.5296951338093021, 0.5296951338093021, 0.3721515704535266, 0.2817424332501796, 0.16441986603750358, 0.20248593790489583, 0.20248593790489583, 0.20248593790489583, 0.20248593790489583, 0.20248593790489583, 0.21614662375993013, 0.2270004198780476, 0.3011837358127735, 0.28912164933702267, 0.2929744093492505, 0.33461977603452586, 0.32837271202748775, 0.26790604381346955, 0.2699270466161176, 0.18076498526256582, 0.1829173583769211, 0.1776406115650075, 0.11138822637071738, 0.04520924350093659, 0.04189411670057359, 0.11187097036918622, 0.20689040270615044, 0.42522315600206, 0.31974556455174824, 0.2852002909578319, 0.23792466695915568, 0.10627643062011376, 0.0550512578205605, 0.04547915117482287, 0.0396468988846519, 0.0396468988846519, 0.03258738244223221, 0.023228652365716588, 0.03857578384132111, 0.05405874970601, 0.09404830886482105, 0.1244381190099164, 0.13485455168275987, 0.13485455168275987, 0.18637183042078964, 0.12587224998638688, 0.10222472220961659, 0.1922198334264827, 0.4645863097650133, 0.7334187422693828, 0.6299896976326674, 0.6227682125189754, 0.3701209535277726, 0.22172984347969937, 0.1567930540973449, 0.10447964766475709, 0.10447964766475709, 0.07683721121509048, 0.05240049454146762, 0.04800113293389339, 0.015053209700195693, 0.023052138320840226, 0.0, 0.02817941871833187, 0.05129821455760765, 0.06968815496938639, 0.1406600759132342, 0.2862196535329916, 0.656571721403717, 0.634437967122201, 0.6585518096779456], [0.2627722217650395, 0.17597855816990846, 0.08466733702466883, 0.09152225343569322, 0.035812526299329066, 0.03481714523002611, 0.03481714523002611, 0.03481714523002611, 0.07871634500996146, 0.36946559552073516, 0.7945802202994252, 0.8557921460157285, 0.7401684844686822, 0.626194523213411, 0.5541946996287537, 0.5186059507987303, 0.5186059507987303, 0.35781685080070913, 0.2634042519554442, 0.17543449886732623, 0.2115276012587123, 0.2115276012587123, 0.2115276012587123, 0.2115276012587123, 0.2115276012587123, 0.1986135935906197, 0.21037392238814429, 0.2878270072089794, 0.2751800710009718, 0.28452924343467817, 0.3283161653025917, 0.3219468091003387, 0.2586436431613056, 0.2589477273764769, 0.1665660741331303, 0.16831887071758542, 0.16256896727617517, 0.11922429573477422, 0.06084280664887877, 0.03235229980529138, 0.0901610896056408, 0.19193250735812872, 0.416698007945875, 0.30831756919809156, 0.2842849924055554, 0.23176219259803305, 0.09089273383144895, 0.04627538872706805, 0.039333244668876964, 0.03673131994812864, 0.03673131994812864, 0.028969825135790876, 0.02258822610397407, 0.023823647076718753, 0.03721829545476242, 0.0798580334144699, 0.11269920769964592, 0.1239720297332907, 0.1239720297332907, 0.168782115350063, 0.11413648567951014, 0.08755660902658943, 0.17494482823585347, 0.44779528975395694, 0.7219210549604407, 0.6177112605643973, 0.6107920644707574, 0.35486744111134966, 0.20206306134650373, 0.14362916858105884, 0.09132556910152824, 0.09132556910152824, 0.0654437403612709, 0.04417841315492551, 0.044032015379508946, 0.015983044366562615, 0.02366980494445599, 0.02817941871833187, 0.0, 0.036416643191031155, 0.057261905050671524, 0.1199065313402017, 0.26404144584308153, 0.6457659612833275, 0.6231694242618654, 0.6475112244193647], [0.28757496832349816, 0.2054719069952409, 0.10826464947395933, 0.11603304663196577, 0.04538466655895157, 0.047385062241303816, 0.047385062241303816, 0.047385062241303816, 0.07141329934503175, 0.3521050931715724, 0.769500178115683, 0.8306630525565555, 0.7143689815410129, 0.599538229207583, 0.5268286838957015, 0.49100213797157344, 0.49100213797157344, 0.34152197225840514, 0.24305084815085373, 0.2062356915216831, 0.24090514860502255, 0.24090514860502255, 0.24090514860502255, 0.24090514860502255, 0.24090514860502255, 0.19553019044165004, 0.1947245041567413, 0.2583704946518138, 0.24650616753838417, 0.28602246466856385, 0.3367454992439606, 0.3301121129002272, 0.2533134126421195, 0.22998251246892001, 0.15587326017197475, 0.15753832911025817, 0.1531526238740693, 0.1479004239308375, 0.08998924707770094, 0.06160642046206814, 0.06906201964453744, 0.1953465158725767, 0.42116162601371415, 0.3210456882196084, 0.3041597603492741, 0.24416571340013954, 0.06513579912775823, 0.03821828217751049, 0.047486486016874774, 0.04898864316469793, 0.04898864316469793, 0.03909893649485961, 0.04226281933495696, 0.033368862552656475, 0.03137776852077412, 0.0543348290465674, 0.08223926214717668, 0.09442060720866255, 0.09442060720866255, 0.1428790556558436, 0.08563426366730495, 0.0550410773623965, 0.1441090870909236, 0.42237136544132936, 0.6958794783839078, 0.5909476226466541, 0.5838688714311825, 0.32749231744123847, 0.17540906781595786, 0.11450458645138235, 0.0632684709607758, 0.0632684709607758, 0.03531627054416729, 0.024230447198773337, 0.028526107724441908, 0.03976828435756631, 0.03687574439547101, 0.05129821455760765, 0.036416643191031155, 0.0, 0.03174702937332661, 0.09549372463775684, 0.24435633233749662, 0.6192100491145454, 0.5963234174325327, 0.6209489622562206], [0.3077641267516212, 0.22154950851419594, 0.13114244406851128, 0.12602151620801633, 0.06228658243244556, 0.06632560403398288, 0.06632560403398288, 0.06632560403398288, 0.07616684436963873, 0.338511851083954, 0.752534079304063, 0.8143038943290134, 0.6966242733373128, 0.582350993490862, 0.5093133480065155, 0.4733424513716142, 0.4733424513716142, 0.32038389419539764, 0.2328442170756956, 0.22536352539650648, 0.25747009291589656, 0.25747009291589656, 0.25747009291589656, 0.25747009291589656, 0.25747009291589656, 0.20409013645505397, 0.17693798963219828, 0.2393771961319682, 0.2296290278443057, 0.27639079975585745, 0.349465581444233, 0.34307822495247287, 0.2403333965811095, 0.21233372681139479, 0.14513976714607743, 0.14680649747129604, 0.1426831221576713, 0.16199083052124472, 0.11028057551300902, 0.0796038634407656, 0.05283063441503774, 0.1894659141144361, 0.4309208252572633, 0.3247619244799552, 0.31072245178248087, 0.2438113011582968, 0.05230014270930363, 0.037964360735848454, 0.05101152316307815, 0.055635891725087996, 0.055635891725087996, 0.0471613414138834, 0.06269406020872771, 0.054503497844048156, 0.05004331215145584, 0.03966065543558874, 0.06604866998501698, 0.07358001751076067, 0.07358001751076067, 0.12628864689222183, 0.06190310997900079, 0.03720841221029074, 0.13124357294849542, 0.4060242480538711, 0.678206552087465, 0.5722621379683587, 0.5650378626671997, 0.3062096303403388, 0.1605275331036188, 0.09612867922839906, 0.04512551856815135, 0.04512551856815135, 0.025427922216425432, 0.03004383614240661, 0.035128833033515015, 0.057733372220821276, 0.0557803401922554, 0.06968815496938639, 0.057261905050671524, 0.03174702937332661, 0.0, 0.07809027688096581, 0.23088038171288133, 0.6017452565033243, 0.5783133298378365, 0.603414540403571], [0.35248720918345183, 0.27497260779144084, 0.18629891260829756, 0.17676461160286452, 0.13529677357486758, 0.1384896604791602, 0.1384896604791602, 0.1384896604791602, 0.07583091542543437, 0.27023166690382094, 0.708659728531768, 0.7730960238379136, 0.6517858504721005, 0.5349894745307529, 0.4672528587797978, 0.43238357444457315, 0.43238357444457315, 0.26727375442255796, 0.17238720888421763, 0.28017211246237256, 0.30659181784354056, 0.30659181784354056, 0.30659181784354056, 0.30659181784354056, 0.30659181784354056, 0.1808595359844117, 0.12605960536744737, 0.19406759153828468, 0.1871171572916908, 0.262457902136336, 0.35256138119667246, 0.34623114148455586, 0.22388558155200464, 0.18227301039011728, 0.11993608988396035, 0.11969497454585884, 0.1168031980195455, 0.21384729478669418, 0.1750151188444322, 0.1344804059120147, 0.03302115017945351, 0.1726444943344515, 0.4210750085823413, 0.3157552363987903, 0.33159303202720825, 0.2514628437823818, 0.059871897774798594, 0.10149357671838853, 0.11287495614503706, 0.11936141861409075, 0.11936141861409075, 0.11565460617493442, 0.12794530780883673, 0.11337177674846924, 0.10090255742195314, 0.07123603593740246, 0.0760948167058492, 0.07721054140125866, 0.07721054140125866, 0.08282876539120372, 0.06617736585619015, 0.056341580397228065, 0.07366740693106674, 0.34198722798961306, 0.632989324163947, 0.5247123741230502, 0.5183537537138561, 0.24804598714695927, 0.09904331244126242, 0.08064657416666561, 0.07008836823900255, 0.07008836823900255, 0.0820265392215503, 0.10132925073876488, 0.10832886359991814, 0.127264466245223, 0.1263904602913422, 0.1406600759132342, 0.1199065313402017, 0.09549372463775684, 0.07809027688096581, 0.0, 0.15769852311144483, 0.5603169278005911, 0.5350662583841646, 0.560999439979409], [0.45407008745392863, 0.3925934228378513, 0.3156498529080735, 0.30273057726161673, 0.28331711789317765, 0.2857880261095273, 0.2857880261095273, 0.2857880261095273, 0.20371530334259688, 0.12855608082815365, 0.6405040304214096, 0.7105707832197001, 0.5843646624159514, 0.4671162227111179, 0.42282896505415557, 0.39520411607166556, 0.39520411607166556, 0.20350230025358512, 0.11525809776997382, 0.3993930715943975, 0.4167552619941723, 0.4167552619941723, 0.4167552619941723, 0.4167552619941723, 0.4167552619941723, 0.21555524689597086, 0.14062416515178727, 0.1997652772318075, 0.20329041498679287, 0.2902977512146829, 0.39409789374097143, 0.3887418042785566, 0.2630827211469139, 0.22795682852362747, 0.18713424143628393, 0.18414460023399395, 0.1849692176347529, 0.33591289411720643, 0.3130128841995005, 0.2713342420941985, 0.18481515529306122, 0.22392953971302992, 0.43084741898567, 0.33925102212093966, 0.401913089611859, 0.31621224460748504, 0.2027297372823089, 0.24915296770621478, 0.2566849181642955, 0.2629973437094708, 0.2629973437094708, 0.2620260744687521, 0.2715489086529615, 0.25627874946691775, 0.24306669111008875, 0.21961192704787716, 0.21529707352085597, 0.21220973371093466, 0.21220973371093466, 0.16731292736723258, 0.20696796663675043, 0.20805103364064487, 0.13990245436763085, 0.22502380454566487, 0.5654261040008166, 0.4575927402930008, 0.4547463496689666, 0.18715469594534398, 0.12830050475969876, 0.20005726245395036, 0.21804791674068646, 0.21804791674068646, 0.23339670431898765, 0.25222071896307807, 0.25904132311667394, 0.2734750163535671, 0.2738800476223267, 0.2862196535329916, 0.26404144584308153, 0.24435633233749662, 0.23088038171288133, 0.15769852311144483, 0.0, 0.5096828908343579, 0.48098235864969263, 0.5072575832660858], [0.8689907639766274, 0.7903933335035818, 0.7137660972015376, 0.7079024750129322, 0.6413411109010562, 0.6458793358897882, 0.6458793358897882, 0.6458793358897882, 0.6039998026215969, 0.483890204532685, 0.2012118599876756, 0.2572139888604557, 0.14004690239943252, 0.09141106378658267, 0.10714471197929555, 0.14613280365144735, 0.14613280365144735, 0.5261080942977787, 0.559151092596409, 0.798429820216637, 0.8276399739813997, 0.8276399739813997, 0.8276399739813997, 0.8276399739813997, 0.8276399739813997, 0.6782944955774469, 0.5815619546251679, 0.3835374406548736, 0.395401949645658, 0.7194324719014535, 0.8402378543308249, 0.8349907542640244, 0.6006577768090422, 0.4105839160686198, 0.6154218553142379, 0.614278243849, 0.6172848269755398, 0.7391233638792718, 0.6952244669662615, 0.6684610563266234, 0.5793814143327465, 0.6535387492394813, 0.8698255373328467, 0.8016504439738795, 0.8402248949250051, 0.7343745529546809, 0.5816099968023904, 0.6162037768803502, 0.6455167876680402, 0.6503055788317457, 0.6503055788317457, 0.6398328859925394, 0.6530212865883275, 0.6442634616519807, 0.6355104195484622, 0.5771498009972762, 0.5469582104353012, 0.5374994511814326, 0.5374994511814326, 0.4984812850761988, 0.5475194139251905, 0.5730296861753241, 0.5238125027944578, 0.4158606048347254, 0.12945158735551282, 0.10023005985736676, 0.09514855962420415, 0.35301604189707025, 0.48043415195505373, 0.5176148972681255, 0.5654114720168901, 0.5654114720168901, 0.5900912091105669, 0.6118408109652602, 0.6155170014121948, 0.6472680371592914, 0.6394769899927297, 0.656571721403717, 0.6457659612833275, 0.6192100491145454, 0.6017452565033243, 0.5603169278005911, 0.5096828908343579, 0.0, 0.042335445819131776, 0.01783026031341786], [0.8470447511186211, 0.7691137372331055, 0.6913013879290757, 0.6849006653755787, 0.6193208143411424, 0.6238722574967014, 0.6238722574967014, 0.6238722574967014, 0.5802316048858746, 0.45378670562567963, 0.22087242664495482, 0.27870193963771067, 0.14863981456088043, 0.06850374520878497, 0.08476438114229548, 0.12371378962646112, 0.12371378962646112, 0.4979354095242166, 0.5312755049750321, 0.7769241126558657, 0.8055588730821418, 0.8055588730821418, 0.8055588730821418, 0.8055588730821418, 0.8055588730821418, 0.6532484903689042, 0.5536211279664602, 0.3583285582610495, 0.370997968459855, 0.6929537727228398, 0.8159989641952763, 0.8107147216436799, 0.5797681712931615, 0.38748573377070816, 0.5903306943280335, 0.5891249856793876, 0.5921858654093372, 0.716933114647632, 0.6732869996419317, 0.6456148251110283, 0.554896528782053, 0.6297800651501979, 0.8452245923573063, 0.7762724862578472, 0.8162454389477151, 0.7116213537682862, 0.558262967548841, 0.5938786654926095, 0.6220520594273301, 0.6270022828431949, 0.6270022828431949, 0.6171413123389969, 0.6305783360841242, 0.6215040944256052, 0.6124715383109021, 0.5543920702152342, 0.523815978893307, 0.5140433814446558, 0.5140433814446558, 0.47448321822967326, 0.5240214166926696, 0.5492984570825594, 0.49810104516508047, 0.3846737554744488, 0.13918586299818725, 0.06978243329969566, 0.06301897269441034, 0.3231882772593524, 0.4547227032892619, 0.494061932994163, 0.5422048865653153, 0.5422048865653153, 0.5672962669023149, 0.5891839054982083, 0.5930126927767608, 0.6248363687002283, 0.6172367340972313, 0.634437967122201, 0.6231694242618654, 0.5963234174325327, 0.5783133298378365, 0.5350662583841646, 0.48098235864969263, 0.042335445819131776, 0.0, 0.04254690028373764], [0.8700318178733577, 0.7915260909689966, 0.7153289804946056, 0.7089586970402242, 0.6436222960914766, 0.648151915563546, 0.648151915563546, 0.648151915563546, 0.6052876777744778, 0.4791052330279948, 0.19194330451954647, 0.25459362861251944, 0.1317412546744354, 0.0843613309038195, 0.11168317695905554, 0.15090320549929917, 0.15090320549929917, 0.5215778258986571, 0.556394376888385, 0.7999378910571688, 0.8287958566963831, 0.8287958566963831, 0.8287958566963831, 0.8287958566963831, 0.8287958566963831, 0.6770652417870567, 0.5802997028153127, 0.3846654876849341, 0.3974306888320142, 0.7176877965202969, 0.8390252191330441, 0.8338414755907902, 0.5987547381419839, 0.4134256328996526, 0.6144148870993619, 0.6132240873662294, 0.6163155169550856, 0.7401905565374338, 0.6970267589954601, 0.6698776493121726, 0.5804706652999057, 0.6521770830317652, 0.867523941359117, 0.7999198994294822, 0.8397588559816291, 0.7332202831778052, 0.5824756003169207, 0.6177534560287548, 0.6470269835554707, 0.6518779086137505, 0.6518779086137505, 0.6414308878409952, 0.6546449814981816, 0.6457072541137894, 0.6367773577179682, 0.5787088521058268, 0.5490463282839312, 0.5395658813032329, 0.5395658813032329, 0.49975517602957625, 0.5491630857164591, 0.5746171239019165, 0.523920993264178, 0.40840275752732824, 0.11654484567860102, 0.08872475182105477, 0.08495491998611111, 0.3506485698871953, 0.48103978316285845, 0.5196441363806515, 0.5673604541197139, 0.5673604541197139, 0.5919499674794063, 0.6139255183717205, 0.6176783207039712, 0.6491789901455025, 0.6415826323343701, 0.6585518096779456, 0.6475112244193647, 0.6209489622562206, 0.603414540403571, 0.560999439979409, 0.5072575832660858, 0.01783026031341786, 0.04254690028373764, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('ec983fbc-a435-4ae6-9be0-31556679d546');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


We now change metric and compute the “:math:`2`-Wasserstein distances”
between the diagrams. This one takes longer to compute!

.. code:: ipython3

    p_W = 2
    PD = PairwiseDistance(
        metric='wasserstein', metric_params={'p': p_W, 'delta': 0.1}, order=None)
    
    X_distance_W = PD.fit_transform(X_diagrams)

And again this is what distances in homology dimension 0 look like:

.. code:: ipython3

    plot_heatmap(X_distance_W[:, :, 0], colorscale='blues')



.. raw:: html

    <div>
    
    
                <div id="a022cb5a-e2f1-491f-85f3-5ddf0153241a" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("a022cb5a-e2f1-491f-85f3-5ddf0153241a")) {
                        Plotly.newPlot(
                            'a022cb5a-e2f1-491f-85f3-5ddf0153241a',
                            [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 0.27621428444099705, 0.3393134921539063, 0.48003825542469036, 0.918005674740128, 1.5233125765988085, 2.2491004794186096, 2.8261938549430607, 3.2690471324841135, 3.713551558737496, 3.979598656684212, 4.113645466919309, 4.002061212453019, 3.7613494899751507, 3.3777661576604783, 2.9284054940515998, 2.5396864232260135, 1.8117593449286455, 1.4697610803836554, 1.0878465757004085, 0.9912067039046879, 0.9972918384784409, 0.9641918653595736, 1.4836212931365018, 2.0292974689371137, 2.67788127115386, 2.825880881501527, 2.9909864501597423, 2.985793683323434, 2.773037952679207, 2.6868731030933293, 2.3457889364586597, 2.4024514431207513, 2.388605394717459, 2.1822991341023195, 2.0156388440307467, 1.9948792479653936, 1.5246631029209747, 0.8311361018114054, 0.8772340016200573, 1.2726794405917041, 1.3741019364140319, 1.3306470164760673, 1.4205472869490268, 1.4315131263885015, 1.4387313601240368, 1.626525970463199, 1.746123240461156, 1.7822387854631108, 2.1022848587794045, 2.537949110750084, 2.4637552130148794, 2.4610077873162295, 2.5450133792109066, 2.400923374518256, 2.319576307244267, 2.1673280131177224, 2.0578341321973737, 2.011752210952067, 2.317101697057616, 2.353506328163939, 2.5592603679416697, 2.8506499721974743, 3.0376011503093734, 3.166598218018536, 3.0224147264908985, 2.8162727194120247, 2.3717342384108555, 2.0218008226539292, 1.6948729865826082, 1.2516316100536804, 0.9726047120408605, 0.8239840736747184, 0.7189276193345437, 0.6608160693275352, 0.595910896082258, 0.6038803460868483, 0.601047669315482, 0.8748761976430749, 1.176911474761994, 1.449754821858176, 1.6927585093245323, 1.9497727680826973, 2.5644238477495507, 2.7765839382942827, 3.039185362284893], [0.2757731864030563, 0.0, 0.3107664999687531, 0.5229430897746342, 0.9719942483832557, 1.606862098041558, 2.3045677474544255, 2.865047779817959, 3.306389291669779, 3.7410524116401556, 3.9906857749603173, 4.128005350933243, 4.012144166962616, 3.7701156417047934, 3.3871197845423926, 2.944217687215536, 2.55147668209288, 1.8388772268233087, 1.487625767783012, 1.0606117118853338, 0.9636071609359232, 0.9769134107896863, 0.957593258641694, 1.5567058224594905, 2.1037296697924246, 2.735934077499912, 2.873954674539245, 3.0206834063941175, 3.0196792356286957, 2.825938366529951, 2.753375866692147, 2.415874631452928, 2.4384380431375963, 2.419587826587178, 2.230382730433679, 2.071916951056108, 2.0509986146368884, 1.5857917995665878, 0.8581316027141052, 0.9110916216740761, 1.2891857425236473, 1.3884093101402155, 1.3834240513691989, 1.4569950069904325, 1.4777877052007842, 1.4756081612398408, 1.6596049726942916, 1.7918801366587238, 1.8481008023049237, 2.1734459764115384, 2.5908598177826008, 2.531243220215872, 2.5301190354637444, 2.6045091762918773, 2.468498979077153, 2.3919784725289635, 2.2430786951440633, 2.131423005087301, 2.0863643604009607, 2.3805402866057306, 2.4155379576045983, 2.6181350182242262, 2.8895648322068963, 3.0603797634923597, 3.1676335020548936, 3.022958538836431, 2.823712233934083, 2.3938991332052573, 2.0546670578338335, 1.7225327485276407, 1.248318423315875, 0.9401231551086358, 0.7601647758922493, 0.6160980422218421, 0.5491313276708852, 0.4932444876887046, 0.5380810096536081, 0.5390398940766009, 0.8410050213114769, 1.1730077490005544, 1.4393223097043262, 1.6901437156596089, 1.9627589271245887, 2.5695044970858145, 2.788110028538195, 3.043882797498961], [0.3396422112722862, 0.3102502850844223, 0.0, 0.3407892114827992, 0.824220691901224, 1.4865393960778428, 2.205558274684321, 2.7459951001592744, 3.1827521119357143, 3.6180816748494005, 3.8668914535904646, 4.007924894164875, 3.8855541841008665, 3.6390753593948713, 3.2484852315971184, 2.792780661661988, 2.3862507574896763, 1.6701534930586615, 1.3038230350338902, 0.8910259925598872, 0.8132932310548562, 0.8429758883069948, 0.8218282645444576, 1.4072040791107006, 1.9785710496824205, 2.6068483783882885, 2.7463913512726696, 2.8798017875082356, 2.867112761986262, 2.7005622676081713, 2.631493330458701, 2.3002949856552766, 2.293130167289073, 2.2319028537921715, 2.054394916238424, 1.9048836883171358, 1.886735032373711, 1.4347629823588386, 0.6511505489013387, 0.702998431450051, 1.0839606168365596, 1.2038935657372194, 1.201421352384668, 1.2796925094944709, 1.311343293620448, 1.3079724720147001, 1.471553984016156, 1.6022967081623656, 1.6696817858307307, 1.988932422181484, 2.4101210492612286, 2.3455066633937967, 2.346090904009852, 2.4323753823453447, 2.306753527080776, 2.233605167108937, 2.07724868458147, 1.9607714674243668, 1.9141703084085866, 2.2058238017934646, 2.2402781284834736, 2.4222851667560317, 2.6958653590481347, 2.8598584548871697, 2.9587039503785655, 2.8169873247609494, 2.6186117550287604, 2.196335173266957, 1.8533626628931632, 1.507288980387103, 1.0679883635388603, 0.7744596834164148, 0.6317029227668515, 0.52214320396098, 0.5083341706736472, 0.46487718358724084, 0.4368652829935847, 0.42308353288968437, 0.671940681884967, 0.9801799064934179, 1.2474426153209364, 1.4946522499305501, 1.763006864030077, 2.3523573948464995, 2.590936764757828, 2.8441172842020435], [0.4802312529126392, 0.5219126624977357, 0.34077338742216884, 0.0, 0.5799175102457357, 1.2791965744630729, 2.0418716353116384, 2.6133205920419327, 3.051531214386922, 3.495342479044492, 3.7398616958207525, 3.8820761155184855, 3.760644480527614, 3.522724315246985, 3.1131551650175977, 2.639536597943966, 2.2009398801758744, 1.457243614737426, 1.1284995405022265, 0.8233499631218487, 0.7469752528732256, 0.7615745558310177, 0.7208186424564179, 1.1994393835362762, 1.777224238793679, 2.4316543205445855, 2.573555409232128, 2.727059824029418, 2.715478786641237, 2.532704332186915, 2.4747560228328735, 2.1300486319537146, 2.1038457553546595, 2.0413881635225213, 1.8576385689620027, 1.6965793185247562, 1.6664798147339812, 1.2210846635049675, 0.5025804244935349, 0.5180264611245724, 0.8782994147931918, 1.0030646015225886, 1.0196046961527534, 1.089824146540766, 1.1117195743819488, 1.0962880161107649, 1.2727881321280856, 1.402883576379071, 1.4672325081070157, 1.7734379829163234, 2.2047952896260745, 2.1425085574784384, 2.1422536472502967, 2.2292105318112143, 2.098947568318935, 2.0192260004205647, 1.8562183880864465, 1.7351502168669442, 1.679486834698895, 1.9906338549308789, 2.025990476434593, 2.2158842890657477, 2.5040700577901713, 2.681868466551996, 2.7944870969516837, 2.6445910690708234, 2.437256040002414, 2.00179760320815, 1.6453111822806528, 1.3162881015149264, 0.9268091077796875, 0.6855382749328449, 0.6263319374036163, 0.6246775844757677, 0.6449187796857817, 0.6090430196066187, 0.49334554088070237, 0.4787722221838922, 0.6386867520391113, 0.8524672980641457, 1.1082973201230892, 1.3460335832303185, 1.5915412705765843, 2.169586363853833, 2.390625800576678, 2.669706093869053], [0.9196401614421965, 0.9721233539012436, 0.8251642737017001, 0.5782697001760347, 0.0, 0.853859280519408, 1.7035142627894497, 2.3391685130067565, 2.7932311512433277, 3.2487157820275354, 3.4900953820672402, 3.63528488033549, 3.5085876165325995, 3.2591409644398466, 2.8197091428553276, 2.3060754299095216, 1.8170120617280634, 1.09310494371809, 0.8265127792601892, 0.8331766457908056, 0.8009941003432848, 0.7604514943253277, 0.6847309578626359, 0.8501343750310081, 1.4035635618970526, 2.109438219572891, 2.2567395228588683, 2.403643769201679, 2.3897447318487366, 2.244846780227595, 2.1898203565934877, 1.7987606367730449, 1.7380755652862487, 1.6675257784166713, 1.5059831385907072, 1.320076736520266, 1.2626261092801143, 0.8086032512356824, 0.5637108582011853, 0.5581813467085067, 0.6527486917146033, 0.7796822036858435, 0.8684683619865887, 0.8860029361906928, 0.865282018900338, 0.8220624995235986, 0.9370689383710064, 1.0842283725526718, 1.144357641915112, 1.4425408109348201, 1.872690710188051, 1.8090056087483557, 1.7967132015329506, 1.8833566139354114, 1.7405148927555152, 1.639005225035311, 1.456916336204058, 1.3258837962966323, 1.2650433956172935, 1.610163379900257, 1.6575124694241794, 1.8602919398064215, 2.1640602363808976, 2.350420890478362, 2.4640430162683864, 2.312323029325963, 2.098381705490273, 1.6384432063467698, 1.2648966037137206, 1.037599520223185, 0.7542408486115914, 0.6349257136913141, 0.8098518253666479, 0.945621080169206, 0.9952631578850756, 0.9871595357243147, 0.8460460820139227, 0.8242113938420431, 0.8227439397802917, 0.7565300805003911, 0.9264612209205382, 1.0782230644088804, 1.2879829665127345, 1.8103474206375274, 2.0227604140045194, 2.3052394089562287], [1.5230336662044142, 1.6042513353064898, 1.4839438114160193, 1.2773825670908248, 0.854225052158397, 0.0, 1.1092640935325613, 1.8824974982345841, 2.404324597232011, 2.9137819232015674, 3.1746630957820305, 3.3232835880726443, 3.1906662374991135, 2.9201400584715747, 2.4246963679779503, 1.812933529399683, 1.3139607345503899, 0.901890603573328, 0.978834677649776, 1.3055862291972316, 1.2920259908232297, 1.2217819725887165, 1.1046826169121426, 0.6864598233503284, 0.8834564778832695, 1.5255723220188884, 1.7110136767493906, 1.9096349778875457, 1.8984018020466593, 1.706106690824525, 1.6402469919649916, 1.204147079240356, 1.1847163453445961, 1.3149283977185804, 1.1680449431105826, 0.9355993134122487, 0.8726096102884403, 0.647540431463648, 1.1052656620473436, 1.0997269969314694, 1.0051850428621076, 1.010902833357546, 1.1201345128084794, 1.038967617725542, 0.9490189162223781, 0.8721814581916085, 0.8555695409617073, 0.8851665287839665, 0.8244971914300653, 1.0566103798910764, 1.5066019515055609, 1.4126113746391917, 1.3858945296457965, 1.448875647208262, 1.28152141910328, 1.1395050501315827, 0.932083244005932, 0.8329250748852223, 0.8167371778620588, 1.1342393725555173, 1.191756178899094, 1.436924462617405, 1.8048384722869886, 2.0316205616890946, 2.1612945120583866, 2.0082621628128683, 1.7895536502167364, 1.3291762381998893, 1.062747778425903, 1.0232220123392064, 0.9332635430417048, 1.150293040030712, 1.494408650772409, 1.6418469278584409, 1.6712431094578601, 1.679084084133603, 1.5094943356405763, 1.4651840646384124, 1.3812119218231944, 1.1957752201787757, 1.2340981757905793, 1.1591253606752028, 1.1798849416647108, 1.5304026618282178, 1.6887948949114866, 1.9726068413910502], [2.249951942922434, 2.3079027979838473, 2.207443255539837, 2.047228087853172, 1.706514821482426, 1.1087492819538165, 0.0, 1.1422058124598284, 1.8144017006300115, 2.4496887115079917, 2.750053948253171, 2.918728386282293, 2.764633402605033, 2.458837405028171, 1.8512414781729696, 1.2148246228005912, 1.0190741905116296, 1.276965161839998, 1.5696445775237198, 1.924802357255379, 1.9340649456299461, 1.882493760665744, 1.7997027574288886, 1.186455566178099, 0.7437252639596392, 0.9321409867948667, 0.9876994402024658, 1.1934170339267542, 1.2050591133801316, 0.9732986001283026, 0.9171588949985865, 0.6450561394165966, 0.7926639254860839, 1.186804873966055, 1.1318768641105452, 1.0250729411825505, 1.0202809865440337, 1.2388181173808808, 1.788986569051012, 1.7719775461336578, 1.6200838885793933, 1.589639910626096, 1.6842973245757122, 1.581327369718124, 1.4814076571769743, 1.4022490056482892, 1.2725562440209632, 1.1879659445584316, 1.0270904849479885, 1.0332835642297495, 1.2682361620918388, 1.1725566725763945, 1.1248890204901387, 1.1212232703243474, 0.9479403960864429, 0.8985537797561491, 0.9270409467728609, 0.9285911238972142, 0.9187491298638227, 0.9320388391955517, 0.9695088435553109, 1.1597473677432473, 1.472238358676942, 1.7513083366906788, 1.910939536783234, 1.7679546610669388, 1.6352533647480163, 1.358049561464143, 1.2764397189874706, 1.407307708640517, 1.54083413276252, 1.8510361741239343, 2.1522111264473875, 2.2795866632456083, 2.3098715018770024, 2.3451496522220117, 2.1817982986726276, 2.138406020683678, 1.9782454082627243, 1.762125396244514, 1.7482170771112808, 1.6209782470025778, 1.4713753222680952, 1.4649102193778978, 1.4918144021839013, 1.7185313768071944], [2.82357426557743, 2.8625117217876253, 2.742633753116979, 2.60649262559676, 2.339459779724819, 1.8821812857248545, 1.1408688576076806, 0.0, 1.0384918278986557, 1.869718116696585, 2.2577450983581144, 2.4571453165251476, 2.2680493483583706, 1.8856161347604847, 1.2123802957502654, 0.9789166580683527, 1.3294904922085111, 1.8456198014439074, 2.110982187153429, 2.393734483340147, 2.4101380393902088, 2.381121451470389, 2.327042038655131, 1.8543703764170583, 1.3757289046089718, 0.7714829483865286, 0.7184928339123645, 0.717285921124123, 0.6990275037403947, 0.5885448837298551, 0.6336999804517667, 1.0312746787887523, 1.1203928203402065, 1.4462869246286552, 1.460314309024272, 1.514578565699517, 1.5477908512226726, 1.8169886665682329, 2.3532998710985473, 2.3312422846234377, 2.1513278926586366, 2.0997445892045725, 2.1887264719624633, 2.076279711344798, 2.0024169730580597, 1.9445918442893957, 1.808593783711622, 1.6691515921669913, 1.5366279778187868, 1.349317232464772, 1.3443972742562906, 1.2735853036866487, 1.2371453116884843, 1.1754387421278683, 1.2119029396718357, 1.270260461447058, 1.354781502188242, 1.3996759049749037, 1.4182612584099084, 1.2524587531516833, 1.2036945426695846, 1.1844043544568796, 1.397287006791462, 1.652775210126563, 1.8351521845460987, 1.7552563784513024, 1.7218078961951115, 1.5889475549190974, 1.6612456405316027, 1.873200233567761, 2.088510293684895, 2.3879440945454045, 2.657047913181566, 2.7830389305617693, 2.8446221338658435, 2.8733836528924668, 2.7331577144670613, 2.6873149701273484, 2.4968635249554127, 2.243286814996164, 2.158687879579381, 2.03159112170569, 1.872270179366549, 1.6937946667829193, 1.5664178219546776, 1.644588408996484], [3.2656969035594714, 3.296577958294338, 3.1811090059088794, 3.047976632821415, 2.79239285940647, 2.4063354479587207, 1.8144268137929973, 1.0383602417971067, 0.0, 1.1284004353748442, 1.6701324217277824, 1.924286467061809, 1.6750335445997204, 1.1895758942550774, 0.8173649764342984, 1.2897088533642647, 1.7847263698881455, 2.254020708382197, 2.4918424152750034, 2.7801350959644826, 2.8070079731738, 2.7902545483295187, 2.7529744497540993, 2.348815826792472, 1.9870792457893163, 1.2580380386539158, 1.0453125107809835, 0.9113161992498922, 0.9054749487048179, 1.144487439525254, 1.2999677692251634, 1.7437222988407397, 1.6351716520067363, 1.7652381175776826, 1.8493039277583647, 1.9617688608536952, 1.9846052770194689, 2.335729557777128, 2.8025559156502857, 2.777608907754339, 2.569687626416342, 2.50499315628232, 2.5746029986352386, 2.4746518617783324, 2.4162522995875872, 2.3816210079624587, 2.2313719923130577, 2.1099909793090124, 2.0894560357286522, 1.8462235107268121, 1.585908297714513, 1.5746023192879912, 1.5837015524954088, 1.5288617809162697, 1.6082520218791276, 1.7166376297446682, 1.8670067040139637, 1.9354960833411776, 1.9648144676528894, 1.703424317045296, 1.6601946056031118, 1.4958758272178996, 1.4671339497420266, 1.6435528973560194, 1.821825991798633, 1.7832015516784716, 1.818432374470005, 1.8699550837729375, 2.0224165007609427, 2.2370699988981286, 2.515683236465429, 2.8219013505596284, 3.079056805265691, 3.2152534168287144, 3.27513757790212, 3.299384768752561, 3.1772948612934457, 3.136738892935969, 2.9458287765334417, 2.6938302916041175, 2.548306948553055, 2.360081693833965, 2.1741762750771634, 1.954807991002278, 1.759144060497392, 1.691167123438508], [3.712305736047025, 3.7378438791693034, 3.616339778639247, 3.4916115953261104, 3.249481112901062, 2.9126258238028777, 2.4489502895998405, 1.8698086315045503, 1.127927641459032, 0.0, 0.8679132783276038, 1.1327186781216492, 0.8554337807149285, 0.6000659978099088, 1.1572892968175335, 1.8287806383885787, 2.2131770358983074, 2.64699666827637, 2.8809424586029766, 3.1959869102361163, 3.252493128017761, 3.2409981176664004, 3.208950943317006, 2.854137965141872, 2.5690884624138297, 1.9629729059587515, 1.7739971421482057, 1.5788025826803098, 1.5883372516533143, 1.8791381092243729, 2.0420939012235717, 2.3741569184067317, 2.2420034558688315, 2.23321316669953, 2.3838197565537125, 2.481483294796057, 2.4838797616577053, 2.8560664870998362, 3.259709014147585, 3.236511111648271, 3.0078441512729426, 2.93712122526284, 2.987108111488914, 2.8993922257288243, 2.8823534215798534, 2.8560120968538314, 2.7103586759557645, 2.6390952787253914, 2.638113375715983, 2.438974540214837, 2.1389675103957, 2.218024314255578, 2.1909727008650997, 2.1238672126578657, 2.237041918033664, 2.309998045203937, 2.410854810374499, 2.4554648977227798, 2.4818116838956534, 2.253794269944371, 2.2319479298249636, 2.071924179832598, 1.832361935666631, 1.7502328454866025, 1.8773783072187433, 1.9018316691466484, 2.0453131648743033, 2.2200202330423084, 2.43392960471972, 2.6624031484096324, 2.9988871435379956, 3.273867329876463, 3.512141714894072, 3.651939450680037, 3.69690679420956, 3.734788333731397, 3.6146084876216547, 3.5796351572422997, 3.405270466000478, 3.168529233776958, 3.000286970021998, 2.7508335116027696, 2.5108800970034935, 2.2317492446436002, 2.0303352107391963, 1.8660742181643306], [3.977352284725857, 3.989417193194092, 3.866585782916937, 3.7378019333309513, 3.489253230504, 3.172651652404343, 2.752707390820352, 2.2562511048945586, 1.6648776389172668, 0.8695029855188415, 0.0, 0.41641608627683185, 0.20884042712849224, 0.6286705037569726, 1.3989691318787372, 2.0243010721298473, 2.3753962736464, 2.9038206024827535, 3.1409348858515758, 3.4879094783180347, 3.5451150763754913, 3.5403206945171317, 3.505302506879489, 3.1774953380397757, 2.92376860134387, 2.37454931066578, 2.1766182612522678, 1.9208307592807279, 1.9340360941095327, 2.2977630664952597, 2.4714235650427416, 2.7393470089983247, 2.548738156730464, 2.4816116830554926, 2.6874097972896958, 2.77970182787735, 2.7803631072121657, 3.144894380593688, 3.5138344700067288, 3.489822665033459, 3.255761684633401, 3.206874606851837, 3.292870258059191, 3.2112686659743677, 3.1962277211790235, 3.147720175172458, 2.9765270207756775, 2.918296495420094, 2.920492890367835, 2.73851725308754, 2.4698985755394567, 2.535015957724237, 2.5190952238241264, 2.4621882556334898, 2.5610759003821792, 2.6094555167190294, 2.6904898487041446, 2.7295998597922813, 2.7527521646620987, 2.534682003023293, 2.523835809026898, 2.389722826578663, 2.151716718220956, 1.9935530367805356, 1.8943201833633747, 1.9880769025381846, 2.138973389278842, 2.4379018170169657, 2.6988836019194253, 2.920240675439976, 3.247137758877675, 3.5117694117025033, 3.7476179908414857, 3.869896280451124, 3.9268406716913664, 3.9625602771672717, 3.8529156905317263, 3.816795927541854, 3.646462725929884, 3.4192379335131227, 3.259785480923977, 3.01944889137933, 2.7797898069550264, 2.3166226022573606, 2.1271123044931106, 1.9263972706858838], [4.123495278523218, 4.137995846045856, 4.012654912674879, 3.8785147564497784, 3.631102703679855, 3.318147258508553, 2.9164317331027796, 2.4526581838624306, 1.9300567939684343, 1.132832858745954, 0.4165786341437147, 0.0, 0.4281843660335226, 0.9680106707400468, 1.687505581991589, 2.2341151821407252, 2.555090905620622, 3.0751492434698635, 3.3029765551931805, 3.639199613904554, 3.6970548273614567, 3.6881833598634906, 3.6556473995111216, 3.3373450446225816, 3.0971728445352404, 2.5817613673756203, 2.400997990103264, 2.148982381423915, 2.1568175655318047, 2.4995155669744276, 2.6525142976580884, 2.9083636236262786, 2.716132617423602, 2.642959584507102, 2.847541195895123, 2.937402921723837, 2.942108671398196, 3.2911454652044414, 3.6592404634077327, 3.634924390808307, 3.402007521337874, 3.349120870219996, 3.435597883728218, 3.3540847578291166, 3.3424650826205666, 3.2955657668976697, 3.1298060568849166, 3.072335549807823, 3.0753568907845166, 2.8932912218743434, 2.632852517707548, 2.695322338579834, 2.6835783124540447, 2.6278119603790704, 2.7248330258721314, 2.7804280069096343, 2.8563386088037777, 2.8957496947888965, 2.9181214447706703, 2.7024257409934664, 2.690006511372352, 2.5613957459440524, 2.3300798889390473, 2.167186200831373, 2.044300357128882, 2.1431069400302984, 2.293642527295657, 2.60244117327665, 2.858274942791032, 3.0768527400449397, 3.399983749323992, 3.663042435219431, 3.890813285065445, 4.009560830919527, 4.058855728224395, 4.087159847519701, 3.9808024380611253, 3.9567491403317328, 3.786209885212096, 3.564196034787262, 3.408696533041953, 3.1736834254987936, 2.945223614760798, 2.4719471467341494, 2.289945809990924, 2.0946361743148154], [3.997291190708784, 4.010668979545676, 3.88968531832604, 3.758030499668507, 3.507426757391628, 3.190092107074384, 2.7681929412056765, 2.2690260641036297, 1.6724533026695534, 0.8570854585599077, 0.2088187242411318, 0.42823873093607534, 0.0, 0.6889807564983007, 1.477915401339714, 2.072423007224757, 2.4169068704505063, 2.9255304668207245, 3.165217150259236, 3.514574608771865, 3.5699404751744006, 3.5601432564733515, 3.5256859985523556, 3.1993954717268194, 2.9414450793757063, 2.3959788185225093, 2.2002665285621807, 1.9521711438960971, 1.9581997710287042, 2.324104461955297, 2.4925702816254156, 2.766310976171936, 2.570534492587839, 2.5015440715204083, 2.70908567047264, 2.796198678370415, 2.8012486655760642, 3.1604691160034006, 3.5339915161030717, 3.5088439516208867, 3.275010040266836, 3.2264262056988517, 3.3194808066288273, 3.2308887210485486, 3.2152961977169587, 3.1682725253619077, 2.9933723476972065, 2.93577889737779, 2.937735552601416, 2.7517333642047483, 2.476030292268449, 2.5447595739709117, 2.5314284418952435, 2.4765438610279715, 2.5730758814697787, 2.61891930650996, 2.7035524521618663, 2.7436878242771465, 2.762393723479021, 2.54663648401731, 2.534849147189998, 2.4012540807254372, 2.1613306700956056, 2.0215941030451994, 1.9469516773193993, 2.0307880010488732, 2.177470966408541, 2.4579016508226563, 2.709536394624762, 2.9366369067217413, 3.27016585502348, 3.5358203832563446, 3.776208728436096, 3.897299800084079, 3.9505965254681903, 3.9765812707114887, 3.8668286255344557, 3.8395407600615346, 3.670187348408531, 3.4428478548878423, 3.2837456389853203, 3.041569119705387, 2.8066076524145007, 2.364939458305284, 2.171138853195108, 1.9740024414383865], [3.758622643080386, 3.76697750855527, 3.637320263547416, 3.5164945761075073, 3.2575315030352145, 2.9218849743650246, 2.4584565039220547, 1.8872783497170431, 1.1889272979365149, 0.6000498644325089, 0.6286125617172232, 0.9674006520831591, 0.6892763139070837, 0.0, 0.9531177154510675, 1.6948637371684692, 2.107509293350213, 2.6462224523316027, 2.887516753564002, 3.2407050500766306, 3.297473989875508, 3.2821686353395503, 3.2502591383677437, 2.9033167542105915, 2.6150252379493604, 1.9950784559099284, 1.7824539445895853, 1.516854992319524, 1.5355191849301235, 1.9343104104415212, 2.1355279095684208, 2.444979038069557, 2.2449448597929393, 2.194732873697518, 2.398108595681517, 2.4990127119661514, 2.5048766553262998, 2.8901475665483654, 3.2799230783830207, 3.2552854612088544, 3.0132137207515424, 2.9610965615867766, 3.061027344459332, 2.9670749216644006, 2.9504074373247113, 2.8950755629526235, 2.7095838913731614, 2.649795071897264, 2.6529538813230897, 2.4537439937743097, 2.1643573753028553, 2.2251651543361253, 2.2122045079855583, 2.145252249616174, 2.2546241894229824, 2.3104081009342106, 2.3985269323272034, 2.445584988609607, 2.464056104400816, 2.2305123439080305, 2.214844265481121, 2.074752820463884, 1.861661136389228, 1.7691698665308873, 1.7437529414250197, 1.8043345632577683, 1.9372929777665535, 2.1882174984310336, 2.4256090070658547, 2.6476375938449275, 2.9897433661029504, 3.2608178822917266, 3.504365259082977, 3.6472791880368263, 3.7000983432124435, 3.735343592654096, 3.619392184155719, 3.590882400547406, 3.4143685899232152, 3.1739447329855905, 3.0078482095158696, 2.7683404116447057, 2.5298230064167333, 2.100495688924827, 1.9033949815051034, 1.7343797572597064], [3.378304878550556, 3.3864546421120383, 3.2427110061101914, 3.108110557690065, 2.821605967850207, 2.42244880129479, 1.8511299772157144, 1.2116917716278293, 0.8159715790204636, 1.1582466043709863, 1.398740440066504, 1.6861366392747228, 1.4744159453442192, 0.9530590806300402, 0.0, 0.9581909392006155, 1.537091498281153, 2.1838157914165004, 2.4580466625264044, 2.837688565542557, 2.8895174856328416, 2.866943394389604, 2.828503709451315, 2.415425016932629, 2.071762864873502, 1.3036087556245712, 1.08256251470105, 0.8410909178918103, 0.8516498212163693, 1.274769118176942, 1.491663564938182, 1.8535891826737996, 1.6659093318053626, 1.7009583459557813, 1.896828431600013, 1.9753787167180628, 1.9819791065164085, 2.3958484622378364, 2.8458674470386582, 2.8211508663688143, 2.5694171364261007, 2.520278037640129, 2.641654822453238, 2.529640807535289, 2.4989418982657, 2.4305017427747884, 2.227991094215122, 2.1405313602943834, 2.1196539500877765, 1.8990424732977316, 1.6711368337012065, 1.6898796448921825, 1.6623028974691683, 1.5936209284773983, 1.6654822129202214, 1.706106782652143, 1.8107937834994934, 1.8763774776827613, 1.9005449977105413, 1.6421805086972165, 1.629985159588143, 1.5317371687703991, 1.4593221935632041, 1.4657640072473415, 1.4574154013682612, 1.474302863055791, 1.5228930227263129, 1.7164605418723151, 1.9495513177742336, 2.190135007644523, 2.5250607471374504, 2.832693499033105, 3.102572628674839, 3.246285761756489, 3.3104998003599233, 3.3499191824559986, 3.227310858667694, 3.19087136165258, 2.995380007104806, 2.7418209884248874, 2.5895339782915427, 2.3515657931537723, 2.103225336635149, 1.64830500154424, 1.4409451620709572, 1.3581862920948586], [2.9292952245009785, 2.944178646815482, 2.7890827958102804, 2.6375459808919874, 2.3052528581493497, 1.8120456505540976, 1.215118855514672, 0.9804536219570897, 1.2902729296700362, 1.8253087048039722, 2.0250221703520936, 2.2356292376892126, 2.073792331290818, 1.6913091111876213, 0.9564605808802854, 0.0, 0.7935328947146773, 1.6182799066864402, 1.9585633138631129, 2.3955366539746596, 2.450492833967668, 2.421528562337226, 2.3596721637677294, 1.8592798264463544, 1.3986848984096347, 0.7946880873121586, 0.7323125710079974, 0.6094192484186741, 0.5889320278386454, 0.8793092774326179, 1.0585049436840777, 1.2574103039811135, 1.123907277294195, 1.2620504771094208, 1.4503024103167945, 1.446771549886691, 1.4264950937399, 1.8457501200527746, 2.366012751747358, 2.332889187284743, 2.0682229921363837, 2.022045075526, 2.1638564755240646, 2.0443244740780706, 2.0071871182054646, 1.9179392850120098, 1.7014847032849534, 1.6096092778420992, 1.5470844450508296, 1.3752813499060854, 1.3245732523616889, 1.318313739426403, 1.2803101489555768, 1.2570311497719526, 1.2339932438489483, 1.2087537773895467, 1.219280519380927, 1.2340340542898376, 1.2358947238304505, 1.0946319555198472, 1.118208507621258, 1.158215034221343, 1.2362682069591182, 1.3018563907861416, 1.3046329213048193, 1.2561354919766303, 1.2149501469357615, 1.2340569494238838, 1.4006281474873847, 1.68100768993468, 2.0338071041549886, 2.3585897692508175, 2.658001751070285, 2.80389810769212, 2.868798925345113, 2.9096436672999366, 2.7701150967000396, 2.732142976361351, 2.543588231184796, 2.2872524927291886, 2.158049867150682, 1.9020486480971475, 1.632405023061279, 1.1323590702649622, 0.9937261310209737, 1.1157909891720212], [2.531861336842859, 2.546939801865491, 2.3823664496545707, 2.2020584474387697, 1.8205328162216468, 1.3139665402227623, 1.0208161952572534, 1.329899296239065, 1.7833273487409012, 2.2147955054810775, 2.3746686869885334, 2.554214904778292, 2.416304743766203, 2.105475635876063, 1.5378831746168022, 0.7941206796163589, 0.0, 1.0334166608759725, 1.4220306342953863, 1.9646432767102648, 2.023627847079647, 1.9780561536717207, 1.9077484815237793, 1.348745354258338, 1.0469389915434602, 1.0423552511022383, 1.0756517401565917, 1.0498096701939748, 1.0250887288175987, 1.1631049305368064, 1.2693045926039388, 1.0851560914295308, 0.8104506974743975, 0.9326793763552897, 1.1007778908882029, 1.053949862383945, 1.0257949020711457, 1.3947601595618266, 1.9141969232594227, 1.883170299904919, 1.6035408539841869, 1.567745043472664, 1.728564780884539, 1.612631806166819, 1.5727775683705565, 1.4657750592533563, 1.2209023264994914, 1.1728931711553952, 1.163203403029408, 1.1400928450940921, 1.236703557050651, 1.2343827185112994, 1.2020430847294468, 1.2183203353245977, 1.1528328913185784, 1.089570665740033, 1.0324567739311543, 0.9677866785564083, 0.9477316800738138, 0.9462722717354117, 0.9939694463167139, 1.078770487015418, 1.2207176157027315, 1.2803708717962372, 1.2531690010210779, 1.1584046207708798, 1.0235577658310717, 0.9171814143568133, 0.9954868925862236, 1.185258158425577, 1.5488827524749098, 1.8994616772707569, 2.2323863864530504, 2.399461742188283, 2.46553136060933, 2.5067485126403097, 2.3590901458608498, 2.3197311822740883, 2.131662035217895, 1.8520939770963534, 1.7179253027534374, 1.4280122802651336, 1.1473566248511584, 0.711671136079932, 0.8037559388100601, 1.054828315353659], [1.8124378784139406, 1.8401024032619901, 1.6717194929848058, 1.4578297345078746, 1.09241208112673, 0.8998025570959505, 1.2769350540657232, 1.851498141746496, 2.255050856010826, 2.646014225011666, 2.9125207714943397, 3.0768092757038388, 2.932431987230558, 2.656954479763812, 2.179658644294423, 1.6184791367482405, 1.0317900668376976, 0.0, 0.5424298831549036, 1.2037945587067145, 1.237851685102783, 1.1776587532120508, 1.0986702438155713, 0.7014626114888916, 1.0003920189263162, 1.5199222460608288, 1.628228242084787, 1.7324559482784099, 1.7151043620540831, 1.5980466750948612, 1.6284752543103804, 1.2503593586753081, 0.9765247998111255, 0.9562287832482239, 0.843115431342151, 0.7011773950634608, 0.6524340222807794, 0.8025353753032807, 1.1969180940461053, 1.1647866014327288, 0.9292393929506929, 0.8660241699842124, 0.9687339009469349, 0.883801271522681, 0.8384803856188189, 0.7382719182259528, 0.6565250101951392, 0.7696899749621673, 0.8909411797682559, 1.0672439077955225, 1.3246257613269463, 1.3260070325557693, 1.3082371591615738, 1.358778287157028, 1.2702165095565414, 1.2232044705192553, 1.1077605731594073, 0.979349175732117, 0.9356564476237323, 1.1114189577333147, 1.1440413969989536, 1.2639097039592913, 1.4502778208068081, 1.5241456590130702, 1.6545382561219033, 1.5084634080468915, 1.3287693816563981, 0.9198470978586171, 0.7306531707096525, 0.6886616371496108, 0.8694224193790048, 1.170981372558146, 1.5335733853806164, 1.7395987196808906, 1.817207385350498, 1.8476442423242614, 1.6909495352978605, 1.647020088734929, 1.4611062699319464, 1.1595554399426082, 1.040180896979289, 0.764171366882184, 0.6414647521229422, 1.0349126616206885, 1.2419808085632946, 1.5056137885370036], [1.4688882509029355, 1.48567801134148, 1.3024196043725247, 1.1266930670639506, 0.8245308595552321, 0.9790970345245167, 1.5691572380605565, 2.110373267579822, 2.4900892688536143, 2.881861614776059, 3.142984018257581, 3.3056009638080424, 3.1688187701362898, 2.8877383113815567, 2.459219947792938, 1.9515278786700057, 1.423825430009374, 0.5431489042466846, 0.0, 0.8101021934924995, 0.843714531013206, 0.79793970362679, 0.752654467501267, 0.6978485428641612, 1.2891207394125008, 1.8453811588541886, 1.9690314639127224, 2.061524518356347, 2.041526019977123, 1.9376460509099205, 1.9263278363103724, 1.552558911310354, 1.3557095273574278, 1.182872648578582, 1.0501360767782106, 0.9167611241973064, 0.8849981355563646, 0.7248912097524902, 0.8617089791872109, 0.8443256032723214, 0.6952397673433928, 0.6832969608253752, 0.7200278614409855, 0.7052177753432038, 0.6845705948425851, 0.6339419863233847, 0.65392175232186, 0.8458079269022054, 1.0087375535145053, 1.2448189250365878, 1.5263579096634332, 1.5293201168583297, 1.5181641756962543, 1.5798672177162145, 1.4987105146601545, 1.4576235095232004, 1.3273924137687758, 1.2064649834931176, 1.1606853132400654, 1.3582959837050712, 1.3891834580418032, 1.49884095144784, 1.6866870200437025, 1.768167736674205, 1.8976911840168749, 1.750017323265105, 1.566957695686943, 1.1561767976806128, 0.872333737424823, 0.6474031576210417, 0.6275758706735023, 0.8069667129461398, 1.1227506052143874, 1.3326006209930767, 1.4375282821197317, 1.4708095949005193, 1.323127361532844, 1.2759301870982729, 1.1007665631730421, 0.7847018041116339, 0.7247432956388485, 0.590401335182118, 0.6830503813018246, 1.2886503384150372, 1.513596656660669, 1.7642633704748965], [1.0893734683049, 1.0622762233423673, 0.891111396221214, 0.8207785552685811, 0.8321498874615563, 1.306904858685999, 1.9217997639156852, 2.392603564773439, 2.7856326801909725, 3.1989768438338873, 3.488634734661615, 3.6402725633440407, 3.517771386916109, 3.241004597409892, 2.838073871870511, 2.395283391163319, 1.9627084944006206, 1.2044177405449328, 0.8076099991129936, 0.0, 0.19594340903795524, 0.3057276389804512, 0.36990540380929493, 1.0620468420970532, 1.669801880554108, 2.2371838295017206, 2.3541906565210264, 2.454663443518093, 2.433372582924999, 2.319809493226262, 2.278065611483934, 1.9562754768494612, 1.8262604455294051, 1.6318881045398772, 1.4793107807426216, 1.377632684264719, 1.3608602220657264, 1.0227383731770827, 0.4992623872622848, 0.5498515469101343, 0.6414655481809176, 0.6757820445263442, 0.688927250465672, 0.70590425227401, 0.716151292911157, 0.7784742907652997, 0.9233974555497788, 1.0923738649782655, 1.284719766465227, 1.5322302427188892, 1.7990058536792495, 1.8088401222877908, 1.8012758916898615, 1.8781649479324931, 1.8162666840478832, 1.7914883217499482, 1.678105632025601, 1.575287583913691, 1.5374695681643333, 1.7336075156145745, 1.74605885531493, 1.8428005713705833, 2.020401701240285, 2.1745642448296025, 2.327716058735804, 2.1675148100480013, 1.9984713743084042, 1.5824866396517199, 1.271521971186441, 0.9267596583557108, 0.6299955779560966, 0.5348376371670468, 0.708099251898656, 0.8506550635946318, 0.9373349308940296, 0.9765605739874242, 0.8479025403053347, 0.7940550790509409, 0.6009839966789905, 0.5353651509481078, 0.5756366632081771, 0.7494103652663399, 1.086602868519576, 1.8100567999190234, 2.0104822608240753, 2.225330749570212], [0.9927278922318755, 0.9646821096743218, 0.811924574297428, 0.7470999860341627, 0.7999960178706735, 1.2938057325514567, 1.9308606088786926, 2.4102903092983388, 2.809471169419665, 3.2534302583403965, 3.5526711311293213, 3.7038140159437067, 3.573336096303908, 3.3014572112433576, 2.8936025563611767, 2.4471747040240497, 2.017774012206807, 1.2388628363650525, 0.8430811104625123, 0.19578719575882153, 0.0, 0.180859831461783, 0.2791843490497107, 1.0575561143563732, 1.6808847187610299, 2.2684317062366888, 2.3859812999007692, 2.4962287424400453, 2.476538265219775, 2.340537075844565, 2.295369620809405, 1.9627269008070436, 1.8514403218641213, 1.6924913062949822, 1.518183889381777, 1.4131025878321954, 1.4008392246412291, 1.0237516415393335, 0.4774900940552029, 0.529327276631108, 0.6963002868375318, 0.7349955938640028, 0.7272180995156933, 0.7562210876739851, 0.7547169685696655, 0.8047404659630639, 0.9729576628656713, 1.130955798028053, 1.3121981151781719, 1.5665714083279947, 1.8541097906788748, 1.8553671628091823, 1.8505310748795103, 1.9295019027771574, 1.8605209718901992, 1.8375784858261863, 1.7223601992948352, 1.625616291464834, 1.5902950165206344, 1.7920628961294458, 1.8027346869512202, 1.903152125361586, 2.099863376843408, 2.270397887039508, 2.426478406748489, 2.2689163486219623, 2.091872192001435, 1.6669841936149894, 1.3476470897852504, 1.0042358215829958, 0.6288602889987125, 0.4872987826523648, 0.6503119216398962, 0.7902958548324396, 0.8784342651529847, 0.9134813347160498, 0.7914092954947837, 0.7339717437561121, 0.5762949188511596, 0.5372091058167077, 0.6250248336187438, 0.8465127450530073, 1.180443907242044, 1.8989032712785636, 2.1001910007651032, 2.3180519360634726], [0.9972348356131775, 0.9789240999962391, 0.8418237687744008, 0.764305989830376, 0.7616546152673933, 1.22244092309143, 1.8809497814669973, 2.379111280382016, 2.790688660136562, 3.2419237168979795, 3.539866709571592, 3.6883038534567505, 3.5593273380423742, 3.284793230370448, 2.8751088663443207, 2.415802960885532, 1.9777329171718194, 1.1789531363328078, 0.7964325599198823, 0.30576384311250954, 0.18080402587442584, 0.0, 0.19495170019911942, 0.9904546206978952, 1.6240388891350295, 2.2286665983930125, 2.3571109037443243, 2.471391703352623, 2.4529878588558383, 2.3066040028270463, 2.25429578066327, 1.9093673840643646, 1.800693094281676, 1.665501712389868, 1.4860468330497887, 1.3763568604847027, 1.36246273765746, 0.9832159638357509, 0.5338692421430362, 0.5817508141370554, 0.7370106867361603, 0.7735765911209339, 0.7673937084625557, 0.7925823870234442, 0.7676821482786362, 0.8012491540358686, 0.9654303572184961, 1.1199049182710827, 1.2969649257380298, 1.561041618931709, 1.8658066691088218, 1.8534969848670906, 1.8529445003532206, 1.927390955155306, 1.8518770643039637, 1.8224220020757036, 1.7095823377899453, 1.610722162377135, 1.5750405048489888, 1.7822841169348862, 1.795079194616947, 1.8998354921596692, 2.1101157739732423, 2.2812217433406228, 2.4363363932073194, 2.2770412918974756, 2.094989351019851, 1.6690845222929709, 1.3505398856300674, 1.0183753785139409, 0.6032266579895167, 0.45543504541589613, 0.6750053555337013, 0.8431372019208924, 0.9259881654412543, 0.9583094850002905, 0.8427936798802973, 0.7853084232796805, 0.6669240511785729, 0.591896185755171, 0.6754618536744298, 0.8495988467407463, 1.1790516628553156, 1.8899823813778738, 2.095405397448231, 2.318417842958013], [0.9658388421852959, 0.958945792796922, 0.8203914018883252, 0.7206330671431764, 0.6852235518595555, 1.1030222644837577, 1.7993856731802962, 2.324017608025184, 2.7557952690192296, 3.2103312743794965, 3.507755316717135, 3.656412126485524, 3.5257175624556556, 3.2531003660360134, 2.8301329113489397, 2.3552884014073276, 1.9034440856068504, 1.0992574713179983, 0.7526462284223625, 0.3702960976766435, 0.2792704196533822, 0.19482407303866545, 0.0, 0.8759296027388735, 1.515545664709907, 2.1562403724585444, 2.2859912012631636, 2.412044321343501, 2.3964681077575496, 2.235482089560321, 2.1816190881973534, 1.8128925854095936, 1.7174567670892689, 1.6184296531791453, 1.4334994084342185, 1.3101445737799153, 1.2934099690190182, 0.909496603027727, 0.4881555572321135, 0.5417673420564793, 0.6899489380819541, 0.7304028637563478, 0.728570881749048, 0.7468708959138823, 0.7141594395474801, 0.7338930280248719, 0.8950654507653374, 1.0454362246075846, 1.2024760744582539, 1.4847649261242204, 1.8171048357518926, 1.7976073577630491, 1.7911796370993398, 1.8661889589234806, 1.7791302780060947, 1.7413349941585266, 1.6205380315092093, 1.516403933827015, 1.4753727156989456, 1.7050111457380486, 1.71975638310186, 1.8405749475225954, 2.070349629013009, 2.247754602681657, 2.407357438064712, 2.2458774772788086, 2.0614212885529692, 1.6239118842349902, 1.2934695510249172, 0.9636355080880084, 0.5457940787355509, 0.4722035142492868, 0.7393548927595225, 0.8977091457805854, 0.9659433185161178, 0.9919642436135585, 0.8553004168100147, 0.798039235091775, 0.6907817995514511, 0.6206354137738289, 0.7131571795144084, 0.8471827561262417, 1.143013329468694, 1.8390275309143562, 2.0503642230756576, 2.2822692419203596], [1.4815366807810213, 1.5551468581108672, 1.4068257330102798, 1.2000672152415013, 0.8525181393776367, 0.6865783556673686, 1.187087776441952, 1.8591042688170039, 2.347544590679328, 2.852745639812746, 3.178225325295641, 3.337338324171263, 3.1976704236428737, 2.8991552033097516, 2.415259317709357, 1.8622130803691186, 1.3489669960513047, 0.7016883969043952, 0.6978227973100463, 1.0612792062783096, 1.055534497770115, 0.9883944046559985, 0.8770371624507283, 0.0, 0.789425897384581, 1.5853055697070748, 1.750657295317394, 1.9083503160150557, 1.8848796492450035, 1.6733031530643092, 1.6062870336111086, 1.1546501614230331, 1.134530523123554, 1.1959221739359904, 0.9916526679292781, 0.8267189400549483, 0.7903364356475436, 0.569524076213634, 0.9764477990658623, 0.9642325845450429, 0.9018731319357572, 0.898351625258863, 0.9203141844783611, 0.8738458961065807, 0.7420952679197513, 0.6860851186530724, 0.7105805745186359, 0.7703117176224192, 0.7939956813014698, 1.0475766717640698, 1.4248252757845634, 1.3886262166471708, 1.3656813898082085, 1.4300107393386912, 1.317630369506837, 1.2735091126174862, 1.1453751721297358, 1.0231557740804398, 0.9665479990569941, 1.2286856634760506, 1.2417603473184546, 1.391280743837879, 1.6850213376546554, 1.9098886298472235, 2.1035979464173855, 1.9382307251660875, 1.7638020990702903, 1.2934837383861986, 0.9633591270765498, 0.7757926067597635, 0.7999926647569184, 1.0938338613256258, 1.3944096241363109, 1.5584507941736905, 1.6312211615112409, 1.641016559624311, 1.4757923271501387, 1.426997787894453, 1.287010472139672, 1.0495030839014352, 1.0462628976238215, 0.9589192750070715, 0.9848481575957213, 1.4817113166498899, 1.657085289275083, 1.9180520986118337], [2.0302214543734527, 2.105907370585296, 1.9838037542687224, 1.7815681110204953, 1.4032045020758233, 0.8844580724231038, 0.7432732744682754, 1.3741954124241522, 1.9939532455663531, 2.564766460317301, 2.930456984204984, 3.096036763856621, 2.944508710889093, 2.6128412616868455, 2.0671848652431133, 1.3986217871685656, 1.0480503196884392, 0.9985849661476675, 1.2884964101322163, 1.6691727667659597, 1.6803989830479098, 1.6221973104008602, 1.5165798232349827, 0.7892726240247632, 0.0, 1.0387759421495395, 1.2577153211299665, 1.4597195202618638, 1.4338455603465377, 1.1530722119243373, 1.0708797641812828, 0.702332142707542, 0.838279676044774, 1.2344970664755333, 1.117080784213634, 0.9889456077431373, 0.9372040651704686, 1.0037605093773303, 1.5696045796974736, 1.5454757252236822, 1.3769267621867005, 1.3401700999964055, 1.383349258193365, 1.310313894504934, 1.2118241450173892, 1.1514436720368855, 1.0603620773307638, 0.9826384757041567, 0.8894440931414209, 0.9843177471871414, 1.3093401720506785, 1.255619640713024, 1.2134423318830139, 1.2626224704678766, 1.1330339851901432, 1.0750216606038425, 0.9734894404297111, 0.8690573773776236, 0.8044923787578475, 1.0517557768179744, 1.063438791944143, 1.2320721927397944, 1.5449593400484565, 1.8077808304118754, 2.020925735805163, 1.8690730310404398, 1.7212948934602295, 1.3023943936859925, 1.0817714819327822, 1.149163130957715, 1.3470376098571732, 1.676042993058235, 1.9701962250853797, 2.1028488302275057, 2.1597277127568537, 2.1708923097973885, 2.0308552294295623, 1.9870967782600815, 1.8587807847383822, 1.6357050349337958, 1.5911079219645616, 1.4167969180257103, 1.274928470377107, 1.4658827377966943, 1.5610696683353147, 1.8078331785125903], [2.6750205561447093, 2.7317185990534942, 2.6015839921173964, 2.4320046913390865, 2.108367422802356, 1.5253382555420187, 0.932256154769377, 0.771173237195088, 1.2578290067182556, 1.9608732412368928, 2.3739069214207236, 2.5801661025842906, 2.3925186020330886, 1.9926682452981896, 1.3026014744151597, 0.7958295701678952, 1.0391556937431146, 1.5208094646436159, 1.850110221130653, 2.237513820983755, 2.265224010539677, 2.2273714333799672, 2.152949770519062, 1.5860226358705363, 1.0392611670525151, 0.0, 0.4246371078985865, 0.7177076622377889, 0.6963156697506766, 0.4873592455429997, 0.5197997240969875, 0.7519527704672108, 0.9050178163312785, 1.243457390382734, 1.246593747070202, 1.2138583601119328, 1.1772994647687645, 1.5668934761390751, 2.181434570609722, 2.1538060992602315, 1.9217075542614104, 1.841845072615617, 1.9005213723715815, 1.7918854848333228, 1.728350748982279, 1.6813260837410426, 1.5324539506047192, 1.402278154619765, 1.2692658428118637, 1.0718785332941294, 1.1259473694713436, 1.0634256093712249, 1.0231539766983548, 1.008739050585683, 0.9479267582731782, 0.923152325419027, 0.9445012633074866, 0.9621826086632421, 0.9889120708190852, 0.8817495696226413, 0.8867261562093781, 0.9683006950098986, 1.2069646668381597, 1.418576136447173, 1.6670772146383384, 1.5562025592791169, 1.467760440997348, 1.2349046604340972, 1.2997981725806917, 1.5923085123334373, 1.9053908974785325, 2.2373659075149703, 2.5293349365570936, 2.668019829111651, 2.7233635593661156, 2.7487058821971804, 2.610985165929996, 2.5684923147700367, 2.3918333132305554, 2.1516616835560907, 2.0592183242529547, 1.8265132511119602, 1.5672369440239615, 1.431139885802662, 1.323415115299762, 1.4722019715451666], [2.8216389142929454, 2.873899659913459, 2.7371466238346316, 2.5686335146335044, 2.25397556233879, 1.7108528309933768, 0.9891823284926176, 0.7183914409184474, 1.045018775995749, 1.7739727874054474, 2.1761263930003674, 2.3946134839642426, 2.1961445592701563, 1.7846445677901297, 1.0813167348054358, 0.732839515893576, 1.0743730953561725, 1.6276778445467188, 1.9687165998851583, 2.358591929000545, 2.3890637042674667, 2.3561752340482864, 2.28864615992628, 1.7504831137367118, 1.2573706109629712, 0.4248704220645809, 0.0, 0.5027002456674936, 0.5056876434562617, 0.40969309121664316, 0.5770175727800589, 0.9166870973902937, 0.9195749805431052, 1.2037482330015967, 1.2504868260347008, 1.2703218495988775, 1.2560265943321687, 1.7029784422021348, 2.3093235209729825, 2.280419894037937, 2.040423621083123, 1.9582525205516925, 2.0414518853628882, 1.9167516094695383, 1.8439594722610724, 1.788472237452721, 1.6343013911023307, 1.4915682207986993, 1.372508297928086, 1.1277782377736711, 1.0734678902763533, 1.0094565479450954, 0.9739741696129511, 0.9450364457771245, 0.9032403597176868, 0.9014636919113986, 1.0232390860793275, 1.0933200891873704, 1.1243025789067098, 0.8979127962744078, 0.8982905332583059, 0.9028499708274288, 1.0839140580843805, 1.2873467540344903, 1.5101603814575355, 1.4072615700003632, 1.3351411676184053, 1.238622365005147, 1.3762862052075584, 1.683145524138974, 2.002861120196798, 2.3523512231478922, 2.6472845316363474, 2.7834300830330143, 2.838786744294527, 2.867551349305705, 2.730351705056224, 2.6875946109584348, 2.500468223110772, 2.2438963655246575, 2.1407226549902094, 1.9007832600748316, 1.6245273959227258, 1.394292978235046, 1.226610491984013, 1.3347360097623098], [2.9871191740121255, 3.0193458173741696, 2.8759511561969537, 2.715198589104931, 2.4048999948178276, 1.9133059284874478, 1.194694167747153, 0.7172816283409938, 0.9129636960814118, 1.5791013988259448, 1.9229117156989084, 2.1509336156120353, 1.9497791576304988, 1.5201301530890132, 0.840975208455233, 0.6092998231139863, 1.0503154960056713, 1.7285513609671215, 2.0623239201482573, 2.454506716323492, 2.501131168467844, 2.4735199686949993, 2.4130954467639816, 1.9039833475879577, 1.4609092534627075, 0.7177101532076047, 0.5036097657845137, 0.0, 0.1563579637498466, 0.6056720472652927, 0.826371577318506, 1.14484725358392, 1.0010204071242441, 1.1424180310147218, 1.2956296024242404, 1.3613139438129458, 1.3782726347032959, 1.8492843924927866, 2.427480646152828, 2.39885901272462, 2.141340335679276, 2.073745217681848, 2.186905664972497, 2.056402398948585, 1.9946685254437537, 1.9196680269951063, 1.7121652037116242, 1.5651908420156362, 1.481634946883856, 1.228612507060147, 1.0433456085689823, 1.0486448178000005, 1.018834193625381, 0.9525941828690208, 1.0067098400893406, 1.0875489932858566, 1.2061101603259192, 1.2645042884484372, 1.2917005345222856, 0.9978350685115787, 0.963055277755461, 0.9028050598090535, 0.9485083152438717, 1.119384031092314, 1.252785985981592, 1.1934026146125882, 1.1931484245454718, 1.2073716695068828, 1.4157170532386454, 1.7235292787343774, 2.0871787915299875, 2.456094022212012, 2.7530493134772667, 2.8953074990961674, 2.959060130843978, 2.993802475566049, 2.8556821838704947, 2.8144147668138935, 2.606966766895215, 2.3302504504439696, 2.1920019849871304, 1.9445030097713412, 1.6632840991072881, 1.2560028099017042, 1.049691103618237, 1.0859849745942955], [2.984786485548626, 3.014520672588619, 2.865444880602149, 2.707511954752987, 2.3906756446845208, 1.8947625747027157, 1.2052448345723203, 0.6990427760361543, 0.9052596714164094, 1.5891265346188517, 1.9283136097034934, 2.1578970101701365, 1.9602677442689087, 1.5419321982471201, 0.8506361494108169, 0.5884996626498767, 1.0245674818964714, 1.711446664930518, 2.0458605814551976, 2.436484435897421, 2.4807838949810352, 2.455901315829999, 2.397451340931032, 1.8821706201555346, 1.4348899476146113, 0.696299700761846, 0.5061454077414266, 0.15634685998575293, 0.0, 0.6234434794108275, 0.8219374290448848, 1.1441309827709019, 0.9942784678862919, 1.129070743428088, 1.2866783672517037, 1.3567922424310834, 1.3660504321695528, 1.8316756018780764, 2.415671461722656, 2.383850878445619, 2.121656383451754, 2.0523973951789314, 2.165865320245596, 2.0394406058838594, 1.9780757405858864, 1.9059457048617714, 1.6952598235662877, 1.5421223349563942, 1.4731988605271265, 1.2175219405565305, 1.0296154542245732, 1.0381953905079981, 1.0076578072272704, 0.9494036255589113, 1.012628595961318, 1.0876433347775054, 1.1972666809683192, 1.2468288311640812, 1.2739236719215479, 0.997524993053696, 0.9654483743258985, 0.888047007323547, 0.9366659565297576, 1.1206474115699872, 1.2564446906623843, 1.1917561871951061, 1.1873920179350184, 1.1866061966417216, 1.387046864307333, 1.6967747673098112, 2.0707419062977626, 2.4439425505099366, 2.742863484890396, 2.889340743172322, 2.958215340785514, 2.9918630441342167, 2.85197024203075, 2.811415656034907, 2.598685485045927, 2.314724434866393, 2.170034975168976, 1.926355780564953, 1.6388174668189102, 1.2374018057795024, 1.0351942590014787, 1.0732400963745223], [2.7733953358972343, 2.825148085449502, 2.696976416488381, 2.5312614610069986, 2.2397712172832978, 1.7054799218782661, 0.9717511026369839, 0.5882020254456614, 1.1444318108127167, 1.885676704628392, 2.291570301901515, 2.495441083880935, 2.318080287432629, 1.9355054564232568, 1.2770760402008607, 0.8799091131099087, 1.1613610547388817, 1.5982284192907095, 1.944906019726975, 2.317001893724268, 2.3378977135966674, 2.3053285550477423, 2.234792115078037, 1.673229604557081, 1.1523803440183724, 0.48737299146812724, 0.41073471221959085, 0.6058983492870319, 0.6229621177186253, 0.0, 0.36879495277451974, 0.7883582854099019, 0.8724462459389438, 1.2220179415821704, 1.2071144518683488, 1.2390808998259137, 1.2475221732453832, 1.644950776859564, 2.260076844032948, 2.234908263130452, 2.0141664247254893, 1.924492198396309, 1.9861175690094315, 1.865860991883297, 1.7890506314548784, 1.7346527757823325, 1.5896708770649028, 1.4399700645015436, 1.2928914954166926, 1.074508567837718, 1.056751216175088, 1.0047055977009873, 0.9605967885605603, 0.9178008389909924, 0.9111474533926518, 0.9729477239670039, 1.072198149623558, 1.1178447190946232, 1.1267061025623193, 0.9459191636831671, 0.9057299304522145, 0.9162867139205192, 1.1242236874399085, 1.3491151370328274, 1.6213675551862703, 1.5159583952586038, 1.4698792666669627, 1.2857871435963708, 1.376581367355334, 1.6570267666601388, 1.9653293321430994, 2.3285598091650925, 2.62432163096874, 2.7587647132644424, 2.822351495831162, 2.8524581882836735, 2.709658228824218, 2.6635867720030304, 2.4647907438300187, 2.208911644910027, 2.1071699264841883, 1.895780851840755, 1.630308245892026, 1.473960385044808, 1.3349715451695305, 1.448671269684409], [2.684994803532316, 2.752209494967302, 2.6321843466482666, 2.4750090920268817, 2.1881633064432298, 1.638495826687535, 0.9175620792857582, 0.6330641453336486, 1.300669082354043, 2.046999679025822, 2.462786898899149, 2.6544928100005865, 2.487053016822205, 2.1270505883016595, 1.4917491856088512, 1.056915584157914, 1.2689986745034696, 1.6274773944286993, 1.928108778578722, 2.279815135373646, 2.296054458372617, 2.2584051554996054, 2.1810705996691504, 1.605720762997667, 1.0678734929927702, 0.5199476559919518, 0.5770104895286657, 0.8271077090262671, 0.8233686341592034, 0.3688609905931792, 0.0, 0.6598786554452926, 0.9305931438342364, 1.3109810695042756, 1.2453971486378723, 1.2542329184463514, 1.2652459350046719, 1.5995388351684696, 2.2119156332671905, 2.1841487994968447, 1.9917275688601819, 1.907631996920241, 1.9315555886368099, 1.8384834061212083, 1.7556081883632195, 1.709136672147848, 1.5828621627939858, 1.4309561077838229, 1.2577709444346574, 1.0688138550947726, 1.1524145485308486, 1.0625908058552094, 1.0162118273180196, 0.9839081169963939, 0.9418937693723173, 0.9919459238585858, 1.073073759517358, 1.1123631938232952, 1.1162460634708142, 0.9950492895543449, 0.9597702726271755, 1.0052263201334166, 1.2671525123070462, 1.5156153333088613, 1.8170946818774727, 1.7054323279658687, 1.6370650646527003, 1.4012243136475746, 1.4099394234583331, 1.6690770607613423, 1.940237651636257, 2.290827556385761, 2.580628463110707, 2.708427585991067, 2.77130545623606, 2.797322283954072, 2.6548496664132553, 2.606043813917889, 2.41959744404093, 2.1756777270583405, 2.1068590945215093, 1.914088824871612, 1.677665273391237, 1.6094188739074853, 1.5040234125195235, 1.6385525205167353], [2.344307222314126, 2.4161580660930952, 2.2979175651414554, 2.1270675336137876, 1.8020108398775605, 1.2041317553405855, 0.64508530148101, 1.0307510173497658, 1.743942794465345, 2.369370957925448, 2.7465383844574554, 2.9169544422720564, 2.768829591052955, 2.4385760564165695, 1.8549695986589223, 1.258180951060843, 1.0824714023671194, 1.2506644202513884, 1.5530503771068613, 1.9596846644481214, 1.9661705835944236, 1.9124805279728794, 1.8160082958371628, 1.1546062952277862, 0.7021396889514424, 0.7520427650272369, 0.9176507202856293, 1.1439348009670018, 1.144709884141529, 0.7887791664290773, 0.6599304364072908, 0.0, 0.7537791518233274, 1.2038692803316946, 1.0564722534237352, 0.978660409902978, 0.9985667363137812, 1.2530678094496943, 1.8540746222894788, 1.8301664515152416, 1.6682437777626116, 1.5890643538856526, 1.597536947535842, 1.5223483630907861, 1.434390902327524, 1.3747280726077478, 1.2597216085494802, 1.1381817521683057, 0.9494191952275016, 0.9388927875942819, 1.1895707966104365, 1.1073750765439792, 1.0680995213813786, 1.0599016105573071, 0.9419711657293814, 0.9530058964244584, 0.9412133104606403, 0.9267299951278365, 0.9155786900111927, 0.932770905138325, 0.9168308304297694, 1.0642136863058127, 1.3719626218778276, 1.6031620472884776, 1.8767670367387914, 1.7387417075978997, 1.6306240862670645, 1.2921344215120991, 1.2187753202752016, 1.3428342078605546, 1.5772167113900808, 1.9397742503616064, 2.2440172895149586, 2.3836080707438603, 2.443213484643395, 2.4691754428587207, 2.316150333203077, 2.2668242492179314, 2.0983777677983784, 1.8611147296794197, 1.818655806917965, 1.6279929580616372, 1.3953132632328453, 1.4848120398916862, 1.4940903239633279, 1.702286298177067], [2.397331477107128, 2.4381043178074497, 2.2905444998075133, 2.1048315795573567, 1.7424265723172838, 1.1834554947707023, 0.7928048085417378, 1.1203137113938173, 1.6345055458547189, 2.2397054601253075, 2.542653334727612, 2.7207290391495893, 2.565564685998167, 2.241047247456192, 1.6678984213235948, 1.1224064036784174, 0.8110408151748534, 0.9773237499075237, 1.3548295154214305, 1.8305949891311117, 1.8584394611077315, 1.8067659188755774, 1.7178907388366378, 1.1332082510173946, 0.8381554396151717, 0.9066984368812445, 0.9187334000598524, 1.0002282032688512, 0.9920490729519802, 0.8726450516185172, 0.9275141096135903, 0.7534769621977002, 0.0, 0.7432656518633068, 0.6829805292129889, 0.695944694109331, 0.7286538197793371, 1.1119325097478787, 1.7755239314619937, 1.744609885561483, 1.4964709868661972, 1.3942386144510737, 1.5196424591917088, 1.375453797778908, 1.2788053003067597, 1.1728506104315313, 1.019583227268662, 0.8699455737428928, 0.8391143583662406, 0.7468505302387853, 0.8909075927835169, 0.8183670692145105, 0.8077352934029878, 0.8106615528524235, 0.7559529001477048, 0.7871695837701991, 0.8384018768341746, 0.8358186906568584, 0.838824579559665, 0.7256785550538838, 0.6955267303586886, 0.7337297544133131, 1.024399897800684, 1.2490977939477301, 1.4355255831953955, 1.3025972527029535, 1.161468881867873, 0.8926126960875221, 0.9156413141119727, 1.1059829471943512, 1.3775445972771174, 1.7994439687319403, 2.1494437295293345, 2.3237850243221896, 2.4009601278469144, 2.434213241103932, 2.272895936105746, 2.21933428636608, 1.9881689628481478, 1.6860532150839287, 1.5672984196625142, 1.3111711755221027, 1.0719330885396656, 1.046965511116086, 1.0557968953943218, 1.241722843497918], [2.3925648668255874, 2.4224218842507073, 2.2330535544459904, 2.044854875563065, 1.6635552691195112, 1.314553154936292, 1.1876911191035788, 1.447383703272735, 1.7605400798091986, 2.2364656569610935, 2.483637455090382, 2.644196464425743, 2.4991636367171886, 2.194438749150836, 1.7025536162183288, 1.2621810392211767, 0.9313541452915092, 0.9559347172444791, 1.183546495107019, 1.6294233059504244, 1.6913969199336356, 1.6654977173306111, 1.617628406973467, 1.195961737491659, 1.2347491533510448, 1.244410460478797, 1.2044582832030035, 1.143293008811384, 1.1289734438429708, 1.2241026358850857, 1.3137278674892525, 1.2059004743214439, 0.7429039435664816, 0.0, 0.4176672404555678, 0.5487882335833641, 0.5972059940946659, 1.0543547299178198, 1.6473924221449912, 1.6145675780619897, 1.3053400655863154, 1.2379270996578378, 1.4004248246892173, 1.2463250047667727, 1.1606963023220005, 1.0755022037616617, 0.840305122330734, 0.7792016017823603, 0.8603153480000657, 0.7309239505983363, 0.6827930706411072, 0.713866551334701, 0.6972136080079883, 0.714531593255978, 0.7616978712410343, 0.8321295541871341, 0.8858293938781996, 0.8945934213164445, 0.9040139708586886, 0.6980000598739947, 0.6743072826582379, 0.5755045414553777, 0.7300674598758435, 0.9454116232014015, 1.0731297687316088, 0.9165441249795624, 0.7710864421739573, 0.5410053006094349, 0.6259299896366154, 0.8595714542098275, 1.2382452216974722, 1.6327957549503027, 2.005216501933991, 2.1991347888376693, 2.2931503965367326, 2.3403076334304, 2.15962770934886, 2.1060439672174285, 1.8230211399819607, 1.436695234657116, 1.2357580429792712, 0.9788140910096903, 0.7624254078254575, 0.7131025370883202, 0.705151266915528, 0.8698756846789031], [2.1846547021829306, 2.2316366544754858, 2.05674316192823, 1.8597163936420056, 1.5056364681203314, 1.1673738955146868, 1.1336816123165938, 1.460445498848017, 1.850870864054064, 2.3853595275327413, 2.694937457424813, 2.8471301011446215, 2.710227747437955, 2.3961536629252835, 1.896254150376083, 1.4493544769243234, 1.1011189176153389, 0.843014494932277, 1.0503259651777856, 1.4782805644259311, 1.516491767489622, 1.485421123121223, 1.4323705234740987, 0.9919621795721348, 1.117338532838908, 1.2470197464389339, 1.2508502119186875, 1.2963341813902398, 1.2869042587433486, 1.2069248270068273, 1.2454028496111387, 1.0579180064924214, 0.6833374658101724, 0.417980377779558, 0.0, 0.29074043469504984, 0.40033670935944266, 0.8374172657448736, 1.4753332165891786, 1.4472008278770006, 1.1864230898654575, 1.0875476610768628, 1.2012952724720727, 1.0556537959475327, 0.9442212815401956, 0.8612801815165503, 0.7244611933183812, 0.6389878122365252, 0.6804754376108756, 0.604825396654715, 0.7303603305416173, 0.6862731925595271, 0.688470002865516, 0.7166388802166971, 0.7145878584014448, 0.7951043320517946, 0.8442360695130676, 0.8448740847082994, 0.8521431974745244, 0.7169638105204276, 0.6784069526764579, 0.6387910441235931, 0.9075642245665665, 1.1385896465442136, 1.366776154734894, 1.2067817726180554, 1.0568885693411108, 0.6944596713574465, 0.6463730209802664, 0.8086163403826891, 1.0994818764344574, 1.4903207342116451, 1.8519894173546207, 2.0489626428148324, 2.1453397163095524, 2.186832287788212, 2.0062512813645843, 1.9467016180712584, 1.6632881913863238, 1.2818113932554533, 1.1189513909871827, 0.9129778499618322, 0.7493714023597835, 0.9915168030199272, 1.0147809893828856, 1.193218068259658], [2.0180715771817996, 2.075277462153678, 1.9047237211454666, 1.7000732853984133, 1.317698299718985, 0.9364960120193262, 1.0258840000653398, 1.5145761332364105, 1.9576580570208177, 2.4800473601620987, 2.784660047952052, 2.941931479577584, 2.8004498490474306, 2.499640409453876, 1.9682979375765552, 1.4462483808337052, 1.0522922681270241, 0.7005022632062871, 0.9165506715736779, 1.3781171310849816, 1.4133860175542856, 1.3750941243160675, 1.309730246758243, 0.8266639576955388, 0.9891840859401716, 1.2138796313564402, 1.2707671059754253, 1.3614662263518855, 1.3561990099227317, 1.2395129964656662, 1.253403902440225, 0.9784680204819025, 0.6969006638021175, 0.5482772925243309, 0.29061293485694756, 0.0, 0.1909332792263488, 0.6681728271816858, 1.3338007954168127, 1.3068315034522087, 1.0571442384102443, 0.9623287535869086, 1.079114906028938, 0.9383234513877315, 0.8198997051097049, 0.7310456423684879, 0.5981169758876709, 0.5580366633464797, 0.5749460267079677, 0.589124777589567, 0.8379004549997677, 0.7847668626304037, 0.7743829388829659, 0.8010633651904665, 0.7163244727631667, 0.7435459739535271, 0.7166235774612207, 0.6944666961283873, 0.6991742590150505, 0.6572175212630676, 0.6479796546140009, 0.760766405846974, 1.051197919366157, 1.266137145823676, 1.476215377771489, 1.315029099239664, 1.1436181246042307, 0.7109860516828054, 0.5896497708252305, 0.7350204763689714, 0.9813515865600045, 1.3590854213176773, 1.7242537356917829, 1.9163600404291028, 2.0006279132162392, 2.040878375262161, 1.857296377380559, 1.798345796048492, 1.542904552966388, 1.187370981616108, 1.055014952518133, 0.8536577849229705, 0.7064384098353691, 1.0178897324821845, 1.0803828492255898, 1.3062025720042045], [1.9956282051515977, 2.052960624356543, 1.8866659290301193, 1.6679306660894089, 1.2618655735754953, 0.8730407595219652, 1.0185362276978334, 1.5457521837937804, 1.9855337105167847, 2.483875133190293, 2.7853391080797345, 2.9436989928055337, 2.807320373129098, 2.5051268251888, 1.9757698268183568, 1.4264560933374772, 1.0237139930675603, 0.6520624264063958, 0.8864089216213156, 1.360636778426551, 1.4002476608270307, 1.3630379846965694, 1.2950140420287357, 0.7902418412495477, 0.9379514868061296, 1.176824025511138, 1.256432031220677, 1.3772130454091354, 1.3659859386197255, 1.2489875583395482, 1.2645299812745443, 0.9973785839697196, 0.7289394418687456, 0.5969146026214982, 0.3995652547302169, 0.19097703318009576, 0.0, 0.6334111609358225, 1.3191610968117273, 1.2910445082095128, 1.0168802099581118, 0.9225636034599886, 1.043162515850755, 0.8986028707766769, 0.7852002589304823, 0.7013265242653909, 0.5793271157095544, 0.5695356058716162, 0.5994092538422048, 0.6223378374923517, 0.8596411580193969, 0.8215818447046841, 0.7957924501367063, 0.8419564521378597, 0.740925149247675, 0.7211931683586693, 0.6737910462236337, 0.6220263979620984, 0.6271713268058523, 0.6425548246234866, 0.661463914237474, 0.7919598102679619, 1.0738881926306783, 1.2920467376857334, 1.4987826195490288, 1.3331832124889804, 1.1502314250574996, 0.6903984090696061, 0.5440305058453704, 0.7237399134143027, 0.9881049606984591, 1.344515837443392, 1.7089279188067665, 1.9019141680163696, 1.982385175722771, 2.020125139848861, 1.8353795509737865, 1.7831158796343383, 1.5402208281012195, 1.186319316641843, 1.0465590831201041, 0.8352950714348846, 0.6865635668065111, 1.0154196952901458, 1.0835482467005428, 1.3201502098415725], [1.5234312767300835, 1.5842510613144363, 1.4327679410118839, 1.2208016668651367, 0.8109134477413573, 0.6469009743131738, 1.238430142884969, 1.8170657222880873, 2.333909293761264, 2.8536149853702364, 3.1501230940409286, 3.2984346205652537, 3.1657742178860997, 2.892221270654825, 2.393204413008292, 1.8499576646145348, 1.3954426226043601, 0.8024729930357458, 0.7255138442658186, 1.0207845415745131, 1.0238843215821507, 0.9841404815359832, 0.908369132782554, 0.5695788426735773, 1.0038670281545146, 1.5669954014598015, 1.7037005667773717, 1.8573776000111155, 1.8363969249055374, 1.6453309450441247, 1.599270794232305, 1.2542610944492603, 1.110441580959137, 1.0540746328015302, 0.8372117475308558, 0.6684374212651003, 0.6330955763559607, 0.0, 0.91288776895665, 0.8986248518625629, 0.7345716582331271, 0.6940583084746115, 0.8181261868749972, 0.6941329599669663, 0.5505002211214846, 0.49295973576469243, 0.541535080466745, 0.5771821498185242, 0.590174961321637, 0.8174904274848102, 1.222457565094701, 1.1431867834453882, 1.1300069730571856, 1.1954377151988205, 1.0885912307110195, 1.0345742011223655, 0.902020298712011, 0.8101898378406188, 0.781347428719681, 1.0005212973046955, 1.0185382045616838, 1.189613520228984, 1.5264753347783682, 1.7727575521592915, 1.9522166257275924, 1.7907165792675885, 1.5965161952798244, 1.1010566073678136, 0.7827033504743154, 0.7306386964552442, 0.7078553696904236, 0.9745827933085727, 1.303390701305075, 1.4707581297023002, 1.5555275370873063, 1.583190730653196, 1.3925526250220845, 1.3409634084020832, 1.143204115127292, 0.8029025225241256, 0.8202062750677754, 0.8178505614386253, 0.8938041308413227, 1.3903187937486436, 1.5211812990487272, 1.7730817637424579], [0.8335587745685877, 0.8583134938072374, 0.6515462706951172, 0.5025986085106594, 0.5643097341534906, 1.1072866756764705, 1.7881844742113293, 2.3504130812376007, 2.805911767030332, 3.2617112185732524, 3.5167571648024283, 3.660665950423272, 3.5340128951008034, 3.282567146678486, 2.853093435723871, 2.3719356791151314, 1.9132599095366074, 1.197654455113101, 0.8596374503697427, 0.4988528404121004, 0.47846390946125567, 0.5323508825241361, 0.4887332207795617, 0.9786199981012864, 1.569839509207176, 2.1828659908558157, 2.306912824145769, 2.428959500543678, 2.4195252299580394, 2.263461792338546, 2.2142474629228377, 1.8521028940162876, 1.7737669974423802, 1.644440009476247, 1.4752628679308077, 1.3338114003741905, 1.3191754033487735, 0.9131559518805717, 0.0, 0.13846978819104216, 0.5190968577151022, 0.6279902277933963, 0.7023992801023053, 0.7195984630961458, 0.7310126056251062, 0.7219358253770709, 0.867410439391282, 1.0065198808490958, 1.1119320566741397, 1.4050011892558723, 1.7900990200517903, 1.7464854224204, 1.742565726156409, 1.8235279825490611, 1.7162687437392874, 1.6630033686091035, 1.5213302870501288, 1.4149059669708033, 1.3687587468494442, 1.6202971808822144, 1.6431528299016847, 1.8093878870439253, 2.0702208989443087, 2.2556200449526447, 2.3905175022240246, 2.229247905157521, 2.0383031555151496, 1.6024125908728244, 1.2623562542804432, 0.9117907552219009, 0.5444258246023561, 0.4757342841433563, 0.6514689819430447, 0.733118335800473, 0.7897059295035854, 0.8125304420043434, 0.6210912487060558, 0.5620176934156348, 0.4029944708151004, 0.4758072372931135, 0.7065890923473671, 0.9331423398617311, 1.1964111946882756, 1.8098854137185034, 2.0116599845833485, 2.2659870884694837], [0.8792295948205756, 0.9109497086393368, 0.7033140011995505, 0.5179972468949748, 0.5595785555745022, 1.1007281946214207, 1.7694499945347146, 2.3309963617159943, 2.7782967923942405, 3.2415080600157204, 3.4933267971082325, 3.6356174675382307, 3.510248821024848, 3.262182657013043, 2.8207328619708343, 2.3322473156612653, 1.8789345674671751, 1.1656952743021782, 0.8445979580896273, 0.5496772602351012, 0.5290140099251024, 0.5817164865586123, 0.5417100069895474, 0.9671915701667473, 1.5462976585392147, 2.161817021355199, 2.2776368273187737, 2.4099491008653446, 2.3923824034960774, 2.233928365571738, 2.183703588370561, 1.8285421684070067, 1.74213024379291, 1.6130163866867306, 1.4475275358327184, 1.3074591446965709, 1.2917175149731983, 0.9004799553634377, 0.13847705215138031, 0.0, 0.4813601803880072, 0.5927949082779533, 0.6747103953570777, 0.6923486141191436, 0.7123246772558633, 0.6972518762298742, 0.8404715209250655, 0.9700063977991817, 1.0863766029766622, 1.3680784458191513, 1.7513847254118888, 1.7076399981501882, 1.7066546273027365, 1.7890386077689506, 1.684619263290459, 1.6289748265966442, 1.4884931243831625, 1.3815255864854106, 1.3322554443422052, 1.5841151556956141, 1.6102068399781966, 1.774804150662781, 2.0377769878862755, 2.2226649094642172, 2.346409010656494, 2.1960551424423804, 2.0041012972624976, 1.569261513310025, 1.2252595747880115, 0.8768136365324193, 0.543225716269237, 0.5065149495560223, 0.6864811154756225, 0.7753498210961637, 0.83684493451016, 0.8564220274878074, 0.6621224919389501, 0.6103309618313226, 0.4397392651564058, 0.4677727536387439, 0.6933316349983262, 0.9229161540900773, 1.1740034369091747, 1.7770691377448142, 1.972828767775967, 2.2286306816496526], [1.2719402380854654, 1.288056572350943, 1.0818772832513146, 0.8802145475248275, 0.6531635961428991, 1.0048121498794007, 1.6218335948060565, 2.1494367541968855, 2.571507116389591, 3.0098905388339388, 3.256878832350447, 3.401506184044149, 3.276774402311015, 3.0163393387960555, 2.5725184979352416, 2.066080161593342, 1.6023317167327011, 0.9309846753516797, 0.6915091875385283, 0.6403575289053477, 0.6958233972687068, 0.7360159436718506, 0.6893445829618144, 0.9029894253701236, 1.378214246529814, 1.9195740709061797, 2.0442396365680735, 2.1388453291211564, 2.1211870222833626, 2.011355505606247, 1.987663771344499, 1.6668460884775882, 1.497452998321098, 1.3068008956112243, 1.1859462153734979, 1.0578115929531235, 1.016144108741267, 0.7337154369945986, 0.5195217350727974, 0.4800994377575447, 0.0, 0.27297914536017437, 0.5086228568483715, 0.43600597544910036, 0.49117695367791026, 0.47050528429590943, 0.5354123042562741, 0.7102787267509569, 0.8751919400846239, 1.1031364970069035, 1.4503219224393158, 1.4216817840877598, 1.413780177337095, 1.4996135151262522, 1.4114114644083848, 1.357782335398543, 1.2112563166218455, 1.088244391013992, 1.0406398586665628, 1.2798145760227186, 1.3123758346904615, 1.46076051120448, 1.700261916779892, 1.8642849197056726, 1.9881063838074338, 1.8377247051436674, 1.6438701825361215, 1.1997108199702384, 0.8321070093715801, 0.59947923148152, 0.502870984923815, 0.6458925143600547, 0.9289799417284919, 1.0815812736183799, 1.1460178523012936, 1.1761385049453639, 0.9797848361834314, 0.939922774604685, 0.6982866122398083, 0.5068241572803883, 0.5237962237491941, 0.6268875057369949, 0.8376526073527091, 1.4351146792272154, 1.6187433015266461, 1.8685751649278348], [1.3733029856761954, 1.3887013395448071, 1.2055766858104882, 1.0021198348215432, 0.7802879049523118, 1.0097160997227348, 1.59081940829427, 2.095714972944037, 2.5036555446378266, 2.9389246984802297, 3.21170984704715, 3.3578734967046437, 3.2283185873564437, 2.963202366608666, 2.517483968297628, 2.0203591091950073, 1.5687346259776584, 0.8644882730026768, 0.6839023178259791, 0.6753229470793883, 0.7349162161693167, 0.773389614581783, 0.7305830966162918, 0.9005531631979954, 1.3403729830568198, 1.838923736644567, 1.9559383889650996, 2.067166337344798, 2.0510306044884543, 1.9188126685091127, 1.9049998565263648, 1.5887002022373728, 1.3956538745599378, 1.238871885765105, 1.0869893659681353, 0.9606036050028703, 0.9217468833658999, 0.694817714975428, 0.6292316005733201, 0.5938622428320791, 0.2731850046711611, 0.0, 0.41983957989240056, 0.2635869606150026, 0.3525325488309372, 0.338372886372383, 0.48082466999966833, 0.6461145665603892, 0.8231405899701225, 1.0268961093478055, 1.3417033334559711, 1.3249598532303888, 1.3137654115967499, 1.3985993035450976, 1.3193523085037462, 1.2733763308110042, 1.1449746285342146, 1.0363453957183388, 0.9947355895114651, 1.2002795119981324, 1.227479172014709, 1.3665204892268843, 1.592700474487612, 1.7489568168834688, 1.9074054753344563, 1.753317734324348, 1.5625195893862576, 1.0958267557476828, 0.7719220249341431, 0.57782092915417, 0.5473744732146283, 0.7393663352406896, 1.0435950136948842, 1.1965485239036582, 1.2624046707242125, 1.2879352067365992, 1.0986308884216593, 1.0517904575836576, 0.7919508466454793, 0.5781604400881197, 0.5312158226664496, 0.5560898781691501, 0.7388387187454101, 1.3962338346004473, 1.5584912398885937, 1.7931513203923795], [1.3318228993007024, 1.3858874188469974, 1.1994617154817058, 1.0193862404739824, 0.8671902599700824, 1.119898123888521, 1.685494515645783, 2.1846894749792773, 2.5733467718412193, 2.9901418391150156, 3.293276788257704, 3.4432764992900164, 3.3209280609313043, 3.0669042438354746, 2.6387509439928998, 2.161670969433783, 1.7291626241728628, 0.9665691036280457, 0.720679619905235, 0.6890543374890354, 0.7273203589942446, 0.7678830108445208, 0.7280893376176072, 0.9193225138754977, 1.3834322184451355, 1.8954873265281493, 2.0382469237934524, 2.1826111655875273, 2.163952447430334, 1.9827372214780477, 1.9294611452341939, 1.5978633100691693, 1.520238741131446, 1.403165096636202, 1.198421685311694, 1.0786457403183933, 1.0428411376417728, 0.8181202491569001, 0.7039969296687846, 0.6759903896087126, 0.5081529005110718, 0.41971686017314824, 0.0, 0.28828488309866934, 0.4057335143169803, 0.5133132532761597, 0.6775432966783793, 0.8287230606389606, 0.976420694570451, 1.1720669988566108, 1.4644023828782742, 1.46711138127927, 1.4525198478236907, 1.5279266419146875, 1.4540131306529454, 1.4295051745360372, 1.303020082562944, 1.2019889764664102, 1.1591649414299259, 1.3658656701495395, 1.3833032042228892, 1.5000238836533413, 1.6943874409041417, 1.8379175130379348, 2.079647820639859, 1.9182656434022354, 1.7472613895052869, 1.270386938007256, 0.9450801865607834, 0.7566561158597561, 0.7115639260696344, 0.851711473140276, 1.1013161310602053, 1.2370403196057727, 1.300003765039713, 1.3208656270916497, 1.1490066059113275, 1.1028894110955862, 0.8794701143379035, 0.710990180648609, 0.6868634614377183, 0.7053783813902178, 0.8571082212648975, 1.5979788052325745, 1.7470191717988661, 1.974217981426004], [1.4199872363793082, 1.458248510288756, 1.2808945345212608, 1.0875893015949585, 0.8841173103786092, 1.037099958227888, 1.5843362664930771, 2.075197383209418, 2.473928176255924, 2.901413439130886, 3.21747702813994, 3.3546685078371357, 3.2378488569960817, 2.9685814909840227, 2.5275212948153185, 2.0431889223395467, 1.616428386776935, 0.8815693819510341, 0.7066639750655755, 0.7072113254592939, 0.7569454475566575, 0.7929604577560341, 0.7473015528187746, 0.8714580422536812, 1.3099671126380017, 1.7938280768091843, 1.915510367789083, 2.056017621822647, 2.0377935085100813, 1.8661721696575957, 1.839329291384507, 1.5218456059246852, 1.375948930875811, 1.2501840748895572, 1.0544357102749415, 0.9373066650190737, 0.8956646526242052, 0.694287835959248, 0.7207638631442933, 0.6932374626890798, 0.4350166053075041, 0.26359279271889063, 0.28819423113804177, 0.0, 0.22683748180074764, 0.3415288655667006, 0.5284813312520731, 0.6752519097586693, 0.8347420595095043, 1.0153518378270845, 1.3106332076924052, 1.3043118805489928, 1.2860882336048365, 1.3646085040496898, 1.2940148908131348, 1.2610477727122458, 1.1475247205978722, 1.048928008111248, 1.0177836073832518, 1.1941310297361207, 1.215570777198082, 1.3373330302471416, 1.5520172027561985, 1.7117403003142175, 1.936826122079037, 1.7716166142544563, 1.5925327909985114, 1.104219785129293, 0.7935974692449667, 0.635688307536801, 0.6384285649739653, 0.8482936537384006, 1.143266531159241, 1.2911951088262974, 1.3524095005879806, 1.381259217028669, 1.1948672112652468, 1.1462696194375792, 0.8884177707095633, 0.6679975293178924, 0.6021859311336615, 0.579883123677863, 0.722920340221472, 1.4650732357211127, 1.601613874345949, 1.8266784349765852], [1.431263698380085, 1.4763444180017211, 1.3133080760058031, 1.1098920964505747, 0.8640511976637587, 0.9457558581364075, 1.4843959704206005, 1.998735748817498, 2.4172779292918753, 2.8815141250929055, 3.1984873704927, 3.33985216310503, 3.2170860685169163, 2.948344345446297, 2.491975324943987, 2.0025140965670207, 1.5757094460693173, 0.8387007151820544, 0.6849817199891896, 0.7160598831912636, 0.7546963403895839, 0.7673470230953026, 0.7141717983778844, 0.7422898238986557, 1.2112621516395028, 1.7291275453011468, 1.8465019297643641, 1.9905830303788181, 1.9744377562676223, 1.7888892951912099, 1.7562706520113012, 1.433232345447309, 1.2801605384417978, 1.159176479944538, 0.9469242098406433, 0.8203157360452917, 0.7853731809910764, 0.5503758524014528, 0.731448853540369, 0.7124546437509274, 0.490257148075193, 0.35254678006660917, 0.4055779649105618, 0.22682902719989279, 0.0, 0.24555061747763396, 0.4622303007697148, 0.5881783945172256, 0.739104083815988, 0.9234629803398419, 1.2369829866495103, 1.2166934228357111, 1.200009458627772, 1.2820500833158335, 1.202554162551759, 1.1754239964399935, 1.0744487160958553, 0.9844858886333634, 0.9550487934356868, 1.1273161854483442, 1.1365806154893094, 1.2613098285195918, 1.5072511000138273, 1.7022091554439744, 1.9346833337139604, 1.762452576063073, 1.581692086788797, 1.090594305915455, 0.7670135670022786, 0.6106434526000014, 0.5987010165112432, 0.8520559048645827, 1.1654769553867907, 1.329818772255148, 1.398990968432179, 1.4302280376758838, 1.2420103127422324, 1.182213953247763, 0.929290161891859, 0.6558723847081207, 0.5942803467504247, 0.5724217200167585, 0.7278971000763047, 1.4509074283633694, 1.5829515572758863, 1.8066905681221879], [1.4380981963322024, 1.4749958483081662, 1.3069637434405537, 1.0959791388048052, 0.8227857174695691, 0.8697854226515185, 1.4009972416177061, 1.9450900667483164, 2.3774934626271382, 2.86166906296667, 3.152066942698478, 3.2977911522749417, 3.1712577054948654, 2.899457292994591, 2.4248447616100077, 1.9199729041351137, 1.469127976775679, 0.7382761496239777, 0.6338932477265228, 0.7805143934465211, 0.8074296393472904, 0.8026153540119527, 0.7334443523592128, 0.6861148182782829, 1.1516911950880957, 1.6807895722393096, 1.7882178387312881, 1.9203802503772363, 1.9057451840543336, 1.7351367355897034, 1.7102084894703684, 1.3744338780311833, 1.172752416478082, 1.0738364184136757, 0.8631529311804781, 0.73090577912672, 0.7011585613300206, 0.49282540757510657, 0.7235846772210623, 0.6971555041044615, 0.46959135924724027, 0.33823933444608917, 0.5135493414352839, 0.3415344148218413, 0.2457056859586784, 0.0, 0.35254664598718943, 0.4931455848647651, 0.6472094581715306, 0.8604031129927556, 1.2087331610854832, 1.166189911315157, 1.1561729803506697, 1.2406425585776806, 1.1432909167996061, 1.1085162089914609, 1.0104376305319165, 0.920486305407359, 0.8840889834592444, 1.0603392736126018, 1.0786238806698716, 1.2166770264706486, 1.4753218585600663, 1.6806968338904067, 1.8706976643692768, 1.705446853491724, 1.5139630591351558, 1.0351027369980412, 0.7107327223622084, 0.5423470901131661, 0.5169625583750472, 0.8242010847118815, 1.1593469538314805, 1.3385112740303249, 1.4080746618189783, 1.4410083557867113, 1.2487342354783484, 1.1887759864087766, 0.9391064544600696, 0.6474306941835174, 0.5975945260930734, 0.5820399769692975, 0.7037356539993339, 1.351726944916708, 1.497394282786157, 1.7359343130709917], [1.626040560470547, 1.6576405833346737, 1.4702823155258717, 1.2725258236630734, 0.9375648937613489, 0.8555415993262709, 1.2715876226007623, 1.8041286425691279, 2.235621330914486, 2.7070776584282643, 2.9755788339015465, 3.1284341841538144, 2.9974147116127527, 2.7125229094444507, 2.224866589022913, 1.6981295761103767, 1.2212222644122686, 0.6568586465670753, 0.654508090223304, 0.9248973853378205, 0.9743899694942333, 0.9660998361803317, 0.8963371297302628, 0.7109964348632257, 1.0596795774736438, 1.5332886498529839, 1.6267047546474454, 1.7077580654373627, 1.689879811070924, 1.5906448219401839, 1.5841471212269873, 1.260298098206686, 1.0214197006592582, 0.8405535953097799, 0.7246059240164567, 0.5982829613063801, 0.5792085006848438, 0.541546447150098, 0.8676437099465192, 0.8411824465191214, 0.5340127606405244, 0.4809043933523023, 0.6768259125277031, 0.5286307650475826, 0.4623589980882339, 0.3524021266914646, 0.0, 0.2984617668239336, 0.5242078410479561, 0.7148772963178829, 1.023395907387372, 1.0086664637206, 0.9909748446596024, 1.0604885455974051, 0.9779776112976335, 0.9619049078841229, 0.8598380128324844, 0.762012750157393, 0.7226070004226847, 0.8692219790041754, 0.8871032951839817, 1.0211602216073439, 1.263363726226238, 1.4725001422760335, 1.6292944667861304, 1.4688611933310993, 1.280958153395298, 0.8082948611526198, 0.46902739451450354, 0.34592510971076323, 0.5423209200810352, 0.9341989195023825, 1.3204224580096593, 1.50125411011991, 1.568941428946384, 1.6103200746761872, 1.4110055573810067, 1.3548276158702413, 1.0899280864199274, 0.7784950151675007, 0.6581008037551702, 0.5046837733714096, 0.5329026350410954, 1.0893108929780109, 1.2440694266186274, 1.4843471765098422], [1.7502988958559187, 1.7940124736423584, 1.6047090659852608, 1.4016030349978919, 1.0840819135739543, 0.8864353049811738, 1.1890348631432404, 1.662552617167756, 2.1088485133373327, 2.6384321728687707, 2.921774192750235, 3.0706561784723987, 2.9380492717512476, 2.650933700603304, 2.138908873787639, 1.6095527585783798, 1.1751727210063496, 0.767388536216161, 0.8457886565500663, 1.0931195014544173, 1.1294599563369772, 1.1204382781569928, 1.0467488833664904, 0.7670215893910345, 0.9830353549843127, 1.4031351759221264, 1.4928660816941401, 1.565680607073043, 1.5428853561529374, 1.4408177344445308, 1.4318233556420017, 1.138878983640419, 0.868351604327747, 0.7776313494256144, 0.6391966799208563, 0.5582075822152407, 0.569158597203054, 0.5773996907446365, 1.0080859955433885, 0.9717352384808104, 0.7119636125892955, 0.644827602133362, 0.82807821853541, 0.6745598914685282, 0.5881172965776504, 0.4935079799363546, 0.29849361275417385, 0.0, 0.3709662833998956, 0.5266826216456816, 0.884912556716007, 0.8201215114280792, 0.8325552872328352, 0.9112530901773304, 0.8284938045655751, 0.8436592284651159, 0.7658691128413211, 0.6847305381738296, 0.6471143773228065, 0.7581092159578205, 0.7499369600107088, 0.8657789876562233, 1.1788560225745421, 1.434939990592093, 1.6058697844292338, 1.448268167363038, 1.2620805525545422, 0.7999244512563415, 0.4978044093560587, 0.45490181793043893, 0.664543074997324, 1.1022046897062605, 1.4861499536468752, 1.656253292049516, 1.7262634253379432, 1.761972597392397, 1.5561202169437056, 1.4982195142931114, 1.2258417906901562, 0.9151520277133998, 0.8196031818302917, 0.6809883187303196, 0.6605170000414387, 1.093120831926103, 1.2099049266759934, 1.4446494041034486], [1.7853760144459823, 1.8504136472263484, 1.6714709957902494, 1.4661873903628453, 1.1438660173486361, 0.8238480320783729, 1.0270565428206715, 1.5366318168798137, 2.088400466741642, 2.6355172607987045, 2.924324426209745, 3.074556714004993, 2.9401305165784684, 2.655130750814677, 2.1158839360683293, 1.5490784906405235, 1.1647908346650957, 0.8904141062703887, 1.0111756107565633, 1.2831546137888339, 1.3086788953402628, 1.2981517509496459, 1.2015279587443461, 0.7922675522014063, 0.8885093416289076, 1.269899454549115, 1.372134704633551, 1.4828148926712055, 1.473673290154455, 1.2931410529220966, 1.2605154049267289, 0.9514464409191276, 0.8369852895061233, 0.8586113241369213, 0.6805483686002872, 0.5753790208364197, 0.599410042523265, 0.5903291331821344, 1.1113364993521404, 1.0823014347175217, 0.8749769794106881, 0.8240466884038699, 0.9784095363506278, 0.8380351369522991, 0.7379853514068982, 0.6471071429792222, 0.5239899052524343, 0.3711139415618889, 0.0, 0.40965833800226753, 0.9142676224671262, 0.7911816517279171, 0.7755361407085484, 0.8525998175760457, 0.7319778347420351, 0.7140889545224685, 0.6366390435898146, 0.5592320591805207, 0.5280423429946178, 0.6606270309773177, 0.6537909214261939, 0.8512505730072768, 1.2471966171962683, 1.5156423656692841, 1.7001865709463109, 1.5457139559571185, 1.3670243138385703, 0.9096638146005178, 0.6594543535830648, 0.6774143424772546, 0.8385009345326504, 1.251058391610259, 1.617553305806458, 1.7577321410452305, 1.8255813640409155, 1.8540543654664434, 1.6431888756770703, 1.5854457233824482, 1.3337198623671447, 1.0648818936237612, 1.0379768569260888, 0.948284321988794, 0.8825113187314021, 1.1966038161635777, 1.2846640149150066, 1.5337144803889684], [2.106928417109118, 2.1732224328108103, 1.9910588826512223, 1.7762776139762506, 1.4425414674312695, 1.0575434159063815, 1.033413313160388, 1.3497008266773238, 1.8468037850961876, 2.4409281142740293, 2.7400673333252654, 2.897106770920563, 2.7577006476264283, 2.4587974646546438, 1.896629005269987, 1.376021180863036, 1.1425275768406782, 1.0667222427556708, 1.244015635469834, 1.5283433881842603, 1.5645929563624401, 1.5608435049400915, 1.482780961198052, 1.0484926263863654, 0.9849324503503745, 1.0734438595018203, 1.1284066830354507, 1.2297103958622775, 1.216588355694217, 1.0759817980188822, 1.0691035703846652, 0.9380596725828957, 0.7466729049663963, 0.7326382026693401, 0.6049719156065932, 0.5891147672925349, 0.6216777552577701, 0.8173996531585043, 1.404716997445942, 1.3665877517932676, 1.099857180107071, 1.0278313446267269, 1.1719597257154653, 1.0164402393137597, 0.9268293269519335, 0.8601791264386985, 0.7147939753631141, 0.5266942130338591, 0.40955461907244894, 0.0, 0.6433051498985404, 0.4659057407803239, 0.47722301893756447, 0.5617952113004723, 0.48583650386198823, 0.511955782553429, 0.5003991976118648, 0.5256904740299215, 0.5331782877129284, 0.45074228274383604, 0.403647326894216, 0.5342807276068612, 0.9903524847821904, 1.3128003561053825, 1.5266108790076052, 1.3760813507435343, 1.2024313304804435, 0.7994495443061392, 0.6504709767737459, 0.8323496074952282, 1.1167013296228814, 1.5314075334765116, 1.8862702273736414, 2.0402035529051705, 2.107951522538873, 2.141284174704434, 1.9272250314222972, 1.8683786596562972, 1.5987716885246674, 1.2921388420079, 1.208385576601902, 1.0812730958559524, 0.9522673737928692, 1.1396357235981798, 1.1362402039395456, 1.3467521249524592], [2.537801003610719, 2.5863443086122264, 2.4074809086888886, 2.2066999738128157, 1.8725693186709955, 1.506533564900018, 1.2688281540485622, 1.3445976771657262, 1.5873380686038165, 2.136524317971065, 2.472594953182896, 2.6390578475294104, 2.475771180574337, 2.1594431024336447, 1.6722176508800317, 1.3252387639772485, 1.2383395186748225, 1.3251449605648653, 1.526655634040705, 1.8022278779594814, 1.8548932340924797, 1.8690613175882638, 1.8194074512807137, 1.424992282531688, 1.3107872963912388, 1.12874337045832, 1.074486157805024, 1.045182576024185, 1.0302806992281763, 1.056030946499928, 1.153470617426369, 1.19162965345753, 0.8895114721945008, 0.6827711605805036, 0.7303476084846634, 0.8363282879685396, 0.8622847610766484, 1.2222050082340623, 1.792076317797416, 1.7516717553076115, 1.4489309719974317, 1.3404652954384233, 1.4656824125509045, 1.3078953746727682, 1.2344705575979424, 1.2068821672841756, 1.0230837940648596, 0.8850324124097201, 0.9145790990792448, 0.643542334431014, 0.0, 0.40845702005292556, 0.2983422682835262, 0.3513189661675663, 0.5461316881912447, 0.7021515899492347, 0.8470665510283664, 0.9154644740382688, 0.9377394958769717, 0.6432256496852176, 0.5722776878105347, 0.3954334192548125, 0.5231556483295334, 0.960883343185072, 1.2379706809296123, 1.0820579982905951, 0.9906604439579079, 0.7317544257190474, 0.8167255313854429, 1.084772191426334, 1.460412933877462, 1.8814418875843992, 2.2358213438736825, 2.402845996782214, 2.478024849696683, 2.5204539819394456, 2.3134912606733247, 2.2565976266558385, 1.9498059742640954, 1.6105218968666635, 1.4100228534264774, 1.2366876594963283, 1.0496786894628494, 1.1087309374413106, 0.9917652182097946, 1.0715705646224705], [2.4648008870832108, 2.526552718878189, 2.3469862183725936, 2.1433771777424444, 1.8109752513660804, 1.4128005713827805, 1.1721170519161543, 1.2745514885235572, 1.5746636688219247, 2.221286412106032, 2.533572175583358, 2.6966824831453513, 2.548979953847249, 2.225054759224374, 1.6874441774996904, 1.3183973123974007, 1.2354049124865027, 1.3261897601535926, 1.5294063999341125, 1.8105785420668565, 1.8586561781149953, 1.8575237309929782, 1.8036814633858456, 1.389114780342218, 1.256092493704385, 1.064382738684965, 1.0100930587210133, 1.0491010127595577, 1.0384802201258252, 1.00642618899894, 1.0640913021307496, 1.1087905798392206, 0.8158844311655356, 0.71499447499631, 0.6862803422550277, 0.782619865215057, 0.8199567454353683, 1.1435727120975105, 1.7500019640980837, 1.7108041668363998, 1.4192505685437375, 1.3221144120467807, 1.4650712554240894, 1.301622503812639, 1.2166766750453486, 1.1665959794811074, 1.0077235081023337, 0.820159574281846, 0.7909111332533839, 0.46649800749952447, 0.40838058015198553, 0.0, 0.2550528519275892, 0.3456556660792001, 0.3479944999233192, 0.5437280349740846, 0.7198147323073403, 0.8054257493835002, 0.8348540844864264, 0.5282480212118067, 0.4544580932476364, 0.3347599716848338, 0.7257943271856898, 1.1165599930858565, 1.3551381623930852, 1.208990995523686, 1.0840454163217366, 0.8114436791561642, 0.840324485564154, 1.1048806092235761, 1.4186442804647135, 1.835860198162186, 2.1941272711186524, 2.355380475220364, 2.426438228866415, 2.4659359285701674, 2.2567098076856453, 2.2000536969543485, 1.8972280138906041, 1.5743886418077802, 1.4381167505175882, 1.2786254663948413, 1.1174669748301558, 1.1712129103923992, 1.0633132419870341, 1.185708857249296], [2.461339369683123, 2.524043223464155, 2.3473658506078783, 2.1437840308027125, 1.7949404013875618, 1.3862890850894685, 1.125016250236084, 1.2382161804205039, 1.5833973330397033, 2.19313051845305, 2.5267927329543616, 2.6877594824248443, 2.5354434038420988, 2.2075436429952147, 1.664127780490821, 1.2804534991532306, 1.2033251436969479, 1.3068713567016303, 1.517671291519637, 1.8036964273702083, 1.853379347655332, 1.8561983328865816, 1.795747465691823, 1.36517562941961, 1.2144612032368365, 1.0226197788113767, 0.9733044032882086, 1.0178359399790595, 1.007108741858453, 0.9616839000352534, 1.0169950410193438, 1.0683902352263432, 0.8062216841042222, 0.6970064795994377, 0.6885500367685052, 0.7719329223087505, 0.794047129904972, 1.1295206255092456, 1.7460029963391588, 1.7093170213416826, 1.413140514868859, 1.3137684432913368, 1.448781354696572, 1.2870564716144943, 1.2010444724110019, 1.1575026819035266, 0.9908245367974643, 0.8330098215100447, 0.7775989062496026, 0.47736943094021295, 0.29840747476734847, 0.2549866029386446, 0.0, 0.22503241580408692, 0.3381670678671162, 0.47819100637529305, 0.6674130860118991, 0.7590154666732406, 0.7884462132281274, 0.4779924434200481, 0.4157122972062444, 0.32033302992895446, 0.6838516146524409, 1.088984134961196, 1.343389644533311, 1.1874035907255105, 1.067398342708218, 0.7813321279251092, 0.8158857877775102, 1.0935166933162506, 1.4235719361355819, 1.8404056365576085, 2.200193144267864, 2.3582286882956347, 2.4262119606460333, 2.4651508958227457, 2.2560956845070934, 2.199054117601346, 1.9058019213952768, 1.5821528944468104, 1.4294485260498715, 1.269439237504941, 1.095066730758579, 1.1514189391110172, 1.0432053185818053, 1.1674913745076339], [2.541053375684274, 2.6023090205766444, 2.4279463102854084, 2.23065377574778, 1.882583487052319, 1.4487212631855257, 1.121378349169983, 1.1758380996745528, 1.5297878378327332, 2.1233809296610993, 2.4645121766086824, 2.6304881661637576, 2.4743912227380354, 2.1398005760520022, 1.5957113144755375, 1.2580270241824028, 1.2219216112779472, 1.3593577587176626, 1.5784293431927248, 1.879443520332498, 1.9358950010764768, 1.931255698594339, 1.869329527272303, 1.4299342333269933, 1.2628802082533253, 1.0094581877077187, 0.9447066690101968, 0.9516215892705021, 0.94911199650157, 0.9162810060343879, 0.9850372729954386, 1.0609277409059112, 0.8094651929046118, 0.7160866343169405, 0.7163811738471434, 0.8002439950910999, 0.8401969838451853, 1.196420917100676, 1.8254426950448044, 1.7927738544515943, 1.4990009668253645, 1.398879998908508, 1.5272408796972499, 1.3639380446937561, 1.2803182672867026, 1.2397216466812837, 1.0585589432545117, 0.9105682781213044, 0.8535873890025879, 0.5619097368445405, 0.35119247533937326, 0.34728603874070424, 0.2249618199119599, 0.0, 0.3459916282565866, 0.5424475560035005, 0.7242532366047, 0.805537963091859, 0.853811984543646, 0.49159252684492366, 0.40550856943009217, 0.3297428894997925, 0.6443740897026886, 1.0409824960788436, 1.3043569870271876, 1.1556274355880045, 1.064872153971706, 0.7931804447254069, 0.8823893020337986, 1.1697499916865148, 1.4958102755396065, 1.9105067741626387, 2.277822947724887, 2.433055305907495, 2.500987693195694, 2.5460916683241654, 2.3329251163204194, 2.2770455167290713, 1.9803409014705264, 1.6566182781088599, 1.5064798567271982, 1.3320308831322243, 1.1403482098782207, 1.1594952143110626, 1.0347715130116122, 1.1424458868038077], [2.4011940259666846, 2.4705386488600123, 2.3070978548547703, 2.1007827628688527, 1.7401509708964846, 1.2809718143408122, 0.9491646185819563, 1.2129974086740576, 1.6087984775619446, 2.2367217909905484, 2.564019588489249, 2.728038377162194, 2.577486146822997, 2.2514076626627504, 1.6675022626378582, 1.234642630057323, 1.1551970449757833, 1.2707261383857011, 1.4988742908948636, 1.8180754121274514, 1.863872804813734, 1.8541833218145365, 1.7815187725257642, 1.3192635709503215, 1.1320672783586554, 0.9479910356171807, 0.9043347910386742, 1.0059180197583433, 1.0128448587242598, 0.9104846177194147, 0.9422538573810106, 0.9429782389200676, 0.7559722267491846, 0.7605122662725381, 0.7147015021248404, 0.7163741802808468, 0.7410179764665878, 1.0887476421458049, 1.7188502869979647, 1.6885864321498827, 1.4093246418989835, 1.3171991368114144, 1.452705675657173, 1.293746008882642, 1.2013371448798413, 1.1449433502480015, 0.9785618681701558, 0.8293014038263986, 0.7319496488308028, 0.48612215145254356, 0.5462968982998054, 0.3478460120412076, 0.33920992665397703, 0.34590165092742364, 0.0, 0.33643599580866124, 0.5568483091060303, 0.6580139676881525, 0.6938686158683383, 0.3646295178939829, 0.3241669295723551, 0.4540642201888471, 0.8361139178457131, 1.1846969928537778, 1.4190178665277953, 1.2670261492014088, 1.139696578630649, 0.8379559754717418, 0.852739862598579, 1.1295420733157764, 1.399598584090667, 1.8162545371806889, 2.1777215721666154, 2.333897061909621, 2.388219978605576, 2.428646856206644, 2.2150498153714895, 2.161344151735565, 1.8862682510535844, 1.5882811822065543, 1.4813497996868756, 1.307300217289638, 1.1280785212786122, 1.1853890774292382, 1.1001476884920618, 1.2610239661353915], [2.3216959598382587, 2.3935908280687954, 2.2355834679714515, 2.02253200647035, 1.6423228995598957, 1.1391182643504256, 0.8992146867247981, 1.2697665090956018, 1.7142429437955031, 2.3103849103163494, 2.6108466920473195, 2.781684985015963, 2.6251268758505746, 2.3096242956006616, 1.7015896229747156, 1.2110362083061925, 1.0915583111848037, 1.2249937851526393, 1.4581627560649242, 1.7934223276210612, 1.8393680882726682, 1.827799372989617, 1.7403924306504668, 1.273588603727639, 1.0770075906667098, 0.9234257349550299, 0.9035471207314537, 1.0881070481504393, 1.08771952552859, 0.9731259782042898, 0.9945954321309075, 0.9535789050092899, 0.7864435739216138, 0.8311496069907299, 0.7940223573265904, 0.743269158602982, 0.7215991347262734, 1.0347980966538668, 1.6652567808161607, 1.6295773387555283, 1.354481433438614, 1.2718063626815037, 1.428673443355992, 1.262675032973923, 1.1766134446821812, 1.108606408734745, 0.9629231259587325, 0.8429657094104114, 0.7137958958283468, 0.5122849054030749, 0.7020383395428431, 0.5440118075764613, 0.4781957446177674, 0.5427461988858888, 0.335612688473883, 0.0, 0.3558476838567184, 0.4942968669342261, 0.5406652312330614, 0.31920947887620127, 0.3896942860888164, 0.5808851208084704, 0.9928727370409641, 1.3044455223722122, 1.4915989912016383, 1.339082978787456, 1.156144284431639, 0.8613495129719166, 0.8413272058559773, 1.1144825670911283, 1.370364746210462, 1.7602774752276948, 2.1223662050623493, 2.271003319544705, 2.316377528458606, 2.3487444126290598, 2.1432068737166365, 2.0900286105706996, 1.844854540998915, 1.555287974930166, 1.4731549270608641, 1.3018070420310173, 1.131913432737495, 1.1811478034768519, 1.118503231141071, 1.31620079262295], [2.1671627404254643, 2.2451279835572886, 2.0788433045024672, 1.8608164436311456, 1.4573258092359063, 0.9310777499778301, 0.9264858303544944, 1.354894806044048, 1.866707792758325, 2.4152173262605006, 2.698140476911817, 2.8596914236561854, 2.704085523388557, 2.399781627767108, 1.8093223841835548, 1.2214226648706201, 1.035119859229653, 1.1080788954191796, 1.328062363084798, 1.6814783067215784, 1.7221499595385747, 1.7076971982725524, 1.6189784348709046, 1.1453975979250337, 0.9739558276251585, 0.9468313111664762, 1.023837960015657, 1.2072096290498084, 1.1962418397736214, 1.0735078192205751, 1.0739688536443306, 0.9427647981568908, 0.8368985126965904, 0.8864111868313337, 0.843029875690408, 0.7157030189243732, 0.6738479473603824, 0.9018545707988678, 1.520951483836631, 1.4874910497099025, 1.210220355157042, 1.1463141195591415, 1.3016714391248074, 1.1487403012141686, 1.0762220155910787, 1.0124088769825408, 0.862454364172742, 0.7649809113935041, 0.6366107021374388, 0.5004917020022651, 0.8471648752390841, 0.7187779689133765, 0.66796256589165, 0.7219137047666631, 0.5574538312858826, 0.35613504324919126, 0.0, 0.29174407009044884, 0.33752495407399635, 0.3560799949944715, 0.43886579803694, 0.7057600339708178, 1.1197905406975845, 1.3936368851509493, 1.5582461815298345, 1.409561458197758, 1.2092711749363367, 0.8394818379541736, 0.7480492784219817, 1.009123935491809, 1.2632756093113586, 1.6316670241522393, 1.98757836153325, 2.13170865150671, 2.175811731488905, 2.203868755741042, 1.9940821437405019, 1.9431359371169135, 1.724545039910188, 1.448355133681995, 1.3831730450865316, 1.216288787703332, 1.063578320536038, 1.144892949902154, 1.1359117591704664, 1.3717363238644193], [2.0611405748213554, 2.135650022222854, 1.9615012816393822, 1.73598221378075, 1.3245904347106305, 0.8342901779207955, 0.9278032682205519, 1.4005834861399435, 1.9394264620153399, 2.46020827044591, 2.7319593133418674, 2.8962651275695857, 2.74247083362709, 2.4503418396778263, 1.8718632684869965, 1.2368018977031248, 0.9655356432533204, 0.9802936308480207, 1.2051311761959163, 1.5747820339121101, 1.6254365960867128, 1.6105078859886168, 1.5146841545630783, 1.022047397824679, 0.8668236620475734, 0.9645728000670918, 1.093008421412598, 1.264390560205824, 1.2468289306952383, 1.1189098070810848, 1.1148842026320251, 0.9275252822799764, 0.8352587665437142, 0.8939650661028473, 0.8429079636378749, 0.694353129431859, 0.621986971256623, 0.8083198196240097, 1.4141682399638054, 1.3797235409821507, 1.08618954754088, 1.0380962494080133, 1.2039015540386522, 1.050247347095406, 0.9847925308583926, 0.9221395152357025, 0.7610831942041614, 0.6844273418061013, 0.5589408146784788, 0.526175394090644, 0.9147055600518442, 0.8047163801768166, 0.7580380486145228, 0.8064709917358146, 0.6580581551886122, 0.49462410482040814, 0.29183659007010204, 0.0, 0.15211082678402488, 0.41117838715432614, 0.4924921180395729, 0.7878136607591625, 1.1783259194767037, 1.4229063830147601, 1.5783152785368288, 1.4275036213383623, 1.2328504823155924, 0.7978547261896562, 0.6520436651119327, 0.8949612612148814, 1.1699591455266873, 1.528729551428211, 1.8891745950144303, 2.0345214494243655, 2.0787587848653057, 2.1073990441774844, 1.8938776107505446, 1.852803280791622, 1.6368416008519078, 1.3712806793500658, 1.3094570569455224, 1.133277967049046, 0.9795370704001732, 1.0954456801883476, 1.1285850854621802, 1.3924336481955495], [2.013450201340324, 2.0882093646347943, 1.916226378620642, 1.6821195730690661, 1.2649558702254167, 0.8167891052688855, 0.9188188352037233, 1.4178939397164978, 1.9696332099560978, 2.4844384751222472, 2.7558186272952105, 2.918969057229731, 2.768624428176465, 2.4666946029196892, 1.8962801124951438, 1.2362413533024943, 0.9462201669031727, 0.9381044509241799, 1.1597000305626168, 1.536520739253276, 1.5863251427331522, 1.5720926321857844, 1.4747217597257198, 0.967944992736857, 0.8032633711916282, 0.991298877790622, 1.12519735214633, 1.2924153559244667, 1.2742558322704436, 1.1288512670548185, 1.1173716162250822, 0.9133618928498134, 0.8385984967063513, 0.9023675145165564, 0.8502459907317504, 0.699126800294918, 0.6273629755829038, 0.7805448476013462, 1.367889554518431, 1.3300938466651826, 1.0377399785508028, 0.9961169557145928, 1.1610842682483717, 1.0191871146163225, 0.9556650713382341, 0.8880073666050585, 0.719249195997745, 0.647055467633976, 0.5282449302746246, 0.5332604128662738, 0.9369820058537521, 0.8357629498793816, 0.7893274196922202, 0.8535474366184147, 0.6938894893467139, 0.5407920532982973, 0.33683134384906094, 0.15201563215771277, 0.0, 0.4655906511831384, 0.5396705745093356, 0.8201303298788242, 1.2056108788790556, 1.44597269356039, 1.5992119955075712, 1.4490908303220864, 1.255626665455615, 0.8250923203161197, 0.6229172939382819, 0.8495838861673272, 1.1318191747442323, 1.494580557294684, 1.852517383858459, 2.0005573797298823, 2.044901233088169, 2.069353243301946, 1.8586727191186854, 1.8164055200633824, 1.6046437774049627, 1.3392826686604218, 1.2836671818805123, 1.1119777929875967, 0.9616218754671587, 1.0875714014042979, 1.139563859368701, 1.410807312708875], [2.319902238080404, 2.382404188407719, 2.207615545911242, 1.993471773859424, 1.607628001031048, 1.1348083216350526, 0.932412455343815, 1.253039879392929, 1.699567643740219, 2.2539617656987074, 2.53658580094766, 2.706860811984466, 2.5472233048759754, 2.230844928358503, 1.6380052735615198, 1.0938414334637334, 0.9451429407119287, 1.111140286170777, 1.358352800063121, 1.7369663793322376, 1.7953376935508334, 1.788810492481906, 1.703888872930202, 1.2293832217183667, 1.0518537483417871, 0.8828482684906449, 0.8989882443989994, 0.9984095661932765, 0.9974078209777542, 0.9469122493453404, 0.9991377672447537, 0.9334055190793862, 0.7230637067959622, 0.6981008054781267, 0.7154178797280564, 0.6573677485845298, 0.6431102068237978, 1.0012428021745357, 1.6260047379761637, 1.5862775330889598, 1.2785071639863923, 1.1980207074618587, 1.3633853546150763, 1.194753543400692, 1.1301961927058837, 1.0631242413189317, 0.8699129792212084, 0.7591149385176558, 0.6605541753568198, 0.45049407174790557, 0.6427922830995089, 0.5283700859085487, 0.47810056930558403, 0.4912536961373065, 0.36472065923654456, 0.31847364143824747, 0.35587858975119124, 0.4105883207108337, 0.46561352532594635, 0.0, 0.17458237958156766, 0.48697940355375624, 0.8618418706964007, 1.133051532321466, 1.3090052141070998, 1.158121965890522, 0.9989974922839083, 0.6506032765025959, 0.6746732222151632, 0.9832690894829704, 1.311087406261367, 1.714638573382818, 2.0850260643708856, 2.237589970990592, 2.2916024211644297, 2.330237347225111, 2.1157229154868453, 2.067232206867676, 1.8048157330048555, 1.507196097903091, 1.4023721659720874, 1.1936946567647544, 0.9769788749899585, 0.9722643150846669, 0.9154408113694832, 1.1400408175573977], [2.3538303544101042, 2.4194430442763424, 2.2423088210603357, 2.025455375559071, 1.6595969834514628, 1.1919498180211832, 0.9717244305020302, 1.2041253489753512, 1.654550776285477, 2.2317254503611044, 2.528770391867875, 2.690709835318062, 2.5401417816718954, 2.213278801629005, 1.626857365309373, 1.1202652832906703, 0.9923699189686023, 1.1453933005184402, 1.3905892783786415, 1.7487530954199706, 1.8064260938221286, 1.7977927572681285, 1.7175317530923948, 1.2421777378030525, 1.064745497542988, 0.8882599712573949, 0.8996744015040893, 0.9615785226061204, 0.9658069388528301, 0.9049458188036485, 0.9602359290660475, 0.9152788174475194, 0.6958919281163063, 0.6742103070420737, 0.6783548521754007, 0.6482323380234034, 0.6616053083047013, 1.0187617676031202, 1.6465410659409094, 1.6129054524268671, 1.3095151194132568, 1.2255238406844313, 1.3794350256024297, 1.215198863989743, 1.1388531694844588, 1.0795734884829196, 0.8852358556854731, 0.7493991816069445, 0.6538155221483021, 0.40418077074160014, 0.5721643017596253, 0.45463754658668754, 0.4159643876943573, 0.40555540778208693, 0.32420738037038954, 0.38941621190490344, 0.4389133814340607, 0.4920398198949588, 0.5398110286634737, 0.17444015884348588, 0.0, 0.4068160557299193, 0.8057238605022213, 1.0980207686182915, 1.2996504246732408, 1.1540122308683662, 1.0092815866857152, 0.6627856498806844, 0.698504196913436, 0.9935577725633945, 1.3300241552842804, 1.7439942931213648, 2.1158093986020625, 2.269252407035381, 2.3288577749494546, 2.3719702610122866, 2.151387436839799, 2.099073310486769, 1.828346866915225, 1.5239613847120337, 1.4086822753867694, 1.2045907241851168, 0.9965712579654636, 1.0013751369447088, 0.9308418486079317, 1.1333418499691876], [2.5504457389185746, 2.6070412320093137, 2.4197624515500498, 2.215181922185277, 1.8623590282288278, 1.437177364572469, 1.1598960557470166, 1.1853768708911967, 1.4972728055046125, 2.0694381187719606, 2.3955331472801724, 2.5587665972619997, 2.4022840275256656, 2.0708187953193065, 1.5324924504173139, 1.1595853870223332, 1.078021855671912, 1.2645141511891098, 1.4989025832103013, 1.8436864068537053, 1.9045380462399095, 1.9050968082295643, 1.8414721535148064, 1.3933608581808434, 1.2318578603638253, 0.9703503957695894, 0.9038504540497377, 0.9022985441426162, 0.8880808187773471, 0.9158210274499964, 1.0064908468110338, 1.0644185462672098, 0.7339278424277191, 0.5754073376649181, 0.6389376655634931, 0.7573143943187678, 0.7910225224798619, 1.190770987329838, 1.8122625241700163, 1.7752457094158267, 1.4598897129513437, 1.3640406893514667, 1.4990285328403516, 1.3367524731292602, 1.2579561659736254, 1.2145152988935886, 1.0211788095685015, 0.8656860831623002, 0.8520861662313877, 0.5341213820996241, 0.39586940830055334, 0.3340397094300273, 0.32039325477063985, 0.3285250464026365, 0.4548175021107624, 0.5808429811418333, 0.7057573727953562, 0.7885083675692626, 0.8195928725478577, 0.4868672950675841, 0.4065112865907336, 0.0, 0.5540414882919241, 0.9100847309988676, 1.1626508130822897, 1.0074419184531238, 0.8888332281441895, 0.6684484865177523, 0.7714226916466141, 1.0760717218816043, 1.4599606989059875, 1.8876959599994392, 2.2555178765525823, 2.4271974629216473, 2.5036875973462664, 2.546400898777714, 2.339203889210787, 2.278476245372461, 1.9795427158451335, 1.6382749088356916, 1.4731239463296608, 1.2507258010861761, 1.0263169604155786, 0.9890387542093673, 0.8598757477726787, 0.9714689304560147], [2.8487818632417996, 2.8866754009137496, 2.693807746807394, 2.5039608774889874, 2.1625511435600684, 1.8066801989313819, 1.4723038216172426, 1.3966234780672695, 1.4672571949154922, 1.8288443416669429, 2.1496372399907027, 2.3370929712885107, 2.1560983749587996, 1.8570271821203772, 1.459958489646607, 1.2373194267164065, 1.2222386577524869, 1.451058793607313, 1.681490635804037, 2.021421504294554, 2.102173230088212, 2.1127461853772074, 2.0695778200389863, 1.680026874559928, 1.5445314240688042, 1.2072832726177267, 1.0838575453756127, 0.9480613777384872, 0.9355605209677542, 1.1246493297554732, 1.2683591175268631, 1.3713919998679232, 1.0249428659256705, 0.7323808226807221, 0.9084799123756769, 1.0514637602972396, 1.0753972856702885, 1.5277362432182269, 2.070914747377161, 2.0403695072796366, 1.7028924541307842, 1.5907522091346877, 1.6922951192430258, 1.548329416498977, 1.503447929899246, 1.4745482537479195, 1.263277401283228, 1.1795377800718105, 1.246786300859273, 0.9903179598260129, 0.523337714818388, 0.725742578277563, 0.6836005643000865, 0.6438937273551721, 0.8355028237208713, 0.9930450573376344, 1.1192577525906422, 1.1786310416168007, 1.2050121923868207, 0.8630332359817218, 0.8048785733913137, 0.5538335232798568, 0.0, 0.530654302609149, 0.8706145480590493, 0.7185387694829483, 0.7382096071880726, 0.7023467153248916, 0.9631842644740203, 1.2645149837699066, 1.712289442418476, 2.1300935115593655, 2.490590365639389, 2.6685518813594777, 2.7494893483822134, 2.80152837500473, 2.5992189725039587, 2.5451881995109753, 2.226985374384743, 1.8745621199442692, 1.6457862874682334, 1.3713874625391398, 1.104130319226872, 0.9789051953498561, 0.7830226625614208, 0.7462174736773529], [3.033304400365735, 3.057594699020303, 2.8564575645474357, 2.6776633868083337, 2.3527940756182892, 2.0337614040321768, 1.7485533742542065, 1.6493489316729044, 1.6434650672717297, 1.7458680351829838, 1.9901614333033508, 2.1620184424930375, 2.0188082661561557, 1.7668570769527947, 1.4667649496711905, 1.3026917781629515, 1.2834219756468361, 1.5256730946555745, 1.7653918471531167, 2.175530673085232, 2.275412521468084, 2.2828858011514286, 2.2507555337898477, 1.9056603293821943, 1.8024923751753772, 1.419316673830559, 1.2874475147085815, 1.1197677568651283, 1.12097007529608, 1.3501985173292004, 1.5164284408841058, 1.603626834778995, 1.2509407209823422, 0.9439639478696059, 1.1400123470883001, 1.2659128129015835, 1.2929729591744439, 1.7689405348067695, 2.2559689012897097, 2.22292179573004, 1.8677527044262254, 1.7477686509755883, 1.8364114614216904, 1.7100578385031369, 1.7004551773201502, 1.678785467974674, 1.4723705527066882, 1.4351425832780769, 1.5163715422932618, 1.3122526865009874, 0.961975997223091, 1.1156140351737864, 1.0880818995171582, 1.0418363741834031, 1.1856910363238136, 1.30384978326536, 1.394048554916981, 1.4228118045786446, 1.4464916932557468, 1.1322902090065992, 1.098510853499963, 0.9107150097242198, 0.5307422936893758, 0.0, 0.5651530408641957, 0.4594056018579584, 0.5985532480121097, 0.7872937909339731, 1.1333006253746667, 1.4297727775437827, 1.8888701752914112, 2.276975955757436, 2.6296659147443737, 2.809823538708208, 2.8941736927941966, 2.951007318470386, 2.7584152282123484, 2.7061104913718355, 2.3894441381970846, 2.0526194704832483, 1.8111918770797646, 1.4800534758536388, 1.1588660335233592, 0.9184304271537398, 0.6992286982124747, 0.5860722578035402], [3.162706207968175, 3.1636203192357115, 2.9575956761021196, 2.7867729459553, 2.4596051879257854, 2.1619516817645272, 1.910625083366474, 1.8330641269669568, 1.8215941240694433, 1.8836435334625317, 1.8947075576566124, 2.0485431051194944, 1.9529188149393264, 1.7423098354919009, 1.4590361108799148, 1.301846821576173, 1.2529313682512346, 1.6537508007672113, 1.9016159807510027, 2.3281064217396072, 2.4280504862874754, 2.4382346394645733, 2.4097922152374203, 2.1074764537687893, 2.024423612782754, 1.6648406955831943, 1.5082837101624726, 1.253618493288144, 1.2566415141861413, 1.6188963766332158, 1.8170416823894067, 1.8757694273075676, 1.4351825628278996, 1.0732981165867574, 1.3667768889267453, 1.4743996475876808, 1.4985799587575743, 1.957818490532967, 2.3804125735558626, 2.347867666320984, 1.9902870274274087, 1.9104176462680786, 2.0819417509308935, 1.9411841473743243, 1.9389956069289072, 1.8698897538095312, 1.6282031172472997, 1.6051060801139188, 1.7030783333643096, 1.5248787537296176, 1.2377113817507, 1.3548426501423918, 1.3415588203090167, 1.302711630779524, 1.418318529518413, 1.491434590111619, 1.556965483741427, 1.577034444807008, 1.6032337969999007, 1.3082010113778688, 1.2989164297880114, 1.1609452286593853, 0.8723037801622123, 0.5642869409380163, 0.0, 0.22876492085429068, 0.44493590925540755, 0.9225581089522099, 1.292244232024403, 1.5622848002281562, 1.993939437007061, 2.36374989451588, 2.7083270948750213, 2.886917733365544, 2.9687897278755853, 3.0323841205461304, 2.845949223398976, 2.7986970995912395, 2.4942946451944934, 2.169747825165567, 1.9366638461059487, 1.6268370019434129, 1.32599845179016, 0.7594787479348709, 0.5402074602163237, 0.31363249868840143], [3.016866834952885, 3.0181012453955236, 2.81502642655426, 2.6426504435573537, 2.3098632211970966, 2.010821226745247, 1.763920765787305, 1.7522353430193078, 1.782027799454858, 1.9028554881049453, 1.9903647769552846, 2.1431171115368652, 2.039526891535257, 1.8027211724398842, 1.4727208278818877, 1.2565990160299831, 1.1582465197009375, 1.5081213389115207, 1.7473389274644695, 2.1695317631676514, 2.268860138480951, 2.27802099495434, 2.2483800225397848, 1.9364042840150488, 1.8657973159526307, 1.5552402499316038, 1.4052702175475635, 1.193796870939007, 1.1935499438244705, 1.5133520114985488, 1.701333016532054, 1.7370462431528704, 1.301066768741853, 0.9178990508500436, 1.2079786660760778, 1.317025874766954, 1.333765738124355, 1.7901202089768438, 2.231310698114053, 2.1971867855765637, 1.838392227326192, 1.7521308410407412, 1.9197406821202725, 1.7696542227339407, 1.7623820944854245, 1.7051456625473074, 1.4662821677767675, 1.4460476415820431, 1.5440712436889898, 1.373248714354131, 1.0805475485262557, 1.2081962388892946, 1.187007990298959, 1.1540312020760086, 1.267463920115581, 1.3374328325601894, 1.407546977957991, 1.4271083631247474, 1.4478815729231636, 1.1574563124022998, 1.1538866285400657, 1.0092566876181979, 0.7178580368935946, 0.4589472642505272, 0.2287035768243046, 0.0, 0.31753376096951685, 0.7624661626660939, 1.130807618180294, 1.4015366367852535, 1.842892413678382, 2.219582043075655, 2.5723304695137927, 2.7498851886353473, 2.8308235332648355, 2.892435148318234, 2.704738709493714, 2.657172465533109, 2.354938301312363, 2.020606090751241, 1.7878314508345932, 1.4614477287928664, 1.161587497509564, 0.6673253411007868, 0.44482698107794794, 0.285754550755895], [2.8160098560905347, 2.8190967434173584, 2.6174978438317007, 2.4397879454729163, 2.1002035186419183, 1.7917768435182249, 1.6337384719048624, 1.7213636404300636, 1.8163026479254287, 2.0436550746096684, 2.1424195269962554, 2.2961689631044293, 2.178255458413349, 1.9352522662604463, 1.5215638410499972, 1.215389960628155, 1.0233075947085155, 1.327409952947227, 1.5647358475138375, 2.000536048495235, 2.0950354731817735, 2.0972109756594297, 2.0635845649329885, 1.761527106172357, 1.7175726138377216, 1.465195222473828, 1.3358103845974794, 1.1932236922296544, 1.1875250932028991, 1.465496092311548, 1.6369877173083205, 1.6291198865089467, 1.1631783393921256, 0.7710796841288078, 1.0585794511990254, 1.1451681205186168, 1.1512770003912611, 1.5939299084174212, 2.041973846138349, 2.006791397657838, 1.6460808283308177, 1.5618266525373912, 1.7449919883435048, 1.591017788338035, 1.5820014445708748, 1.5125656777114438, 1.2802617464831108, 1.2610065672330235, 1.3652913641899738, 1.203146293679886, 0.9928958431333221, 1.0835358497385, 1.0662736423445898, 1.0629354139959282, 1.1391584980340743, 1.1546691710572425, 1.2088900924103183, 1.2325839523680524, 1.2541859032357388, 0.9961275110984366, 1.0105490014269507, 0.8903669531665824, 0.739806365247194, 0.5972082879859519, 0.445104929494212, 0.3177376854800275, 0.0, 0.5978231840347101, 0.9495075125892726, 1.227512994724025, 1.6490602806559946, 2.019121676786184, 2.3747467711266643, 2.557559693968567, 2.63363879590556, 2.693814697601885, 2.5044119044944866, 2.456420023997879, 2.1635999039292653, 1.833284492110974, 1.612412558839534, 1.289661131671737, 1.0019738211263987, 0.5191332580067641, 0.3361458904356334, 0.3523340381031451], [2.3719949773385856, 2.3953832288731776, 2.1973753474023936, 2.0046872427180875, 1.6353010272060426, 1.328946776816146, 1.3586987056341218, 1.5851448690615093, 1.875320062683891, 2.2176705095592064, 2.4447733466994745, 2.603588254837379, 2.4593791266630185, 2.1851077062151556, 1.7134855567131848, 1.234397388259542, 0.9159624158711064, 0.9216472510803869, 1.1572004648073235, 1.5816770949044234, 1.6664405960400361, 1.6684799263629244, 1.6215771230491405, 1.2944447348648527, 1.3042486534914233, 1.2359757900713093, 1.238872988164583, 1.208342532788567, 1.1860048863767305, 1.2872935958034735, 1.4019118097111096, 1.2931873892454242, 0.8922838087825831, 0.541334714497773, 0.6946183109887252, 0.7089526847489416, 0.6905284348102969, 1.1007213078333917, 1.607358198714335, 1.5735859333757645, 1.198887736285138, 1.0971093221050106, 1.267381654929086, 1.1054232181343768, 1.0930247810562712, 1.0364665498549868, 0.8087899231413336, 0.7997985966144487, 0.9097815187425856, 0.7996250917526204, 0.72976995944977, 0.8111493772274512, 0.7806091348747685, 0.7915315627221421, 0.8386016339519857, 0.8622760064175721, 0.8389563637628934, 0.7984178193080096, 0.8241742739640884, 0.6504388726601406, 0.6627394923415488, 0.6688350516546715, 0.7026723544005812, 0.7862436458019163, 0.921204360363772, 0.7623280488500426, 0.5978248756465592, 0.0, 0.46938200979895106, 0.8034057967551104, 1.2431996243469339, 1.6184583388415845, 1.9871378309262218, 2.16732430712596, 2.2434154568158533, 2.2964087774465547, 2.1007621101731844, 2.0533189417516855, 1.763107687906917, 1.423992226250587, 1.2076220223145016, 0.8916806928257203, 0.6072451176096184, 0.5818862524690678, 0.5700853443406123, 0.7771292474863606], [2.0218135131041293, 2.0578964802664235, 1.8551113159077404, 1.6497961380111188, 1.2648960610731983, 1.0635626406655585, 1.2773868065208867, 1.657985666315807, 2.0267777369242883, 2.4340255491649585, 2.7006427729961704, 2.860964487563895, 2.7143971025814997, 2.4306491747384693, 1.9459561116804378, 1.402290679039681, 0.9957075609881064, 0.7285920103229019, 0.8718109933316917, 1.2691894512745352, 1.3457627837508477, 1.3474059682260853, 1.2908608918016737, 0.964504302879062, 1.0828011826064314, 1.2997139390008223, 1.3766623445923043, 1.41561046805774, 1.3872270018415873, 1.3770326779406517, 1.4098029119607944, 1.219245370268787, 0.9173370947699577, 0.6259370061523429, 0.6467768745216939, 0.5897490050975103, 0.5438719967677261, 0.7816909222035466, 1.2603902228988748, 1.2227739548755778, 0.8341474158042401, 0.7712372530344893, 0.9472237551707642, 0.7931442521652599, 0.7664439235961856, 0.7104515397590502, 0.46919959580665715, 0.49755089667205593, 0.6593862220676758, 0.6502258886025019, 0.8163311992705606, 0.8397528958414983, 0.8163262786753724, 0.8819701549663571, 0.8533095813790373, 0.8410232938693207, 0.7474848228987827, 0.6517610119280404, 0.6231758931075122, 0.6745258460533675, 0.69825952828141, 0.7709091849225813, 0.9641356899039454, 1.1335211274691706, 1.2943039534967329, 1.131217448634434, 0.9491726371401532, 0.46941977101286236, 0.0, 0.49155820516746757, 0.9400320201644549, 1.312337282599393, 1.6773953382175744, 1.8566331646847751, 1.9395616369276654, 1.9775691698562317, 1.7829404204292176, 1.7348944269693392, 1.4636822760047001, 1.1136862134696268, 0.9293944891413715, 0.6629986661527507, 0.46183514287557337, 0.7821093922296037, 0.8870251473255911, 1.1251530247592019], [1.69722902732814, 1.7249467302080346, 1.5054877474979846, 1.3150676318948273, 1.0381716742882983, 1.02539368419664, 1.407377703947613, 1.8731223904549301, 2.2391697745716184, 2.6640336600907895, 2.924029067805151, 3.076983037222744, 2.938685333193909, 2.647756304022442, 2.187228458719936, 1.67827989409908, 1.185932239507702, 0.686146032633415, 0.6478406417377836, 0.9280171222980093, 1.005580180209861, 1.0185952893975676, 0.9654828396464533, 0.7747716755809148, 1.1493320404578566, 1.590398362625515, 1.6803234905068196, 1.722226167072586, 1.6965725258714168, 1.6538785124695112, 1.6666515840825624, 1.3444536678342247, 1.1071685988100868, 0.8585218376876423, 0.8066029868670905, 0.7332737459112698, 0.7226715683761165, 0.7292092799348078, 0.9136074034993718, 0.8777161764318042, 0.5995334132312966, 0.5776096003639011, 0.7556039515560437, 0.6349879613882412, 0.6090141599534737, 0.5415402266725676, 0.3460403608365937, 0.45474260158670227, 0.6774710457515367, 0.8335651576978317, 1.084573486988804, 1.1041565720970705, 1.0940787395962153, 1.1698298764926187, 1.1290149448288351, 1.11619098566031, 1.0079514300860717, 0.8962422114046131, 0.8494945851596002, 0.982714783019465, 0.9949990599870712, 1.075454294286727, 1.2653694169493797, 1.430696791507631, 1.5586754088404402, 1.4022475810144714, 1.2292705375499486, 0.8032226751701838, 0.49172297158733014, 0.0, 0.6214142030593279, 1.016774873762014, 1.3647229302914123, 1.5434891498675467, 1.6321428137246343, 1.668709625680178, 1.4777842923851876, 1.42059575717577, 1.1512330841181715, 0.8361509230320092, 0.6835421260457276, 0.48822081292770236, 0.4730992532268174, 0.9939552448718206, 1.1755792383144774, 1.416881996148128], [1.2489378677966483, 1.2453961047728765, 1.0661911979259742, 0.9273997505398566, 0.7538167775262511, 0.9325252915924838, 1.5416623328777368, 2.0867867557176916, 2.5179755741145144, 2.9992978513400983, 3.252061334578605, 3.4014165590267433, 3.270366583700506, 2.992684474723245, 2.527696302645922, 2.0310516571137054, 1.545832981736458, 0.8678620793621916, 0.6272958922003836, 0.6298480940332252, 0.6279875069100093, 0.6024698255002081, 0.5449359986287738, 0.7988603904940843, 1.3476409095919741, 1.9019975833260991, 2.0010384345993253, 2.0844731096645472, 2.069445903222566, 1.9634848526218345, 1.9356917482290275, 1.5743578735940977, 1.3771530622630785, 1.2394730171407522, 1.101979593800025, 0.9815664271247041, 0.988561124747366, 0.7063069020644328, 0.543975950615452, 0.5427284112740606, 0.5028174228886201, 0.5460108915290176, 0.7113433277025333, 0.6380350408774842, 0.5984163719802671, 0.5172877920267009, 0.5420597463056955, 0.6646783176032739, 0.8390098187199485, 1.1162425957064512, 1.461260470452727, 1.4192402482424338, 1.4243682443918495, 1.4957419428940661, 1.3997413241349237, 1.3703364327608425, 1.2635336185852812, 1.1695880159973682, 1.1318010430700154, 1.3108530605172295, 1.3295228072003995, 1.460054207147678, 1.7127216528001021, 1.8890501114565217, 1.9923715220128757, 1.8412960722147227, 1.6448436236611907, 1.2426809152892007, 0.9406175194892356, 0.6210474861921073, 0.0, 0.5586167566963002, 0.9410883212285326, 1.1001735207195205, 1.1728371593125666, 1.2191753025721221, 1.0289375309912356, 0.9624561367643126, 0.7411243387999678, 0.5220720363947755, 0.5708771170601605, 0.6262286021044564, 0.8427986515444268, 1.423594514035116, 1.6284605136617598, 1.8719724217285907], [0.9738106842738841, 0.9421702778493234, 0.7748196147469475, 0.6848370535771309, 0.6351722361149664, 1.1508920293911606, 1.856794701702196, 2.387676429924504, 2.8235608738946976, 3.2721882709763244, 3.5150643210939094, 3.660907889361743, 3.5355851218739005, 3.2659851081511215, 2.839534765200819, 2.3690862504186456, 1.8971744689487446, 1.1714280678612772, 0.8058935032359741, 0.5336966122992707, 0.4880452709997527, 0.4560575011695647, 0.4725267637901686, 1.0941680756941423, 1.6716739056104268, 2.236520438872664, 2.3541915895050285, 2.4551607302137803, 2.4447726806508183, 2.326524363745463, 2.2927153407819802, 1.9376740616384889, 1.7967172789348596, 1.6289319127506148, 1.4912245209565378, 1.358979500820969, 1.3457884887177904, 0.9756048113938708, 0.4748281212127599, 0.5054422078385713, 0.6455160323700923, 0.7390153853522474, 0.8530348897217351, 0.8489998990890215, 0.8511016639239124, 0.8236103618534114, 0.9367169754484335, 1.1024560948445215, 1.2518209735854364, 1.5264246690724015, 1.8806522735284272, 1.8366230669586037, 1.8424061854836227, 1.9118691080048216, 1.815006549691979, 1.760892491219019, 1.62903226155576, 1.5277235917631513, 1.4970954785295947, 1.7111341583711654, 1.7424472335981775, 1.8893913357978873, 2.1303042963104932, 2.279624725199142, 2.3687649834168814, 2.218796401789479, 2.019124879395467, 1.615257168367223, 1.3136012186435977, 1.017351456674838, 0.5589963069216779, 0.0, 0.5040530046153346, 0.68396274619968, 0.7602431623830539, 0.8113138640618865, 0.6698998026988262, 0.6275073798499846, 0.5100637597836475, 0.4857009761340138, 0.6587944410687424, 0.8712309232945725, 1.187189339919221, 1.795762423144027, 2.0096860634185463, 2.2599072484812432], [0.825703978542926, 0.7618162830710462, 0.6305195559412601, 0.62629937539132, 0.8080245230438564, 1.4954773371407695, 2.15015007230013, 2.659167175121683, 3.081023833583285, 3.517088519187096, 3.7462456131329973, 3.887298434189044, 3.766798816806405, 3.5059166829447035, 3.107708398099541, 2.6619179855443567, 2.2308191046100694, 1.5312020912980526, 1.1231234378027286, 0.7079235626436208, 0.6494521092433749, 0.6746870032216497, 0.7386077104228463, 1.3950840641867253, 1.9661675167357513, 2.532183019495967, 2.6488029941821734, 2.7567199112359204, 2.7481128475588688, 2.6281063154838304, 2.5829027274698575, 2.2494500563104185, 2.156160821206875, 2.002216288121387, 1.8494353629551248, 1.7218711443427726, 1.7060648742697135, 1.3048133144908378, 0.651165378291589, 0.685614493498539, 0.9290150849158707, 1.0446158419176075, 1.1021267048387537, 1.1441306258184893, 1.167813235187688, 1.1601686674772484, 1.3215007909441034, 1.4865356785302761, 1.6150847646815276, 1.8884805185504372, 2.237343931129148, 2.1941537192776224, 2.2008120007133094, 2.2781491391589053, 2.1775750596332064, 2.11884370289584, 1.9855540475189588, 1.8878602132201294, 1.8510005300797925, 2.08134202220862, 2.1109773177989033, 2.253828939915259, 2.494340772524662, 2.632326780691773, 2.7139663618364023, 2.5774214466680836, 2.376977717419306, 1.9857288981524146, 1.673113127420176, 1.3663762521743295, 0.9411779103078045, 0.5052723995701155, 0.0, 0.3369493251698259, 0.48040427980265143, 0.5218760394514179, 0.48690033925569387, 0.4684407328120072, 0.5217114892631766, 0.6821727176901661, 0.9012546858675845, 1.2266420969740146, 1.5530209233152856, 2.1539903052197387, 2.375063318068925, 2.6107669430995957], [0.7182326014514785, 0.6156470054982094, 0.5215650029904951, 0.624722935300439, 0.9447466078920936, 1.6400941115295136, 2.273639554811773, 2.7869064421563268, 3.218645569839903, 3.6400080406017277, 3.866953199745406, 4.006997861936804, 3.891164260896155, 3.6359908454204795, 3.252733762901174, 2.811805884581412, 2.4028919527237336, 1.7334436730087894, 1.3352564904638002, 0.8525240333732761, 0.7925458633186102, 0.8459448692224983, 0.8988003209573685, 1.5560396047747358, 2.1065374330921216, 2.670905812852796, 2.7819592710306558, 2.90005979808544, 2.8928467845724573, 2.758624657630846, 2.7070357603103274, 2.388439278217682, 2.3243284681513114, 2.200293466060983, 2.048708710865403, 1.913176768207083, 1.8993841419911985, 1.4714642110072396, 0.7325487752238256, 0.7748376445781421, 1.0812663085846526, 1.1931471209202815, 1.2373962253235755, 1.2886928897029837, 1.3272338749936923, 1.3344319896842725, 1.4985463859845018, 1.6527288582933088, 1.7568971002454803, 2.0387394475775733, 2.4097457567063674, 2.3576783140376136, 2.3611309886947756, 2.4362792202095163, 2.339689408559075, 2.2710640682339633, 2.1317641131748295, 2.0327237068431603, 1.9974932478416603, 2.2368113365496463, 2.2672702116995813, 2.4302246350118435, 2.6713718006484433, 2.8104707568652585, 2.888581220520321, 2.753606947177317, 2.560043223184669, 2.165072630006987, 1.8555575564062985, 1.540712146124345, 1.1018497434120587, 0.6826420006910042, 0.33706789640109536, 0.0, 0.252761299822571, 0.299871513258093, 0.3247654822390895, 0.3326879366323483, 0.5262266016357939, 0.836426344155053, 1.1044831475605976, 1.4255908333836933, 1.7449446471951726, 2.345006402066015, 2.5571143867300474, 2.791275357096375], [0.6608752727205364, 0.5487852733880281, 0.5080355038873946, 0.6449251148611383, 0.9949622676674579, 1.6691777706244233, 2.31297071826785, 2.847180640478083, 3.274777189751959, 3.6960840998072064, 3.9180192313359656, 4.054653659034602, 3.941601003222953, 3.694309095899856, 3.3109487348434232, 2.8699135090822963, 2.471476891055453, 1.81491703487519, 1.4351824979753978, 0.9370681446135514, 0.8789393872080798, 0.925928950281384, 0.966185007880224, 1.6249020849350184, 2.1568912029540526, 2.729958523542197, 2.8421036960187522, 2.966927613947979, 2.9607408340690684, 2.8262272584383568, 2.774615260209936, 2.4466841308425695, 2.403671021194394, 2.295628634817771, 2.143698859346441, 1.9993050480223682, 1.9804396042305557, 1.5548260952995128, 0.7896750989732098, 0.8367880928895225, 1.1456973613815031, 1.2588154879907556, 1.2989720543831043, 1.3511668475257443, 1.3974753135938867, 1.407617628543929, 1.5691380176349594, 1.7243021399851284, 1.8235708648126991, 2.1076916329520228, 2.480743180170989, 2.4285395214569583, 2.430807830111456, 2.50318643891234, 2.395181772457286, 2.3207575182956868, 2.1753155437518545, 2.0767668247837174, 2.0436345947744172, 2.2995604207461016, 2.3355589657749825, 2.5075888021312887, 2.75520854186168, 2.900773048182443, 2.973410935076499, 2.834812607826081, 2.6395067792950533, 2.2427999928392035, 1.9377873299882418, 1.627968917914364, 1.1748544017412539, 0.7593079525666093, 0.48125023475415263, 0.25260457192494756, 0.0, 0.12936681497827615, 0.2411910374761423, 0.291684907874195, 0.5737617967281375, 0.960042293241997, 1.2238441166379161, 1.5153746610648466, 1.829268659277727, 2.4326355201547023, 2.6333656592284878, 2.8727854469369114], [0.5961162185208135, 0.4931584739058183, 0.46592340258847775, 0.6096078488900111, 0.987126017009973, 1.6775285266985214, 2.3431407747412916, 2.8781120960732576, 3.3067887498095825, 3.7308752634682825, 3.9506384351828845, 4.087025562067034, 3.9746009158895967, 3.731973110400003, 3.3520488264173403, 2.9123496827347903, 2.5106945168844543, 1.8466457826606895, 1.4694674425728174, 0.9765589212500192, 0.913134360814391, 0.9582302881868224, 0.99195557715915, 1.6401086337743944, 2.1685621169585216, 2.753245852782157, 2.870045381398011, 2.9976332839315374, 3.0006278252042913, 2.8536415847112626, 2.8014528268644496, 2.4732940644839467, 2.4397049927892516, 2.343874318511932, 2.1855608240790363, 2.0404067834456914, 2.017331133391925, 1.5800479977125894, 0.812362662534346, 0.8564357648630299, 1.1751532057651397, 1.2891791015710137, 1.319696026501057, 1.3801742288068417, 1.4275242950272624, 1.4391202725286467, 1.6108680624660743, 1.7619218778187669, 1.8539526365566015, 2.1408717767285883, 2.525138167347802, 2.468757469554721, 2.470873946163365, 2.5475417847492023, 2.430948638718197, 2.3508145465408234, 2.201622920975571, 2.10387878104067, 2.0671224911323747, 2.3370922908839344, 2.372779310293809, 2.5529118985040267, 2.8063325663107443, 2.9530013466296383, 3.034664660866421, 2.895695309413806, 2.6987371851240494, 2.295130538349658, 1.9756002164236, 1.6679082693018152, 1.2224745593584947, 0.8101998676121384, 0.5226433107485517, 0.3000910485125221, 0.1294225847874432, 0.0, 0.2589749068406113, 0.3131639929965963, 0.6308580538259319, 1.0110177977906933, 1.2772679614465394, 1.568947391426895, 1.8787186221140166, 2.482768779907788, 2.686349414895638, 2.926870887404575], [0.603960182882302, 0.5378795119547841, 0.43669158540147085, 0.49392761498003707, 0.845598865578811, 1.5074370786764175, 2.180979421301548, 2.734850276331084, 3.175145991853241, 3.6137295495370902, 3.8414921376683546, 3.9774974078083773, 3.865837597186533, 3.6219268133450275, 3.227218951850543, 2.7777893296538103, 2.3645084152471947, 1.6881713532976952, 1.3253434212435802, 0.8477810589349278, 0.7921659360535728, 0.8422835010386207, 0.8552973866001395, 1.4773765906173386, 2.02751801243985, 2.6176626905138414, 2.7344596922354985, 2.8573435115720955, 2.8585504121611556, 2.7130056325981475, 2.655643502880171, 2.3186617287743108, 2.268910080896433, 2.159168539566337, 2.003842493210116, 1.8569109141479256, 1.8327731967283452, 1.3947179205548708, 0.6211193138182636, 0.6625088006025925, 0.9798456672841567, 1.1019240930143976, 1.1499686628322596, 1.19623264635879, 1.240259651200022, 1.2479993218162233, 1.4107786273594443, 1.5534168466613492, 1.641281787214459, 1.9247181167167156, 2.3172293805648865, 2.2563296222252616, 2.254896225051408, 2.337994425844209, 2.2156362275355397, 2.140249837889684, 1.992595810693023, 1.8937118500891061, 1.8570763452483066, 2.1140826200265717, 2.1507844650657044, 2.3421107783100017, 2.6037950041702627, 2.7662899629207693, 2.850681058895934, 2.7121466762876922, 2.5075868203484846, 2.0997253450350417, 1.7810724135414369, 1.4771975765144174, 1.0329680317005496, 0.6693359466151902, 0.4873471443815666, 0.32488896810806644, 0.2414517175703185, 0.2589040556739937, 0.0, 0.12637899603592254, 0.4432280664573514, 0.838005151294143, 1.1155184501565774, 1.4038839981347209, 1.7015515577286857, 2.291078238718895, 2.502034205980551, 2.7451996574818174], [0.6005794233633072, 0.5392610856890594, 0.4229343837914549, 0.4808075869670783, 0.8235567495771103, 1.4630358440648548, 2.136963263186078, 2.689302510239387, 3.139984331656307, 3.5808498658744523, 3.8159754547903506, 3.950161982051607, 3.8384728090111278, 3.590110554112337, 3.193365207274112, 2.7375942971352747, 2.317518886639544, 1.6446608159299894, 1.2770289776938895, 0.7942100359819775, 0.7331052304061182, 0.7852230622002403, 0.7975941849109861, 1.4286295847387225, 1.9859766598073436, 2.569987171472879, 2.692017380790089, 2.816344592624967, 2.8126860725575518, 2.664970861363863, 2.6057310734227888, 2.266657366920205, 2.2191557776354105, 2.1036832502884772, 1.9434545330280317, 1.7944820171636937, 1.7784844830565476, 1.342563596516759, 0.5618496807193419, 0.6105702624208978, 0.9398458922380953, 1.0548576044118023, 1.1030166158071344, 1.148278490214418, 1.182844691925739, 1.1895506524862436, 1.3563618953028016, 1.4964163426466381, 1.5821313652377593, 1.8666732760868858, 2.25615004044289, 2.1974764294381233, 2.197430630795086, 2.2745742318181845, 2.159680119334452, 2.0879495508928767, 1.9423759013633284, 1.8501531090928154, 1.8145258452578874, 2.064411104888786, 2.09789253852393, 2.276450160846604, 2.5471257692737526, 2.7078152387400034, 2.803560510098748, 2.662105164675747, 2.459321562980636, 2.051543890951029, 1.7331129468590938, 1.4225298190471185, 0.9614733304425652, 0.6286924812018546, 0.47011396024311114, 0.33295623642020095, 0.29136600025262144, 0.3128998956962971, 0.12640712408760235, 0.0, 0.3860704284731557, 0.7800677988938615, 1.0640748636035533, 1.3530379975878521, 1.6499539037819735, 2.2451968151271777, 2.4590479906893874, 2.698378702780799], [0.8750826057672382, 0.8406597293989545, 0.6720469762194066, 0.6392420392454297, 0.8223867775814099, 1.3845886574036372, 1.9741702801279328, 2.497345430279151, 2.9479979432730183, 3.404258089479157, 3.647566485814125, 3.789162166840597, 3.6732094172990877, 3.4156045493699327, 3.000282380839589, 2.5461265484708973, 2.125573186553581, 1.4624203699094105, 1.1022076162885956, 0.6015764489151317, 0.5766396411265315, 0.6660892579074369, 0.6906943922113279, 1.2886830790089294, 1.8539916318126661, 2.398577219040116, 2.5064466327849497, 2.607675384115327, 2.6013369926755585, 2.466928774227515, 2.4215840954273, 2.0962484750108965, 1.987223049355268, 1.8196341761799228, 1.661283964432293, 1.5406862831810404, 1.5373624188585775, 1.1457758463950196, 0.40317088818700075, 0.43982958791926374, 0.6983014121562062, 0.7919478021348937, 0.8809253448959858, 0.8901456584000329, 0.9313288199615773, 0.9407089483883372, 1.0950125630657648, 1.2280985846640826, 1.335237057206537, 1.5973790360320508, 1.9502927681300763, 1.8979052303338675, 1.9042783458762647, 1.9785591326730785, 1.8851298535783987, 1.8412211313606037, 1.7227951117331177, 1.636689462291639, 1.6042590425725953, 1.8042671141673832, 1.828568366052999, 1.9796565906919719, 2.2247105592435172, 2.3951606297985975, 2.4982680672944624, 2.3599371504659703, 2.163544396239145, 1.7634720558334067, 1.4608012429265596, 1.1521919950732733, 0.7397232988751891, 0.5105435666363992, 0.5221519554482161, 0.5266804800202824, 0.5723830721704611, 0.6304054600315239, 0.4434319333449061, 0.3862146793387176, 0.0, 0.4958171787435819, 0.7633101086466922, 1.0743513418963508, 1.374448473002415, 1.9862477682248199, 2.173643268778991, 2.4183988406019594], [1.1740408400616449, 1.170488899269042, 0.9808732000732173, 0.8543597588213265, 0.7553193196040913, 1.1964927809565211, 1.7606849407636924, 2.241492516757174, 2.6944893898868236, 3.1688328513545474, 3.4206666932863246, 3.57058536663915, 3.4476151150330576, 3.176693407158954, 2.7398486336745864, 2.283324077376298, 1.846891838921841, 1.1601998285767732, 0.7825602771551458, 0.5353083566099063, 0.5358209515330405, 0.5910026849234454, 0.6198587538089071, 1.0507967126731494, 1.6293144065927372, 2.15145296568327, 2.2433872959646157, 2.332055788465478, 2.3208501006474265, 2.20883297723425, 2.1766568096256074, 1.8587222903266185, 1.6807462948033185, 1.4382465340820627, 1.2814080816535063, 1.1881860294376905, 1.1870313271394684, 0.8026705667761236, 0.4751833672803357, 0.4682407411332466, 0.5057799797738708, 0.5770870637284952, 0.7102451249769433, 0.667507610269503, 0.6543625459241481, 0.6462839359264914, 0.776865994793865, 0.9155552596077706, 1.0635847727256884, 1.2928058393692692, 1.6095531754628112, 1.5738275328548308, 1.577963767120871, 1.6528686184325851, 1.584591620960621, 1.555455417345505, 1.4487557814375958, 1.3714085216771674, 1.338701239472737, 1.5070394515054553, 1.523471683876446, 1.6344491957384988, 1.875709949434897, 2.053595517596864, 2.167024894309122, 2.018802013661322, 1.8290157794036561, 1.4256015104689346, 1.113991657234322, 0.8349188042566882, 0.5223100529540137, 0.4855344667560817, 0.6839022732094927, 0.837094502948759, 0.9611795390752036, 1.0114216489968828, 0.8385331912456402, 0.781980364231262, 0.49497572162628356, 0.0, 0.3813426666779606, 0.7411107112629779, 1.0414881779376848, 1.6543763071617992, 1.8279497236876505, 2.0525654671542197], [1.4477529263035138, 1.4374355746342706, 1.2458386634391012, 1.1063080603024098, 0.9261215243730531, 1.234838515193747, 1.7426839880318887, 2.1609660589319075, 2.549550466455174, 2.999067321299587, 3.261585050127457, 3.411377928851862, 3.2874791546092865, 3.0072262362172872, 2.5916183933030905, 2.156302616870419, 1.7171677130789142, 1.042214604606435, 0.7229629557610866, 0.5747059886722709, 0.6242545092913789, 0.6746204646400326, 0.7128079355643572, 1.045622664007833, 1.5888332153488212, 2.0573569487715857, 2.1398450445692623, 2.1888244738165947, 2.1679510616367907, 2.110723503446251, 2.1120321478238657, 1.815704905554073, 1.567802450270161, 1.2370976383759693, 1.1186395816937857, 1.0554028660672743, 1.04562155145076, 0.8195496335158191, 0.7076011354787757, 0.6951962056930512, 0.5230907433360621, 0.5290489529392278, 0.6856746187702816, 0.6023400234410661, 0.5933192639424992, 0.5975351455092093, 0.6581745546793347, 0.8206399869934604, 1.037923784193557, 1.2074347664980405, 1.4103477285890627, 1.4388362248651938, 1.4298841805694276, 1.5077811022059295, 1.4813301683600717, 1.472408498006798, 1.3831302504162273, 1.308647314379069, 1.2838981190414787, 1.4027378248805016, 1.408395396168677, 1.4731955861491703, 1.6472134332829977, 1.81350296355248, 1.934337548789023, 1.7851015474308554, 1.6080065204035592, 1.2085300644009656, 0.9282538909635581, 0.683306547666459, 0.570923814614227, 0.6589585546413513, 0.9015207521305163, 1.1035378675414174, 1.2206133752348416, 1.2745231581018424, 1.1140884934674404, 1.0615578334289317, 0.7647466072502607, 0.3809815692232444, 0.0, 0.49226649169432063, 0.8211696031360816, 1.460774606563778, 1.6248470196918126, 1.8221870257879498], [1.6969179723580208, 1.6940581004157849, 1.4933017309655945, 1.3428428620550086, 1.07786589904993, 1.1577845030019291, 1.6217003181996668, 2.0320306844155565, 2.3622686928957193, 2.7504040406591974, 3.025589770485433, 3.1765632976574922, 3.044428099581813, 2.769760924894781, 2.35691034105915, 1.8991675589929025, 1.4292683307134777, 0.7626920555585518, 0.5902667900137061, 0.750564912875466, 0.8487645220843889, 0.8519349459905928, 0.8481603744080316, 0.9590022180019158, 1.4163629596548377, 1.8224660575139504, 1.9006880006099203, 1.9442798351387587, 1.9218364248274376, 1.8901575826583472, 1.9098585802352273, 1.622520314254109, 1.3121804277155649, 0.9770546921251678, 0.9136325286609276, 0.8525682142929741, 0.834299064134317, 0.816405573383149, 0.9342845685484156, 0.9240983257501644, 0.626929832652404, 0.5549280536519489, 0.705184852912616, 0.5795148070839724, 0.5725319127145477, 0.5807322863869967, 0.5046532460863836, 0.6811458831483, 0.9471176854729536, 1.0823495197542627, 1.2369196036902865, 1.279674862030145, 1.2705714390592844, 1.3324574164410203, 1.3069662057775302, 1.3025941406255224, 1.2167975032652234, 1.132852636067656, 1.111379654771258, 1.1948553704871203, 1.204360666736838, 1.2511652957002013, 1.3714741690430432, 1.4797415334547788, 1.6227342420802948, 1.4635583065995106, 1.2909242466946398, 0.8919112635299958, 0.6629647317703085, 0.4881536252941309, 0.626414906014118, 0.8708506026396764, 1.224956709156757, 1.4256000293947826, 1.5165261910547436, 1.5711818110098468, 1.4076822887610347, 1.3521596500901905, 1.0725454189892527, 0.7420309540266318, 0.49191910728801547, 0.0, 0.41125334338140035, 1.1467469598345192, 1.317727481286829, 1.5161617866292072], [1.953674874020528, 1.963898320668652, 1.7662407566921579, 1.5909243115253244, 1.287929726373603, 1.179746974676315, 1.4713816955992265, 1.8727902564210281, 2.1767972015373043, 2.509022915814851, 2.7833167501263403, 2.946202505274321, 2.8074900678631067, 2.5334141266251895, 2.1020746423505816, 1.6335511531750584, 1.1476935910452526, 0.6415432550001908, 0.6829791063854952, 1.0879641251473424, 1.1797746005358947, 1.1778552856615312, 1.1409990794983398, 0.9872384679525642, 1.2750174963864576, 1.5678515802159723, 1.6253047328765, 1.6609529773849485, 1.6390047045582914, 1.6304873165526415, 1.6712478165579798, 1.3963290797512948, 1.0735791079694232, 0.761185136159127, 0.748248369657956, 0.7064867959592276, 0.6869569313787157, 0.8953643487899062, 1.1936422076339706, 1.170727866675692, 0.8389545467446153, 0.7383453963977311, 0.8580368479348666, 0.7214846941763932, 0.7275315646652118, 0.702837240319083, 0.5325726718959346, 0.6608050962272927, 0.8823614613521644, 0.9532317858944059, 1.04970469590245, 1.1170862135701956, 1.0931940091950292, 1.1404464495523021, 1.127486393727262, 1.1323956864941922, 1.0634407583164354, 0.9798737790388145, 0.9617171005420745, 0.976588316127268, 0.9963191311668387, 1.0264766315999996, 1.103651864435851, 1.1583972817475254, 1.3270025895290445, 1.165051372545032, 1.00074302711788, 0.6069773016669865, 0.46245136440385665, 0.47314282933031093, 0.8426958103777762, 1.1857685788585, 1.5583156571382752, 1.7516525675502006, 1.8305371513080864, 1.8792473875494389, 1.7013873696253388, 1.6554027091333987, 1.3730145737874955, 1.0407525273693612, 0.8202850371800714, 0.4115046554636732, 0.0, 0.8528041573721076, 1.0081606959336027, 1.2183237871891022], [2.557973803042211, 2.562778544814264, 2.351833088708986, 2.1718394741161884, 1.8118520713696407, 1.5287052843950713, 1.46279189303367, 1.6895806494970362, 1.960022425288227, 2.2338137312536324, 2.3143576454000705, 2.4731043889495847, 2.362021091156289, 2.102314944993173, 1.6500111106552855, 1.1326286047342702, 0.7120186961197074, 1.0365230503619656, 1.28748143232359, 1.8135116773104951, 1.9031089139898283, 1.8947319961781046, 1.8426445594700755, 1.4807878408425788, 1.4648993337625333, 1.4290032244316955, 1.3926328374596435, 1.2566084589086806, 1.238038713391488, 1.4703665120725062, 1.6079227224812143, 1.4844035248920742, 1.0508655826178992, 0.7132290016511874, 0.9933453685191003, 1.0208733176446683, 1.0160271040733269, 1.3895556337793251, 1.8124825293306315, 1.7783034325459748, 1.433573622664333, 1.3953108075377891, 1.5969775798792392, 1.4611776669624885, 1.44943309267814, 1.3502770015593772, 1.0861775462869308, 1.090334748880812, 1.1947846915231364, 1.138860855942157, 1.107138887847809, 1.1676270081262008, 1.1485568502663228, 1.1597952439577204, 1.1838925230407351, 1.177507467722194, 1.1445032712976673, 1.0941697476372385, 1.0872130299005416, 0.9730266146971421, 1.0014896330605232, 0.9902253554098362, 0.9806570710097023, 0.9200778573559174, 0.7596510366025482, 0.6676422688410238, 0.5190588858595642, 0.5816569109779881, 0.7843361491997507, 0.9928478904002042, 1.4219662958564414, 1.79798014336222, 2.157900370374255, 2.3414757705628615, 2.4243075835441266, 2.478461898080191, 2.2919212605410024, 2.24743563614941, 1.9901017333857238, 1.654420311897971, 1.4602339872487964, 1.1451885596816742, 0.8545914553312156, 0.0, 0.33323458302099696, 0.6022270782227533], [2.7718363099019654, 2.785257996839443, 2.5839261930012105, 2.3941529899210545, 2.02402432971722, 1.6857323163739748, 1.491242278182217, 1.5629925170220262, 1.7562080523449766, 2.031434508113643, 2.127743224002132, 2.293050711821, 2.1727255521760522, 1.9008936719958827, 1.436479051159892, 0.9933819033795168, 0.8040460885332361, 1.238515024971347, 1.512440176841331, 2.013188645880223, 2.102837222729759, 2.0963457908377174, 2.0525801791820206, 1.6558383250493391, 1.5590869952430242, 1.3177941939095787, 1.227731224108486, 1.0501964873281935, 1.0357715221018435, 1.3334953586449658, 1.5022203212872112, 1.4936322557698283, 1.0555490578035587, 0.7046596537231311, 1.016425217457812, 1.0819296206576956, 1.0843982219306276, 1.5204942270237656, 2.013537630316257, 1.973879115284588, 1.6201824197445245, 1.5563693545042454, 1.745756883878026, 1.5994797687176787, 1.578853586159507, 1.4969808425538689, 1.240636523485113, 1.208527043212412, 1.281459990651095, 1.1359763278804793, 0.9929412241921491, 1.0613293376464779, 1.044296051168809, 1.0373264500248387, 1.0963259170503428, 1.1178875377808115, 1.1341198583280863, 1.1280488380680276, 1.1382659305458844, 0.9172538318971463, 0.9333284157354858, 0.8605518202145472, 0.78475228532087, 0.6988093183331415, 0.5404164973750902, 0.4450826285692133, 0.3359689783266162, 0.5696903329317886, 0.8892978504608786, 1.175246298427859, 1.6291488759501895, 2.0111125892901835, 2.3703935022827, 2.554147894691652, 2.6288021528218963, 2.682637027113212, 2.4980888078852153, 2.453992282807337, 2.1750860311176936, 1.8316404042916055, 1.627304835881875, 1.3152726211168593, 1.0093475365475828, 0.33344935090922834, 0.0, 0.3384990825518887], [3.0324328136103884, 3.042524760518095, 2.8400008308726066, 2.6647845164820807, 2.3058144544822254, 1.9753196518730174, 1.7154457675886612, 1.641330389581397, 1.6893341039472025, 1.8740059499760413, 1.9261578819921985, 2.0966563892481944, 1.9744917037029759, 1.737285461383364, 1.355944448840366, 1.1169159384736311, 1.0546702473998046, 1.5025421272802362, 1.7635356547952097, 2.2280582380993508, 2.3188872328395274, 2.3211380873451297, 2.28292189168103, 1.9167669818660689, 1.8072875643203175, 1.4724507077051499, 1.3327462590881154, 1.0873101954112048, 1.0729395226267602, 1.4470794103338753, 1.638005999056968, 1.7017678119021462, 1.2407580307184751, 0.869785897255797, 1.1921555010985565, 1.303645270599354, 1.3181537833207784, 1.771179885281629, 2.267132296369971, 2.2327015985281307, 1.8699568034570306, 1.795126124033651, 1.9799032760238735, 1.8256496578926824, 1.8061320814648896, 1.7342184242852356, 1.4839112356882216, 1.4432054175320352, 1.532185735795059, 1.345640892441564, 1.0715465872747578, 1.183705829357194, 1.1651014897115985, 1.1411329509825048, 1.2592214024321027, 1.3141814891000987, 1.3715051569121868, 1.3913912142281875, 1.4085618135782034, 1.1374825849670447, 1.1312921582986029, 0.9740812376217373, 0.7465145881310407, 0.5846942989959468, 0.3134792558229309, 0.28591031301502445, 0.3520365093294799, 0.7792574733234983, 1.1224477520627902, 1.4157555331951868, 1.8745380696386917, 2.254924340641609, 2.6087906566847567, 2.788802141737996, 2.8705645430793543, 2.9245120486191367, 2.7414568113289555, 2.6962811025849116, 2.409003143683698, 2.053743670751744, 1.822911036078616, 1.513716857379189, 1.2166803145138254, 0.6015146658825283, 0.3382472521587468, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('a022cb5a-e2f1-491f-85f3-5ddf0153241a');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Notice that how dramatically things can change when the metrics are
modified.

New distances in the embedding space: kNN graphs and geodesic distances
-----------------------------------------------------------------------

We propose here a new way to compute distances between points in the
embedding space. Instead of considering the Euclidean distance in the
Takens space, we propose to build a :math:`k`-nearest neighbors graph
and then use the geodesic distance on such graph.

.. code:: ipython3

    n_neighbors = 3
    kNN = KNeighborsGraph(n_neighbors=n_neighbors)
    
    X_kNN = kNN.fit_transform(X_windows)

Given the graph embedding, the natural notion of distance between
vertices corresponds to the lengths of the shortest path connecting two
vertices. This is also known as *graph geodesic distance*. We compute it
and plot it for our chosen window number.

.. code:: ipython3

    GGD = GraphGeodesicDistance()
    
    GGD.fit_transform_plot(X_kNN, sample=window_number);



.. raw:: html

    <div>
    
    
                <div id="7439e7bb-e0f0-463c-a2ae-de84388813ac" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("7439e7bb-e0f0-463c-a2ae-de84388813ac")) {
                        Plotly.newPlot(
                            '7439e7bb-e0f0-463c-a2ae-de84388813ac',
                            [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 6.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 1.0, 1.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0], [1.0, 0.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 6.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 2.0, 2.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0], [1.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 2.0, 2.0, 1.0, 1.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0], [2.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 3.0, 3.0, 2.0, 2.0, 3.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0], [3.0, 3.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 11.0, 11.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 4.0, 4.0, 3.0, 3.0, 3.0, 2.0, 3.0, 3.0, 4.0, 5.0, 6.0], [3.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 4.0, 4.0, 3.0, 3.0, 2.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0], [4.0, 4.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 11.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0], [5.0, 5.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 11.0, 11.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 2.0, 3.0, 4.0], [6.0, 6.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 11.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 2.0, 1.0, 2.0, 3.0], [6.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 2.0, 1.0, 2.0, 2.0], [7.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 3.0, 3.0, 2.0, 2.0, 1.0], [7.0, 7.0, 7.0, 6.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 9.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0], [8.0, 8.0, 8.0, 7.0, 7.0, 6.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 1.0], [8.0, 8.0, 8.0, 7.0, 7.0, 6.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0], [9.0, 9.0, 9.0, 8.0, 8.0, 7.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0], [10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0], [10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0], [9.0, 10.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0], [8.0, 9.0, 9.0, 10.0, 11.0, 10.0, 10.0, 9.0, 8.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0], [8.0, 9.0, 9.0, 10.0, 11.0, 10.0, 10.0, 9.0, 8.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0], [7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 11.0, 10.0, 9.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 8.0, 8.0, 9.0, 9.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0], [6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 11.0, 10.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0], [6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 11.0, 10.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0], [5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 11.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 6.0, 6.0, 7.0, 7.0, 8.0, 9.0, 10.0, 10.0, 9.0, 9.0], [4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 6.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0], [4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 6.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0], [3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 10.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 4.0, 4.0, 5.0, 5.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0], [2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 8.0, 8.0, 9.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0], [2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 8.0, 8.0, 9.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 3.0, 3.0, 4.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0], [1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 9.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 3.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0], [1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 9.0, 10.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0], [1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0], [1.0, 1.0, 1.0, 2.0, 3.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0], [2.0, 2.0, 1.0, 2.0, 3.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0], [2.0, 2.0, 2.0, 3.0, 3.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0, 3.0, 3.0, 4.0, 5.0], [3.0, 3.0, 3.0, 2.0, 2.0, 1.0, 1.0, 2.0, 3.0, 3.0, 4.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0], [4.0, 4.0, 4.0, 3.0, 3.0, 2.0, 2.0, 2.0, 2.0, 2.0, 3.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 0.0, 1.0, 1.0, 2.0, 3.0], [5.0, 5.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 2.0, 2.0, 3.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0], [5.0, 5.0, 5.0, 4.0, 4.0, 3.0, 3.0, 2.0, 1.0, 1.0, 2.0, 2.0, 3.0, 3.0, 4.0, 5.0, 5.0, 6.0, 7.0, 7.0, 8.0, 9.0, 9.0, 10.0, 9.0, 9.0, 8.0, 7.0, 7.0, 6.0, 6.0, 5.0, 4.0, 4.0, 3.0, 2.0, 1.0, 1.0, 0.0, 1.0, 2.0], [6.0, 6.0, 6.0, 5.0, 5.0, 4.0, 4.0, 3.0, 2.0, 2.0, 2.0, 1.0, 2.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 9.0, 8.0, 8.0, 7.0, 7.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 2.0, 1.0, 0.0, 1.0], [7.0, 7.0, 7.0, 6.0, 6.0, 5.0, 5.0, 4.0, 3.0, 2.0, 1.0, 1.0, 1.0, 2.0, 3.0, 4.0, 4.0, 5.0, 6.0, 6.0, 7.0, 8.0, 8.0, 9.0, 10.0, 10.0, 10.0, 9.0, 9.0, 8.0, 8.0, 7.0, 6.0, 6.0, 5.0, 4.0, 3.0, 3.0, 2.0, 1.0, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('7439e7bb-e0f0-463c-a2ae-de84388813ac');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


For comparison, this is what the ordinary pairwise Euclidean distance
matrix looks like for the same window:

.. code:: ipython3

    plot_heatmap(pairwise_distances(X_windows[window_number]), colorscale='blues')



.. raw:: html

    <div>
    
    
                <div id="0eb5d22a-d3e2-42d7-8ae0-422eae5d9052" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("0eb5d22a-d3e2-42d7-8ae0-422eae5d9052")) {
                        Plotly.newPlot(
                            '0eb5d22a-d3e2-42d7-8ae0-422eae5d9052',
                            [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 14.232091903686523, 16.150529861450195, 21.858339309692383, 33.10795211791992, 31.87007713317871, 28.654582977294922, 29.702476501464844, 31.862218856811523, 33.971187591552734, 31.23921012878418, 29.74435806274414, 31.15587043762207, 28.47098159790039, 27.127397537231445, 30.25933074951172, 31.588199615478516, 30.141407012939453, 30.07880973815918, 29.906747817993164, 28.20078468322754, 31.109914779663086, 31.636943817138672, 31.030038833618164, 34.26268768310547, 32.56038284301758, 28.382633209228516, 27.792295455932617, 23.190406799316406, 16.430830001831055, 17.249427795410156, 16.452259063720703, 13.733892440795898, 20.085041046142578, 24.017229080200195, 27.1395206451416, 33.63869857788086, 33.33115768432617, 29.452831268310547, 26.455493927001953, 25.30567169189453], [14.232091903686523, 0.0, 8.132235527038574, 19.763246536254883, 32.85911560058594, 33.16930389404297, 31.71687889099121, 34.109554290771484, 36.96628189086914, 39.43306350708008, 37.660972595214844, 36.283660888671875, 35.97565460205078, 30.841489791870117, 29.027143478393555, 33.518890380859375, 35.74004364013672, 35.91728973388672, 37.21965026855469, 36.384029388427734, 32.383888244628906, 32.4835319519043, 33.737056732177734, 34.627647399902344, 38.698184967041016, 38.26420211791992, 35.979122161865234, 36.81450653076172, 33.81233596801758, 28.476539611816406, 26.33800506591797, 21.51938819885254, 13.416857719421387, 15.50771713256836, 22.323827743530273, 28.050729751586914, 35.87852478027344, 37.003570556640625, 34.6693000793457, 33.114288330078125, 32.639404296875], [16.150529861450195, 8.132235527038574, 0.0, 13.35400104522705, 27.24783706665039, 27.679216384887695, 26.57337760925293, 29.99872589111328, 33.72920608520508, 36.93894958496094, 35.818817138671875, 34.97959899902344, 35.342838287353516, 31.2563419342041, 29.68316078186035, 33.07707595825195, 33.84060287475586, 33.81694030761719, 35.855350494384766, 34.539852142333984, 29.09333610534668, 28.152729034423828, 29.441482543945312, 30.287845611572266, 34.81829071044922, 34.93380355834961, 33.35324478149414, 35.313011169433594, 32.73419952392578, 27.339384078979492, 24.985319137573242, 19.030553817749023, 10.801090240478516, 15.014588356018066, 20.20320701599121, 24.246124267578125, 31.850341796875, 33.47470474243164, 31.60303497314453, 30.785024642944336, 31.159563064575195], [21.858339309692383, 19.763246536254883, 13.35400104522705, 0.0, 14.200610160827637, 15.515490531921387, 16.51246452331543, 23.069135665893555, 28.996803283691406, 33.779319763183594, 33.77479553222656, 33.788330078125, 34.96614456176758, 31.868635177612305, 30.158823013305664, 31.461484909057617, 28.89118194580078, 28.140365600585938, 32.29261779785156, 32.04875183105469, 27.88393783569336, 28.545333862304688, 29.075634002685547, 27.71036148071289, 30.86397933959961, 31.508386611938477, 30.966623306274414, 34.239131927490234, 32.556541442871094, 28.396377563476562, 27.832393646240234, 23.312602996826172, 16.79670524597168, 17.91993522644043, 17.67685890197754, 15.951554298400879, 22.18147087097168, 25.72242546081543, 25.701766967773438, 26.76222038269043, 28.80633544921875], [33.10795211791992, 32.85911560058594, 27.24783706665039, 14.200610160827637, 0.0, 7.32454252243042, 14.557328224182129, 23.690141677856445, 31.01677894592285, 36.8125114440918, 38.03731918334961, 38.89018630981445, 40.475975036621094, 38.32909393310547, 36.737884521484375, 36.332618713378906, 31.334882736206055, 30.1400146484375, 35.655059814453125, 36.6618766784668, 34.64572525024414, 36.44091033935547, 36.04188537597656, 32.23779296875, 32.452396392822266, 33.75889587402344, 34.66942596435547, 38.73829650878906, 38.301666259765625, 36.01652908325195, 36.8587532043457, 33.90250015258789, 28.689746856689453, 26.7789363861084, 22.467378616333008, 15.694938659667969, 18.211780548095703, 24.341873168945312, 27.15719223022461, 30.269893646240234, 33.57478332519531], [31.87007713317871, 33.16930389404297, 27.679216384887695, 15.515490531921387, 7.32454252243042, 0.0, 9.037556648254395, 19.341419219970703, 27.16861915588379, 33.61528396606445, 35.26842498779297, 36.446929931640625, 38.4437141418457, 36.772335052490234, 35.589080810546875, 35.76811599731445, 31.802289962768555, 30.992395401000977, 35.92204666137695, 36.328834533691406, 34.3164176940918, 36.36760711669922, 35.133094787597656, 29.695585250854492, 28.622404098510742, 29.74263572692871, 30.449426651000977, 34.85877990722656, 34.89183044433594, 33.24262619018555, 35.16847229003906, 32.57850646972656, 27.222061157226562, 25.045583724975586, 19.554929733276367, 12.741717338562012, 17.396827697753906, 22.649465560913086, 24.766691207885742, 28.00254249572754, 31.613916397094727], [28.654582977294922, 31.71687889099121, 26.57337760925293, 16.51246452331543, 14.557328224182129, 9.037556648254395, 0.0, 10.829265594482422, 19.431554794311523, 27.46920394897461, 29.952110290527344, 31.82552146911621, 34.610382080078125, 33.511688232421875, 32.791072845458984, 33.603240966796875, 30.399539947509766, 29.801082611083984, 34.316349029541016, 34.098670959472656, 32.02090072631836, 34.64699172973633, 33.3613395690918, 28.288192749023438, 28.02376365661621, 27.817806243896484, 25.74631690979004, 28.656021118164062, 28.99456787109375, 28.120330810546875, 31.492496490478516, 29.51171875, 24.77518653869629, 24.19357681274414, 19.15998077392578, 11.49717903137207, 14.838135719299316, 17.525365829467773, 18.67148780822754, 22.670551300048828, 27.147119522094727], [29.702476501464844, 34.109554290771484, 29.99872589111328, 23.069135665893555, 23.690141677856445, 19.341419219970703, 10.829265594482422, 0.0, 10.516725540161133, 21.4647159576416, 25.885887145996094, 29.417715072631836, 33.53140640258789, 33.5377082824707, 33.596275329589844, 34.90442657470703, 32.35780334472656, 31.739503860473633, 35.316749572753906, 34.466121673583984, 32.79548263549805, 36.111244201660156, 35.30419158935547, 31.55479621887207, 32.21628952026367, 30.682157516479492, 25.06988525390625, 24.510522842407227, 25.585783004760742, 26.282474517822266, 31.097715377807617, 30.2170352935791, 26.96515655517578, 27.906110763549805, 23.878246307373047, 16.216773986816406, 14.710733413696289, 12.760909080505371, 13.396489143371582, 19.327661514282227, 25.0877628326416], [31.862218856811523, 36.96628189086914, 33.72920608520508, 28.996803283691406, 31.01677894592285, 27.16861915588379, 19.431554794311523, 10.516725540161133, 0.0, 12.20455265045166, 19.329652786254883, 25.60667610168457, 31.701379776000977, 33.088470458984375, 34.1364860534668, 36.12800216674805, 34.22472381591797, 33.0864372253418, 34.75486755371094, 32.38397979736328, 31.19317626953125, 35.853816986083984, 35.90130615234375, 33.464412689208984, 35.21877670288086, 33.62380599975586, 27.556772232055664, 26.098041534423828, 27.06707763671875, 27.582456588745117, 32.08220672607422, 31.657508850097656, 29.279130935668945, 30.92430877685547, 27.435606002807617, 20.47301483154297, 18.14126968383789, 13.802824020385742, 12.00597095489502, 17.08631706237793, 22.69434928894043], [33.971187591552734, 39.43306350708008, 36.93894958496094, 33.779319763183594, 36.8125114440918, 33.61528396606445, 27.46920394897461, 21.4647159576416, 12.20455265045166, 0.0, 10.96535873413086, 20.523401260375977, 29.084556579589844, 32.10300064086914, 34.336788177490234, 37.154396057128906, 35.9315185546875, 34.38251876831055, 34.22624969482422, 30.2373046875, 29.514602661132812, 35.44511795043945, 36.27749252319336, 35.0564079284668, 37.924591064453125, 37.06285095214844, 32.793128967285156, 32.70695877075195, 32.593936920166016, 30.79214859008789, 33.00302505493164, 32.70400619506836, 31.14166831970215, 33.381553649902344, 30.591114044189453, 25.152128219604492, 24.34905242919922, 20.799955368041992, 16.77814483642578, 16.95931625366211, 20.031612396240234], [31.23921012878418, 37.660972595214844, 35.818817138671875, 33.77479553222656, 38.03731918334961, 35.26842498779297, 29.952110290527344, 25.885887145996094, 19.329652786254883, 10.96535873413086, 0.0, 11.520899772644043, 22.800588607788086, 27.64656639099121, 31.428300857543945, 35.51258850097656, 35.3471794128418, 34.67039489746094, 35.197757720947266, 31.670019149780273, 30.597370147705078, 35.621177673339844, 35.82586669921875, 34.936405181884766, 38.50455856323242, 38.044715881347656, 34.8011589050293, 35.532989501953125, 34.21334457397461, 29.247594833374023, 28.514076232910156, 28.863990783691406, 28.746835708618164, 32.47193908691406, 30.852062225341797, 26.9820499420166, 27.778018951416016, 24.713905334472656, 18.729440689086914, 13.565690994262695, 13.123252868652344], [29.74435806274414, 36.283660888671875, 34.97959899902344, 33.788330078125, 38.89018630981445, 36.446929931640625, 31.82552146911621, 29.417715072631836, 25.60667610168457, 20.523401260375977, 11.520899772644043, 0.0, 12.556045532226562, 19.9498233795166, 26.361040115356445, 32.43656539916992, 33.678565979003906, 34.3154296875, 36.12592697143555, 33.32420349121094, 31.22254180908203, 34.070648193359375, 32.569488525390625, 31.977313995361328, 36.870845794677734, 37.129417419433594, 34.917396545410156, 36.68260192871094, 35.188941955566406, 29.407350540161133, 27.846454620361328, 28.32700538635254, 28.28931999206543, 32.18598175048828, 31.269248962402344, 28.487817764282227, 30.20195198059082, 27.348234176635742, 20.499120712280273, 12.885407447814941, 9.457598686218262], [31.15587043762207, 35.97565460205078, 35.342838287353516, 34.96614456176758, 40.475975036621094, 38.4437141418457, 34.610382080078125, 33.53140640258789, 31.701379776000977, 29.084556579589844, 22.800588607788086, 12.556045532226562, 0.0, 11.142565727233887, 20.786701202392578, 29.343582153320312, 32.2664909362793, 34.3170280456543, 37.27493667602539, 35.11668014526367, 32.2607307434082, 33.065792083740234, 29.821128845214844, 29.639780044555664, 35.83686065673828, 36.83625793457031, 35.74364471435547, 38.62063217163086, 37.79977035522461, 33.59877014160156, 33.39300537109375, 33.015625, 30.89649772644043, 32.768524169921875, 32.176029205322266, 30.42430305480957, 32.82335662841797, 30.475130081176758, 24.354076385498047, 18.678483963012695, 16.3599796295166], [28.47098159790039, 30.841489791870117, 31.2563419342041, 31.868635177612305, 38.32909393310547, 36.772335052490234, 33.511688232421875, 33.5377082824707, 33.088470458984375, 32.10300064086914, 27.64656639099121, 19.9498233795166, 11.142565727233887, 0.0, 11.59591293334961, 22.87957191467285, 27.669580459594727, 31.425643920898438, 35.8593864440918, 34.642784118652344, 32.419315338134766, 33.84954833984375, 30.98384666442871, 30.38043785095215, 35.69487380981445, 36.05908966064453, 35.27364730834961, 38.86296081542969, 38.43014144897461, 35.20720672607422, 35.8489875793457, 34.35762023925781, 29.16620635986328, 28.184194564819336, 28.361988067626953, 28.21028709411621, 32.168312072753906, 30.88959312438965, 25.83786964416504, 21.790510177612305, 20.15065574645996], [27.127397537231445, 29.027143478393555, 29.68316078186035, 30.158823013305664, 36.737884521484375, 35.589080810546875, 32.791072845458984, 33.596275329589844, 34.1364860534668, 34.336788177490234, 31.428300857543945, 26.361040115356445, 20.786701202392578, 11.59591293334961, 0.0, 12.568832397460938, 19.939407348632812, 26.459842681884766, 33.041439056396484, 33.069969177246094, 31.971960067749023, 34.70604705810547, 32.53460693359375, 30.84142303466797, 33.97854232788086, 32.63844299316406, 32.14847183227539, 37.07061767578125, 37.351322174072266, 35.14579772949219, 36.84282302856445, 35.226806640625, 29.28207015991211, 27.562057495117188, 27.978397369384766, 28.00771141052246, 32.14775848388672, 31.484020233154297, 27.20104217529297, 24.096647262573242, 22.75887680053711], [30.25933074951172, 33.518890380859375, 33.07707595825195, 31.461484909057617, 36.332618713378906, 35.76811599731445, 33.603240966796875, 34.90442657470703, 36.12800216674805, 37.154396057128906, 35.51258850097656, 32.43656539916992, 29.343582153320312, 22.87957191467285, 12.568832397460938, 0.0, 11.148630142211914, 21.006742477416992, 30.141035079956055, 31.67103385925293, 31.897138595581055, 35.82273864746094, 34.2890625, 31.806062698364258, 32.887149810791016, 29.804391860961914, 29.73356819152832, 35.96876525878906, 36.99092483520508, 35.90157699584961, 38.72512435913086, 37.812320709228516, 33.50141143798828, 33.2138671875, 32.82581329345703, 30.802946090698242, 32.901092529296875, 32.494895935058594, 29.10446548461914, 26.911975860595703, 26.1318302154541], [31.588199615478516, 35.74004364013672, 33.84060287475586, 28.89118194580078, 31.334882736206055, 31.802289962768555, 30.399539947509766, 32.35780334472656, 34.22472381591797, 35.9315185546875, 35.3471794128418, 33.678565979003906, 32.2664909362793, 27.669580459594727, 19.939407348632812, 11.148630142211914, 0.0, 11.87600326538086, 23.722929000854492, 26.734973907470703, 28.56088638305664, 34.23079299926758, 33.73191452026367, 31.929250717163086, 33.666866302490234, 30.98134994506836, 30.502796173095703, 35.864376068115234, 36.261348724365234, 35.4833869934082, 39.01189041137695, 38.48210144042969, 35.14701843261719, 35.70047378540039, 34.17683792114258, 29.04705238342285, 28.296646118164062, 28.661348342895508, 26.683439254760742, 25.977094650268555, 26.484159469604492], [30.141407012939453, 35.91728973388672, 33.81694030761719, 28.140365600585938, 30.1400146484375, 30.992395401000977, 29.801082611083984, 31.739503860473633, 33.0864372253418, 34.38251876831055, 34.67039489746094, 34.3154296875, 34.3170280456543, 31.425643920898438, 26.459842681884766, 21.006742477416992, 11.87600326538086, 0.0, 13.018623352050781, 17.863853454589844, 22.785058975219727, 31.28116226196289, 32.24052810668945, 31.69577407836914, 34.793704986572266, 32.863922119140625, 31.34659767150879, 34.52898406982422, 33.26225662231445, 32.782676696777344, 37.55064392089844, 37.65680694580078, 35.25286865234375, 36.73991394042969, 34.95363235473633, 28.887008666992188, 27.292146682739258, 28.006793975830078, 26.6622257232666, 26.664791107177734, 27.638273239135742], [30.07880973815918, 37.21965026855469, 35.855350494384766, 32.29261779785156, 35.655059814453125, 35.92204666137695, 34.316349029541016, 35.316749572753906, 34.75486755371094, 34.22624969482422, 35.197757720947266, 36.12592697143555, 37.27493667602539, 35.8593864440918, 33.041439056396484, 30.141035079956055, 23.722929000854492, 13.018623352050781, 0.0, 8.344938278198242, 18.207401275634766, 29.491674423217773, 31.96107292175293, 32.740562438964844, 36.893592834472656, 35.61591720581055, 33.3672981262207, 34.477264404296875, 31.582008361816406, 31.471776962280273, 37.26169204711914, 37.91487503051758, 36.424007415771484, 38.772735595703125, 37.4302864074707, 32.72993469238281, 32.460105895996094, 32.72002029418945, 30.942670822143555, 30.610984802246094, 31.127960205078125], [29.906747817993164, 36.384029388427734, 34.539852142333984, 32.04875183105469, 36.6618766784668, 36.328834533691406, 34.098670959472656, 34.466121673583984, 32.38397979736328, 30.2373046875, 31.670019149780273, 33.32420349121094, 35.11668014526367, 34.642784118652344, 33.069969177246094, 31.67103385925293, 26.734973907470703, 17.863853454589844, 8.344938278198242, 0.0, 11.847651481628418, 24.347309112548828, 27.564739227294922, 29.422847747802734, 34.949527740478516, 34.412437438964844, 32.56699752807617, 34.18935012817383, 31.4387264251709, 30.792985916137695, 35.82209396362305, 35.69248962402344, 34.244991302490234, 37.23250961303711, 36.01964569091797, 31.91263198852539, 32.626712799072266, 32.459354400634766, 29.96563720703125, 29.309913635253906, 29.754783630371094], [28.20078468322754, 32.383888244628906, 29.09333610534668, 27.88393783569336, 34.64572525024414, 34.3164176940918, 32.02090072631836, 32.79548263549805, 31.19317626953125, 29.514602661132812, 30.597370147705078, 31.22254180908203, 32.2607307434082, 32.419315338134766, 31.971960067749023, 31.897138595581055, 28.56088638305664, 22.785058975219727, 18.207401275634766, 11.847651481628418, 0.0, 12.880829811096191, 17.30446434020996, 21.923730850219727, 30.358936309814453, 31.073488235473633, 30.251956939697266, 33.28207015991211, 31.05650520324707, 29.19758415222168, 32.24479293823242, 30.284666061401367, 29.035648345947266, 33.67029571533203, 33.16582107543945, 29.97800636291504, 31.9752197265625, 31.756906509399414, 28.81717300415039, 28.035667419433594, 28.66190528869629], [31.109914779663086, 32.4835319519043, 28.152729034423828, 28.545333862304688, 36.44091033935547, 36.36760711669922, 34.64699172973633, 36.111244201660156, 35.853816986083984, 35.44511795043945, 35.621177673339844, 34.070648193359375, 33.065792083740234, 33.84954833984375, 34.70604705810547, 35.82273864746094, 34.23079299926758, 31.28116226196289, 29.491674423217773, 24.347309112548828, 12.880829811096191, 0.0, 7.969804286956787, 17.706562042236328, 28.960031509399414, 31.266460418701172, 31.874223709106445, 35.97942352294922, 34.52296447753906, 32.01879119873047, 32.91010665893555, 29.390047073364258, 28.723663330078125, 34.50485610961914, 34.80227279663086, 32.947662353515625, 35.788665771484375, 35.620365142822266, 32.74348068237305, 31.945585250854492, 32.592533111572266], [31.636943817138672, 33.737056732177734, 29.441482543945312, 29.075634002685547, 36.04188537597656, 35.133094787597656, 33.3613395690918, 35.30419158935547, 35.90130615234375, 36.27749252319336, 35.82586669921875, 32.569488525390625, 29.821128845214844, 30.98384666442871, 32.53460693359375, 34.2890625, 33.73191452026367, 32.24052810668945, 31.96107292175293, 27.564739227294922, 17.30446434020996, 7.969804286956787, 0.0, 11.71546459197998, 24.14951515197754, 27.250505447387695, 28.993799209594727, 34.4836540222168, 33.83427047729492, 31.824560165405273, 33.291812896728516, 30.124589920043945, 29.066390991210938, 34.031002044677734, 33.64046859741211, 32.01564407348633, 35.468223571777344, 35.155555725097656, 31.88947296142578, 30.87229347229004, 31.529170989990234], [31.030038833618164, 34.627647399902344, 30.287845611572266, 27.71036148071289, 32.23779296875, 29.695585250854492, 28.288192749023438, 31.55479621887207, 33.464412689208984, 35.0564079284668, 34.936405181884766, 31.977313995361328, 29.639780044555664, 30.38043785095215, 30.84142303466797, 31.806062698364258, 31.929250717163086, 31.69577407836914, 32.740562438964844, 29.422847747802734, 21.923730850219727, 17.706562042236328, 11.71546459197998, 0.0, 12.811745643615723, 17.13926887512207, 21.682886123657227, 30.104719161987305, 30.744213104248047, 29.813121795654297, 32.74317169189453, 30.24067497253418, 28.05742645263672, 30.998682022094727, 28.809085845947266, 27.526851654052734, 32.68931198120117, 32.92464828491211, 29.79485321044922, 29.057884216308594, 30.046985626220703], [34.26268768310547, 38.698184967041016, 34.81829071044922, 30.86397933959961, 32.452396392822266, 28.622404098510742, 28.02376365661621, 32.21628952026367, 35.21877670288086, 37.924591064453125, 38.50455856323242, 36.870845794677734, 35.83686065673828, 35.69487380981445, 33.97854232788086, 32.887149810791016, 33.666866302490234, 34.793704986572266, 36.893592834472656, 34.949527740478516, 30.358936309814453, 28.960031509399414, 24.14951515197754, 12.811745643615723, 0.0, 7.8999924659729, 17.603652954101562, 28.844520568847656, 31.105304718017578, 31.64948081970215, 35.68907165527344, 34.07487869262695, 31.379316329956055, 32.175716400146484, 28.535444259643555, 27.981605529785156, 34.19601821899414, 35.01101303100586, 32.60823440551758, 32.37315368652344, 33.52546310424805], [32.56038284301758, 38.26420211791992, 34.93380355834961, 31.508386611938477, 33.75889587402344, 29.74263572692871, 27.817806243896484, 30.682157516479492, 33.62380599975586, 37.06285095214844, 38.044715881347656, 37.129417419433594, 36.83625793457031, 36.05908966064453, 32.63844299316406, 29.804391860961914, 30.98134994506836, 32.863922119140625, 35.61591720581055, 34.412437438964844, 31.073488235473633, 31.266460418701172, 27.250505447387695, 17.13926887512207, 7.8999924659729, 0.0, 11.684414863586426, 24.10108757019043, 27.168649673461914, 28.86750030517578, 34.31222915649414, 33.56237030029297, 31.445085525512695, 32.89067459106445, 29.736461639404297, 28.86541748046875, 34.17205810546875, 34.159175872802734, 31.486839294433594, 31.3160400390625, 32.53341293334961], [28.382633209228516, 35.979122161865234, 33.35324478149414, 30.966623306274414, 34.66942596435547, 30.449426651000977, 25.74631690979004, 25.06988525390625, 27.556772232055664, 32.793128967285156, 34.8011589050293, 34.917396545410156, 35.74364471435547, 35.27364730834961, 32.14847183227539, 29.73356819152832, 30.502796173095703, 31.34659767150879, 33.3672981262207, 32.56699752807617, 30.251956939697266, 31.874223709106445, 28.993799209594727, 21.682886123657227, 17.603652954101562, 11.684414863586426, 0.0, 12.793911933898926, 17.09328269958496, 21.605289459228516, 30.000064849853516, 30.57657814025879, 29.596057891845703, 32.56044387817383, 30.159488677978516, 28.230594635009766, 31.498191833496094, 29.645355224609375, 26.710784912109375, 27.482301712036133, 29.656963348388672], [27.792295455932617, 36.81450653076172, 35.313011169433594, 34.239131927490234, 38.73829650878906, 34.85877990722656, 28.656021118164062, 24.510522842407227, 26.098041534423828, 32.70695877075195, 35.532989501953125, 36.68260192871094, 38.62063217163086, 38.86296081542969, 37.07061767578125, 35.96876525878906, 35.864376068115234, 34.52898406982422, 34.477264404296875, 34.18935012817383, 33.28207015991211, 35.97942352294922, 34.4836540222168, 30.104719161987305, 28.844520568847656, 24.10108757019043, 12.793911933898926, 0.0, 7.879006385803223, 17.5670108795166, 28.791807174682617, 31.022958755493164, 31.56351661682129, 35.663082122802734, 34.19124221801758, 31.773006439208984, 32.88938522338867, 29.535114288330078, 27.004533767700195, 28.76194190979004, 31.61199951171875], [23.190406799316406, 33.81233596801758, 32.73419952392578, 32.556541442871094, 38.301666259765625, 34.89183044433594, 28.99456787109375, 25.585783004760742, 27.06707763671875, 32.593936920166016, 34.21334457397461, 35.188941955566406, 37.79977035522461, 38.43014144897461, 37.351322174072266, 36.99092483520508, 36.261348724365234, 33.26225662231445, 31.582008361816406, 31.4387264251709, 31.05650520324707, 34.52296447753906, 33.83427047729492, 30.744213104248047, 31.105304718017578, 27.168649673461914, 17.09328269958496, 7.879006385803223, 0.0, 11.671819686889648, 24.077125549316406, 27.134563446044922, 28.858285903930664, 34.38347625732422, 33.80917739868164, 31.99825096130371, 33.74003601074219, 30.785667419433594, 27.76114273071289, 28.320056915283203, 30.363941192626953], [16.430830001831055, 28.476539611816406, 27.339384078979492, 28.396377563476562, 36.01652908325195, 33.24262619018555, 28.120330810546875, 26.282474517822266, 27.582456588745117, 30.79214859008789, 29.247594833374023, 29.407350540161133, 33.59877014160156, 35.20720672607422, 35.14579772949219, 35.90157699584961, 35.4833869934082, 32.782676696777344, 31.471776962280273, 30.792985916137695, 29.19758415222168, 32.01879119873047, 31.824560165405273, 29.813121795654297, 31.64948081970215, 28.86750030517578, 21.605289459228516, 17.5670108795166, 11.671819686889648, 0.0, 12.78563404083252, 17.091890335083008, 21.656816482543945, 30.14451026916504, 30.925376892089844, 30.27488136291504, 33.49454879760742, 31.214828491210938, 26.920503616333008, 24.603958129882812, 24.83266830444336], [17.249427795410156, 26.33800506591797, 24.985319137573242, 27.832393646240234, 36.8587532043457, 35.16847229003906, 31.492496490478516, 31.097715377807617, 32.08220672607422, 33.00302505493164, 28.514076232910156, 27.846454620361328, 33.39300537109375, 35.8489875793457, 36.84282302856445, 38.72512435913086, 39.01189041137695, 37.55064392089844, 37.26169204711914, 35.82209396362305, 32.24479293823242, 32.91010665893555, 33.291812896728516, 32.74317169189453, 35.68907165527344, 34.31222915649414, 30.000064849853516, 28.791807174682617, 24.077125549316406, 12.78563404083252, 0.0, 7.901519775390625, 17.642553329467773, 28.947629928588867, 31.36712646484375, 32.19261932373047, 36.49336624145508, 35.049888610839844, 30.38530731201172, 25.923992156982422, 24.284765243530273], [16.452259063720703, 21.51938819885254, 19.030553817749023, 23.312602996826172, 33.90250015258789, 32.57850646972656, 29.51171875, 30.2170352935791, 31.657508850097656, 32.70400619506836, 28.863990783691406, 28.32700538635254, 33.015625, 34.35762023925781, 35.226806640625, 37.812320709228516, 38.48210144042969, 37.65680694580078, 37.91487503051758, 35.69248962402344, 30.284666061401367, 29.390047073364258, 30.124589920043945, 30.24067497253418, 34.07487869262695, 33.56237030029297, 30.57657814025879, 31.022958755493164, 27.134563446044922, 17.091890335083008, 7.901519775390625, 0.0, 11.7160005569458, 24.19329833984375, 27.425731658935547, 29.40865707397461, 35.091796875, 34.46787643432617, 30.265296936035156, 26.456600189208984, 25.25044059753418], [13.733892440795898, 13.416857719421387, 10.801090240478516, 16.79670524597168, 28.689746856689453, 27.222061157226562, 24.77518653869629, 26.96515655517578, 29.279130935668945, 31.14166831970215, 28.746835708618164, 28.28931999206543, 30.89649772644043, 29.16620635986328, 29.28207015991211, 33.50141143798828, 35.14701843261719, 35.25286865234375, 36.424007415771484, 34.244991302490234, 29.035648345947266, 28.723663330078125, 29.066390991210938, 28.05742645263672, 31.379316329956055, 31.445085525512695, 29.596057891845703, 31.56351661682129, 28.858285903930664, 21.656816482543945, 17.642553329467773, 11.7160005569458, 0.0, 12.856377601623535, 17.345794677734375, 22.14398193359375, 30.720046997070312, 31.359420776367188, 28.01668357849121, 25.57505226135254, 25.200891494750977], [20.085041046142578, 15.50771713256836, 15.014588356018066, 17.91993522644043, 26.7789363861084, 25.045583724975586, 24.19357681274414, 27.906110763549805, 30.92430877685547, 33.381553649902344, 32.47193908691406, 32.18598175048828, 32.768524169921875, 28.184194564819336, 27.562057495117188, 33.2138671875, 35.70047378540039, 36.73991394042969, 38.772735595703125, 37.23250961303711, 33.67029571533203, 34.50485610961914, 34.031002044677734, 30.998682022094727, 32.175716400146484, 32.89067459106445, 32.56044387817383, 35.663082122802734, 34.38347625732422, 30.14451026916504, 28.947629928588867, 24.19329833984375, 12.856377601623535, 0.0, 8.063227653503418, 17.94068145751953, 29.294086456298828, 31.50228500366211, 29.693883895874023, 28.927186965942383, 29.35033416748047], [24.017229080200195, 22.323827743530273, 20.20320701599121, 17.67685890197754, 22.467378616333008, 19.554929733276367, 19.15998077392578, 23.878246307373047, 27.435606002807617, 30.591114044189453, 30.852062225341797, 31.269248962402344, 32.176029205322266, 28.361988067626953, 27.978397369384766, 32.82581329345703, 34.17683792114258, 34.95363235473633, 37.4302864074707, 36.01964569091797, 33.16582107543945, 34.80227279663086, 33.64046859741211, 28.809085845947266, 28.535444259643555, 29.736461639404297, 30.159488677978516, 34.19124221801758, 33.80917739868164, 30.925376892089844, 31.36712646484375, 27.425731658935547, 17.345794677734375, 8.063227653503418, 0.0, 11.830119132995605, 24.35177993774414, 27.293018341064453, 26.30561065673828, 26.76059913635254, 28.268558502197266], [27.1395206451416, 28.050729751586914, 24.246124267578125, 15.951554298400879, 15.694938659667969, 12.741717338562012, 11.49717903137207, 16.216773986816406, 20.47301483154297, 25.152128219604492, 26.9820499420166, 28.487817764282227, 30.42430305480957, 28.21028709411621, 28.00771141052246, 30.802946090698242, 29.04705238342285, 28.887008666992188, 32.72993469238281, 31.91263198852539, 29.97800636291504, 32.947662353515625, 32.01564407348633, 27.526851654052734, 27.981605529785156, 28.86541748046875, 28.230594635009766, 31.773006439208984, 31.99825096130371, 30.27488136291504, 32.19261932373047, 29.40865707397461, 22.14398193359375, 17.94068145751953, 11.830119132995605, 0.0, 12.890164375305176, 16.89211654663086, 17.651887893676758, 20.62691307067871, 24.257896423339844], [33.63869857788086, 35.87852478027344, 31.850341796875, 22.18147087097168, 18.211780548095703, 17.396827697753906, 14.838135719299316, 14.710733413696289, 18.14126968383789, 24.34905242919922, 27.778018951416016, 30.20195198059082, 32.82335662841797, 32.168312072753906, 32.14775848388672, 32.901092529296875, 28.296646118164062, 27.292146682739258, 32.460105895996094, 32.626712799072266, 31.9752197265625, 35.788665771484375, 35.468223571777344, 32.68931198120117, 34.19601821899414, 34.17205810546875, 31.498191833496094, 32.88938522338867, 33.74003601074219, 33.49454879760742, 36.49336624145508, 35.091796875, 30.720046997070312, 29.294086456298828, 24.35177993774414, 12.890164375305176, 0.0, 7.3042192459106445, 12.8178071975708, 19.47443389892578, 25.090517044067383], [33.33115768432617, 37.003570556640625, 33.47470474243164, 25.72242546081543, 24.341873168945312, 22.649465560913086, 17.525365829467773, 12.760909080505371, 13.802824020385742, 20.799955368041992, 24.713905334472656, 27.348234176635742, 30.475130081176758, 30.88959312438965, 31.484020233154297, 32.494895935058594, 28.661348342895508, 28.006793975830078, 32.72002029418945, 32.459354400634766, 31.756906509399414, 35.620365142822266, 35.155555725097656, 32.92464828491211, 35.01101303100586, 34.159175872802734, 29.645355224609375, 29.535114288330078, 30.785667419433594, 31.214828491210938, 35.049888610839844, 34.46787643432617, 31.359420776367188, 31.50228500366211, 27.293018341064453, 16.89211654663086, 7.3042192459106445, 0.0, 7.579392910003662, 15.951141357421875, 22.400922775268555], [29.452831268310547, 34.6693000793457, 31.60303497314453, 25.701766967773438, 27.15719223022461, 24.766691207885742, 18.67148780822754, 13.396489143371582, 12.00597095489502, 16.77814483642578, 18.729440689086914, 20.499120712280273, 24.354076385498047, 25.83786964416504, 27.20104217529297, 29.10446548461914, 26.683439254760742, 26.6622257232666, 30.942670822143555, 29.96563720703125, 28.81717300415039, 32.74348068237305, 31.88947296142578, 29.79485321044922, 32.60823440551758, 31.486839294433594, 26.710784912109375, 27.004533767700195, 27.76114273071289, 26.920503616333008, 30.38530731201172, 30.265296936035156, 28.01668357849121, 29.693883895874023, 26.30561065673828, 17.651887893676758, 12.8178071975708, 7.579392910003662, 0.0, 8.90837287902832, 15.593905448913574], [26.455493927001953, 33.114288330078125, 30.785024642944336, 26.76222038269043, 30.269893646240234, 28.00254249572754, 22.670551300048828, 19.327661514282227, 17.08631706237793, 16.95931625366211, 13.565690994262695, 12.885407447814941, 18.678483963012695, 21.790510177612305, 24.096647262573242, 26.911975860595703, 25.977094650268555, 26.664791107177734, 30.610984802246094, 29.309913635253906, 28.035667419433594, 31.945585250854492, 30.87229347229004, 29.057884216308594, 32.37315368652344, 31.3160400390625, 27.482301712036133, 28.76194190979004, 28.320056915283203, 24.603958129882812, 25.923992156982422, 26.456600189208984, 25.57505226135254, 28.927186965942383, 26.76059913635254, 20.62691307067871, 19.47443389892578, 15.951141357421875, 8.90837287902832, 0.0, 6.784940719604492], [25.30567169189453, 32.639404296875, 31.159563064575195, 28.80633544921875, 33.57478332519531, 31.613916397094727, 27.147119522094727, 25.0877628326416, 22.69434928894043, 20.031612396240234, 13.123252868652344, 9.457598686218262, 16.3599796295166, 20.15065574645996, 22.75887680053711, 26.1318302154541, 26.484159469604492, 27.638273239135742, 31.127960205078125, 29.754783630371094, 28.66190528869629, 32.592533111572266, 31.529170989990234, 30.046985626220703, 33.52546310424805, 32.53341293334961, 29.656963348388672, 31.61199951171875, 30.363941192626953, 24.83266830444336, 24.284765243530273, 25.25044059753418, 25.200891494750977, 29.35033416748047, 28.268558502197266, 24.257896423339844, 25.090517044067383, 22.400922775268555, 15.593905448913574, 6.784940719604492, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('0eb5d22a-d3e2-42d7-8ae0-422eae5d9052');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


This is what the first few steps (before scaling and filtering) of the
pipeline described above would be if you’d like persistence diagrams to
be obtained using this new distance instead. Notice that we have to pass
``metric='precomputed'`` to the ``VietorisRipsPersistence`` constructor
this time, because the input already consists of distance matrices:

.. code:: ipython3

    # Steps of the Pipeline
    steps = [
        ('sampling', periodicSampler),
        ('embedding', TE),
        ('window', SW),
        ('kNN_graph', kNN),
        ('graph_geo_distance', GGD),
        ('diagrams', VietorisRipsPersistence(
            metric='precomputed', max_edge_length=100, homology_dimensions=homology_dimensions))
    ]
    
    # Define the Pipeline
    pipeline = Pipeline(steps)
    
    # Run the pipeline
    X_diagrams = pipeline.fit_transform(X)

Let’s look at the persistence diagrams obtained with this new distance:

.. code:: ipython3

    plot_diagram(X_diagrams[window_number])



.. raw:: html

    <div>
    
    
                <div id="82feb2e9-459c-468a-8655-4b6ec0f1410b" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("82feb2e9-459c-468a-8655-4b6ec0f1410b")) {
                        Plotly.newPlot(
                            '82feb2e9-459c-468a-8655-4b6ec0f1410b',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-700.0, 700.0], "y": [-700.0, 700.0]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.0, 1.0, 1.0, 1.0, 1.0], "y": [2.0, 2.0, 2.0, 2.0, 7.0]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [2.0], "y": [3.0]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 7.700000000000001], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 7.700000000000001], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('82feb2e9-459c-468a-8655-4b6ec0f1410b');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>

